-- MariaDB dump 10.19  Distrib 10.5.22-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: heat
-- ------------------------------------------------------
-- Server version	10.5.22-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `event`
--

DROP TABLE IF EXISTS `event`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `event` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `uuid` varchar(36) DEFAULT NULL,
  `stack_id` varchar(36) NOT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `resource_action` varchar(255) DEFAULT NULL,
  `resource_status` varchar(255) DEFAULT NULL,
  `resource_name` varchar(255) DEFAULT NULL,
  `physical_resource_id` varchar(255) DEFAULT NULL,
  `resource_status_reason` varchar(255) DEFAULT NULL,
  `resource_type` varchar(255) DEFAULT NULL,
  `resource_properties` blob DEFAULT NULL,
  `rsrc_prop_data_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uuid` (`uuid`),
  KEY `stack_id` (`stack_id`),
  KEY `ev_rsrc_prop_data_ref` (`rsrc_prop_data_id`),
  CONSTRAINT `ev_rsrc_prop_data_ref` FOREIGN KEY (`rsrc_prop_data_id`) REFERENCES `resource_properties_data` (`id`),
  CONSTRAINT `event_ibfk_1` FOREIGN KEY (`stack_id`) REFERENCES `stack` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2805 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `event`
--

LOCK TABLES `event` WRITE;
/*!40000 ALTER TABLE `event` DISABLE KEYS */;
INSERT INTO `event` VALUES (1,'0635b648-9a8c-4448-87b4-063269d25158','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:02',NULL,'CREATE','IN_PROGRESS','overcloud','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2,'61975e89-0309-4817-8078-deaf7c66c6f4','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:04',NULL,'CREATE','IN_PROGRESS','ControllerRoleUserData','overcloud-ControllerRoleUserData-37t3h3zzua3u','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(3,'d37ac9fe-14de-41af-8e9d-eb4191113579','555f1d0c-b13b-4761-809f-7f218f5570d8','2026-06-10 07:59:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerRoleUserData-37t3h3zzua3u','555f1d0c-b13b-4761-809f-7f218f5570d8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(4,'c907c1f3-18b1-4018-8f3f-edb5a14116a3','555f1d0c-b13b-4761-809f-7f218f5570d8','2026-06-10 07:59:04',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ControllerRoleUserData-37t3h3zzua3u-userdata-25penrvztjwk','state changed','OS::Heat::MultipartMime',NULL,NULL),(5,'5308f1d1-596f-44e3-b3f3-9bca76a71585','555f1d0c-b13b-4761-809f-7f218f5570d8','2026-06-10 07:59:04',NULL,'CREATE','COMPLETE','userdata','88beb7e4-3aa0-4b47-ba5d-a9fdc241d725','state changed','OS::Heat::MultipartMime',NULL,NULL),(6,'3e0a8378-7821-4d70-8093-046c10cbb770','555f1d0c-b13b-4761-809f-7f218f5570d8','2026-06-10 07:59:04',NULL,'CREATE','COMPLETE','overcloud-ControllerRoleUserData-37t3h3zzua3u','555f1d0c-b13b-4761-809f-7f218f5570d8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(7,'f2db5c73-ca3a-4af2-b5f9-b75028a31dbe','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:05',NULL,'CREATE','IN_PROGRESS','ServiceNetMap','overcloud-ServiceNetMap-gwfrqqlvqqb4','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(8,'eb598cc8-7dc6-4ddb-b5da-2c9e0d189e4c','1c30a31a-1c20-4a03-bbe7-1ae4efca0175','2026-06-10 07:59:05',NULL,'CREATE','IN_PROGRESS','overcloud-ServiceNetMap-gwfrqqlvqqb4','1c30a31a-1c20-4a03-bbe7-1ae4efca0175','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(9,'6aaa24dc-f79c-4aa2-b48b-2f763f6e0a77','1c30a31a-1c20-4a03-bbe7-1ae4efca0175','2026-06-10 07:59:05',NULL,'CREATE','IN_PROGRESS','ServiceNetMapValue','overcloud-ServiceNetMap-gwfrqqlvqqb4-ServiceNetMapValue-ke7estlvffhq','state changed','OS::Heat::Value',NULL,1),(10,'fec7420c-a42f-4cfe-bc04-1d05e9361007','1c30a31a-1c20-4a03-bbe7-1ae4efca0175','2026-06-10 07:59:05',NULL,'CREATE','COMPLETE','ServiceNetMapValue','overcloud-ServiceNetMap-gwfrqqlvqqb4-ServiceNetMapValue-ke7estlvffhq','state changed','OS::Heat::Value',NULL,1),(11,'b39880d7-4b63-4d06-acf3-618d6a769dfd','1c30a31a-1c20-4a03-bbe7-1ae4efca0175','2026-06-10 07:59:05',NULL,'CREATE','COMPLETE','overcloud-ServiceNetMap-gwfrqqlvqqb4','1c30a31a-1c20-4a03-bbe7-1ae4efca0175','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(12,'a7a789d3-7ad5-4960-9fe1-459e5392bf76','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:05',NULL,'CREATE','COMPLETE','ControllerRoleUserData','555f1d0c-b13b-4761-809f-7f218f5570d8','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(13,'c075dbdb-eff3-4a67-9560-94b6c770a050','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','IN_PROGRESS','CloudNames','overcloud-CloudNames-d6zww426d3oy','state changed','OS::Heat::Value',NULL,3),(14,'a2f72838-e922-455b-be5c-06a10440da84','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','COMPLETE','CloudNames','overcloud-CloudNames-d6zww426d3oy','state changed','OS::Heat::Value',NULL,3),(15,'eb6dfda9-f8e3-4fbb-a181-066ef9289aaf','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','COMPLETE','ServiceNetMap','1c30a31a-1c20-4a03-bbe7-1ae4efca0175','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(16,'537f2d3d-99b7-46f8-a4ba-6dbf105163a0','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-jcjymdyagllg','state changed','OS::Heat::Value',NULL,6),(17,'f7f167b1-a509-4043-9619-fbb2b40bb2cf','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','COMPLETE','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-jcjymdyagllg','state changed','OS::Heat::Value',NULL,6),(18,'4363cb67-e8f2-496c-96e9-ded6e3710dcc','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-asbg25htivsu','state changed','OS::Heat::Value',NULL,7),(19,'30a9605b-df4c-41bc-b7b6-7dd58dce2f18','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','COMPLETE','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-asbg25htivsu','state changed','OS::Heat::Value',NULL,7),(20,'a4e400ef-1354-48ec-b39f-6dc44475157c','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','IN_PROGRESS','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-bu7e2yhqjkto','state changed','OS::Heat::Value',NULL,10),(21,'40d3f689-d4e2-45c2-92e1-3561ab6b8371','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','COMPLETE','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-bu7e2yhqjkto','state changed','OS::Heat::Value',NULL,10),(22,'e491ce17-f74d-41a9-a00b-a4f4e12a89f5','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-jxd2cru3ke7o','state changed','OS::Heat::Value',NULL,11),(23,'ff17521e-c6c2-487c-bcbd-a01ef818534f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','COMPLETE','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-jxd2cru3ke7o','state changed','OS::Heat::Value',NULL,11),(24,'34ed5daa-48b3-4745-9f7a-5b9585964bce','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','IN_PROGRESS','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-3doltymbbg2t','state changed','OS::Heat::Value',NULL,12),(25,'8199911b-9303-4857-b0e3-caefeeb9feec','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','COMPLETE','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-3doltymbbg2t','state changed','OS::Heat::Value',NULL,12),(26,'c7238475-c848-47a0-876a-add6ff73e215','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-6efndug645jv','state changed','OS::Heat::Value',NULL,14),(27,'dfc38e03-a3da-4ccc-9d15-1103b22320c3','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:06',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-6efndug645jv','state changed','OS::Heat::Value',NULL,14),(28,'2976194a-5b28-40eb-ac91-9c215f27c85f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:07',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-4ccx2xltvybm','state changed','OS::Heat::Value',NULL,18),(29,'3040f76d-e1c7-4191-a366-07b1d09809c6','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:07',NULL,'CREATE','IN_PROGRESS','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-cxlasqovag26','state changed','OS::Heat::Value',NULL,19),(30,'cf71012a-4664-4f06-b79c-b399caba9457','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:07',NULL,'CREATE','COMPLETE','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-4ccx2xltvybm','state changed','OS::Heat::Value',NULL,18),(31,'56e2c8d6-f7c7-4bf5-bd4e-b54de3054566','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:07',NULL,'CREATE','COMPLETE','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-cxlasqovag26','state changed','OS::Heat::Value',NULL,19),(32,'4b727b8c-bede-41e1-93e8-a3b60cdca94d','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:07',NULL,'CREATE','IN_PROGRESS','ControlVirtualIP','overcloud-ControlVirtualIP-7cywhzx57pdv','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,21),(33,'4afc6372-88ce-448e-bff0-cc4ae12e454f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:07',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-3v4zgyzxlbxv','state changed','OS::Heat::Value',NULL,22),(34,'b4f0b74e-d679-44ec-99e1-4bca2a73697f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:07',NULL,'CREATE','COMPLETE','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-3v4zgyzxlbxv','state changed','OS::Heat::Value',NULL,22),(35,'7d6092c9-9ca5-44ae-ba63-205570df24eb','559ec3c6-361a-4daa-ad7d-e5727748674e','2026-06-10 07:59:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControlVirtualIP-7cywhzx57pdv','559ec3c6-361a-4daa-ad7d-e5727748674e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(36,'353c3cfe-2f03-4388-9027-7bd2f4c9e288','559ec3c6-361a-4daa-ad7d-e5727748674e','2026-06-10 07:59:07',NULL,'CREATE','COMPLETE','overcloud-ControlVirtualIP-7cywhzx57pdv','559ec3c6-361a-4daa-ad7d-e5727748674e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(37,'7bc4be7b-600d-49c7-86f4-e8811bb43001','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:08',NULL,'CREATE','IN_PROGRESS','ObjectStorageRoleUserData','overcloud-ObjectStorageRoleUserData-cawvezunmjmg','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(38,'7173ef11-fcfa-451b-b7ad-331d4d7c7e7b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:08',NULL,'CREATE','COMPLETE','ControlVirtualIP','559ec3c6-361a-4daa-ad7d-e5727748674e','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,21),(39,'17cf712f-bcb4-46bc-b79d-5c61d67a7533','05e0a0ef-de0c-4781-bb6e-86bc68032cf3','2026-06-10 07:59:08',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageRoleUserData-cawvezunmjmg','05e0a0ef-de0c-4781-bb6e-86bc68032cf3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(40,'23a2928b-09bc-41f1-a095-90c88adfa014','05e0a0ef-de0c-4781-bb6e-86bc68032cf3','2026-06-10 07:59:08',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ObjectStorageRoleUserData-cawvezunmjmg-userdata-zthtop2bh5ik','state changed','OS::Heat::MultipartMime',NULL,NULL),(41,'818a29e6-ca36-4d0a-9d77-5a4ff81c2d51','05e0a0ef-de0c-4781-bb6e-86bc68032cf3','2026-06-10 07:59:08',NULL,'CREATE','COMPLETE','userdata','5a3410eb-5f81-49a0-902c-8307bb9a90e2','state changed','OS::Heat::MultipartMime',NULL,NULL),(42,'ade26969-c2ab-4e72-9a6b-879812be4881','05e0a0ef-de0c-4781-bb6e-86bc68032cf3','2026-06-10 07:59:08',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageRoleUserData-cawvezunmjmg','05e0a0ef-de0c-4781-bb6e-86bc68032cf3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(43,'3a1af7fb-9763-4004-b223-59b30964c8ac','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:08',NULL,'CREATE','IN_PROGRESS','Networks','overcloud-Networks-3gopbgpfbu4m','state changed','OS::TripleO::Network',NULL,26),(44,'8dc3776b-a24c-469e-9305-ec4021bcfcde','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:08',NULL,'CREATE','IN_PROGRESS','overcloud-Networks-3gopbgpfbu4m','225789d8-8ef3-40b4-8b39-ca2138f6c49d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(45,'59a30235-58cc-46d7-b570-09305e419a81','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:08',NULL,'CREATE','IN_PROGRESS','NetworkExtraConfig','overcloud-Networks-3gopbgpfbu4m-NetworkExtraConfig-yf7ug7iumett','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(46,'1d84babf-f6c9-4d35-b36f-e57638e1250f','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:08',NULL,'CREATE','COMPLETE','NetworkExtraConfig','b3f594b7-5ec8-4496-a9f6-28f7b790476d','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(47,'d6491448-ffe1-4229-8f7c-ae7b7dccdfa8','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:09',NULL,'CREATE','IN_PROGRESS','CellControllerComputeRoleUserData','overcloud-CellControllerComputeRoleUserData-r4kfq5hn2tby','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(48,'d18a4f87-66e6-4cb2-ae50-267288a2b457','631026d1-d176-43cf-960c-1022ed907e67','2026-06-10 07:59:09',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeRoleUserData-r4kfq5hn2tby','631026d1-d176-43cf-960c-1022ed907e67','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(49,'e768c4c7-1050-47d2-a6fd-493756505c2b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:09',NULL,'CREATE','COMPLETE','ObjectStorageRoleUserData','05e0a0ef-de0c-4781-bb6e-86bc68032cf3','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(50,'2809e026-a764-48ef-b805-7900628d69c2','631026d1-d176-43cf-960c-1022ed907e67','2026-06-10 07:59:09',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerComputeRoleUserData-r4kfq5hn2tby-userdata-5urmd4ycdrvi','state changed','OS::Heat::MultipartMime',NULL,NULL),(51,'a6e634b0-1658-4b1d-accb-30a0e5887285','631026d1-d176-43cf-960c-1022ed907e67','2026-06-10 07:59:09',NULL,'CREATE','COMPLETE','userdata','85269fd5-010b-49b7-bc0a-18d01702f946','state changed','OS::Heat::MultipartMime',NULL,NULL),(52,'6d1726e7-9d27-46f7-955a-580e796cf894','631026d1-d176-43cf-960c-1022ed907e67','2026-06-10 07:59:09',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeRoleUserData-r4kfq5hn2tby','631026d1-d176-43cf-960c-1022ed907e67','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(53,'c55b1a3d-d967-4e08-afe4-73af80726200','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:09',NULL,'CREATE','IN_PROGRESS','NetworkIpVersionMap','overcloud-Networks-3gopbgpfbu4m-NetworkIpVersionMap-ahznzxtr2sy7','state changed','OS::Heat::Value',NULL,29),(54,'0f8bee85-eca9-47d2-95f2-1162b0050a56','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:09',NULL,'CREATE','COMPLETE','NetworkIpVersionMap','overcloud-Networks-3gopbgpfbu4m-NetworkIpVersionMap-ahznzxtr2sy7','state changed','OS::Heat::Value',NULL,29),(55,'4190dcb9-010d-4a41-8d01-832aced33675','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:10',NULL,'CREATE','IN_PROGRESS','CellControllerRoleUserData','overcloud-CellControllerRoleUserData-zhuam6ksi2qa','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(56,'5070bee2-5d27-421a-a54a-870e6932c897','7e9d8119-b42b-4e1a-9a58-372735d8167b','2026-06-10 07:59:10',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerRoleUserData-zhuam6ksi2qa','7e9d8119-b42b-4e1a-9a58-372735d8167b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(57,'36410900-f568-44dd-9001-5b37d8302b96','7e9d8119-b42b-4e1a-9a58-372735d8167b','2026-06-10 07:59:10',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerRoleUserData-zhuam6ksi2qa-userdata-iadn2tbjf4od','state changed','OS::Heat::MultipartMime',NULL,NULL),(58,'dd590b17-883f-418b-a66c-b773d59e3743','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:10',NULL,'CREATE','COMPLETE','CellControllerComputeRoleUserData','631026d1-d176-43cf-960c-1022ed907e67','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(59,'9a754323-ad5a-47cb-9792-cc377afcc70c','7e9d8119-b42b-4e1a-9a58-372735d8167b','2026-06-10 07:59:10',NULL,'CREATE','COMPLETE','userdata','cadd4e3f-35fe-4bb4-9ff6-352692d13426','state changed','OS::Heat::MultipartMime',NULL,NULL),(60,'6a170935-6f30-4ccd-847e-0751c7e317e5','7e9d8119-b42b-4e1a-9a58-372735d8167b','2026-06-10 07:59:10',NULL,'CREATE','COMPLETE','overcloud-CellControllerRoleUserData-zhuam6ksi2qa','7e9d8119-b42b-4e1a-9a58-372735d8167b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(61,'15fd515a-f82a-404b-aa4b-98f5acf99b13','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:10',NULL,'CREATE','IN_PROGRESS','NetworkCidrMap','overcloud-Networks-3gopbgpfbu4m-NetworkCidrMap-vkv7qz75qo5t','state changed','OS::Heat::Value',NULL,31),(62,'aae4cc99-2e45-4986-a493-480f11237a24','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:10',NULL,'CREATE','COMPLETE','NetworkCidrMap','overcloud-Networks-3gopbgpfbu4m-NetworkCidrMap-vkv7qz75qo5t','state changed','OS::Heat::Value',NULL,31),(63,'78193704-685e-4620-a3c6-a4e389fc3c6f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:11',NULL,'CREATE','IN_PROGRESS','NodeAdminUserData','overcloud-NodeAdminUserData-girk4g72hz6u','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(64,'4a3ee872-5f92-405d-819b-53f5f0d07d28','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:11',NULL,'CREATE','COMPLETE','CellControllerRoleUserData','7e9d8119-b42b-4e1a-9a58-372735d8167b','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(65,'69e75750-093a-4ef6-b62b-a7678370b1a9','f790ccac-e836-4433-a519-8d10e02b6eb7','2026-06-10 07:59:11',NULL,'CREATE','IN_PROGRESS','overcloud-NodeAdminUserData-girk4g72hz6u','f790ccac-e836-4433-a519-8d10e02b6eb7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(66,'c81d4763-5a73-463a-87bc-0db07b3db070','f790ccac-e836-4433-a519-8d10e02b6eb7','2026-06-10 07:59:11',NULL,'CREATE','IN_PROGRESS','user_config','overcloud-NodeAdminUserData-girk4g72hz6u-user_config-z2lsm2jzjqo2','state changed','OS::Heat::CloudConfig',NULL,33),(67,'cab4d4a4-4cde-46a9-8024-8056a578a107','f790ccac-e836-4433-a519-8d10e02b6eb7','2026-06-10 07:59:11',NULL,'CREATE','COMPLETE','user_config','0b7c55cd-6c56-488d-b691-f8d40c83b6d3','state changed','OS::Heat::CloudConfig',NULL,33),(68,'0ed5e912-be67-4676-a3d6-5442f78b3751','f790ccac-e836-4433-a519-8d10e02b6eb7','2026-06-10 07:59:11',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeAdminUserData-girk4g72hz6u-userdata-yw2xxb62mpdt','state changed','OS::Heat::MultipartMime',NULL,34),(69,'53f4db82-ea21-4826-be1d-d3e4fafb8e13','f790ccac-e836-4433-a519-8d10e02b6eb7','2026-06-10 07:59:11',NULL,'CREATE','COMPLETE','userdata','3789f197-c2e9-4b12-b15c-cca412761da6','state changed','OS::Heat::MultipartMime',NULL,34),(70,'9e305c68-64f1-4421-a0b8-c84dbbb23737','f790ccac-e836-4433-a519-8d10e02b6eb7','2026-06-10 07:59:11',NULL,'CREATE','COMPLETE','overcloud-NodeAdminUserData-girk4g72hz6u','f790ccac-e836-4433-a519-8d10e02b6eb7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(71,'ae2f70d6-86e2-49d3-a706-aa4129c608ba','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:11',NULL,'CREATE','IN_PROGRESS','NetworkAttributesMap','overcloud-Networks-3gopbgpfbu4m-NetworkAttributesMap-gl27zud5qyys','state changed','OS::Heat::Value',NULL,35),(72,'91e0d967-7595-4cc8-bf96-6dd04d05d566','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:11',NULL,'CREATE','COMPLETE','NetworkAttributesMap','overcloud-Networks-3gopbgpfbu4m-NetworkAttributesMap-gl27zud5qyys','state changed','OS::Heat::Value',NULL,35),(73,'0ef8d6ec-57ab-4cc4-97e1-659fd87a90a9','225789d8-8ef3-40b4-8b39-ca2138f6c49d','2026-06-10 07:59:11',NULL,'CREATE','COMPLETE','overcloud-Networks-3gopbgpfbu4m','225789d8-8ef3-40b4-8b39-ca2138f6c49d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(74,'03478bfd-808d-499d-8222-02bcb82d9b34','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:12',NULL,'CREATE','IN_PROGRESS','ComputeRoleUserData','overcloud-ComputeRoleUserData-gnrgmycmu5fu','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(75,'5d5141a7-252f-4e77-aefb-c687245fcd2e','25791237-fcc2-4477-a0ad-b0197c54fa52','2026-06-10 07:59:12',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeRoleUserData-gnrgmycmu5fu','25791237-fcc2-4477-a0ad-b0197c54fa52','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(76,'44ac2c1a-9c66-467b-94aa-71e365aa9e81','25791237-fcc2-4477-a0ad-b0197c54fa52','2026-06-10 07:59:12',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ComputeRoleUserData-gnrgmycmu5fu-userdata-7g3465hfabol','state changed','OS::Heat::MultipartMime',NULL,NULL),(77,'b0cf1fc3-22c4-41e4-bc39-b019be46ee7a','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:12',NULL,'CREATE','COMPLETE','NodeAdminUserData','f790ccac-e836-4433-a519-8d10e02b6eb7','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(78,'d6d520e5-8b57-4914-84bc-03b0f409cc0f','25791237-fcc2-4477-a0ad-b0197c54fa52','2026-06-10 07:59:12',NULL,'CREATE','COMPLETE','userdata','2e5d6410-80a1-40fb-b9b1-c6dfc88a6ab2','state changed','OS::Heat::MultipartMime',NULL,NULL),(79,'f19fb0a6-de9b-45f9-9857-cad4a8916a07','25791237-fcc2-4477-a0ad-b0197c54fa52','2026-06-10 07:59:12',NULL,'CREATE','COMPLETE','overcloud-ComputeRoleUserData-gnrgmycmu5fu','25791237-fcc2-4477-a0ad-b0197c54fa52','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(80,'c5d6b0f6-54df-4545-bc7c-283a8df5c52d','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:12',NULL,'CREATE','COMPLETE','Networks','225789d8-8ef3-40b4-8b39-ca2138f6c49d','state changed','OS::TripleO::Network',NULL,26),(81,'3b960df2-c735-4b36-ad0a-c1a5bdf7adaf','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:12',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkConfig','overcloud-BlockStorageNetworkConfig-qm734klt35da','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(82,'565849a6-0aaf-43e5-8f45-0f51969a355b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:12',NULL,'CREATE','COMPLETE','BlockStorageNetworkConfig','04e899d0-3fc8-4866-b623-04cf7d14d40d','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(83,'f4c17d3e-5c4f-4432-8bf5-9b282a2436c7','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:12',NULL,'CREATE','IN_PROGRESS','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-ja525un6wxk2','state changed','OS::Heat::Value',NULL,41),(84,'6d8bdb60-1b85-46c9-a058-a0d99f4c07ca','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:12',NULL,'CREATE','IN_PROGRESS','PublicVirtualIP','overcloud-PublicVirtualIP-sn7pazzftibo','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,40),(85,'698bb28f-4ccd-4b58-ad36-1bbe03896aeb','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:12',NULL,'CREATE','COMPLETE','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-ja525un6wxk2','state changed','OS::Heat::Value',NULL,41),(86,'bb3538f7-d1c0-42d2-8d5a-f702099dfe2f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkConfig','overcloud-NetworkerNetworkConfig-z24kbashcfyo','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(87,'22f33fea-7ec5-412b-ab0d-0c230a39eb4a','9ec2fcce-5c04-494c-80c3-573e1d6212c1','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','overcloud-PublicVirtualIP-sn7pazzftibo','9ec2fcce-5c04-494c-80c3-573e1d6212c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(88,'0edde28a-9690-45e5-b379-e5e448c1a79a','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkConfig','overcloud-CellControllerNetworkConfig-rck2yllh7wx4','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(89,'955268b0-b479-4aff-a832-aa96eb8d32b2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','NetworkerNetworkConfig','c76a8baa-0016-4281-94a8-a7cea22935bf','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(90,'8e6477c6-a7f8-4e9c-a4d4-f4348bd50a29','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','CellControllerNetworkConfig','e73f29e1-fabc-4559-86be-4618d8f682d6','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(91,'c36502a6-cbed-4396-a76c-156b01d9147e','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','InternalApiVirtualIP','overcloud-InternalApiVirtualIP-s3zmz6amrw5n','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,42),(92,'9cb93788-3e18-42af-b045-7f7d1ab1f0d2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','ComputeNetworkConfig','overcloud-ComputeNetworkConfig-lewhomi76trh','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(93,'af4aefc7-56d2-45b1-9dce-3897767cbfc2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','ComputeNetworkConfig','19849820-2f55-464e-98ae-1bb9ba982338','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(94,'c895a6d3-ca89-4be4-803d-88207325fa2c','9ec2fcce-5c04-494c-80c3-573e1d6212c1','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','overcloud-PublicVirtualIP-sn7pazzftibo','9ec2fcce-5c04-494c-80c3-573e1d6212c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(95,'e5fd4eac-0c1e-45cc-bf39-c6a465c1987a','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','NodeUserData','overcloud-NodeUserData-y3zppvzkg7iu','state changed','OS::TripleO::NodeUserData',NULL,NULL),(96,'ca01e7f3-9731-4bf0-b7f3-0de5c0656ece','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkConfig','overcloud-CellControllerComputeNetworkConfig-7w56lueexdef','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(97,'dbb82a04-fab0-4640-995e-a75939e721c9','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkConfig','ea33b88c-c4e2-497a-bfd7-fecc2041486b','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(98,'4b9b67c9-2454-4af9-bba1-e835be080f68','4a68d037-8636-4c97-ad7e-760384c022a9','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','overcloud-InternalApiVirtualIP-s3zmz6amrw5n','4a68d037-8636-4c97-ad7e-760384c022a9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(99,'500308b8-d813-46dd-9d38-2c8bd178a736','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkConfig','overcloud-ObjectStorageNetworkConfig-z74qvk4kth6x','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(100,'5d7a086c-46a1-44a8-a0b1-9d122e1a99d8','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','StorageMgmtVirtualIP','overcloud-StorageMgmtVirtualIP-6fupojbzackt','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,43),(101,'03bd0624-85f7-4bc3-b9c2-0131388da3f2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','ComputeRoleUserData','25791237-fcc2-4477-a0ad-b0197c54fa52','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(102,'0b061d4c-0449-44ae-96c7-1b379f76c604','4a68d037-8636-4c97-ad7e-760384c022a9','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','overcloud-InternalApiVirtualIP-s3zmz6amrw5n','4a68d037-8636-4c97-ad7e-760384c022a9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(103,'5f7590e7-6f49-4bf9-88c8-0c50eb28b4d3','3ef83aef-5f98-468e-83b6-c558f11932e9','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','overcloud-NodeUserData-y3zppvzkg7iu','3ef83aef-5f98-468e-83b6-c558f11932e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(104,'5120fa59-49ef-4296-ab2a-04a74af84985','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','ObjectStorageNetworkConfig','57bc5fd7-5999-4d4d-8f5d-5957c3de25aa','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(105,'6b4806af-c24c-433f-97ad-d65aaec39d0e','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkConfig','overcloud-CephStorageNetworkConfig-ln4awxyecxf3','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(106,'1bb3d236-b143-4690-9581-152757ef620b','cfef023d-df0b-415c-9e75-8a705360829e','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','overcloud-StorageMgmtVirtualIP-6fupojbzackt','cfef023d-df0b-415c-9e75-8a705360829e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(107,'c415c132-543e-4d06-a43f-9247553c0755','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','CephStorageNetworkConfig','bae739da-70d2-4046-a9a4-496b7f04fea1','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(108,'cde856fb-936a-4c44-a088-a94f92b6e396','cfef023d-df0b-415c-9e75-8a705360829e','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','overcloud-StorageMgmtVirtualIP-6fupojbzackt','cfef023d-df0b-415c-9e75-8a705360829e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(109,'d57ead9b-d781-45c2-b7db-4c8853897797','3ef83aef-5f98-468e-83b6-c558f11932e9','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeUserData-y3zppvzkg7iu-userdata-fzhb2j23626r','state changed','OS::Heat::MultipartMime',NULL,NULL),(110,'a54d539d-4b27-4c3c-ae47-3d666b672d67','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','StorageVirtualIP','overcloud-StorageVirtualIP-ykinjwztl7ne','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,46),(111,'8689b665-a298-45c2-af74-d827e01b420d','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','ControllerNetworkConfig','overcloud-ControllerNetworkConfig-c5c2zhkb4zzf','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(112,'3e15a66e-01bf-4466-a478-fff5b31010b4','3ef83aef-5f98-468e-83b6-c558f11932e9','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','userdata','a37e756b-73d6-47c9-9631-06661152a505','state changed','OS::Heat::MultipartMime',NULL,NULL),(113,'458678ef-cf0b-4c37-83af-2909ca137374','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','ControllerNetworkConfig','d75aed8a-297f-457e-8715-19adb28aa653','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(114,'95744be4-03e5-4968-85f5-e46dc134ff8e','3ef83aef-5f98-468e-83b6-c558f11932e9','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','overcloud-NodeUserData-y3zppvzkg7iu','3ef83aef-5f98-468e-83b6-c558f11932e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(115,'d8b35079-0f5f-417d-8477-8b910a991a95','a1d418d3-7d9e-4651-a245-7cde3bb28155','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','overcloud-StorageVirtualIP-ykinjwztl7ne','a1d418d3-7d9e-4651-a245-7cde3bb28155','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(116,'853b1fd0-c65d-4fa2-a480-9450e5cf73db','a1d418d3-7d9e-4651-a245-7cde3bb28155','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','overcloud-StorageVirtualIP-ykinjwztl7ne','a1d418d3-7d9e-4651-a245-7cde3bb28155','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(117,'163db898-52c7-4717-9f87-7c50969c8ee2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','IN_PROGRESS','NetCidrMapValue','overcloud-NetCidrMapValue-22hhvytodglu','state changed','OS::Heat::Value',NULL,48),(118,'23a1aa2c-c787-4770-a58a-f2005edfc4ba','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:13',NULL,'CREATE','COMPLETE','NetCidrMapValue','overcloud-NetCidrMapValue-22hhvytodglu','state changed','OS::Heat::Value',NULL,48),(119,'63a6c6b3-bc5b-479b-ba59-7c6a5870ceee','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:14',NULL,'CREATE','COMPLETE','PublicVirtualIP','9ec2fcce-5c04-494c-80c3-573e1d6212c1','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,40),(120,'3825c7e7-d986-4702-a2c1-302151f80497','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:14',NULL,'CREATE','IN_PROGRESS','CephStorageRoleUserData','overcloud-CephStorageRoleUserData-yavfn4ssklw4','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(121,'aab82692-0c14-44a0-b5ec-2303d8e8e77e','affe9e29-93e1-4727-a539-c398e4e5a78e','2026-06-10 07:59:14',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageRoleUserData-yavfn4ssklw4','affe9e29-93e1-4727-a539-c398e4e5a78e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(122,'02ca7e19-ebec-4ca1-8e0a-96afbad280be','affe9e29-93e1-4727-a539-c398e4e5a78e','2026-06-10 07:59:14',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CephStorageRoleUserData-yavfn4ssklw4-userdata-qenkzustkc33','state changed','OS::Heat::MultipartMime',NULL,NULL),(123,'b91b9745-e6c6-4c72-99c1-30d98ebc43ff','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:14',NULL,'CREATE','COMPLETE','InternalApiVirtualIP','4a68d037-8636-4c97-ad7e-760384c022a9','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,42),(124,'ac2588bd-6820-4f72-83a1-8b97bcbab7d1','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:14',NULL,'CREATE','COMPLETE','NodeUserData','3ef83aef-5f98-468e-83b6-c558f11932e9','state changed','OS::TripleO::NodeUserData',NULL,NULL),(125,'1201e38e-79ff-4fa2-bb4f-708a480f2f41','affe9e29-93e1-4727-a539-c398e4e5a78e','2026-06-10 07:59:14',NULL,'CREATE','COMPLETE','userdata','c301f924-5d8a-484a-bc67-be36fb36d9c9','state changed','OS::Heat::MultipartMime',NULL,NULL),(126,'193b1e83-af68-407a-b602-907849b25709','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:14',NULL,'CREATE','COMPLETE','StorageMgmtVirtualIP','cfef023d-df0b-415c-9e75-8a705360829e','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,43),(127,'0e23f2c1-a72f-47ed-8365-967320587c97','affe9e29-93e1-4727-a539-c398e4e5a78e','2026-06-10 07:59:14',NULL,'CREATE','COMPLETE','overcloud-CephStorageRoleUserData-yavfn4ssklw4','affe9e29-93e1-4727-a539-c398e4e5a78e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(128,'56a9cf88-c0c2-4524-98d2-e83a7760d99e','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:14',NULL,'CREATE','COMPLETE','StorageVirtualIP','a1d418d3-7d9e-4651-a245-7cde3bb28155','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,46),(129,'984669c3-bda4-4df5-9834-a55a99ad73da','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:14',NULL,'CREATE','IN_PROGRESS','VipMap','overcloud-VipMap-fsbsf27v2bbl','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,55),(130,'8b1c8cfc-d45a-4b5d-8b12-60fe57738c62','e9373b56-3b29-4e31-a1e9-c095bafa5236','2026-06-10 07:59:14',NULL,'CREATE','IN_PROGRESS','overcloud-VipMap-fsbsf27v2bbl','e9373b56-3b29-4e31-a1e9-c095bafa5236','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(131,'80f75e61-009b-43e0-a536-d7cef31c7987','e9373b56-3b29-4e31-a1e9-c095bafa5236','2026-06-10 07:59:14',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-VipMap-fsbsf27v2bbl-NetIpMapValue-o7iy6evavl7l','state changed','OS::Heat::Value',NULL,56),(132,'5ed2f7d7-1d06-4450-99c0-0549f7be7c37','e9373b56-3b29-4e31-a1e9-c095bafa5236','2026-06-10 07:59:15',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-VipMap-fsbsf27v2bbl-NetIpMapValue-o7iy6evavl7l','state changed','OS::Heat::Value',NULL,56),(133,'9c6be8d0-af98-413c-909c-d85428ee9c62','e9373b56-3b29-4e31-a1e9-c095bafa5236','2026-06-10 07:59:15',NULL,'CREATE','COMPLETE','overcloud-VipMap-fsbsf27v2bbl','e9373b56-3b29-4e31-a1e9-c095bafa5236','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(134,'d2c11cd3-a629-4dbe-81c0-9f948298524e','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:15',NULL,'CREATE','IN_PROGRESS','NetworkerRoleUserData','overcloud-NetworkerRoleUserData-fgr5edhffxsk','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(135,'9c06751e-fd1c-4275-87e2-359f2ffdc348','d2a0b957-7230-40e4-8507-90f8946cc556','2026-06-10 07:59:15',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerRoleUserData-fgr5edhffxsk','d2a0b957-7230-40e4-8507-90f8946cc556','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(136,'dc4c8c5c-331f-4962-b108-52b0d7542ca8','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:15',NULL,'CREATE','COMPLETE','CephStorageRoleUserData','affe9e29-93e1-4727-a539-c398e4e5a78e','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(137,'a71397f9-28e7-461d-8a19-61ef34719ea2','d2a0b957-7230-40e4-8507-90f8946cc556','2026-06-10 07:59:15',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NetworkerRoleUserData-fgr5edhffxsk-userdata-wqjadhbgbe46','state changed','OS::Heat::MultipartMime',NULL,NULL),(138,'a3e8a300-d892-4c67-b22c-bc460a2595d0','d2a0b957-7230-40e4-8507-90f8946cc556','2026-06-10 07:59:15',NULL,'CREATE','COMPLETE','userdata','a0d070d3-1672-4b83-a324-3237d49ad2a4','state changed','OS::Heat::MultipartMime',NULL,NULL),(139,'daeade51-547e-4a58-b61c-4ba8d03df8ec','d2a0b957-7230-40e4-8507-90f8946cc556','2026-06-10 07:59:15',NULL,'CREATE','COMPLETE','overcloud-NetworkerRoleUserData-fgr5edhffxsk','d2a0b957-7230-40e4-8507-90f8946cc556','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(140,'505599a5-0985-474c-b76f-6cdeffb3b78a','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:15',NULL,'CREATE','COMPLETE','VipMap','e9373b56-3b29-4e31-a1e9-c095bafa5236','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,55),(141,'0afc4c12-f34f-40c4-ac3b-26aa0805c566','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:16',NULL,'CREATE','IN_PROGRESS','NodeTimesyncUserData','overcloud-NodeTimesyncUserData-qhy3pxxjz5yk','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(142,'98e0e397-b85f-4cce-b116-5d5560387801','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:16',NULL,'CREATE','IN_PROGRESS','EndpointMap','overcloud-EndpointMap-r57lg4za4w2v','state changed','OS::TripleO::EndpointMap',NULL,60),(143,'1ad6f0ad-9705-4388-8937-8e47aea8650f','01ced5a6-a410-4d0d-8464-b29772521240','2026-06-10 07:59:16',NULL,'CREATE','IN_PROGRESS','overcloud-NodeTimesyncUserData-qhy3pxxjz5yk','01ced5a6-a410-4d0d-8464-b29772521240','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(144,'5f014c0e-a29d-493c-af59-5a062ff33f39','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:16',NULL,'CREATE','COMPLETE','NetworkerRoleUserData','d2a0b957-7230-40e4-8507-90f8946cc556','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(145,'2144420b-14e0-4915-9b1d-ea1c16ceffa6','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:16',NULL,'CREATE','IN_PROGRESS','VipHosts','overcloud-VipHosts-q7vrcfva2sqx','state changed','OS::Heat::Value',NULL,61),(146,'b974f68c-6da3-48a7-98e6-b3ee301786a1','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:16',NULL,'CREATE','COMPLETE','VipHosts','overcloud-VipHosts-q7vrcfva2sqx','state changed','OS::Heat::Value',NULL,61),(147,'aa50db10-7931-4fb1-8f59-57881dddc41e','01ced5a6-a410-4d0d-8464-b29772521240','2026-06-10 07:59:16',NULL,'CREATE','IN_PROGRESS','timesync_sync','overcloud-NodeTimesyncUserData-qhy3pxxjz5yk-timesync_sync-anzue62kgqt6','state changed','OS::Heat::SoftwareConfig',NULL,64),(148,'7f8c4305-db0d-49ab-8c06-3a549bf6ec09','43d5f730-59e2-47c9-a44e-c28c4cac61df','2026-06-10 07:59:16',NULL,'CREATE','IN_PROGRESS','overcloud-EndpointMap-r57lg4za4w2v','43d5f730-59e2-47c9-a44e-c28c4cac61df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(149,'010b52c6-daab-40d3-90bd-19412b3a13a2','01ced5a6-a410-4d0d-8464-b29772521240','2026-06-10 07:59:16',NULL,'CREATE','COMPLETE','timesync_sync','70532ec1-ac13-497d-8494-68b8686276fe','state changed','OS::Heat::SoftwareConfig',NULL,64),(150,'ba2c6df1-cd0c-4fcc-9b0e-3c8a49755cdc','43d5f730-59e2-47c9-a44e-c28c4cac61df','2026-06-10 07:59:16',NULL,'CREATE','COMPLETE','overcloud-EndpointMap-r57lg4za4w2v','43d5f730-59e2-47c9-a44e-c28c4cac61df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(151,'134224cf-17b9-46ae-a0df-50926c0a207b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:17',NULL,'CREATE','IN_PROGRESS','BlockStorageRoleUserData','overcloud-BlockStorageRoleUserData-dm7dz5xtfmgt','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(152,'879765a9-ecfd-4190-ba2a-7ccd285853bd','20b68bce-1fb9-4f89-a17c-1a7cc0fefc91','2026-06-10 07:59:17',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageRoleUserData-dm7dz5xtfmgt','20b68bce-1fb9-4f89-a17c-1a7cc0fefc91','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(153,'45d6a543-ba7d-4891-8157-b34f8815b1dc','20b68bce-1fb9-4f89-a17c-1a7cc0fefc91','2026-06-10 07:59:17',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-BlockStorageRoleUserData-dm7dz5xtfmgt-userdata-wep2cq5jfbxn','state changed','OS::Heat::MultipartMime',NULL,NULL),(154,'040f9bee-4eb9-42c2-8e1a-a5acdabc2640','20b68bce-1fb9-4f89-a17c-1a7cc0fefc91','2026-06-10 07:59:17',NULL,'CREATE','COMPLETE','userdata','004961bd-4a7e-4efe-bba8-b93e8e1fe9bb','state changed','OS::Heat::MultipartMime',NULL,NULL),(155,'7875f41b-6fe3-4f29-a9a3-397be4ded66c','20b68bce-1fb9-4f89-a17c-1a7cc0fefc91','2026-06-10 07:59:17',NULL,'CREATE','COMPLETE','overcloud-BlockStorageRoleUserData-dm7dz5xtfmgt','20b68bce-1fb9-4f89-a17c-1a7cc0fefc91','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(156,'029a9e34-e569-491b-9291-b2fa3ebad967','01ced5a6-a410-4d0d-8464-b29772521240','2026-06-10 07:59:17',NULL,'CREATE','IN_PROGRESS','timesync_chrony','overcloud-NodeTimesyncUserData-qhy3pxxjz5yk-timesync_chrony-62hugxuqvetc','state changed','OS::Heat::SoftwareConfig',NULL,65),(157,'090588d4-42e9-4380-9445-6c33add228fa','01ced5a6-a410-4d0d-8464-b29772521240','2026-06-10 07:59:17',NULL,'CREATE','COMPLETE','timesync_chrony','3fbc7823-0102-4f72-9645-0ac72e2c80a4','state changed','OS::Heat::SoftwareConfig',NULL,65),(158,'dbcded1f-1945-4009-8110-823b2d6dc490','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:17',NULL,'CREATE','COMPLETE','EndpointMap','43d5f730-59e2-47c9-a44e-c28c4cac61df','state changed','OS::TripleO::EndpointMap',NULL,60),(159,'82887675-2983-460a-a226-8f445caae104','01ced5a6-a410-4d0d-8464-b29772521240','2026-06-10 07:59:17',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeTimesyncUserData-qhy3pxxjz5yk-userdata-doq665qqs623','state changed','OS::Heat::MultipartMime',NULL,66),(160,'4ac0b7f0-e813-405d-8a82-1618f4f0d4fc','01ced5a6-a410-4d0d-8464-b29772521240','2026-06-10 07:59:17',NULL,'CREATE','COMPLETE','userdata','ee0d87e5-d4dd-4fbe-a61e-5b7e4cf8be87','state changed','OS::Heat::MultipartMime',NULL,66),(161,'d0751ac1-9b10-418d-94d2-dd344e1b2a4c','01ced5a6-a410-4d0d-8464-b29772521240','2026-06-10 07:59:17',NULL,'CREATE','COMPLETE','overcloud-NodeTimesyncUserData-qhy3pxxjz5yk','01ced5a6-a410-4d0d-8464-b29772521240','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(162,'156e389b-1f1f-4670-8e2b-3229f2ec4bb9','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:17',NULL,'CREATE','IN_PROGRESS','EndpointMapData','overcloud-EndpointMapData-bia3lf3mlgww','state changed','OS::Heat::Value',NULL,68),(163,'09dc1c91-7669-44c4-a1d0-2b05255597bf','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:17',NULL,'CREATE','COMPLETE','EndpointMapData','overcloud-EndpointMapData-bia3lf3mlgww','state changed','OS::Heat::Value',NULL,68),(164,'69b94925-8784-4062-a6c1-07f8f72d1c24','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChain','overcloud-CephStorageServiceChain-tpglbezicx2r','state changed','OS::TripleO::CephStorageServices',NULL,69),(165,'79987ce5-ddac-467c-8d4e-f11049364389','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChain','overcloud-NetworkerServiceChain-ecmgjcuhokar','state changed','OS::TripleO::NetworkerServices',NULL,70),(166,'2262fe45-5f33-47ca-b66a-8eb1e4283df3','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','ControllerServiceChain','overcloud-ControllerServiceChain-prlzcjjdciyj','state changed','OS::TripleO::ControllerServices',NULL,71),(167,'c618a94f-c44d-4341-a672-76a55030e960','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChain','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks','state changed','OS::TripleO::BlockStorageServices',NULL,72),(168,'0b47fe1e-fb90-4ab1-8ea2-f0ccaee83ba3','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','COMPLETE','BlockStorageRoleUserData','20b68bce-1fb9-4f89-a17c-1a7cc0fefc91','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(169,'ff1e2087-430c-40f8-874d-fbdd36eb9dc7','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','ComputeServiceChain','overcloud-ComputeServiceChain-4wlndewsilqw','state changed','OS::TripleO::ComputeServices',NULL,74),(170,'be53171b-1e7c-4d6a-bd8d-5dcbfc512c91','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChain','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y','state changed','OS::TripleO::CellControllerComputeServices',NULL,73),(171,'6bc034e7-3d99-48e1-b660-a42afbe33c3a','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-ecmgjcuhokar','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(172,'8e3a7696-9d52-4b67-b9a3-b3a9782b67d8','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','COMPLETE','NodeTimesyncUserData','01ced5a6-a410-4d0d-8464-b29772521240','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(173,'a554faae-994d-46c8-bcb7-8423eb0831ad','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChain','overcloud-ObjectStorageServiceChain-4nfkfwybokfg','state changed','OS::TripleO::ObjectStorageServices',NULL,75),(174,'f684e0fe-43de-47e0-b63c-ff7429171563','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y','a0ba3861-b4e7-4777-aaed-19041c4163de','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(175,'896b8562-6127-4119-a0e3-99cb99c13fe5','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj','c3125286-a4ec-445d-a8c0-75dff7f0790d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(176,'2fbcbc44-c7c3-465e-985d-ef6818482bff','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChain','overcloud-CellControllerServiceChain-56k57ysbdzn5','state changed','OS::TripleO::CellControllerServices',NULL,77),(177,'07fb3f75-f9c7-46b8-898f-5425cdafbfa4','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw','a5c071db-18d0-4b8e-bf6b-5841cb648922','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(178,'de468400-5cee-43cc-b9c8-dc474f1019a2','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-tpglbezicx2r','968982ca-6aab-421a-b1ed-6efe22be173a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(179,'bf63149d-634b-47e4-9d84-3ccd334cd328','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks','ccc6fa04-9c15-45b6-b661-960f4e4de801','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(180,'31d5b704-23d6-4b7a-9384-97ea7e453a52','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','BlockStorageUserData','overcloud-BlockStorageUserData-rj436qncozzj','state changed','OS::Heat::MultipartMime',NULL,80),(181,'f90c9d79-55b0-4b19-8e92-29390531c31e','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:18',NULL,'CREATE','IN_PROGRESS','ObjectStorageUserData','overcloud-ObjectStorageUserData-qzhht6ahrody','state changed','OS::Heat::MultipartMime',NULL,79),(182,'3af61326-f8d8-422c-9166-1587a805bb52','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','CellControllerComputeUserData','overcloud-CellControllerComputeUserData-ig5rtqcgx5or','state changed','OS::Heat::MultipartMime',NULL,81),(183,'fe772dc8-53fa-440e-8463-4162560d020c','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','NetworkerUserData','overcloud-NetworkerUserData-lu3qlbzkxsq3','state changed','OS::Heat::MultipartMime',NULL,83),(184,'524b997f-170a-433d-b42d-d0e36eeb28b4','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','ComputeUserData','overcloud-ComputeUserData-scrfbgwt3fpe','state changed','OS::Heat::MultipartMime',NULL,82),(185,'09b1a1dc-dcc3-4d55-9897-ca3f2cccc83d','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-4nfkfwybokfg','11e12d7d-7494-4632-8634-8244a0908d4f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(186,'5a8346fa-62b9-433a-b806-98ee098786b9','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','CephStorageUserData','overcloud-CephStorageUserData-rezywuo6zx4r','state changed','OS::Heat::MultipartMime',NULL,85),(187,'f7b6cd13-5395-43fe-b230-af6a1b8474f9','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','CellControllerUserData','overcloud-CellControllerUserData-2vugebwovaxb','state changed','OS::Heat::MultipartMime',NULL,86),(188,'be54b16c-0cc2-4db9-b5ea-228c3055a7de','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-56k57ysbdzn5','83b349e1-364b-4be6-aee0-273246c0e1df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(189,'fab3fddc-6ef9-4d59-99b8-4fd7f7a9b9e6','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','ObjectStorageUserData','886b8f25-9eae-49de-9301-41e449b762ea','state changed','OS::Heat::MultipartMime',NULL,79),(190,'7827451c-b7b2-4951-9d0e-854b5a3de022','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','ControllerUserData','overcloud-ControllerUserData-d5l5akc4v4ig','state changed','OS::Heat::MultipartMime',NULL,87),(191,'04cb9555-6583-4d02-ba28-fe0511df5056','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','CephStorageUserData','172cfc37-789a-4f32-a9ff-786469ec1b28','state changed','OS::Heat::MultipartMime',NULL,85),(192,'c634219f-747f-43f1-998a-7fcc9f4a7736','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','BlockStorageUserData','f6a0aeb1-06aa-4bf6-81fd-8e252ca6fef6','state changed','OS::Heat::MultipartMime',NULL,80),(193,'7f31be13-3278-4e63-a983-b392af18dba6','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','NetworkerUserData','a97a6efb-8393-4363-bd51-0d3726905336','state changed','OS::Heat::MultipartMime',NULL,83),(194,'aabbf446-8612-430a-8996-e9c1dcbfa6bf','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','CellControllerComputeUserData','da5dced4-dce5-4953-8ccc-2cf48e400d3b','state changed','OS::Heat::MultipartMime',NULL,81),(195,'e3416c59-753b-49c3-bde8-8e545230a63c','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','ComputeUserData','249a35cc-1588-4b42-b236-f5fd6bbdf411','state changed','OS::Heat::MultipartMime',NULL,82),(196,'ba799075-a7bd-4287-a973-420ad9dac231','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','CellControllerUserData','4a36b4bd-f767-4915-8379-c737afe98f95','state changed','OS::Heat::MultipartMime',NULL,86),(197,'66cf7fcf-8344-4770-802d-1ee7b4c2b2a7','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','ControllerUserData','93cec394-69b4-4727-b320-bcaef63ff3fd','state changed','OS::Heat::MultipartMime',NULL,87),(198,'21410f11-c612-4793-a4c7-20202e0ae1b8','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceChain-l2rd3b36yx2t','state changed','OS::Heat::ResourceChain',NULL,88),(199,'4e7d7df6-9996-46e4-ac6a-0edc3cb2bcaa','45779b4b-2862-48b9-a0b9-01bb2bc408ef','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceChain-l2rd3b36yx2t','45779b4b-2862-48b9-a0b9-01bb2bc408ef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(200,'76575d26-da17-4295-a046-deb6c840ee0c','45779b4b-2862-48b9-a0b9-01bb2bc408ef','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceChain-l2rd3b36yx2t','45779b4b-2862-48b9-a0b9-01bb2bc408ef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(201,'4fba4e20-040d-47c5-afc1-ef98defea236','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceChain-4xeebtbophi2','state changed','OS::Heat::ResourceChain',NULL,89),(202,'01c7a516-12d9-44e1-acba-4d2e151c148e','52ee6a8e-a62f-40c2-acc8-f6a5b405360a','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceChain-4xeebtbophi2','52ee6a8e-a62f-40c2-acc8-f6a5b405360a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(203,'9e10ce7b-2512-423c-81c4-f66ce3b34aba','52ee6a8e-a62f-40c2-acc8-f6a5b405360a','2026-06-10 07:59:19',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceChain-4xeebtbophi2','52ee6a8e-a62f-40c2-acc8-f6a5b405360a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(204,'0eba56d7-eb4e-4964-87d9-600bc5cceb81','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:19',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceChain-khy5o6dxis4h','state changed','OS::Heat::ResourceChain',NULL,90),(205,'a51d0c0e-14ca-474c-8541-85697c8b10e9','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceChain-fqhzmz7zyqb3','state changed','OS::Heat::ResourceChain',NULL,91),(206,'69aa0190-42f2-485b-b1c4-740752552c6f','f9f73235-ceb5-4c2c-b003-daaaec97493d','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceChain-fqhzmz7zyqb3','f9f73235-ceb5-4c2c-b003-daaaec97493d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(207,'c38690f5-7424-4c99-81a0-0e5d9bf9e53d','ddd27658-115c-41e8-8457-e9caf1183d86','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceChain-khy5o6dxis4h','ddd27658-115c-41e8-8457-e9caf1183d86','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(208,'ee9ed6dc-2ebe-4783-a0a5-5f773657a38f','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceChain-w4uijmwfelur','state changed','OS::Heat::ResourceChain',NULL,92),(209,'a6a846f1-edcd-42f7-9fff-6d3f6fc6c7b3','f9f73235-ceb5-4c2c-b003-daaaec97493d','2026-06-10 07:59:20',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceChain-fqhzmz7zyqb3','f9f73235-ceb5-4c2c-b003-daaaec97493d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(210,'c8914520-2a51-4300-a090-d1512c73913b','ddd27658-115c-41e8-8457-e9caf1183d86','2026-06-10 07:59:20',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceChain-khy5o6dxis4h','ddd27658-115c-41e8-8457-e9caf1183d86','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(211,'97852947-0673-4188-95ee-3465cda423f3','1a18b479-2be1-4673-a215-58d7e59ca3c7','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceChain-w4uijmwfelur','1a18b479-2be1-4673-a215-58d7e59ca3c7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(212,'77a62f51-1bf4-4576-b37a-ce793b1eaa6c','1a18b479-2be1-4673-a215-58d7e59ca3c7','2026-06-10 07:59:20',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceChain-w4uijmwfelur','1a18b479-2be1-4673-a215-58d7e59ca3c7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(213,'2b334ec8-df43-4fd3-b8e0-bd780a54b44c','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33','state changed','OS::Heat::ResourceChain',NULL,93),(214,'686a02a2-3e4a-4feb-b43c-d39c2c19a3c5','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4','state changed','OS::Heat::ResourceChain',NULL,94),(215,'4cc15047-fb19-40cd-b12c-ef340f44dd59','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceChain-m72quwkbr5du','state changed','OS::Heat::ResourceChain',NULL,95),(216,'75785140-ba89-4892-8053-388f0f613467','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4','aa8926d6-afc6-4776-8293-07e5a80e1326','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(217,'34bab87d-b724-46e6-a0cc-57b2da0ec9ba','ed64806b-ce00-4a05-a107-32af3aa978b9','2026-06-10 07:59:20',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceChain-m72quwkbr5du','ed64806b-ce00-4a05-a107-32af3aa978b9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(218,'eac00568-ae60-422b-be1c-3bafadf1cb7c','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:20',NULL,'CREATE','COMPLETE','ServiceChain','52ee6a8e-a62f-40c2-acc8-f6a5b405360a','state changed','OS::Heat::ResourceChain',NULL,89),(219,'d9bf54a6-5620-4a21-91eb-ed365886f78d','ed64806b-ce00-4a05-a107-32af3aa978b9','2026-06-10 07:59:20',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceChain-m72quwkbr5du','ed64806b-ce00-4a05-a107-32af3aa978b9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(220,'ed1d0cff-3c0f-4d72-a37f-6e16339b5bb6','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:20',NULL,'CREATE','COMPLETE','ServiceChain','ed64806b-ce00-4a05-a107-32af3aa978b9','state changed','OS::Heat::ResourceChain',NULL,95),(221,'9c288b9a-e938-4107-8d36-f3ccc88c223b','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-NetworkerServiceChain-ecmgjcuhokar-FirewallRules-xu2xxlkibemx','state changed','OS::Heat::Value',NULL,96),(222,'53902205-c04c-4729-a3c3-ac9cf6a23a77','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceConfigSettings-lcuutc6yepue','state changed','OS::Heat::Value',NULL,97),(223,'33913a47-620a-4687-8032-f789988aeedb','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceServerMetadataHook-uipgrimsggxy','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,98),(224,'8a20879f-2089-4d77-9410-93a283032089','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceConfigSettings-lcuutc6yepue','state changed','OS::Heat::Value',NULL,97),(225,'bda266ae-1663-48e4-8ed1-20f986ca6db1','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerServiceChain-56k57ysbdzn5-DockerConfigScripts-nkccdh64n2ml','state changed','OS::Heat::Value',NULL,99),(226,'7318b50e-90c2-4c73-b81e-2ee12a9d078d','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-NetworkerServiceChain-ecmgjcuhokar-FirewallRules-xu2xxlkibemx','state changed','OS::Heat::Value',NULL,96),(227,'ed39bf72-2a0b-4956-87bf-81765e71373c','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerServiceChain-56k57ysbdzn5-DockerConfigScripts-nkccdh64n2ml','state changed','OS::Heat::Value',NULL,99),(228,'36a42c5a-9793-4034-a5b6-cb337353aba3','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-PostUpgradeTasks-a4hcdkgabdlw','state changed','OS::Heat::Value',NULL,100),(229,'dbcd306f-c35e-4a2c-ab61-920004353c93','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerServiceChain-56k57ysbdzn5-FirewallRules-77unbqvyy5xo','state changed','OS::Heat::Value',NULL,103),(230,'d4dfff01-f469-426e-952e-3eac40e858e1','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ContainerPuppetTasks-xlgormdyeeua','state changed','OS::Heat::Value',NULL,101),(231,'0048db33-947e-4e94-9b6b-2912d51c80f0','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-PostUpgradeTasks-a4hcdkgabdlw','state changed','OS::Heat::Value',NULL,100),(232,'4db539ef-cd5a-4000-9ef1-16d3743ab763','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerServiceChain-56k57ysbdzn5-FirewallRules-77unbqvyy5xo','state changed','OS::Heat::Value',NULL,103),(233,'c7cb6a5c-9822-49c1-b18f-bba6db83ebe1','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ServiceChain','ddd27658-115c-41e8-8457-e9caf1183d86','state changed','OS::Heat::ResourceChain',NULL,90),(234,'c6edc186-04d8-4fd3-b890-6366a2fe1ada','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceConfigSettings-i725oriigaqr','state changed','OS::Heat::Value',NULL,102),(235,'3a699094-32a8-47d1-aae5-974839acfbc1','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ContainerPuppetTasks-xlgormdyeeua','state changed','OS::Heat::Value',NULL,101),(236,'e2651c65-8d64-4b25-9fe6-3c5100e2f6ba','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ExternalUpgradeTasks-ejipudwodrv5','state changed','OS::Heat::Value',NULL,104),(237,'3b1848b5-3a50-483e-971c-0326fc752cda','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-UpdateTasks-eom4eqjzvmlg','state changed','OS::Heat::Value',NULL,105),(238,'d9743c62-7977-424f-af4c-a7fc94ebf740','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ServiceChain','f9f73235-ceb5-4c2c-b003-daaaec97493d','state changed','OS::Heat::ResourceChain',NULL,91),(239,'9f23b363-500b-4b1a-9818-30263717c8db','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-KollaConfig-ealnwnfipset','state changed','OS::Heat::Value',NULL,106),(240,'daad8b85-5a65-4513-8b29-2d681011786a','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-HostPrepTasks-npxaz4tc4tc2','state changed','OS::Heat::Value',NULL,107),(241,'4a1277e9-85be-4831-8edc-1bbca7d9cae7','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-UpdateTasks-eom4eqjzvmlg','state changed','OS::Heat::Value',NULL,105),(242,'9ce3d193-3fdf-4a8e-82f9-5e607b22d2b3','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ExternalUpgradeTasks-ejipudwodrv5','state changed','OS::Heat::Value',NULL,104),(243,'65437a20-eb1b-41f7-8a03-3eee6cd7f9b1','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-HostFirewallTasks-pt47posa7g2i','state changed','OS::Heat::Value',NULL,108),(244,'ba721dae-2eed-450d-a9f3-a58cc7479be9','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceConfigSettings-i725oriigaqr','state changed','OS::Heat::Value',NULL,102),(245,'5c66f092-85d0-4f75-b7fb-b71d35846304','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-DockerConfig-chzsyvx462ev','state changed','OS::Heat::Value',NULL,110),(246,'6cf724e0-f200-401b-90f3-d6f8269b1d38','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ExternalUpgradeTasks-mxnzszpqprqs','state changed','OS::Heat::Value',NULL,109),(247,'8c7bbd0e-1b47-4dd0-97f5-dcef0942aa2b','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-HostPrepTasks-npxaz4tc4tc2','state changed','OS::Heat::Value',NULL,107),(248,'dab6cf5f-58ee-4e87-b301-78c8b724baf8','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-FirewallRules-lbfxxixdnwtk','state changed','OS::Heat::Value',NULL,112),(249,'1448c849-58ff-4599-a2dd-059504289009','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-HostFirewallTasks-pt47posa7g2i','state changed','OS::Heat::Value',NULL,108),(250,'0f681418-7268-41dd-8957-e10075e0b7ce','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ServiceChain','1a18b479-2be1-4673-a215-58d7e59ca3c7','state changed','OS::Heat::ResourceChain',NULL,92),(251,'a1e0754e-b47d-4b27-8c8a-8aca36781521','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ScaleTasks-43vvsmgsjply','state changed','OS::Heat::Value',NULL,111),(252,'19f311ea-db1d-43aa-9da8-8da9b18bf784','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ServiceChain','45779b4b-2862-48b9-a0b9-01bb2bc408ef','state changed','OS::Heat::ResourceChain',NULL,88),(253,'0cb10446-df2a-48e3-8e1e-e93997b62cae','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-KollaConfig-ealnwnfipset','state changed','OS::Heat::Value',NULL,106),(254,'0a2870e3-23d3-47b2-86b6-2ce252a95cef','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-HostFirewallTasks-7oapnnxkghh3','state changed','OS::Heat::Value',NULL,114),(255,'008ffb3f-bd48-4e6d-bfeb-5bc9a0a2af0f','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-FirewallRules-lbfxxixdnwtk','state changed','OS::Heat::Value',NULL,112),(256,'e25c30e4-2d0c-4d4e-a27b-a6990a0d961b','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-DockerPuppetTasks-vil6n7jp5gil','state changed','OS::Heat::Value',NULL,113),(257,'01203e7a-734b-48e7-8e40-f6f9796da8b5','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-DockerConfig-chzsyvx462ev','state changed','OS::Heat::Value',NULL,110),(258,'117a625b-e063-4cf1-8d11-8d0ddc6baf71','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-PostUpgradeTasks-zob32f4heehp','state changed','OS::Heat::Value',NULL,115),(259,'5cdaa879-109f-4ae5-9fd3-318e191f135e','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-HostFirewallTasks-7oapnnxkghh3','state changed','OS::Heat::Value',NULL,114),(260,'bcd4879a-0b3e-44b7-b206-fc5dbb9c8f09','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceNames-3ifftzfbwfdj','state changed','OS::Heat::Value',NULL,116),(261,'3d93fae3-3723-4ddc-a021-7575729dc5d9','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-UpdateTasks-6kbne24fkmrh','state changed','OS::Heat::Value',NULL,117),(262,'1f2296a1-733f-4688-9f80-6963e5e48baa','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-AnsibleGroupVars-wldgfekfkbcr','state changed','OS::Heat::Value',NULL,118),(263,'b94313cd-a241-47db-b7ee-445cf7ccc7c8','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-DockerPuppetTasks-vil6n7jp5gil','state changed','OS::Heat::Value',NULL,113),(264,'f62002f1-2695-4c62-9b11-17ba5809bf36','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceNames-3ifftzfbwfdj','state changed','OS::Heat::Value',NULL,116),(265,'2684e03f-e32f-4933-9375-6bbbb42e6cdb','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ScaleTasks-l65iknuhikze','state changed','OS::Heat::Value',NULL,119),(266,'afc232a6-4c08-4d54-8556-c93714688a67','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ExternalUpgradeTasks-mxnzszpqprqs','state changed','OS::Heat::Value',NULL,109),(267,'2edbbe03-85e0-4895-8ad9-e34ae7a5475d','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-AnsibleGroupVars-wldgfekfkbcr','state changed','OS::Heat::Value',NULL,118),(268,'d4b1ce24-2506-4595-a194-aff899c64924','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceConfigSettings-diy64t57nk2r','state changed','OS::Heat::Value',NULL,125),(269,'500a2da7-f703-402d-bf23-b67622ad26a5','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-FirewallFrontendRules-wp5ghtfybfvz','state changed','OS::Heat::Value',NULL,126),(270,'b4b6075e-871f-486c-a3f9-8cbf60db0bfb','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-UpdateTasks-6kbne24fkmrh','state changed','OS::Heat::Value',NULL,117),(271,'370bb739-4e2d-45a4-bac7-647fcd637b3d','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-PuppetStepConfig-uyl7yflpidzm','state changed','OS::Heat::Value',NULL,120),(272,'2402106d-0b85-4adc-a22a-dc46faaf9366','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-HostPrepTasks-5b3rd4u4hnx5','state changed','OS::Heat::Value',NULL,133),(273,'76917904-060c-4d4e-b429-3d814f713d0c','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-PreDeployStepTasks-3nk4qx3goarl','state changed','OS::Heat::Value',NULL,121),(274,'618728ed-0224-433f-bcd7-d06bf28397e9','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-IpaRegistrationTasks-i4uhxbedoypa','state changed','OS::Heat::Value',NULL,130),(275,'92ed488d-318e-4441-8362-aedc2839b79c','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ScaleTasks-l65iknuhikze','state changed','OS::Heat::Value',NULL,119),(276,'49fe54ab-0919-43da-afa0-d28833764727','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ScaleTasks-43vvsmgsjply','state changed','OS::Heat::Value',NULL,111),(277,'de378c10-0956-4ee4-a29b-32888a940576','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceConfigSettings-diy64t57nk2r','state changed','OS::Heat::Value',NULL,125),(278,'13ee9d95-578d-4833-8c2e-270c94683dba','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ExternalDeployTasks-kvo5p4obsutx','state changed','OS::Heat::Value',NULL,136),(279,'3fb95809-722e-4f97-9b08-82acf57c9fed','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-FirewallFrontendRules-wp5ghtfybfvz','state changed','OS::Heat::Value',NULL,126),(280,'140090ed-5e8a-4eb7-a7dd-57b353d5d381','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-PostUpgradeTasks-zob32f4heehp','state changed','OS::Heat::Value',NULL,115),(281,'876e387e-f9e2-4d69-8427-3957ba3e4935','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-IpaRegistrationTasks-efh3xd3uhk5i','state changed','OS::Heat::Value',NULL,137),(282,'c879ee6c-9cf9-4531-acb6-b2a0aa046d9d','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ExternalUpdateTasks-xc6rsnemgfmk','state changed','OS::Heat::Value',NULL,131),(283,'4c084bed-f7ec-40b6-a0b4-3ddda4639c70','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ScaleTasks-wns57naeb4ja','state changed','OS::Heat::Value',NULL,132),(284,'355fd498-f183-44b6-8472-5b0d2885fcaa','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-DeployStepsTasks-skiyjj3klpta','state changed','OS::Heat::Value',NULL,127),(285,'2a206028-714f-4e27-9574-e558cd012d8e','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ExternalPostDeployTasks-hvmddm4ovut7','state changed','OS::Heat::Value',NULL,124),(286,'293cde12-ddda-4f4e-8ca2-e254339f8635','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-NetworkerServiceChain-ecmgjcuhokar-AnsibleGroupVars-x2grvmkifzod','state changed','OS::Heat::Value',NULL,122),(287,'292b3886-c78b-4e98-89de-9f300ae41d98','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-PuppetConfig-fwcjvhebotej','state changed','OS::Heat::Value',NULL,128),(288,'906906ba-814f-41ff-b16f-2ee7c8979e7b','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-IpaRegistrationTasks-i4uhxbedoypa','state changed','OS::Heat::Value',NULL,130),(289,'92ce47c0-21af-4bdf-9af5-21cf79f59017','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-HostPrepTasks-5b3rd4u4hnx5','state changed','OS::Heat::Value',NULL,133),(290,'5d2e0638-1fbf-4863-98b8-efb25ef6d1c3','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-DockerPuppetTasks-q43fkghvrfj7','state changed','OS::Heat::Value',NULL,139),(291,'06f9bd00-ac87-4fb0-9453-1114dfc847d8','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerServiceChain-56k57ysbdzn5-FirewallFrontendRules-jed4fknr5ofn','state changed','OS::Heat::Value',NULL,123),(292,'21805e41-c251-4f27-b898-ae9039db1bb3','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-PreUpgradeRollingTasks-x5lttt6by7gg','state changed','OS::Heat::Value',NULL,129),(293,'7aa99ba9-dd64-4d64-9c5e-64c3756600ee','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-PostUpdateTasks-d6vttjo43ltp','state changed','OS::Heat::Value',NULL,134),(294,'9160e4de-82b1-4f06-844c-7943793b24be','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ExternalDeployTasks-56d2dknw64pr','state changed','OS::Heat::Value',NULL,140),(295,'0f51948f-7e67-4433-9eab-a3bf9270bc3b','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-IpaRegistrationTasks-efh3xd3uhk5i','state changed','OS::Heat::Value',NULL,137),(296,'1f3af163-2739-48c0-8aed-ac60eb1a27d2','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-PuppetStepConfig-2pnmcqvpybgt','state changed','OS::Heat::Value',NULL,143),(297,'60ac125b-8a39-48ef-8231-f7d7a6c4f951','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-NetworkerServiceChain-ecmgjcuhokar-GlobalConfigSettings-bu6oa3mgnxez','state changed','OS::Heat::Value',NULL,135),(298,'e847ed89-e1cb-4712-93be-46cfb0d1ca23','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ExternalDeployTasks-kvo5p4obsutx','state changed','OS::Heat::Value',NULL,136),(299,'212d1884-928b-47cd-9496-a2379ab212a1','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ExternalDeployTasks-56d2dknw64pr','state changed','OS::Heat::Value',NULL,140),(300,'6a700a5e-65f8-438a-8d63-b14dbf4eb8eb','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PreUpgradeRollingTasks-vv7b7t5suljd','state changed','OS::Heat::Value',NULL,138),(301,'1ffb23bc-c096-4d94-9345-338e4dd1c618','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PostUpgradeTasks-ipfpmwqyjd2a','state changed','OS::Heat::Value',NULL,144),(302,'548e9316-e0b4-4ed2-a99e-44e0af338488','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-PuppetStepConfig-uyl7yflpidzm','state changed','OS::Heat::Value',NULL,120),(303,'335f509c-5125-4f9c-a199-1f3e2520b0a9','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-DockerPuppetTasks-q43fkghvrfj7','state changed','OS::Heat::Value',NULL,139),(304,'3fa21856-428c-4f82-be38-d37c57133483','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-UpgradeBatchTasks-5dveos6i7467','state changed','OS::Heat::Value',NULL,147),(305,'13dfec33-df86-4a9c-8259-cd753753adaf','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-PuppetStepConfig-2pnmcqvpybgt','state changed','OS::Heat::Value',NULL,143),(306,'74a2a63d-4b85-4832-bb89-9a4247c1ccf0','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-PreDeployStepTasks-3nk4qx3goarl','state changed','OS::Heat::Value',NULL,121),(307,'297dbb9c-92e6-4aa4-bb5b-30ca0d899514','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-DockerConfigScripts-dncokh2sir6z','state changed','OS::Heat::Value',NULL,148),(308,'78417d58-9fd8-49bb-ab14-2b93b465b49a','d7907784-4888-4c0f-82a3-01aeba312f90','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceServerMetadataHook-uipgrimsggxy','d7907784-4888-4c0f-82a3-01aeba312f90','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(309,'736fde9a-c8d9-45f3-a740-1cd060185682','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PostUpgradeTasks-ipfpmwqyjd2a','state changed','OS::Heat::Value',NULL,144),(310,'92cfab4f-88f4-4938-a524-8584afce4732','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ScaleTasks-ysmpkpg6ss5d','state changed','OS::Heat::Value',NULL,145),(311,'4f067e31-eb45-4059-907b-fb7bddd59481','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-ecmgjcuhokar-KeystoneResourcesConfigs-de62vifm2yam','state changed','OS::Heat::Value',NULL,141),(312,'d6420109-12f1-47c1-8992-2323e7a2d5c6','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PuppetStepConfig-tyfhhznz5j2y','state changed','OS::Heat::Value',NULL,153),(313,'605cc6ef-5731-4492-97aa-6c113fc444f5','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-UpdateTasks-udtmojc2i5yv','state changed','OS::Heat::Value',NULL,152),(314,'544ca760-88a6-4711-89bb-cbb375d1326b','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-UpgradeBatchTasks-bwgxfb4bboqs','state changed','OS::Heat::Value',NULL,142),(315,'3bc4429d-4d4a-49aa-8394-d94e5971fd54','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ExternalUpgradeTasks-gaon7cffovxe','state changed','OS::Heat::Value',NULL,146),(316,'4f6cf734-6a6c-4593-96b1-d68abf169fc6','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-DockerConfigScripts-dncokh2sir6z','state changed','OS::Heat::Value',NULL,148),(317,'945e6be8-9042-4089-953c-b6860d734317','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-UpgradeBatchTasks-5dveos6i7467','state changed','OS::Heat::Value',NULL,147),(318,'38f56184-1156-4da1-915d-758e3d56dd3d','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-DeployStepsTasks-6bucu6guef46','state changed','OS::Heat::Value',NULL,156),(319,'5b128f4a-c31c-49cd-b193-6bbafb29396c','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ScaleTasks-wns57naeb4ja','state changed','OS::Heat::Value',NULL,132),(320,'fc53595c-7eb7-4f06-83ef-8e3e6294dcd8','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-KeystoneResourcesConfigs-schfkinf4p27','state changed','OS::Heat::Value',NULL,155),(321,'45758f45-92bc-4d8b-9224-83a2f9d220ad','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ExternalUpdateTasks-xc6rsnemgfmk','state changed','OS::Heat::Value',NULL,131),(322,'9e161d7d-7eb2-4f26-a481-bc753ffac74f','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PuppetStepConfig-tyfhhznz5j2y','state changed','OS::Heat::Value',NULL,153),(323,'1cc9bfa9-9630-4d60-ba98-90d625aae916','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-UpdateTasks-udtmojc2i5yv','state changed','OS::Heat::Value',NULL,152),(324,'43e6de61-ace6-49a9-843c-fb16d85e5f12','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-DeployStepsTasks-6bucu6guef46','state changed','OS::Heat::Value',NULL,156),(325,'cbf79a23-453e-48fc-8ca2-841d0048d999','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceServerMetadataHook-oy3rqaiaex76','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,149),(326,'189ca663-7b35-494d-8ccf-631f30a2921e','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CephStorageServiceChain-tpglbezicx2r-AnsibleGroupVars-bhcivnqbojzo','state changed','OS::Heat::Value',NULL,150),(327,'1d116995-3544-4889-ad94-04e75766fc3a','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-UpgradeTasks-nz6qlu2z26pz','state changed','OS::Heat::Value',NULL,158),(328,'b6be183a-0e4f-4d12-a93b-b86234da73e1','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-DockerPuppetTasks-5gkezjarntzv','state changed','OS::Heat::Value',NULL,160),(329,'bff6f31c-2103-4594-afaa-8ff5b04acbae','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-KeystoneResourcesConfigs-schfkinf4p27','state changed','OS::Heat::Value',NULL,155),(330,'ecb28d1b-840c-4692-b1f0-25d087e93ea9','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceNames-vspsihfqzfru','state changed','OS::Heat::Value',NULL,151),(331,'e1c9974e-e654-4bf2-bb2f-7dbd5649d1a7','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-DockerConfig-kunl7iynqn2g','state changed','OS::Heat::Value',NULL,163),(332,'220f7fdf-7f4d-4eba-b915-206aad4230e8','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceNames-4aqpfylp43lj','state changed','OS::Heat::Value',NULL,154),(333,'c0ea2313-2357-4f18-a471-a44ff69b42ad','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ExternalPostDeployTasks-hvmddm4ovut7','state changed','OS::Heat::Value',NULL,124),(334,'d471c93b-0b5e-41a1-9db1-b2d11ac7c201','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-DeployStepsTasks-skiyjj3klpta','state changed','OS::Heat::Value',NULL,127),(335,'a2ede4d0-81a1-41b2-8d9f-fe3b9148fc36','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-UpgradeTasks-nz6qlu2z26pz','state changed','OS::Heat::Value',NULL,158),(336,'b785eee9-db10-4184-8974-d3f1f89876ad','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-DockerConfigScripts-o2b6kc6lvkpx','state changed','OS::Heat::Value',NULL,162),(337,'0563afbf-0c17-4823-b609-6e04c72a502c','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-DockerPuppetTasks-5gkezjarntzv','state changed','OS::Heat::Value',NULL,160),(338,'e2c6b504-5710-44d0-ac4d-e0e1519ccfb6','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-NetworkerServiceChain-ecmgjcuhokar-AnsibleGroupVars-x2grvmkifzod','state changed','OS::Heat::Value',NULL,122),(339,'30ee33c2-e2ea-4b23-a72d-ee385bb3561e','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PostUpdateTasks-foejgenglj4o','state changed','OS::Heat::Value',NULL,157),(340,'30b7392f-2fb8-446b-98e5-8feeed005887','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PreDeployStepTasks-nhppauzg5pzl','state changed','OS::Heat::Value',NULL,165),(341,'b7050869-b0da-4234-bc00-bc83ea1ef397','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-KollaConfig-h7zwrbcby74b','state changed','OS::Heat::Value',NULL,167),(342,'e745aab8-c17a-4dea-9434-b72f6462a03a','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-DockerConfig-kunl7iynqn2g','state changed','OS::Heat::Value',NULL,163),(343,'2d7a7bff-ce1e-4a3c-8915-55d36ce22cbd','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:21',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-DockerConfigScripts-o2b6kc6lvkpx','state changed','OS::Heat::Value',NULL,162),(344,'f108aac9-99cc-4d01-89cf-a1e52fb54fc7','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-MonitoringSubscriptionsConfig-dwwr3nn75zeb','state changed','OS::Heat::Value',NULL,170),(345,'9bd253e3-f837-47a9-919a-df9f5e9857bd','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:21',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-GlobalConfigSettings-k6m6su6ahx3i','state changed','OS::Heat::Value',NULL,169),(346,'78aa0bf3-f77c-48e9-aae5-df3589184853','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerServiceChain-56k57ysbdzn5-FirewallFrontendRules-jed4fknr5ofn','state changed','OS::Heat::Value',NULL,123),(347,'cf82b75c-d26d-4396-833f-669f483705ce','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-KollaConfig-h7zwrbcby74b','state changed','OS::Heat::Value',NULL,167),(348,'9273cacf-fa32-449c-97ef-f364bbdf99f0','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PreUpgradeRollingTasks-vv7b7t5suljd','state changed','OS::Heat::Value',NULL,138),(349,'96a3283c-c535-4103-b624-7720293aa3d8','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PreDeployStepTasks-nhppauzg5pzl','state changed','OS::Heat::Value',NULL,165),(350,'5217d8a8-32da-42b0-85a0-fddc74145379','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PuppetConfig-fnw6twu77wox','state changed','OS::Heat::Value',NULL,174),(351,'e9fad81c-16fd-480b-b17f-797bf05385b2','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-MonitoringSubscriptionsConfig-dwwr3nn75zeb','state changed','OS::Heat::Value',NULL,170),(352,'32586c86-376c-49d3-8f0b-50d622264627','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-NetworkerServiceChain-ecmgjcuhokar-FirewallFrontendRules-bh2oondj7adz','state changed','OS::Heat::Value',NULL,161),(353,'39f0d191-2c2e-4590-97fd-46663c63f40d','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-GlobalConfigSettings-k6m6su6ahx3i','state changed','OS::Heat::Value',NULL,169),(354,'721cfaba-23a1-48f1-a5de-9b7d431ce0ba','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-UpgradeTasks-i6urf7mkgsmn','state changed','OS::Heat::Value',NULL,175),(355,'ab320f3e-4d57-4d8b-8474-2e68f2c26c3b','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PuppetConfig-fnw6twu77wox','state changed','OS::Heat::Value',NULL,174),(356,'9ec16cb2-4faa-441c-a2ce-8d8e25626e1f','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-PostUpdateTasks-d6vttjo43ltp','state changed','OS::Heat::Value',NULL,134),(357,'22f2c3e4-114a-4e46-a0f4-2e6bf8342613','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-PreUpgradeRollingTasks-x5lttt6by7gg','state changed','OS::Heat::Value',NULL,129),(358,'8b0229d8-acba-467d-a411-c2f69b16c515','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-UpgradeTasks-i6urf7mkgsmn','state changed','OS::Heat::Value',NULL,175),(359,'8eb8671a-b8e8-414c-9e91-bcba64972582','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ScaleTasks-ysmpkpg6ss5d','state changed','OS::Heat::Value',NULL,145),(360,'de6a51dc-7f03-41f3-a220-8720862d71d8','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ExternalUpgradeTasks-gaon7cffovxe','state changed','OS::Heat::Value',NULL,146),(361,'5174b9bb-1ae7-4a39-bf74-5de17c78ac8c','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ExternalPostDeployTasks-wjijgmt36f4p','state changed','OS::Heat::Value',NULL,168),(362,'2c2777e8-31c8-4ad4-b122-16cd90b4169a','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerServiceChain-56k57ysbdzn5-GlobalConfigSettings-vjlo7vdxifda','state changed','OS::Heat::Value',NULL,159),(363,'4a8d5ee4-3dcb-4a57-b7da-fa474fd9083b','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-NetworkerServiceChain-ecmgjcuhokar-GlobalConfigSettings-bu6oa3mgnxez','state changed','OS::Heat::Value',NULL,135),(364,'0987cbb9-d7c2-452b-937b-4964225a5d28','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-MonitoringSubscriptionsConfig-xhslpymoaqtl','state changed','OS::Heat::Value',NULL,173),(365,'3ff0a159-cfd6-4ff9-9dc2-8e9963469849','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-KollaConfig-p62wppx4z4pf','state changed','OS::Heat::Value',NULL,182),(366,'da6ef251-5855-4997-b64c-400a2572004f','115cce35-eb28-482d-b98e-377426e98526','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceServerMetadataHook-oy3rqaiaex76','115cce35-eb28-482d-b98e-377426e98526','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(367,'232ff62e-b32e-4e2f-b1b1-e497a39fc52a','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ExternalUpdateTasks-wfsoi2rnt63y','state changed','OS::Heat::Value',NULL,164),(368,'8a044741-6b6d-4bae-92b1-1f2930a3eba0','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceNames-vspsihfqzfru','state changed','OS::Heat::Value',NULL,151),(369,'8842bdd5-8d76-4320-9a56-e64fc05ed8be','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-DeployStepsTasks-qwemuwmitris','state changed','OS::Heat::Value',NULL,179),(370,'41348a77-ba89-477e-aa65-7dcb90f5a9a0','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PuppetConfig-55rixdzylzqh','state changed','OS::Heat::Value',NULL,177),(371,'b74827ca-6c65-40f9-a075-95e5650f71b6','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-NetworkerServiceChain-ecmgjcuhokar-PuppetConfig-fwcjvhebotej','state changed','OS::Heat::Value',NULL,128),(372,'c7a27767-0716-4dc7-8b20-41f50ba39f4d','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-KollaConfig-p62wppx4z4pf','state changed','OS::Heat::Value',NULL,182),(373,'1e322c39-2496-4aac-9e8c-2a08264e7a79','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-PostUpdateTasks-foejgenglj4o','state changed','OS::Heat::Value',NULL,157),(374,'92198f35-56c5-4a84-96ae-61d56d94374d','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ContainerPuppetTasks-32g2qyptdcvq','state changed','OS::Heat::Value',NULL,181),(375,'3b3da12b-2da9-4a02-850a-a62a996ee6a2','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-UpdateTasks-gr3fsjkxhfpd','state changed','OS::Heat::Value',NULL,184),(376,'154e10bb-3569-43c1-9782-72774c4bee58','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-UpgradeBatchTasks-bwgxfb4bboqs','state changed','OS::Heat::Value',NULL,142),(377,'4a584bee-a46b-45a3-9608-00d4d4321062','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-UpdateTasks-gr3fsjkxhfpd','state changed','OS::Heat::Value',NULL,184),(378,'79622ae7-72a3-4d73-b7e6-734a77381369','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-NetworkerServiceChain-ecmgjcuhokar-DockerConfigScripts-eebijhkmnwsa','state changed','OS::Heat::Value',NULL,171),(379,'537db1c8-08c4-4154-ae35-1dd7cb082857','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PuppetStepConfig-on7xmpb52b5u','state changed','OS::Heat::Value',NULL,176),(380,'abd2f831-1f5f-4cd8-954f-7fae57860fe7','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-HostPrepTasks-rjoukxcikgin','state changed','OS::Heat::Value',NULL,178),(381,'ab230af5-2514-4860-a404-949f6dd80adb','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceServerMetadataHook-isp6brnvsiwm','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,180),(382,'d8d75c4e-68a9-40d1-96db-5bcd6727c776','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-NetworkerServiceChain-ecmgjcuhokar-FirewallFrontendRules-bh2oondj7adz','state changed','OS::Heat::Value',NULL,161),(383,'51a2f941-c9d8-4075-ab0a-2412bcb1e097','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CephStorageServiceChain-tpglbezicx2r-AnsibleGroupVars-bhcivnqbojzo','state changed','OS::Heat::Value',NULL,150),(384,'dc707bce-ff7f-458d-b1e5-e6af7d0b49a7','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceServerMetadataHook-m7374klzri4y','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,188),(385,'9e115f16-88d1-4e02-bd14-7239074860da','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-ecmgjcuhokar-KeystoneResourcesConfigs-de62vifm2yam','state changed','OS::Heat::Value',NULL,141),(386,'8bb27b10-b9c5-47a5-860c-52104a469beb','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-ExternalPostDeployTasks-wjijgmt36f4p','state changed','OS::Heat::Value',NULL,168),(387,'5c1231f0-97a7-4ed9-96c5-5b56563f8750','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-IpaRegistrationTasks-n362xeqijjh2','state changed','OS::Heat::Value',NULL,183),(388,'6bac5b1b-0905-4418-93b5-3f32bfee1ced','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-AnsibleGroupVars-rzhoh2ze3sco','state changed','OS::Heat::Value',NULL,190),(389,'0565e2b8-cf5e-4c19-8123-dec20f285668','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-MonitoringSubscriptionsConfig-xhslpymoaqtl','state changed','OS::Heat::Value',NULL,173),(390,'e3334a34-0bf9-4d91-a943-922b9ace4419','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-DockerConfig-5f5eallcuuxr','state changed','OS::Heat::Value',NULL,186),(391,'420bfbb9-d4bd-445c-814b-9a0971c6a692','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ExternalPostDeployTasks-pilx23hzsjov','state changed','OS::Heat::Value',NULL,185),(392,'5b87f0b0-4f3b-4c2f-bd40-ec67fd475d58','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceNames-4aqpfylp43lj','state changed','OS::Heat::Value',NULL,154),(393,'7f778398-6525-4e5e-9506-cb9be8453976','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-DeployStepsTasks-qwemuwmitris','state changed','OS::Heat::Value',NULL,179),(394,'685d5993-a955-42ba-8a9a-921350bb4626','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-AnsibleGroupVars-rzhoh2ze3sco','state changed','OS::Heat::Value',NULL,190),(395,'e6e672cc-208d-450e-9db1-568cb643c147','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PuppetConfig-55rixdzylzqh','state changed','OS::Heat::Value',NULL,177),(396,'60ba906e-37e0-4b88-a025-910f541b4837','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ContainerPuppetTasks-32g2qyptdcvq','state changed','OS::Heat::Value',NULL,181),(397,'0a68faaa-ac98-4371-b598-b565a21a1004','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-DeployStepsTasks-brx6lhrzw5zx','state changed','OS::Heat::Value',NULL,191),(398,'3684c918-2c06-4b62-9a7f-3c734cf51aae','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-IpaRegistrationTasks-iiftmt5qge4z','state changed','OS::Heat::Value',NULL,192),(399,'c41ae020-838e-4078-bac5-3a2f9e27e0d5','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerServiceChain-56k57ysbdzn5-GlobalConfigSettings-vjlo7vdxifda','state changed','OS::Heat::Value',NULL,159),(400,'205c8892-5a65-4a4b-961a-f3e5350e2c7f','bea127a4-acca-40d0-bdb4-3b1062a35646','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceServerMetadataHook-m7374klzri4y','bea127a4-acca-40d0-bdb4-3b1062a35646','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(401,'c83f2f7c-a0cd-4eb6-8361-48c38c4bc5eb','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-UpgradeTasks-t4q42marknft','state changed','OS::Heat::Value',NULL,195),(402,'379e215b-da8d-4fc8-9fa8-d9cb6e3ef46f','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ContainerPuppetTasks-pahb6arzlfyj','state changed','OS::Heat::Value',NULL,194),(403,'049d538c-0dc9-450a-928f-65fd50a4a46e','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-DockerConfig-4kgzf6cpb7ja','state changed','OS::Heat::Value',NULL,189),(404,'5a589d76-b968-442e-9200-fdc26f763247','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-PreDeployStepTasks-ni7xbglfugry','state changed','OS::Heat::Value',NULL,187),(405,'76e90fd3-0121-4c2a-bb65-c4fc418e3267','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-UpgradeTasks-t4q42marknft','state changed','OS::Heat::Value',NULL,195),(406,'81d3fb47-6220-4806-aace-1063ece1329f','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-DockerConfig-5f5eallcuuxr','state changed','OS::Heat::Value',NULL,186),(407,'9c9f987a-dfab-4d6b-892b-b44db3004692','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ContainerPuppetTasks-g6vk5skwpkn5','state changed','OS::Heat::Value',NULL,196),(408,'3ee0c0d3-6b5a-4b53-832b-ae9823278d2f','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ExternalUpdateTasks-wfsoi2rnt63y','state changed','OS::Heat::Value',NULL,164),(409,'dc16332d-f333-4056-a10e-10fb6e9390d3','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ContainerPuppetTasks-pahb6arzlfyj','state changed','OS::Heat::Value',NULL,194),(410,'0de045b3-33f8-438f-9e91-a39a01c9b92a','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-PreDeployStepTasks-hfe4ynbxjqal','state changed','OS::Heat::Value',NULL,198),(411,'fe3f6194-89db-4a03-9f08-d46b7c898954','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ContainerPuppetTasks-g6vk5skwpkn5','state changed','OS::Heat::Value',NULL,196),(412,'3a9cca84-55bd-4f86-94bd-eda95c0f5646','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-DeployStepsTasks-brx6lhrzw5zx','state changed','OS::Heat::Value',NULL,191),(413,'909894fe-8add-49b8-befc-734b31b53d6b','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-PreDeployStepTasks-hfe4ynbxjqal','state changed','OS::Heat::Value',NULL,198),(414,'baad713a-3763-4048-aa30-0431ecbf8b6a','115cce35-eb28-482d-b98e-377426e98526','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceServerMetadataHook-oy3rqaiaex76-IncomingMetadataSettings-s23663u75eit','state changed','OS::Heat::Value',NULL,193),(415,'ceee5f94-a3f6-4b02-aed3-cfb2cd2dcac4','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-NetworkerServiceChain-ecmgjcuhokar-DockerConfigScripts-eebijhkmnwsa','state changed','OS::Heat::Value',NULL,171),(416,'79467726-7f45-45a7-aca8-1161ca778a28','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-IpaRegistrationTasks-iiftmt5qge4z','state changed','OS::Heat::Value',NULL,192),(417,'5cad9af9-aa18-4d19-943d-6dea13ee6088','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-HostPrepTasks-rjoukxcikgin','state changed','OS::Heat::Value',NULL,178),(418,'9734fe60-9530-4f32-8997-60eadaa2d0f8','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-UpgradeBatchTasks-pnfc7rrow5wb','state changed','OS::Heat::Value',NULL,199),(419,'001a3933-2556-4246-a55e-3beb62cb8379','bea127a4-acca-40d0-bdb4-3b1062a35646','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceServerMetadataHook-m7374klzri4y-IncomingMetadataSettings-fu5hc4rl6aau','state changed','OS::Heat::Value',NULL,201),(420,'64d2bb45-090e-412d-bc51-f6482c16c9ba','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerServiceChain-56k57ysbdzn5-AnsibleGroupVars-jck6w53p7htu','state changed','OS::Heat::Value',NULL,197),(421,'b25b1a71-086c-4a44-8b6a-a4d20525588a','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-NetworkerServiceChain-ecmgjcuhokar-IpaRegistrationTasks-n362xeqijjh2','state changed','OS::Heat::Value',NULL,183),(422,'ed9d6c50-13bf-44d2-88e3-440e29e165cd','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PuppetStepConfig-on7xmpb52b5u','state changed','OS::Heat::Value',NULL,176),(423,'ea7b97d2-894d-462e-bf0e-65ec4cd0c2bf','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ExternalUpdateTasks-jvuvespuok35','state changed','OS::Heat::Value',NULL,202),(424,'b637cba5-5670-4920-937f-87d627017319','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-HostFirewallTasks-uorv5iux7mg7','state changed','OS::Heat::Value',NULL,203),(425,'cf5c9317-9020-4457-a664-c4418d2dbf0b','67be4ab8-c3b8-43ec-974a-ea525386ea10','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceServerMetadataHook-isp6brnvsiwm','67be4ab8-c3b8-43ec-974a-ea525386ea10','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(426,'f0e915cc-dc20-4d8a-8825-8eeb79986243','bea127a4-acca-40d0-bdb4-3b1062a35646','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceServerMetadataHook-m7374klzri4y-IncomingMetadataSettings-fu5hc4rl6aau','state changed','OS::Heat::Value',NULL,201),(427,'91fe285e-cf11-4600-8a01-adcc48ce1928','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ExternalPostDeployTasks-pilx23hzsjov','state changed','OS::Heat::Value',NULL,185),(428,'df044540-2ccf-4e7d-b085-4788ab5ab77e','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-HostFirewallTasks-uorv5iux7mg7','state changed','OS::Heat::Value',NULL,203),(429,'f12748c7-4e24-49e2-99d9-fe0091adc5e3','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ExternalUpdateTasks-jvuvespuok35','state changed','OS::Heat::Value',NULL,202),(430,'6643e337-ced4-41d3-9570-4498de9746cf','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33','90e79527-4e38-430d-8d4e-d2687a4894e3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(431,'5fa9dd9d-06d4-4272-9ec6-0f3088f3f9e9','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ExternalPostDeployTasks-3hdevbfxzab5','state changed','OS::Heat::Value',NULL,207),(432,'9ec8a418-0370-4f77-aed6-55441b78291b','bea127a4-acca-40d0-bdb4-3b1062a35646','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceServerMetadataHook-m7374klzri4y-IndividualServices-urzqhmdxgtn2','state changed','OS::Heat::Value',NULL,209),(433,'433975c1-fc31-4945-b8c1-bb4e73e9d712','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-tpglbezicx2r-KeystoneResourcesConfigs-ylku2ghpc4g5','state changed','OS::Heat::Value',NULL,204),(434,'503f4f41-21cb-479c-b841-05b6a13083cc','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-DockerConfig-4kgzf6cpb7ja','state changed','OS::Heat::Value',NULL,189),(435,'2035dd2d-bba0-42f7-8edc-4ead99f82823','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-PreDeployStepTasks-ni7xbglfugry','state changed','OS::Heat::Value',NULL,187),(436,'0d93b674-47d8-48ba-9da0-78bd4cc88a36','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-DeployStepsTasks-ol36w6bd36kd','state changed','OS::Heat::Value',NULL,200),(437,'f229bb44-d0c8-41d1-9148-dedd91d122e8','bea127a4-acca-40d0-bdb4-3b1062a35646','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceServerMetadataHook-m7374klzri4y-IndividualServices-urzqhmdxgtn2','state changed','OS::Heat::Value',NULL,209),(438,'a4939d3d-4c0b-40f2-9840-376be14e3e36','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ExternalPostDeployTasks-3hdevbfxzab5','state changed','OS::Heat::Value',NULL,207),(439,'8cd73903-a01b-4a7a-8f44-3e69a508b490','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-UpgradeBatchTasks-pnfc7rrow5wb','state changed','OS::Heat::Value',NULL,199),(440,'0d6773ac-b6c4-436d-b181-ff4dc52d3ff0','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PreUpgradeRollingTasks-plilpr5h5qhv','state changed','OS::Heat::Value',NULL,211),(441,'51bb438b-973f-4273-8f5a-83b20e6fe027','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-UpgradeTasks-sku37vhpaetv','state changed','OS::Heat::Value',NULL,208),(442,'e7b8bebf-f9e2-45f2-9e8c-6b8d5fa4c534','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PreUpgradeRollingTasks-plilpr5h5qhv','state changed','OS::Heat::Value',NULL,211),(443,'f74a272d-587e-4339-a345-ddf6c736ff07','115cce35-eb28-482d-b98e-377426e98526','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceServerMetadataHook-oy3rqaiaex76-IncomingMetadataSettings-s23663u75eit','state changed','OS::Heat::Value',NULL,193),(444,'7288fa2e-c3a8-49f6-aa51-be63d97c73a0','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-UpgradeBatchTasks-a74fryxkvrqa','state changed','OS::Heat::Value',NULL,205),(445,'22c1a112-6ab7-4325-a924-0093a2ef3693','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-PreUpgradeRollingTasks-bbf4zwusxguw','state changed','OS::Heat::Value',NULL,214),(446,'ae8f23a5-62a1-49dc-9a7c-df2e1dcd2c54','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-UpdateTasks-bnvtyo75ucfq','state changed','OS::Heat::Value',NULL,210),(447,'4c04552c-82f7-473c-bec4-5a2b69970ab8','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-PreUpgradeRollingTasks-bbf4zwusxguw','state changed','OS::Heat::Value',NULL,214),(448,'bce73569-c3ef-441b-829d-5b75b72b88f5','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ContainerPuppetTasks-uly3fs3li7nq','state changed','OS::Heat::Value',NULL,212),(449,'58b08173-7941-4e94-a34c-94d30e468078','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ScaleTasks-nhr6tynlcpqf','state changed','OS::Heat::Value',NULL,216),(450,'0a78259c-c576-4fc1-b4b0-13c863d790e5','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ScaleTasks-nhr6tynlcpqf','state changed','OS::Heat::Value',NULL,216),(451,'2c00c49d-f64a-4532-8777-6f85e16d5ddd','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-tpglbezicx2r-KeystoneResourcesConfigs-ylku2ghpc4g5','state changed','OS::Heat::Value',NULL,204),(452,'8b5cd5b5-7edc-4609-93ca-cabab6efe4b0','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PreDeployStepTasks-zxcxgbxmr3nk','state changed','OS::Heat::Value',NULL,215),(453,'e8a93553-d046-4696-8ed7-9d16c75d7ddd','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-UpgradeTasks-sku37vhpaetv','state changed','OS::Heat::Value',NULL,208),(454,'941ab3b9-c2c0-4c2a-9c45-c0971dd3af39','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ExternalUpdateTasks-l7whio3yukxl','state changed','OS::Heat::Value',NULL,217),(455,'af5da430-6c66-436d-be8f-d52b00e0d703','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ContainerPuppetTasks-uly3fs3li7nq','state changed','OS::Heat::Value',NULL,212),(456,'b6925c8c-98fd-41f6-906f-7dd21c65fc1c','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-DockerConfig-ehktmcebv7vq','state changed','OS::Heat::Value',NULL,219),(457,'805bfff8-56e6-46ce-89d8-be98e63ef7be','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ExternalUpdateTasks-l7whio3yukxl','state changed','OS::Heat::Value',NULL,217),(458,'39dbfddb-152e-4a93-88bb-26b2fa072b35','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-DockerConfig-ehktmcebv7vq','state changed','OS::Heat::Value',NULL,219),(459,'537bfe22-9f0a-4a8e-a2a6-01a0b0d7f032','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ExternalUpdateTasks-xnu47q3fpztj','state changed','OS::Heat::Value',NULL,218),(460,'6b266870-675a-4bf4-9812-894a63b90a9c','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PreDeployStepTasks-zxcxgbxmr3nk','state changed','OS::Heat::Value',NULL,215),(461,'7f32efe5-423f-4482-952a-2a76848c3545','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:22',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerServiceChain-56k57ysbdzn5-AnsibleGroupVars-jck6w53p7htu','state changed','OS::Heat::Value',NULL,197),(462,'f37f5519-19d2-4a26-bf98-f1c448bdf2b8','bea127a4-acca-40d0-bdb4-3b1062a35646','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceServerMetadataHook-m7374klzri4y-CompactServices-ozblnj7ylrui','state changed','OS::Heat::Value',NULL,213),(463,'9816340e-9ede-4456-acd1-2b0da083ff01','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:22',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-PuppetStepConfig-4bwczvnbp725','state changed','OS::Heat::Value',NULL,221),(464,'d4ae58c7-3e1f-4306-8e7f-109350c3c753','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-PostUpdateTasks-mvhp5tmahcdy','state changed','OS::Heat::Value',NULL,222),(465,'039e557d-5b7c-4d54-b2d8-3dd9765733c9','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-PuppetStepConfig-4bwczvnbp725','state changed','OS::Heat::Value',NULL,221),(466,'3fe3c6bf-19bb-402c-a50b-0c023e8eb6c1','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-PostUpdateTasks-mvhp5tmahcdy','state changed','OS::Heat::Value',NULL,222),(467,'c9b4d44a-5a91-4f99-ba56-720af452097c','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-DeployStepsTasks-ol36w6bd36kd','state changed','OS::Heat::Value',NULL,200),(468,'2c6bb17f-e72e-4b7f-a551-eb1f5e5588f2','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-GlobalConfigSettings-uzcxoxoihdvx','state changed','OS::Heat::Value',NULL,225),(469,'828a4e1c-5f1a-492c-9a10-3d2556876fb8','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-DockerPuppetTasks-5iib2vxko4qf','state changed','OS::Heat::Value',NULL,220),(470,'856d4cab-3a51-4352-b94c-350e1fcb15ae','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-PuppetConfig-erk6xp4i4kot','state changed','OS::Heat::Value',NULL,223),(471,'5bd099bb-a81b-43e7-a6fb-54ff5905a36c','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ExternalUpdateTasks-xnu47q3fpztj','state changed','OS::Heat::Value',NULL,218),(472,'6cfc4edb-005d-4e38-873e-74a5efc91e80','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-GlobalConfigSettings-uzcxoxoihdvx','state changed','OS::Heat::Value',NULL,225),(473,'3580667c-f9a4-41c3-982b-f7cf8bfbf0d5','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ContainerPuppetTasks-57lcabbthbbw','state changed','OS::Heat::Value',NULL,226),(474,'e72c15f9-b123-4743-8dbb-5f42721c6b8e','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceConfigSettings-rteu76vxkupj','state changed','OS::Heat::Value',NULL,224),(475,'af1883a1-9c14-4496-91ad-2fc1728f69b4','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-UpgradeBatchTasks-a74fryxkvrqa','state changed','OS::Heat::Value',NULL,205),(476,'64a3feec-61bb-4f31-bed4-85139c9012ca','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-56k57ysbdzn5-KeystoneResourcesConfigs-3f5ksopzayxq','state changed','OS::Heat::Value',NULL,227),(477,'747ccc13-c5d3-402d-851a-9e98161418cc','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-UpdateTasks-bnvtyo75ucfq','state changed','OS::Heat::Value',NULL,210),(478,'e188a569-509b-4dc1-a2ac-910353f12ce6','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ContainerPuppetTasks-57lcabbthbbw','state changed','OS::Heat::Value',NULL,226),(479,'e8790fcd-00f7-41cf-8615-858f2db4c353','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ExternalDeployTasks-k5jpxi32a4k2','state changed','OS::Heat::Value',NULL,230),(480,'e24c54d5-e411-4ad5-8acf-311dbb47a66d','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-KollaConfig-6uvziptvf5ci','state changed','OS::Heat::Value',NULL,232),(481,'3437d860-67e7-4f00-9fd2-0a1f046f3d0d','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-PuppetConfig-erk6xp4i4kot','state changed','OS::Heat::Value',NULL,223),(482,'d5424914-23e8-4955-aac3-4d97d9113aac','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-KollaConfig-6uvziptvf5ci','state changed','OS::Heat::Value',NULL,232),(483,'c53e1367-469d-4355-b791-69760bfac270','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-ExternalDeployTasks-k5jpxi32a4k2','state changed','OS::Heat::Value',NULL,230),(484,'673bcabf-e0b2-4460-9e8f-fc6e1b2fef13','115cce35-eb28-482d-b98e-377426e98526','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceServerMetadataHook-oy3rqaiaex76-IndividualServices-5pvocnw4rbvx','state changed','OS::Heat::Value',NULL,233),(485,'241e5b9c-1952-4040-8af8-dafd8c1a3b0e','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceConfigSettings-rteu76vxkupj','state changed','OS::Heat::Value',NULL,224),(486,'cb5680b0-898d-4285-8614-f5282cf3770e','bea127a4-acca-40d0-bdb4-3b1062a35646','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceServerMetadataHook-m7374klzri4y-CompactServices-ozblnj7ylrui','state changed','OS::Heat::Value',NULL,213),(487,'f067b7e7-7232-42f0-888e-f6202f8ad596','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-IpaRegistrationTasks-n6rtelart4nu','state changed','OS::Heat::Value',NULL,228),(488,'c7b6fe89-17c9-4f87-a972-313dad92239d','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-UpgradeTasks-7p32ddpsflkc','state changed','OS::Heat::Value',NULL,229),(489,'7e0eba66-867a-4272-9658-6a0964db1718','115cce35-eb28-482d-b98e-377426e98526','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceServerMetadataHook-oy3rqaiaex76-IndividualServices-5pvocnw4rbvx','state changed','OS::Heat::Value',NULL,233),(490,'8e8ab212-a2c2-4157-8283-456dad83ac6c','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ExternalPostDeployTasks-bj3734g7q3dv','state changed','OS::Heat::Value',NULL,237),(491,'3a0fd521-0ce9-4ff5-a640-af65d0d06e26','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-HostFirewallTasks-zzj7zeiw546i','state changed','OS::Heat::Value',NULL,238),(492,'064ceff8-80ab-4ade-bade-7ea6baf1f551','115cce35-eb28-482d-b98e-377426e98526','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceServerMetadataHook-oy3rqaiaex76-CompactServices-aqlzbiwclrvv','state changed','OS::Heat::Value',NULL,231),(493,'7a44930d-511a-4101-8513-abb59b90bbb4','67be4ab8-c3b8-43ec-974a-ea525386ea10','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceServerMetadataHook-isp6brnvsiwm-IncomingMetadataSettings-4rhjhgu37kmj','state changed','OS::Heat::Value',NULL,239),(494,'ba22be76-9ec2-476c-abe5-bff3590eb42f','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-56k57ysbdzn5-KeystoneResourcesConfigs-3f5ksopzayxq','state changed','OS::Heat::Value',NULL,227),(495,'4d4b472a-51f5-4a94-933a-3151c2976d0e','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-PreUpgradeRollingTasks-57v2soczahni','state changed','OS::Heat::Value',NULL,236),(496,'e402d052-8afd-4f1a-bb50-9a7b041c8d7b','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ExternalPostDeployTasks-bj3734g7q3dv','state changed','OS::Heat::Value',NULL,237),(497,'eb09044c-773f-4a81-a40d-4c9cdd5532f3','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-HostFirewallTasks-zzj7zeiw546i','state changed','OS::Heat::Value',NULL,238),(498,'83b6bb85-c67a-4215-b915-0ff4abe15c4d','67be4ab8-c3b8-43ec-974a-ea525386ea10','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceServerMetadataHook-isp6brnvsiwm-IncomingMetadataSettings-4rhjhgu37kmj','state changed','OS::Heat::Value',NULL,239),(499,'4c1fd55d-71a7-4650-902b-4c85df3453d2','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ExternalDeployTasks-zuu77gpngezv','state changed','OS::Heat::Value',NULL,234),(500,'8b041b92-c5bb-4141-8af8-2db243b25955','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-DockerPuppetTasks-5iib2vxko4qf','state changed','OS::Heat::Value',NULL,220),(501,'b7748eda-2b8e-4753-a295-630390c72def','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PreDeployStepTasks-x4jzikivozx5','state changed','OS::Heat::Value',NULL,243),(502,'61349aa1-6c18-42cf-a63f-9ba43fc38b12','67be4ab8-c3b8-43ec-974a-ea525386ea10','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceServerMetadataHook-isp6brnvsiwm-CompactServices-72hfubf6hpza','state changed','OS::Heat::Value',NULL,245),(503,'120ed378-669b-47d5-b60f-ce5a3fcb942f','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-MonitoringSubscriptionsConfig-vitdxjjfmcmw','state changed','OS::Heat::Value',NULL,240),(504,'cf322f4a-164d-46df-a76f-cdee189ecb7a','67be4ab8-c3b8-43ec-974a-ea525386ea10','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceServerMetadataHook-isp6brnvsiwm-CompactServices-72hfubf6hpza','state changed','OS::Heat::Value',NULL,245),(505,'ea7923d8-da13-467d-8f52-51902bf24312','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PreDeployStepTasks-x4jzikivozx5','state changed','OS::Heat::Value',NULL,243),(506,'2af48da9-2340-48c0-922c-1f409ec5210e','d7907784-4888-4c0f-82a3-01aeba312f90','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceServerMetadataHook-uipgrimsggxy-IncomingMetadataSettings-ymvsnqztnof7','state changed','OS::Heat::Value',NULL,247),(507,'175818e4-53a9-4b05-8198-47da32433fa7','d7907784-4888-4c0f-82a3-01aeba312f90','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceServerMetadataHook-uipgrimsggxy-IncomingMetadataSettings-ymvsnqztnof7','state changed','OS::Heat::Value',NULL,247),(508,'2045c23a-dd27-446b-ac48-98b05a50b3b3','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ExternalUpgradeTasks-5hz4luzsgsva','state changed','OS::Heat::Value',NULL,248),(509,'7935f70b-c1a4-426d-83fd-5a992c785e42','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceNames-npeciimufpy2','state changed','OS::Heat::Value',NULL,246),(510,'6aeaacdf-e387-41a7-9525-416bae81ad72','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ExternalUpgradeTasks-5hz4luzsgsva','state changed','OS::Heat::Value',NULL,248),(511,'39879c59-1432-44f1-a9ca-84e173131302','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-56k57ysbdzn5-PreUpgradeRollingTasks-57v2soczahni','state changed','OS::Heat::Value',NULL,236),(512,'829c3aae-1250-4e63-a9b1-c9fa9c127cda','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-HostPrepTasks-hi3cx3kvut6n','state changed','OS::Heat::Value',NULL,249),(513,'b7c69ff3-e598-4849-b079-4bfaf1940687','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CephStorageServiceChain-tpglbezicx2r-DockerConfigScripts-mazklenvd7n5','state changed','OS::Heat::Value',NULL,252),(514,'f553bd85-1824-4f04-82b8-eec5985b20b7','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CephStorageServiceChain-tpglbezicx2r-DockerConfigScripts-mazklenvd7n5','state changed','OS::Heat::Value',NULL,252),(515,'42764921-7429-4818-96a3-dffd957d39b3','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CephStorageServiceChain-tpglbezicx2r-GlobalConfigSettings-hewb4mqqnfga','state changed','OS::Heat::Value',NULL,242),(516,'0d690819-c63d-4343-9718-0bdbe991222e','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-56k57ysbdzn5-MonitoringSubscriptionsConfig-vitdxjjfmcmw','state changed','OS::Heat::Value',NULL,240),(517,'174413cf-fbcd-412a-87ad-ac00797804fd','d7907784-4888-4c0f-82a3-01aeba312f90','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceServerMetadataHook-uipgrimsggxy-IndividualServices-f2gzhkpoq5fl','state changed','OS::Heat::Value',NULL,251),(518,'dba93dc0-9a0b-42b8-8262-f1c049b6fe7b','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceNames-npeciimufpy2','state changed','OS::Heat::Value',NULL,246),(519,'76762ef8-6f38-4242-aa55-3fedd14c9c15','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-PostUpdateTasks-lr7cdvoozcid','state changed','OS::Heat::Value',NULL,255),(520,'1f95f8bd-685a-4dc2-a224-eaf2c92e7b6b','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-PostUpdateTasks-lr7cdvoozcid','state changed','OS::Heat::Value',NULL,255),(521,'5abfd8a1-7ff9-4f19-b292-71162b3e630c','bea127a4-acca-40d0-bdb4-3b1062a35646','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-tpglbezicx2r-ServiceServerMetadataHook-m7374klzri4y','bea127a4-acca-40d0-bdb4-3b1062a35646','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(522,'27bf3da1-6df0-4be6-a9d1-2f8e4d4f5834','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-PostUpgradeTasks-e3xj62ghcu4g','state changed','OS::Heat::Value',NULL,258),(523,'245c2224-dff5-43c0-8415-cece6a19fd08','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-IpaRegistrationTasks-n6rtelart4nu','state changed','OS::Heat::Value',NULL,228),(524,'02e7a9fb-7844-4128-8da8-6eb96e241ec4','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-PostUpgradeTasks-e3xj62ghcu4g','state changed','OS::Heat::Value',NULL,258),(525,'89e8752b-2642-4be7-a88e-14ab4a8203be','115cce35-eb28-482d-b98e-377426e98526','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','CompactServices','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceServerMetadataHook-oy3rqaiaex76-CompactServices-aqlzbiwclrvv','state changed','OS::Heat::Value',NULL,231),(526,'b6fdd046-23ef-434b-bbcd-f0e4618a4c04','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-HostPrepTasks-hi3cx3kvut6n','state changed','OS::Heat::Value',NULL,249),(527,'1cef0712-f224-4a33-b2de-5dcb46717914','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-KollaConfig-gw4kfckzcss2','state changed','OS::Heat::Value',NULL,254),(528,'dcf90de0-ec48-4dad-9112-f42e157a1714','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-PuppetConfig-wwwwwan257hv','state changed','OS::Heat::Value',NULL,253),(529,'ab076545-68b4-4a3e-b31c-f3908b0e2bc0','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceConfigSettings-yq5hvhne4df2','state changed','OS::Heat::Value',NULL,257),(530,'7d352bd8-55ae-4078-934b-03689f16d5f1','d7907784-4888-4c0f-82a3-01aeba312f90','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceServerMetadataHook-uipgrimsggxy-IndividualServices-f2gzhkpoq5fl','state changed','OS::Heat::Value',NULL,251),(531,'654c8ea3-224c-48e4-b123-bf08abd21686','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-ExternalDeployTasks-zuu77gpngezv','state changed','OS::Heat::Value',NULL,234),(532,'080d1539-a026-4d65-8ac9-3e8fe7d65fb7','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-DeployStepsTasks-2y5p2ejfxcaw','state changed','OS::Heat::Value',NULL,261),(533,'a25a53f1-02d4-4f63-8a54-cd5cd752d195','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-UpgradeTasks-7p32ddpsflkc','state changed','OS::Heat::Value',NULL,229),(534,'4c4da37c-081e-4f1e-8d84-4c48dd54bbcd','67be4ab8-c3b8-43ec-974a-ea525386ea10','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceServerMetadataHook-isp6brnvsiwm-IndividualServices-dxru6b2ulhns','state changed','OS::Heat::Value',NULL,256),(535,'db216355-2123-4b28-8fcf-938b03af79f4','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-DeployStepsTasks-2y5p2ejfxcaw','state changed','OS::Heat::Value',NULL,261),(536,'6331eed0-a025-43ff-98d1-bbb5e03c7819','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceConfigSettings-yq5hvhne4df2','state changed','OS::Heat::Value',NULL,257),(537,'bbc5ee7a-04f3-44b9-83e5-9f3b84849929','d7907784-4888-4c0f-82a3-01aeba312f90','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceServerMetadataHook-uipgrimsggxy-CompactServices-ud6y5gaon4xc','state changed','OS::Heat::Value',NULL,259),(538,'a7a27a77-2e6b-45bb-89b6-61dcd245b2ca','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CephStorageServiceChain-tpglbezicx2r-FirewallFrontendRules-k346u6zzzshj','state changed','OS::Heat::Value',NULL,262),(539,'65ab2669-ff7e-498d-8f87-46b47afdf38c','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-MonitoringSubscriptionsConfig-sx3j5hezuqb3','state changed','OS::Heat::Value',NULL,263),(540,'d6f0422c-13f6-4d62-ae22-6242f1cedae0','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CephStorageServiceChain-tpglbezicx2r-GlobalConfigSettings-hewb4mqqnfga','state changed','OS::Heat::Value',NULL,242),(541,'bcb42c0f-b770-4b02-b6ab-38d8e323206d','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-KeystoneResourcesConfigs-pofnk7ttfqsm','state changed','OS::Heat::Value',NULL,260),(542,'b0ef8360-0cf1-4a18-9b3a-940e51c069d4','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-MonitoringSubscriptionsConfig-sx3j5hezuqb3','state changed','OS::Heat::Value',NULL,263),(543,'517e1c65-bbbe-41af-b9cb-ba9d2d74644c','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CephStorageServiceChain-tpglbezicx2r-FirewallFrontendRules-k346u6zzzshj','state changed','OS::Heat::Value',NULL,262),(544,'765e5cc0-0e01-4f7a-9116-f792eb36532e','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-HostPrepTasks-iw2alv4vbai2','state changed','OS::Heat::Value',NULL,266),(545,'c1a567f9-8891-4fd8-aac0-6568da3e5b22','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CephStorageServiceChain-tpglbezicx2r-FirewallRules-zxthilvu72tv','state changed','OS::Heat::Value',NULL,267),(546,'f795302b-0e7d-44b4-81e3-1e55274bf217','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-UpgradeBatchTasks-gfrplrrjksoq','state changed','OS::Heat::Value',NULL,268),(547,'2c139566-c713-4e63-965c-44a1419aeb5b','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CephStorageServiceChain-tpglbezicx2r-HostPrepTasks-iw2alv4vbai2','state changed','OS::Heat::Value',NULL,266),(548,'c27eaf8d-7f85-425f-941f-7f234a4313b4','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CephStorageServiceChain-tpglbezicx2r-FirewallRules-zxthilvu72tv','state changed','OS::Heat::Value',NULL,267),(549,'d396d337-cff2-47f0-a5f0-6fe5ec9516f4','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-UpgradeBatchTasks-gfrplrrjksoq','state changed','OS::Heat::Value',NULL,268),(550,'81e84aa9-13e8-4c09-8852-e8719dab13db','115cce35-eb28-482d-b98e-377426e98526','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-ecmgjcuhokar-ServiceServerMetadataHook-oy3rqaiaex76','115cce35-eb28-482d-b98e-377426e98526','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(551,'4762ce6d-bf24-4496-9fd3-596adc866abf','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-KollaConfig-gw4kfckzcss2','state changed','OS::Heat::Value',NULL,254),(552,'1a897a2d-09d4-4807-8dfa-129afdbe8769','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CephStorageServiceChain-tpglbezicx2r-PuppetConfig-wwwwwan257hv','state changed','OS::Heat::Value',NULL,253),(553,'78a720d0-d5d6-472c-a174-aa33599cd7b0','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ExternalUpdateTasks-4w2pbhxnxntz','state changed','OS::Heat::Value',NULL,265),(554,'1a51ea79-d063-48e1-810c-9e11123a711c','67be4ab8-c3b8-43ec-974a-ea525386ea10','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceServerMetadataHook-isp6brnvsiwm-IndividualServices-dxru6b2ulhns','state changed','OS::Heat::Value',NULL,256),(555,'2c1195e2-7da9-465c-a6d5-5d33c9f9317f','d7907784-4888-4c0f-82a3-01aeba312f90','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceServerMetadataHook-uipgrimsggxy-CompactServices-ud6y5gaon4xc','state changed','OS::Heat::Value',NULL,259),(556,'35fc4bd3-141b-490b-89a1-c9c9de5daa26','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-DockerConfig-5kzu2ptym7dl','state changed','OS::Heat::Value',NULL,270),(557,'432608a1-7d87-47c8-9d21-cc49c9069eb6','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-FirewallRules-ljy7obapa52m','state changed','OS::Heat::Value',NULL,269),(558,'9410077c-116a-4582-8c8d-03cd856c6e6e','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PostUpgradeTasks-7ln6ftfykpnk','state changed','OS::Heat::Value',NULL,271),(559,'0123ffba-2a62-4652-8090-338178f1fa74','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-DockerConfig-5kzu2ptym7dl','state changed','OS::Heat::Value',NULL,270),(560,'b8836140-dee9-4a94-bef7-79ab897d2b45','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-KeystoneResourcesConfigs-pofnk7ttfqsm','state changed','OS::Heat::Value',NULL,260),(561,'24e54c45-ec1e-4123-86af-73fe2993bf68','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-DockerPuppetTasks-6axkofymg7qn','state changed','OS::Heat::Value',NULL,272),(562,'c94477ae-2763-4c0c-b8cd-4c4cd92df53e','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-DockerPuppetTasks-6axkofymg7qn','state changed','OS::Heat::Value',NULL,272),(563,'5770cff3-1912-4aad-8159-cf55122f377d','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ExternalUpdateTasks-4w2pbhxnxntz','state changed','OS::Heat::Value',NULL,265),(564,'e2cc2dcc-f17e-4e28-8309-fd3e56cc598b','67be4ab8-c3b8-43ec-974a-ea525386ea10','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-4nfkfwybokfg-ServiceServerMetadataHook-isp6brnvsiwm','67be4ab8-c3b8-43ec-974a-ea525386ea10','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(565,'566a63d6-43bc-4f3f-b01d-15d2ac9a8266','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PostUpgradeTasks-7ln6ftfykpnk','state changed','OS::Heat::Value',NULL,271),(566,'10625919-30c7-4f82-b17b-eaeb90411876','d7907784-4888-4c0f-82a3-01aeba312f90','2026-06-10 07:59:23',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-56k57ysbdzn5-ServiceServerMetadataHook-uipgrimsggxy','d7907784-4888-4c0f-82a3-01aeba312f90','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(567,'918ec29c-77fe-4f5a-94c6-29beb7cc8741','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-MonitoringSubscriptionsConfig-qsnp4ezgzlxm','state changed','OS::Heat::Value',NULL,274),(568,'8e570524-57bc-42e5-9f4b-65be8cfc54cf','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:23',NULL,'CREATE','IN_PROGRESS','0','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-0-fzxpit5qdqij','state changed','OS::TripleO::Services::BootParams',NULL,275),(569,'dff43cd3-fda3-4d01-a9af-1ad3bd52c8c4','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-MonitoringSubscriptionsConfig-qsnp4ezgzlxm','state changed','OS::Heat::Value',NULL,274),(570,'acaad94d-6122-4989-ba97-8254a0a08756','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-KollaConfig-vr3cg2etlauh','state changed','OS::Heat::Value',NULL,273),(571,'2778b64c-b479-4dae-89f7-6c66dff32d76','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-FirewallRules-ljy7obapa52m','state changed','OS::Heat::Value',NULL,269),(572,'9d9fe962-e949-4c00-9422-9f07f6e9ce9a','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceServerMetadataHook-kad2yiyuis62','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,276),(573,'99dc7d79-7834-492f-83ba-57856c3d4029','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ScaleTasks-7v5qbrgz3ug7','state changed','OS::Heat::Value',NULL,277),(574,'5b7ac0ce-361f-49dd-8658-87df1a421f14','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ExternalDeployTasks-txxg3wruo2xi','state changed','OS::Heat::Value',NULL,278),(575,'6d81846b-f9ac-4335-8a21-f93f84153434','61ccc313-1f92-49c5-899f-151b791f5a85','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-0-fzxpit5qdqij','61ccc313-1f92-49c5-899f-151b791f5a85','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(576,'be764a42-a867-42f0-91fe-082da5447fcc','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ScaleTasks-7v5qbrgz3ug7','state changed','OS::Heat::Value',NULL,277),(577,'dce9584b-0cd0-4f4e-a2a2-7c21f54898ca','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-UpdateTasks-3fgladf4pc6x','state changed','OS::Heat::Value',NULL,279),(578,'9cf44463-f34b-4528-b588-b0d560bf9dd3','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ExternalDeployTasks-txxg3wruo2xi','state changed','OS::Heat::Value',NULL,278),(579,'187e305b-2dc3-4ebb-be94-c4ec7a5d7ac3','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-KollaConfig-vr3cg2etlauh','state changed','OS::Heat::Value',NULL,273),(580,'73b384df-f213-4037-ac29-4d6eefdee332','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-UpdateTasks-3fgladf4pc6x','state changed','OS::Heat::Value',NULL,279),(581,'dea8c3bb-94ab-42a1-bde2-8f2c99c9aa26','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-GlobalConfigSettings-dmcfm5ayen3w','state changed','OS::Heat::Value',NULL,282),(582,'449af97f-4d66-4ebe-88d7-3a2abfdf234c','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PostUpdateTasks-qtknpyojwmpn','state changed','OS::Heat::Value',NULL,280),(583,'b5a150ae-d9db-43ae-bd96-ab0459b6504c','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceServerMetadataHook-qz5qlgfhsc7o','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,281),(584,'daec8a05-fd3b-4a09-a8c9-0b2840053ec8','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-GlobalConfigSettings-dmcfm5ayen3w','state changed','OS::Heat::Value',NULL,282),(585,'4310e7ca-6bbc-440a-8082-21d29e22d86a','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-UpgradeBatchTasks-zzongkqie7ts','state changed','OS::Heat::Value',NULL,283),(586,'2eb4ef68-563c-4228-a3f2-57f4dd9bb2b4','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-AnsibleGroupVars-wtud54qt5sfn','state changed','OS::Heat::Value',NULL,285),(587,'d71e8b9e-3330-4059-bf26-94f26f672001','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceServerMetadataHook-kad2yiyuis62','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(588,'7b49be7e-540d-408d-bd2d-55c65b0b59ee','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PostUpdateTasks-qtknpyojwmpn','state changed','OS::Heat::Value',NULL,280),(589,'597a7d3c-6d2b-404a-aaad-bde21d600ab8','61ccc313-1f92-49c5-899f-151b791f5a85','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-0-fzxpit5qdqij-RoleParametersValue-fgjrmvazb2w2','state changed','OS::Heat::Value',NULL,284),(590,'a4bbe52e-5777-488c-be33-e17514b040c6','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-FirewallFrontendRules-eos76omjydp2','state changed','OS::Heat::Value',NULL,286),(591,'8a34c5a1-de94-43b4-a477-04e5729a3c61','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-AnsibleGroupVars-wtud54qt5sfn','state changed','OS::Heat::Value',NULL,285),(592,'42b6e936-f99a-4eba-a9fd-b7add6f1b530','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-UpgradeBatchTasks-zzongkqie7ts','state changed','OS::Heat::Value',NULL,283),(593,'4631f136-259a-4750-a801-cb2f94b93afa','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-FirewallFrontendRules-eos76omjydp2','state changed','OS::Heat::Value',NULL,286),(594,'a70bf191-5dbb-4fc5-916b-097ee25063a0','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','d7907784-4888-4c0f-82a3-01aeba312f90','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,98),(595,'88998552-ca4c-4a70-8b6b-648b0468841f','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ExternalDeployTasks-hixllytexdjn','state changed','OS::Heat::Value',NULL,287),(596,'d13391f3-9966-4035-9d7f-45bd7eb332fc','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-HostFirewallTasks-32kczxxk3tzs','state changed','OS::Heat::Value',NULL,289),(597,'c094f33c-1068-4106-a1de-ce177b84f3a7','229b99c5-b170-4e76-bac6-3ac2867ffb5e','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceServerMetadataHook-qz5qlgfhsc7o','229b99c5-b170-4e76-bac6-3ac2867ffb5e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(598,'f21dcd4f-fad5-4f5e-b992-c9b67b702432','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-KeystoneResourcesConfigs-h2l7yag2n2dl','state changed','OS::Heat::Value',NULL,288),(599,'56f43231-0ec1-405f-8306-86473107dd9a','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceNames-7t6v4wcajeaq','state changed','OS::Heat::Value',NULL,290),(600,'cab83492-a64d-4ff6-92dd-b8483cd13883','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-HostFirewallTasks-32kczxxk3tzs','state changed','OS::Heat::Value',NULL,289),(601,'fcf2620c-8b3a-4368-bab2-4b8332926c0e','61ccc313-1f92-49c5-899f-151b791f5a85','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-0-fzxpit5qdqij-RoleParametersValue-fgjrmvazb2w2','state changed','OS::Heat::Value',NULL,284),(602,'f76e4a16-985e-4460-8d58-aa5be9daff25','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceNames-7t6v4wcajeaq','state changed','OS::Heat::Value',NULL,290),(603,'ccfa92db-744a-446b-bd89-f34960f4441e','83b349e1-364b-4be6-aee0-273246c0e1df','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-56k57ysbdzn5','83b349e1-364b-4be6-aee0-273246c0e1df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(604,'1cafaab7-70db-4a65-90a6-4a94ccfc7f28','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ExternalDeployTasks-hixllytexdjn','state changed','OS::Heat::Value',NULL,287),(605,'5f65a024-f03e-4676-b151-6a1450979931','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ExternalUpgradeTasks-yaapufgp66cg','state changed','OS::Heat::Value',NULL,291),(606,'f67ac1bf-1c3d-45a7-9d9c-bab687f25c77','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-MonitoringSubscriptionsConfig-mewfpprqtx7e','state changed','OS::Heat::Value',NULL,292),(607,'eb1fba40-5aa2-4d85-8fbe-88f6addf3277','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ExternalUpgradeTasks-yaapufgp66cg','state changed','OS::Heat::Value',NULL,291),(608,'8b7e0cb2-f357-4e13-92d8-a3cbf154c434','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ExternalUpgradeTasks-s2cpau2mw4eq','state changed','OS::Heat::Value',NULL,294),(609,'6e2e2f56-8364-4615-9ead-c73cd3180f29','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-MonitoringSubscriptionsConfig-mewfpprqtx7e','state changed','OS::Heat::Value',NULL,292),(610,'d54257e1-613f-42ba-aff1-f61d51f876b0','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-KeystoneResourcesConfigs-h2l7yag2n2dl','state changed','OS::Heat::Value',NULL,288),(611,'21df8847-c1a1-4617-9398-8fdaa939dd6b','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ExternalUpgradeTasks-s2cpau2mw4eq','state changed','OS::Heat::Value',NULL,294),(612,'d6bfafd2-b01b-4eb1-80a3-403555ed0dd4','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PuppetConfig-exms2um6tqm7','state changed','OS::Heat::Value',NULL,293),(613,'32bb0241-7730-4527-b61e-2a1c968d2dd0','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceServerMetadataHook-kad2yiyuis62-IncomingMetadataSettings-rvsw54uwq2v4','state changed','OS::Heat::Value',NULL,295),(614,'9ed11618-1e06-4fd2-807d-738cc4e8f50f','61ccc313-1f92-49c5-899f-151b791f5a85','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-0-fzxpit5qdqij','61ccc313-1f92-49c5-899f-151b791f5a85','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(615,'7305f74e-7062-45f7-bca0-e2bcf223e868','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceServerMetadataHook-kad2yiyuis62-IncomingMetadataSettings-rvsw54uwq2v4','state changed','OS::Heat::Value',NULL,295),(616,'67b05485-ce45-4e19-b3aa-255dd51583d9','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','CellControllerServiceChain','83b349e1-364b-4be6-aee0-273246c0e1df','state changed','OS::TripleO::CellControllerServices',NULL,77),(617,'0f62a208-57b9-4b48-8186-27ada5479c0d','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-FirewallRules-mhhh2lfztdik','state changed','OS::Heat::Value',NULL,298),(618,'b60e54d5-abdf-4a08-8e00-1f57be8ee59e','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceServerMetadataHook-kad2yiyuis62-CompactServices-c5jktdhrfvgz','state changed','OS::Heat::Value',NULL,299),(619,'23e8ee89-c0c7-4c34-9218-1672eb55564b','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-UpgradeTasks-4in5jqtmxn2s','state changed','OS::Heat::Value',NULL,297),(620,'cd1f2590-dc58-432f-9f54-cb08007bc306','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PuppetStepConfig-oibh35cyipp2','state changed','OS::Heat::Value',NULL,301),(621,'9901ae91-1ecd-47a4-8e3e-019d88d8620b','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceServerMetadataHook-kad2yiyuis62-IndividualServices-ihojjah5byvt','state changed','OS::Heat::Value',NULL,302),(622,'b15e879d-891c-4156-914d-6d7cd33879fd','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-UpgradeTasks-4in5jqtmxn2s','state changed','OS::Heat::Value',NULL,297),(623,'6851e369-8e28-453f-b179-e15d1c33aeb7','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','CompactServices','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceServerMetadataHook-kad2yiyuis62-CompactServices-c5jktdhrfvgz','state changed','OS::Heat::Value',NULL,299),(624,'023a89e2-16dc-4668-bcf0-babd479a8b06','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-FirewallRules-mhhh2lfztdik','state changed','OS::Heat::Value',NULL,298),(625,'f0e40b2c-5404-442e-bbbf-0044c2929d59','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceServerMetadataHook-kad2yiyuis62-IndividualServices-ihojjah5byvt','state changed','OS::Heat::Value',NULL,302),(626,'c3154cba-51ce-4e4a-9e59-de5bb1b0b8fd','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PuppetStepConfig-oibh35cyipp2','state changed','OS::Heat::Value',NULL,301),(627,'79ed7902-4750-4a86-8ef9-5b23f3e55328','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','bea127a4-acca-40d0-bdb4-3b1062a35646','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,188),(628,'1c561dc3-d88b-48d0-af9f-73610d8e2350','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceServerMetadataHook-kad2yiyuis62','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(629,'006325d2-7692-4316-9c88-81e27a3e4e71','968982ca-6aab-421a-b1ed-6efe22be173a','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-tpglbezicx2r','968982ca-6aab-421a-b1ed-6efe22be173a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(630,'2b3c96ce-7ac9-4210-bcca-df5f17613b3f','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PreUpgradeRollingTasks-ikqslgrd6vmh','state changed','OS::Heat::Value',NULL,296),(631,'2e33d143-4cee-4c43-8e60-6547798f4f21','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PuppetConfig-exms2um6tqm7','state changed','OS::Heat::Value',NULL,293),(632,'6f693478-9d24-406c-8888-e0070e26c5d5','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-DockerPuppetTasks-vctnhswtfihf','state changed','OS::Heat::Value',NULL,304),(633,'d8d0ab8c-7452-4f9d-a753-3ddee87b3fc3','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-DockerPuppetTasks-vctnhswtfihf','state changed','OS::Heat::Value',NULL,304),(634,'33497fa2-d6df-4972-992a-63acdd96ab9f','229b99c5-b170-4e76-bac6-3ac2867ffb5e','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceServerMetadataHook-qz5qlgfhsc7o-IncomingMetadataSettings-37vnvi5ayv3o','state changed','OS::Heat::Value',NULL,303),(635,'5eaa710e-1576-40dc-9bb1-4399ea0402b0','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','115cce35-eb28-482d-b98e-377426e98526','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,149),(636,'f902891a-4e70-4a2e-9174-93b65f7b26fe','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-HostPrepTasks-ofn4ay6bf7d6','state changed','OS::Heat::Value',NULL,307),(637,'a07cab23-eec5-46c6-899f-c8f9b5d5c5ef','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PreUpgradeRollingTasks-ikqslgrd6vmh','state changed','OS::Heat::Value',NULL,296),(638,'29836cb0-13ed-44f1-b9df-32adb50c70d7','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ExternalPostDeployTasks-u3jvvoux3s6c','state changed','OS::Heat::Value',NULL,305),(639,'df3f5eac-9000-4d1c-a566-cace9ca5110d','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-HostPrepTasks-ofn4ay6bf7d6','state changed','OS::Heat::Value',NULL,307),(640,'8815af99-0115-4aa7-816d-47ba114d4019','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PostUpgradeTasks-li7g2da6aoou','state changed','OS::Heat::Value',NULL,309),(641,'f1c8838c-2977-4cb8-9b65-1165edbb9623','229b99c5-b170-4e76-bac6-3ac2867ffb5e','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceServerMetadataHook-qz5qlgfhsc7o-IncomingMetadataSettings-37vnvi5ayv3o','state changed','OS::Heat::Value',NULL,303),(642,'98a5f3b2-7993-4805-919f-2d4ef724c655','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-PostUpgradeTasks-li7g2da6aoou','state changed','OS::Heat::Value',NULL,309),(643,'11545450-8ffb-4943-a3f5-2edbe4e05af0','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-HostFirewallTasks-dkugudfqlrdl','state changed','OS::Heat::Value',NULL,310),(644,'20cfb2da-970a-4f79-a1ce-5c67687b1333','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-IpaRegistrationTasks-clzn7mtqonmz','state changed','OS::Heat::Value',NULL,313),(645,'4af6b4ac-fff1-4cbe-8971-5e2f25358c82','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-ecmgjcuhokar','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(646,'2babc44a-f3f3-4151-bf85-7ed6aa072f3f','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceNames-fvceeg7c2vox','state changed','OS::Heat::Value',NULL,312),(647,'edc86cb2-a62a-4ea5-969a-07feb3ac8194','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-HostFirewallTasks-dkugudfqlrdl','state changed','OS::Heat::Value',NULL,310),(648,'a1ae1b3e-b11a-4bfc-a39c-007c7c3595fd','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-IpaRegistrationTasks-clzn7mtqonmz','state changed','OS::Heat::Value',NULL,313),(649,'38ae304b-c221-4ff6-8b8a-83ebea819349','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ExternalPostDeployTasks-u3jvvoux3s6c','state changed','OS::Heat::Value',NULL,305),(650,'39302c93-6432-4bd0-b26e-2236e3f44812','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-FirewallFrontendRules-lysnkpamjthi','state changed','OS::Heat::Value',NULL,316),(651,'af968613-8349-4e3d-a64d-e7abb978a86e','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PostUpdateTasks-cr4e7qm4nmco','state changed','OS::Heat::Value',NULL,317),(652,'036d19d1-b62f-4d47-a50b-4ef0948c0b16','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-DockerConfigScripts-vrewbbz46bvf','state changed','OS::Heat::Value',NULL,318),(653,'b348ec15-287b-4f35-b50a-d821fd62b199','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-FirewallFrontendRules-lysnkpamjthi','state changed','OS::Heat::Value',NULL,316),(654,'f7bb1317-64bc-442c-bf5c-a13f8e98a4ef','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-PostUpdateTasks-cr4e7qm4nmco','state changed','OS::Heat::Value',NULL,317),(655,'98103fcb-c49f-4d8a-aa5a-678aa7336b86','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-DockerConfigScripts-vrewbbz46bvf','state changed','OS::Heat::Value',NULL,318),(656,'9712fce2-cde6-48f6-9c9e-af46f4c99cf7','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceNames-fvceeg7c2vox','state changed','OS::Heat::Value',NULL,312),(657,'423198e9-de64-4bae-a56b-30a1bef890e0','229b99c5-b170-4e76-bac6-3ac2867ffb5e','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceServerMetadataHook-qz5qlgfhsc7o-IndividualServices-kfkn7pgkn4dp','state changed','OS::Heat::Value',NULL,323),(658,'28208d22-1101-4c46-835e-12fedf8f7bcb','229b99c5-b170-4e76-bac6-3ac2867ffb5e','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceServerMetadataHook-qz5qlgfhsc7o-CompactServices-a2qxazgikfos','state changed','OS::Heat::Value',NULL,320),(659,'63c1d341-83fe-44ed-99d9-a08ecac31d90','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceConfigSettings-hn3usurquxew','state changed','OS::Heat::Value',NULL,325),(660,'dba4420f-f2dd-49f8-a683-eab4472fcf20','229b99c5-b170-4e76-bac6-3ac2867ffb5e','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceServerMetadataHook-qz5qlgfhsc7o-IndividualServices-kfkn7pgkn4dp','state changed','OS::Heat::Value',NULL,323),(661,'d50e9a0f-efbb-4fe0-a586-b44f4dfee710','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:24',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks-ServiceConfigSettings-hn3usurquxew','state changed','OS::Heat::Value',NULL,325),(662,'cff66bfc-9a52-4ce6-b6f5-95d21510ba71','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','2','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-2-rmk4ixn3uwew','state changed','OS::TripleO::Services::Collectd',NULL,326),(663,'0a82a099-1687-48db-8e56-1c5348b25d50','229b99c5-b170-4e76-bac6-3ac2867ffb5e','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceServerMetadataHook-qz5qlgfhsc7o-CompactServices-a2qxazgikfos','state changed','OS::Heat::Value',NULL,320),(664,'3de070b9-e6bd-4af6-83cf-b385f88c2311','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','67be4ab8-c3b8-43ec-974a-ea525386ea10','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,180),(665,'c51063f0-6bd7-44a2-bc02-f7299f3feca8','229b99c5-b170-4e76-bac6-3ac2867ffb5e','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y-ServiceServerMetadataHook-qz5qlgfhsc7o','229b99c5-b170-4e76-bac6-3ac2867ffb5e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(666,'dadd0152-4def-4033-9656-62da312a9d41','11e12d7d-7494-4632-8634-8244a0908d4f','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-4nfkfwybokfg','11e12d7d-7494-4632-8634-8244a0908d4f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(667,'0e12b262-843c-45f2-bf13-70d6eacf6416','c47bb683-8b96-4313-ba1d-80d827192670','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-2-rmk4ixn3uwew','c47bb683-8b96-4313-ba1d-80d827192670','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(668,'5aa68326-7fff-4daa-a1b4-2244f83ce490','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','0','61ccc313-1f92-49c5-899f-151b791f5a85','state changed','OS::TripleO::Services::BootParams',NULL,275),(669,'2e4a4440-231f-45d4-9c2f-dce4e138011a','c47bb683-8b96-4313-ba1d-80d827192670','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-2-rmk4ixn3uwew-ContainersCommon-337l2r6sm2m6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(670,'096fd24c-eb52-4e75-81e4-f675991f0625','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','4566a7fe-720d-4ec5-8f76-4fc3aa25dacf','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,276),(671,'672f247b-9d9a-4853-b00f-a60312b231ee','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','ObjectStorageServiceChain','11e12d7d-7494-4632-8634-8244a0908d4f','state changed','OS::TripleO::ObjectStorageServices',NULL,75),(672,'89f7c6d7-3928-4684-9ecc-260bcf02b0e6','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','4','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,346),(673,'3e177b4a-8dc6-448c-998b-d9a38ccccb42','41f6d909-d4ee-4e2d-9781-3c923436f355','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-2-rmk4ixn3uwew-ContainersCommon-337l2r6sm2m6','41f6d909-d4ee-4e2d-9781-3c923436f355','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(674,'24403828-3726-4776-a991-8f6c7827bb77','ccc6fa04-9c15-45b6-b661-960f4e4de801','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-fwwaqc6pd3ks','ccc6fa04-9c15-45b6-b661-960f4e4de801','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(675,'a11bf422-87c2-4a22-86d0-2a8e8042f5a8','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','229b99c5-b170-4e76-bac6-3ac2867ffb5e','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,281),(676,'31a0c9fe-2abb-45ab-aba6-86e48f5016ad','41f6d909-d4ee-4e2d-9781-3c923436f355','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-2-rmk4ixn3uwew-ContainersCommon-337l2r6sm2m6','41f6d909-d4ee-4e2d-9781-3c923436f355','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(677,'494e812d-32bd-4e68-aaa4-bafa33e34674','a0ba3861-b4e7-4777-aaed-19041c4163de','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-3m6gdegdh43y','a0ba3861-b4e7-4777-aaed-19041c4163de','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(678,'8ea80225-697c-4d48-b681-93e82d21c252','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx','f7f6a884-6171-4851-be71-d7f5cd6edafd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(679,'7c3f5a45-e7d9-4b40-81b4-e70ce7334dee','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChain','a0ba3861-b4e7-4777-aaed-19041c4163de','state changed','OS::TripleO::CellControllerComputeServices',NULL,73),(680,'6da71666-7a6b-439f-b018-d60dda60af41','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','CephStorageServiceChain','968982ca-6aab-421a-b1ed-6efe22be173a','state changed','OS::TripleO::CephStorageServices',NULL,69),(681,'92336047-333a-4641-892b-cf398ab22fad','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-dbwj5rcay3kv','state changed','OS::Heat::Value',NULL,368),(682,'90055445-42b7-4387-91ff-fe626527004f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','NetworkerServiceChain','55b50f3a-b0ac-4b43-886f-2a08a63a69c8','state changed','OS::TripleO::NetworkerServices',NULL,70),(683,'19122992-7063-4c4e-b4fd-dcab0c86bbfb','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-dbwj5rcay3kv','state changed','OS::Heat::Value',NULL,368),(684,'74c7fa1b-e256-405b-95a9-a3295ea18e6e','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerServiceBase-dyy2lwxpvbyz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,371),(685,'25391979-0c90-4916-82df-500067f0beee','45d255d0-31ad-47af-a7ff-4ff3001005aa','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerServiceBase-dyy2lwxpvbyz','45d255d0-31ad-47af-a7ff-4ff3001005aa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(686,'7b73b8fe-9920-44e6-a56a-d11b2bcce808','45d255d0-31ad-47af-a7ff-4ff3001005aa','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerServiceBase-dyy2lwxpvbyz','45d255d0-31ad-47af-a7ff-4ff3001005aa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(687,'5d2d18d0-5ca0-49ea-b6c0-f3fe3f289702','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:25',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNames','overcloud-CellControllerServiceNames-pkbvpsqhc7lu','state changed','OS::Heat::Value',NULL,422),(688,'b7ed1e6d-1c6d-486b-ab14-0a4088f073c6','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:25',NULL,'CREATE','COMPLETE','CellControllerServiceNames','overcloud-CellControllerServiceNames-pkbvpsqhc7lu','state changed','OS::Heat::Value',NULL,422),(689,'e09f4272-fe8c-4e77-987f-008b336de96b','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','1','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-1-aug5xkkhaixg','state changed','OS::TripleO::Services::CACerts',NULL,441),(690,'5437e273-ab27-4b2c-a221-a325b1206223','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','CellController','overcloud-CellController-3o66mgibon36','state changed','OS::Heat::ResourceGroup',NULL,470),(691,'a8698a34-ba7e-45bc-8bfe-10d14fc1c0ce','e2c8d3cf-0511-4e64-962b-1a59a4073f68','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-1-aug5xkkhaixg','e2c8d3cf-0511-4e64-962b-1a59a4073f68','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(692,'f6be22fc-c7c3-4531-a958-7c3820c15ba6','e2c8d3cf-0511-4e64-962b-1a59a4073f68','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-1-aug5xkkhaixg','e2c8d3cf-0511-4e64-962b-1a59a4073f68','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(693,'e371ee38-4746-4152-a9ba-89d25c480796','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-ri7c7horyka3','state changed','OS::Heat::Value',NULL,486),(694,'3573265a-6c6b-4145-a2da-59fd66042dbf','61667547-3b0a-46f1-b5fd-9126cd018121','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','overcloud-CellController-3o66mgibon36','61667547-3b0a-46f1-b5fd-9126cd018121','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(695,'a51869f9-e13a-4039-91fa-2555c3375e00','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-ri7c7horyka3','state changed','OS::Heat::Value',NULL,486),(696,'0df013e1-01fd-4413-a4fe-fedb9befa0f3','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-urthajie3qrj','state changed','OS::Heat::Value',NULL,492),(697,'a378eeaa-041f-4fc3-b725-d1a79239c336','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-urthajie3qrj','state changed','OS::Heat::Value',NULL,492),(698,'5d40b417-f3aa-46b3-9852-cb97c4ff8111','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','BlockStorageServiceChain','ccc6fa04-9c15-45b6-b661-960f4e4de801','state changed','OS::TripleO::BlockStorageServices',NULL,72),(699,'476eed2d-cfb1-4d35-9dc1-c0e226bdf0b0','c47bb683-8b96-4313-ba1d-80d827192670','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-2-rmk4ixn3uwew-RoleParametersValue-6stdv35anff6','state changed','OS::Heat::Value',NULL,496),(700,'998ab2c6-a367-46d2-8f07-7a45d842e0a3','c47bb683-8b96-4313-ba1d-80d827192670','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-2-rmk4ixn3uwew-RoleParametersValue-6stdv35anff6','state changed','OS::Heat::Value',NULL,496),(701,'c4051a5b-6c03-4dec-ab42-88113cc61d26','61667547-3b0a-46f1-b5fd-9126cd018121','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','overcloud-CellController-3o66mgibon36','61667547-3b0a-46f1-b5fd-9126cd018121','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(702,'a776e780-ac2d-4061-90b6-cb83f307b2e1','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-e4hxhj2apu75','state changed','OS::Heat::Value',NULL,508),(703,'b2d80ca8-4515-4583-bc04-88cfe5135dc5','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-6lmvbutte6h2','state changed','OS::Heat::Value',NULL,510),(704,'e4a91f2a-0aa3-438a-ace3-7c43358e2c23','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-e4hxhj2apu75','state changed','OS::Heat::Value',NULL,508),(705,'17c05a97-3e04-4f55-b73f-9d9e2d8d22c6','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-6lmvbutte6h2','state changed','OS::Heat::Value',NULL,510),(706,'409dc92b-5ca7-4aa4-9032-ddf34cac22f8','c47bb683-8b96-4313-ba1d-80d827192670','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','ContainersCommon','41f6d909-d4ee-4e2d-9781-3c923436f355','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(707,'de8c915f-1dbd-45b2-9631-450f2d0cfa44','c47bb683-8b96-4313-ba1d-80d827192670','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-2-rmk4ixn3uwew','c47bb683-8b96-4313-ba1d-80d827192670','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(708,'7fab2584-e12f-4cdc-87ed-8dbf16434704','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNames','overcloud-CephStorageServiceNames-ljtvr5jtre5c','state changed','OS::Heat::Value',NULL,533),(709,'b1a60d92-b121-4b04-ae0f-d3d00771216a','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-RoleParametersValue-tm6gyfmomy4q','state changed','OS::Heat::Value',NULL,536),(710,'2e860278-a978-4b74-87da-6a4a366f1e00','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-RoleParametersValue-tm6gyfmomy4q','state changed','OS::Heat::Value',NULL,536),(711,'37163d0e-1faf-4013-9fcf-ad64bb6b7776','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-4ygmpsgrwnji','state changed','OS::Heat::Value',NULL,549),(712,'484096b4-8136-43d3-a060-81bbbb609f99','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','CephStorageServiceNames','overcloud-CephStorageServiceNames-ljtvr5jtre5c','state changed','OS::Heat::Value',NULL,533),(713,'6be9b5d4-cfdb-4aad-bcc7-5876d2a75d38','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-4ygmpsgrwnji','state changed','OS::Heat::Value',NULL,549),(714,'12d24881-d516-427a-89e0-dfcbca18c29b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-uvesqnbyek5v','state changed','OS::Heat::Value',NULL,550),(715,'4dba4be0-718f-4457-a7bf-0ce595e8fb6d','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','1','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-1-rdgaduvr5xok','state changed','OS::TripleO::Services::CACerts',NULL,552),(716,'ff79c6d2-9614-4195-889c-da08937de892','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-uvesqnbyek5v','state changed','OS::Heat::Value',NULL,550),(717,'adb4b233-2c76-4f5f-bc0d-848cfe454f87','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','CeilometerServiceBase','45d255d0-31ad-47af-a7ff-4ff3001005aa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,371),(718,'8bdd6a90-1a00-43a0-af9e-9341db612556','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','CellControllerCompute','overcloud-CellControllerCompute-lncwxsn72iz4','state changed','OS::Heat::ResourceGroup',NULL,556),(719,'2afc3eb4-2fdf-427f-b4bb-89bbbe2cbb78','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','CephStorage','overcloud-CephStorage-mklxdt4s7qbh','state changed','OS::Heat::ResourceGroup',NULL,557),(720,'4353da5f-ab22-4d68-b6cd-1afc3bbb023e','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-wsatzcuzjynr','state changed','OS::Heat::Value',NULL,558),(721,'e2547ad9-0bbb-4e78-87a6-2b2930ef18fb','00aee618-0007-43b2-8434-682c5cf94037','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-1-rdgaduvr5xok','00aee618-0007-43b2-8434-682c5cf94037','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(722,'a88d6836-d00b-4d8b-8117-0c1b36c78dd7','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:26',NULL,'CREATE','COMPLETE','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-wsatzcuzjynr','state changed','OS::Heat::Value',NULL,558),(723,'4e308759-4c87-45b1-94af-6ec29ac5aad6','300c5ce0-3a66-44dd-903a-940e49d984db','2026-06-10 07:59:26',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorage-mklxdt4s7qbh','300c5ce0-3a66-44dd-903a-940e49d984db','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(724,'8655ad2d-0d4b-4117-9218-c7eaeb697608','00aee618-0007-43b2-8434-682c5cf94037','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-1-rdgaduvr5xok','00aee618-0007-43b2-8434-682c5cf94037','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(725,'05e8bcc7-0dd0-4367-b626-022bb9b443f1','300c5ce0-3a66-44dd-903a-940e49d984db','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','overcloud-CephStorage-mklxdt4s7qbh','300c5ce0-3a66-44dd-903a-940e49d984db','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(726,'1c308cd5-42eb-4c5d-87e2-0c618fc0da81','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','3','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,559),(727,'21c64f17-54fd-4100-b42b-b40193ba52c3','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNames','overcloud-NetworkerServiceNames-ysrqiikhcy2s','state changed','OS::Heat::Value',NULL,560),(728,'a2ff3d42-ce7a-4c25-8b17-23cc0e2681d9','02d6318b-cd10-42c2-8c94-be9128f75e7e','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerCompute-lncwxsn72iz4','02d6318b-cd10-42c2-8c94-be9128f75e7e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(729,'d31c4770-31ca-409d-90c4-e326b266bac6','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','CephStorage','300c5ce0-3a66-44dd-903a-940e49d984db','state changed','OS::Heat::ResourceGroup',NULL,557),(730,'4485a429-371a-4583-bec7-46e861645aec','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','NetworkerServiceNames','overcloud-NetworkerServiceNames-ysrqiikhcy2s','state changed','OS::Heat::Value',NULL,560),(731,'4ead7da2-480a-4f8d-87e1-3696f728a191','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(732,'68e23c2c-12e8-40a1-a38e-d17eb3787558','02d6318b-cd10-42c2-8c94-be9128f75e7e','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','overcloud-CellControllerCompute-lncwxsn72iz4','02d6318b-cd10-42c2-8c94-be9128f75e7e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(733,'117f0fc0-d567-42a7-bb7e-54612bee9096','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','1','e2c8d3cf-0511-4e64-962b-1a59a4073f68','state changed','OS::TripleO::Services::CACerts',NULL,441),(734,'59f9bee4-fd9f-42e2-919c-8e6c26dd161b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-rjv5rqctr6qj','state changed','OS::Heat::Value',NULL,563),(735,'1c8ef45b-97dd-42c3-aeed-fcd3bb1f4670','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','2','c47bb683-8b96-4313-ba1d-80d827192670','state changed','OS::TripleO::Services::Collectd',NULL,326),(736,'18098962-729b-45ae-8387-16d3a30ef1e4','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','ObjectStorage','overcloud-ObjectStorage-wenxxqlwuzzr','state changed','OS::Heat::ResourceGroup',NULL,564),(737,'dc55e710-dbad-4dec-bea4-70d36a73e1c2','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd-ContainersCommon-hllk24ar4wxt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(738,'1a51910a-9200-460d-ad26-c06be3184d33','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-rjv5rqctr6qj','state changed','OS::Heat::Value',NULL,563),(739,'dc192c8d-db6c-433b-8d6d-49fc1468eb35','cc737e75-0b29-4e5b-b2a4-d751de6d2869','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd-ContainersCommon-hllk24ar4wxt','cc737e75-0b29-4e5b-b2a4-d751de6d2869','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(740,'458cde95-ad7a-42f5-a36b-591854bf67ca','ff8152d0-12ef-4091-acb3-9e06c16cbf3d','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorage-wenxxqlwuzzr','ff8152d0-12ef-4091-acb3-9e06c16cbf3d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(741,'cfc573d3-eda0-4eba-822f-78f5f1475979','cc737e75-0b29-4e5b-b2a4-d751de6d2869','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd-ContainersCommon-hllk24ar4wxt','cc737e75-0b29-4e5b-b2a4-d751de6d2869','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(742,'a4255393-6c28-4f27-bd2b-7ed272dca936','ff8152d0-12ef-4091-acb3-9e06c16cbf3d','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','overcloud-ObjectStorage-wenxxqlwuzzr','ff8152d0-12ef-4091-acb3-9e06c16cbf3d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(743,'5615cb9c-e926-4656-9bdf-5131567bc525','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','5','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-5-xso6gxjusxt5','state changed','OS::TripleO::Services::IpaClient',NULL,568),(744,'e31713b0-df66-4cfa-abe3-410e1bc570aa','bb4becce-bcc0-4ffc-b7f0-8ab31905930a','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-5-xso6gxjusxt5','bb4becce-bcc0-4ffc-b7f0-8ab31905930a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(745,'d004503f-c0ac-4f72-a232-f859efbf6eae','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','CellController','61667547-3b0a-46f1-b5fd-9126cd018121','state changed','OS::Heat::ResourceGroup',NULL,470),(746,'81fa1a55-a001-4632-962c-cb8d3bd24ada','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','Networker','overcloud-Networker-sgvfkcunrheg','state changed','OS::Heat::ResourceGroup',NULL,572),(747,'b6c449f6-f3eb-4855-bb62-b89fefdf73ec','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','BlockStorage','overcloud-BlockStorage-ejrivmg3dubf','state changed','OS::Heat::ResourceGroup',NULL,574),(748,'445d7203-0c6f-4853-90e7-0f09cef9ac57','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','CephStorageServers','overcloud-CephStorageServers-f3y65uhstp57','state changed','OS::Heat::Value',NULL,577),(749,'73e6ea0b-f4b2-46de-aef7-b449ba129543','bb4becce-bcc0-4ffc-b7f0-8ab31905930a','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-5-xso6gxjusxt5','bb4becce-bcc0-4ffc-b7f0-8ab31905930a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(750,'65636b3d-9148-4328-b218-eb4d63327d51','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-jdve4zxg4qox','state changed','OS::Heat::Value',NULL,576),(751,'0902b2c3-20f1-4cd2-9f38-f49d0e964b2f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','CephStorageServers','overcloud-CephStorageServers-f3y65uhstp57','state changed','OS::Heat::Value',NULL,577),(752,'e4b1cfc6-8311-47d9-bc7f-289658797ceb','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-jdve4zxg4qox','state changed','OS::Heat::Value',NULL,576),(753,'48f40732-670c-4464-a11f-723b926d63a6','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','6','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-6-6hk7qpxvy4ke','state changed','OS::TripleO::Services::Iscsid',NULL,578),(754,'00050e6d-9680-48f7-8798-245929f8798e','a9c737ad-2db9-4805-99f4-89b0cc294ff3','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorage-ejrivmg3dubf','a9c737ad-2db9-4805-99f4-89b0cc294ff3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(755,'e953099f-58df-46e7-9e95-83e95fdac115','9ba361b2-dda4-4546-bafa-353744058934','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-Networker-sgvfkcunrheg','9ba361b2-dda4-4546-bafa-353744058934','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(756,'0de77dd5-b4ee-4ad7-b34e-b7dae49801f7','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-ContainersCommon-adyxg4skcosm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(757,'5f5674cb-86cf-431d-90c2-79934d2d875c','9ba361b2-dda4-4546-bafa-353744058934','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','overcloud-Networker-sgvfkcunrheg','9ba361b2-dda4-4546-bafa-353744058934','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(758,'60cb106a-1f52-4364-b471-315660b86d82','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','CellControllerServers','overcloud-CellControllerServers-m2qs7fcpmya4','state changed','OS::Heat::Value',NULL,580),(759,'47bdc341-7a02-486c-b4b5-339252a7acc7','817f39eb-2845-4f8d-a7b8-7f800de23f31','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-6-6hk7qpxvy4ke','817f39eb-2845-4f8d-a7b8-7f800de23f31','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(760,'d958d4fd-fbf8-4baa-b5d0-02a352b6329b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','CellControllerServers','overcloud-CellControllerServers-m2qs7fcpmya4','state changed','OS::Heat::Value',NULL,580),(761,'80847c65-c887-4bf2-a878-f433ab9a0c8d','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','3','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,581),(762,'5d8530f0-a28e-43b3-a2f8-47b0aa28831f','a9c737ad-2db9-4805-99f4-89b0cc294ff3','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','overcloud-BlockStorage-ejrivmg3dubf','a9c737ad-2db9-4805-99f4-89b0cc294ff3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(763,'b74c3c39-57c7-4417-b7d8-37d5342ab513','db7df701-b3dd-4ccb-b0b6-968cc3377fad','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-ContainersCommon-adyxg4skcosm','db7df701-b3dd-4ccb-b0b6-968cc3377fad','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(764,'1728a6cd-b85a-48e9-a588-2b69f8105a6e','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','CephStorageIpListMap','overcloud-CephStorageIpListMap-g2xt2jer7wjw','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,583),(765,'7c24d07c-1c29-4af8-af31-839eab8eb91d','db7df701-b3dd-4ccb-b0b6-968cc3377fad','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-ContainersCommon-adyxg4skcosm','db7df701-b3dd-4ccb-b0b6-968cc3377fad','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(766,'731e9eb2-980c-4c05-bb92-22b702d09e06','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','Networker','9ba361b2-dda4-4546-bafa-353744058934','state changed','OS::Heat::ResourceGroup',NULL,572),(767,'d6f5d69f-8d87-4987-a4ee-6ebf44dc8a5a','817f39eb-2845-4f8d-a7b8-7f800de23f31','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-6-6hk7qpxvy4ke-RoleParametersValue-urqwmoufpjnd','state changed','OS::Heat::Value',NULL,585),(768,'de6110b8-2242-4537-a2e9-019b822d4b9a','3e578826-fb12-4344-87e8-7d4985802045','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageIpListMap-g2xt2jer7wjw','3e578826-fb12-4344-87e8-7d4985802045','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(769,'a8c6f0c7-9299-49ba-9f59-37d2a5ee49fe','134de2d6-a72f-4041-8075-fd768d4281fd','2026-06-10 07:59:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk','134de2d6-a72f-4041-8075-fd768d4281fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(770,'e2d4e403-6cae-4e25-8231-28d4bef28421','817f39eb-2845-4f8d-a7b8-7f800de23f31','2026-06-10 07:59:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-6-6hk7qpxvy4ke-RoleParametersValue-urqwmoufpjnd','state changed','OS::Heat::Value',NULL,585),(771,'c3cdd60f-47ee-40c7-920b-c55567a00c02','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-aketdkya7ry7','state changed','OS::Heat::Value',NULL,587),(772,'6b2e57ca-dcc0-4cca-acea-f8ab32a34a66','3e578826-fb12-4344-87e8-7d4985802045','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CephStorageIpListMap-g2xt2jer7wjw-EnabledServicesValue-eerpejrq6g6o','state changed','OS::Heat::Value',NULL,588),(773,'7e51b5e7-a963-4a47-9bee-da7e150408f4','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-aketdkya7ry7','state changed','OS::Heat::Value',NULL,587),(774,'4ab9d141-45b0-4b85-acd8-c7d5e3719ef2','3e578826-fb12-4344-87e8-7d4985802045','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CephStorageIpListMap-g2xt2jer7wjw-EnabledServicesValue-eerpejrq6g6o','state changed','OS::Heat::Value',NULL,588),(775,'4af5e9fd-f184-4f19-b2a4-d2a871c39524','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','1','00aee618-0007-43b2-8434-682c5cf94037','state changed','OS::TripleO::Services::CACerts',NULL,552),(776,'035f56ee-7da7-4301-93fc-8a72a87c36c6','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','CellControllerCompute','02d6318b-cd10-42c2-8c94-be9128f75e7e','state changed','OS::Heat::ResourceGroup',NULL,556),(777,'4e396202-50f1-4e9a-81f2-e02d6a835e2f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','NetworkerServers','overcloud-NetworkerServers-dmdrngdgnwbb','state changed','OS::Heat::Value',NULL,591),(778,'ddc4d63a-884b-4ca0-a1a2-21239dd2a6cb','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','NetworkerServers','overcloud-NetworkerServers-dmdrngdgnwbb','state changed','OS::Heat::Value',NULL,591),(779,'f522b931-e740-4faf-95a0-e555a9a69a17','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-gxza2nv6f3gx','state changed','OS::Heat::Value',NULL,590),(780,'cc7d8195-28a3-4b9f-a081-03129f818cec','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','CellControllerIpListMap','overcloud-CellControllerIpListMap-lwdu54jkqxqi','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,592),(781,'702949b9-d9df-4ce7-87c8-cf93ad52f260','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-gxza2nv6f3gx','state changed','OS::Heat::Value',NULL,590),(782,'1cca147e-785a-4967-9dd7-29306d9c4765','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd-RoleParametersValue-w3k3l3uzi3s3','state changed','OS::Heat::Value',NULL,596),(783,'52223d26-1e58-4ac0-b7d7-497495a0fc11','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd-RoleParametersValue-w3k3l3uzi3s3','state changed','OS::Heat::Value',NULL,596),(784,'ed800028-a4fe-4310-a6fc-7d8bdbea33c5','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','ContainersCommon','cc737e75-0b29-4e5b-b2a4-d751de6d2869','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(785,'8ec82bde-8a98-47f8-904e-791f9382c536','8fd5977e-fc36-4ae5-a819-03e0826c7532','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerIpListMap-lwdu54jkqxqi','8fd5977e-fc36-4ae5-a819-03e0826c7532','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(786,'8e832fad-327d-4098-adf0-b8de27e87edf','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServers','overcloud-CellControllerComputeServers-z2ptzirvvahy','state changed','OS::Heat::Value',NULL,597),(787,'8c7481d5-8c89-4d05-84e4-bb0095e8ef5a','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','ObjectStorage','ff8152d0-12ef-4091-acb3-9e06c16cbf3d','state changed','OS::Heat::ResourceGroup',NULL,564),(788,'8a7ca7b7-ced4-4bf7-8680-32ffc8117a96','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','5','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu','state changed','OS::TripleO::Services::CinderBackup',NULL,598),(789,'976a531e-b063-42cd-91e7-0ffd0c4d5f11','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','CellControllerComputeServers','overcloud-CellControllerComputeServers-z2ptzirvvahy','state changed','OS::Heat::Value',NULL,597),(790,'d0967103-b570-473a-a1fa-34a6a70c5ea2','134de2d6-a72f-4041-8075-fd768d4281fd','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk-CeilometerServiceBase-vqi5hxkyvtlr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,601),(791,'57c77bae-6e05-4dec-a4d2-971a99fb6b4f','8fd5977e-fc36-4ae5-a819-03e0826c7532','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerIpListMap-lwdu54jkqxqi-EnabledServicesValue-b4caydlks2lr','state changed','OS::Heat::Value',NULL,603),(792,'0f3c6f87-9663-43f3-ac76-7272b13422b9','8fd5977e-fc36-4ae5-a819-03e0826c7532','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerIpListMap-lwdu54jkqxqi-EnabledServicesValue-b4caydlks2lr','state changed','OS::Heat::Value',NULL,603),(793,'92bcc42b-2344-4558-a97b-a45c63660173','c983b213-b587-4f6a-84bc-235e3545d9da','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk-CeilometerServiceBase-vqi5hxkyvtlr','c983b213-b587-4f6a-84bc-235e3545d9da','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(794,'78664ada-3efa-428a-929f-4d5dba4026aa','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-utgjlh6a6hui','state changed','OS::Heat::Value',NULL,605),(795,'e95003d8-093d-478a-9b41-2514abea16b7','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','5','bb4becce-bcc0-4ffc-b7f0-8ab31905930a','state changed','OS::TripleO::Services::IpaClient',NULL,568),(796,'4df63ba7-be69-49c9-8b14-625501699188','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','NetworkerIpListMap','overcloud-NetworkerIpListMap-2w44izntwh4j','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,604),(797,'38d48b28-ce99-415f-b19c-2b91b31763b9','c983b213-b587-4f6a-84bc-235e3545d9da','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk-CeilometerServiceBase-vqi5hxkyvtlr','c983b213-b587-4f6a-84bc-235e3545d9da','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(798,'051acb02-dda5-41c0-878a-0472d22629bd','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu','1daff97e-3488-4459-ad96-1a5a190eb767','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(799,'3ec33420-64e2-4719-abf8-9f3003fad8a9','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','CeilometerAgentCentralBase','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,606),(800,'1382c25f-9679-4bd1-be73-26cab1c442d0','bc1ff4dd-8f99-401d-9fc5-87847531f706','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerIpListMap-2w44izntwh4j','bc1ff4dd-8f99-401d-9fc5-87847531f706','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(801,'5595f7fd-4786-4fd7-a07a-8513b2f5f435','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','BlockStorage','a9c737ad-2db9-4805-99f4-89b0cc294ff3','state changed','OS::Heat::ResourceGroup',NULL,574),(802,'90c65e02-e857-494c-91bc-622cca1cacba','55f99268-25d8-40f1-b1b8-90e0629cdb06','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac','55f99268-25d8-40f1-b1b8-90e0629cdb06','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(803,'badc17c6-0701-48b1-9892-dc1462dcd560','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-utgjlh6a6hui','state changed','OS::Heat::Value',NULL,605),(804,'a1a57546-747c-4c1a-ad1d-e5629fed59b0','bc1ff4dd-8f99-401d-9fc5-87847531f706','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-NetworkerIpListMap-2w44izntwh4j-NetIpMapValue-cx76ie6ejbtv','state changed','OS::Heat::Value',NULL,607),(805,'96ef13ec-006e-4219-9240-8bec9cb2217a','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','ContainersCommon','db7df701-b3dd-4ccb-b0b6-968cc3377fad','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(806,'92ac7ba9-be2a-41aa-b07d-584a7c5eed12','bc1ff4dd-8f99-401d-9fc5-87847531f706','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-NetworkerIpListMap-2w44izntwh4j-NetIpMapValue-cx76ie6ejbtv','state changed','OS::Heat::Value',NULL,607),(807,'f1821d9f-d50c-42cd-bed8-1a876f77619b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','ObjectStorageServers','overcloud-ObjectStorageServers-nveenwrgoolg','state changed','OS::Heat::Value',NULL,609),(808,'71ed2c8d-758e-4a40-9103-03d8296dcef2','817f39eb-2845-4f8d-a7b8-7f800de23f31','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-6-6hk7qpxvy4ke-ContainersCommon-whhrjpviydf4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(809,'5819baac-5bb3-4d07-b397-2dd9ca20ac21','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','ObjectStorageServers','overcloud-ObjectStorageServers-nveenwrgoolg','state changed','OS::Heat::Value',NULL,609),(810,'d5348c96-823e-4bd5-8def-4bfdc09eab7b','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','0','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-0-dynnefcpept2','state changed','OS::TripleO::Services::BootParams',NULL,608),(811,'aa94ae6f-57e8-4b76-8bcb-6f5b8d66d639','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-bm252xsfdjy4','state changed','OS::Heat::Value',NULL,612),(812,'0ba5c39a-6898-48d2-8978-fc426bbb6676','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:28',NULL,'CREATE','IN_PROGRESS','9','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-9-bnrprqmo527o','state changed','OS::TripleO::Services::MySQLClient',NULL,613),(813,'62cc262b-4e6b-4d9e-a2d1-ebb3e300038c','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:28',NULL,'CREATE','COMPLETE','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-bm252xsfdjy4','state changed','OS::Heat::Value',NULL,612),(814,'5b29b250-41fe-4149-8e69-1b5d76a38d85','575b4f7e-cd2a-4596-b67b-b6e7059fe72d','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-6-6hk7qpxvy4ke-ContainersCommon-whhrjpviydf4','575b4f7e-cd2a-4596-b67b-b6e7059fe72d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(815,'8f385b16-0c7f-4c82-a4a5-78f85fcd271e','575b4f7e-cd2a-4596-b67b-b6e7059fe72d','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-6-6hk7qpxvy4ke-ContainersCommon-whhrjpviydf4','575b4f7e-cd2a-4596-b67b-b6e7059fe72d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(816,'34f9f520-e1ad-455a-9fb8-aad9aa8785ef','b6f5fa1a-ca0e-4408-bebb-c24e8610e64c','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-9-bnrprqmo527o','b6f5fa1a-ca0e-4408-bebb-c24e8610e64c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(817,'78d2c8a9-6748-45b9-90a7-d0633ee1f483','3e578826-fb12-4344-87e8-7d4985802045','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CephStorageIpListMap-g2xt2jer7wjw-NetIpMapValue-cthmuu5leq5l','state changed','OS::Heat::Value',NULL,616),(818,'ab219a6b-11fd-4927-a917-f23112006806','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','CellControllerComputeIpListMap','overcloud-CellControllerComputeIpListMap-unubgxulgzih','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,618),(819,'39ad39bf-c456-4328-9f17-6cb85b0038e8','96e9ebf1-6b4d-4c60-b279-398b946f8d91','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-0-dynnefcpept2','96e9ebf1-6b4d-4c60-b279-398b946f8d91','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(820,'8f627bd0-f93f-4bd9-8118-0f1789cbc234','3e578826-fb12-4344-87e8-7d4985802045','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CephStorageIpListMap-g2xt2jer7wjw-NetIpMapValue-cthmuu5leq5l','state changed','OS::Heat::Value',NULL,616),(821,'a1c7e140-466a-4501-9a3b-67b227679e27','55f99268-25d8-40f1-b1b8-90e0629cdb06','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac-ContainersCommon-co5z3uqhwwha','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(822,'6d8330d0-53d7-4974-88d4-8d380ba61c97','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-ContainersCommon-wfmopbtx7f2i','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(823,'068a5fe0-b738-4324-a697-d3f52349e47e','3e578826-fb12-4344-87e8-7d4985802045','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-CephStorageIpListMap-g2xt2jer7wjw','3e578826-fb12-4344-87e8-7d4985802045','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(824,'ae085c1b-6c45-4523-aca2-95dc9e48d652','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','ObjectStorageIpListMap','overcloud-ObjectStorageIpListMap-dq7n2b6flxeh','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,619),(825,'7f28ce62-932a-479f-a271-c3a4a733184f','b6f5fa1a-ca0e-4408-bebb-c24e8610e64c','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-9-bnrprqmo527o','b6f5fa1a-ca0e-4408-bebb-c24e8610e64c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(826,'d3a3a678-19ba-4669-b67c-62bdae932947','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-sk2lnskvwu42','state changed','OS::Heat::Value',NULL,620),(827,'3992d155-7fff-4715-912c-481444eaf278','52d37caa-a0a7-401e-ae0b-edd227ab4245','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeIpListMap-unubgxulgzih','52d37caa-a0a7-401e-ae0b-edd227ab4245','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(828,'69433cfe-655a-4cc5-a980-5ffdb5664174','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-sk2lnskvwu42','state changed','OS::Heat::Value',NULL,620),(829,'ff94212a-884b-4a21-9cd3-e467b5881c01','d1c885a1-a75a-433e-9537-bd19ec79f29f','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-ContainersCommon-wfmopbtx7f2i','d1c885a1-a75a-433e-9537-bd19ec79f29f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(830,'f520a961-cc21-457b-9912-9862e5d9f21a','d1c885a1-a75a-433e-9537-bd19ec79f29f','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-ContainersCommon-wfmopbtx7f2i','d1c885a1-a75a-433e-9537-bd19ec79f29f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(831,'cfe62f9e-f13f-45b2-894f-8af6e12a8251','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd-CeilometerServiceBase-zcs2rcicaka6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,622),(832,'27160307-929e-40f9-8995-cd1f3ca9b9fd','96e9ebf1-6b4d-4c60-b279-398b946f8d91','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-0-dynnefcpept2-RoleParametersValue-a5hdtoeokeki','state changed','OS::Heat::Value',NULL,623),(833,'5327f84d-6f80-4b7f-8a0e-909b0e225ec2','3e662c9c-c9d5-41ec-885d-ca23ad8dbd1f','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac-ContainersCommon-co5z3uqhwwha','3e662c9c-c9d5-41ec-885d-ca23ad8dbd1f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(834,'d729a0a9-be78-41ab-8d99-e1db88400a2a','96e9ebf1-6b4d-4c60-b279-398b946f8d91','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-0-dynnefcpept2-RoleParametersValue-a5hdtoeokeki','state changed','OS::Heat::Value',NULL,623),(835,'7c265f61-5891-43f4-b6a0-adef95227420','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','BlockStorageServers','overcloud-BlockStorageServers-4d76prnxcy6n','state changed','OS::Heat::Value',NULL,625),(836,'cd24c06e-617d-480f-9093-823338364732','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','BlockStorageServers','overcloud-BlockStorageServers-4d76prnxcy6n','state changed','OS::Heat::Value',NULL,625),(837,'7bde7258-761e-4a6c-b0de-679288a1b526','bb9b8271-6aba-40eb-98e2-709be3687e8c','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd-CeilometerServiceBase-zcs2rcicaka6','bb9b8271-6aba-40eb-98e2-709be3687e8c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(838,'2784a041-9211-4952-a192-5a484cdc94d6','96e9ebf1-6b4d-4c60-b279-398b946f8d91','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-0-dynnefcpept2','96e9ebf1-6b4d-4c60-b279-398b946f8d91','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(839,'24c14afe-e824-4f97-af43-8d541298348a','77be398b-7e23-4193-9d16-f7b02a2f681a','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageIpListMap-dq7n2b6flxeh','77be398b-7e23-4193-9d16-f7b02a2f681a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(840,'0bf3fd63-56ad-4c7d-8b12-3232b48c0dfe','3e662c9c-c9d5-41ec-885d-ca23ad8dbd1f','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac-ContainersCommon-co5z3uqhwwha','3e662c9c-c9d5-41ec-885d-ca23ad8dbd1f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(841,'6f16671e-37bf-4faa-9365-b17546ffd3c9','bb9b8271-6aba-40eb-98e2-709be3687e8c','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd-CeilometerServiceBase-zcs2rcicaka6','bb9b8271-6aba-40eb-98e2-709be3687e8c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(842,'8afc522b-f3c5-443e-91ef-802617cab45f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','BlockStorageIpListMap','overcloud-BlockStorageIpListMap-3u2kiwzeaxz2','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,626),(843,'c45c13cf-abf1-46a6-a19a-f52cbbe3d22d','52d37caa-a0a7-401e-ae0b-edd227ab4245','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerComputeIpListMap-unubgxulgzih-NetIpMapValue-mrrktaddf6e7','state changed','OS::Heat::Value',NULL,627),(844,'a8880262-09e2-49a6-8d19-584b803fa2a4','52d37caa-a0a7-401e-ae0b-edd227ab4245','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerComputeIpListMap-unubgxulgzih-NetIpMapValue-mrrktaddf6e7','state changed','OS::Heat::Value',NULL,627),(845,'e9bf491e-ee04-44a3-94c8-84fff70dfbef','77be398b-7e23-4193-9d16-f7b02a2f681a','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ObjectStorageIpListMap-dq7n2b6flxeh-EnabledServicesValue-xf7oshanbw2p','state changed','OS::Heat::Value',NULL,629),(846,'f6d38995-7481-4f71-bcff-47e277f9c5ca','77be398b-7e23-4193-9d16-f7b02a2f681a','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ObjectStorageIpListMap-dq7n2b6flxeh-EnabledServicesValue-xf7oshanbw2p','state changed','OS::Heat::Value',NULL,629),(847,'f2d815f1-df86-4939-9dba-d45b928d68e7','9678db07-ac43-4084-a84a-fb914a1e62b1','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageIpListMap-3u2kiwzeaxz2','9678db07-ac43-4084-a84a-fb914a1e62b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(848,'90320a00-eba2-4b10-8c3c-f8623319df87','134de2d6-a72f-4041-8075-fd768d4281fd','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk-ContainersCommon-q3xkf6tpqal7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(849,'3c9a4e0e-71be-429a-aeac-431a1e1b1a3a','8fd5977e-fc36-4ae5-a819-03e0826c7532','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerIpListMap-lwdu54jkqxqi-NetIpMapValue-tig3kh3jmvlb','state changed','OS::Heat::Value',NULL,631),(850,'323d7d55-b7f7-4f6b-9e2e-11a3ee01ac54','9678db07-ac43-4084-a84a-fb914a1e62b1','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-BlockStorageIpListMap-3u2kiwzeaxz2-EnabledServicesValue-lkl4vhedahbs','state changed','OS::Heat::Value',NULL,630),(851,'fd7b77cb-d20f-4bfd-a214-dc62556d222c','8fd5977e-fc36-4ae5-a819-03e0826c7532','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerIpListMap-lwdu54jkqxqi-NetIpMapValue-tig3kh3jmvlb','state changed','OS::Heat::Value',NULL,631),(852,'75a725b9-e9b8-41d9-95f4-a0f0917bee7d','0e7816ce-3364-44b8-bcad-eefd8af37841','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk-ContainersCommon-q3xkf6tpqal7','0e7816ce-3364-44b8-bcad-eefd8af37841','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(853,'f0ec36a9-8ad8-4731-90d2-52ec18468e3a','9678db07-ac43-4084-a84a-fb914a1e62b1','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-BlockStorageIpListMap-3u2kiwzeaxz2-EnabledServicesValue-lkl4vhedahbs','state changed','OS::Heat::Value',NULL,630),(854,'cd55bc65-b445-4b45-86c3-1031a529b919','8fd5977e-fc36-4ae5-a819-03e0826c7532','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-CellControllerIpListMap-lwdu54jkqxqi','8fd5977e-fc36-4ae5-a819-03e0826c7532','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(855,'c3311bc0-22f2-42cc-8eb9-355472ae1d49','0e7816ce-3364-44b8-bcad-eefd8af37841','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk-ContainersCommon-q3xkf6tpqal7','0e7816ce-3364-44b8-bcad-eefd8af37841','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(856,'77b21c05-c692-4a00-9860-7f94d28ce16a','134de2d6-a72f-4041-8075-fd768d4281fd','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','CeilometerServiceBase','c983b213-b587-4f6a-84bc-235e3545d9da','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,601),(857,'a8798b92-ded5-4814-9cdf-74613985d85a','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','2','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,633),(858,'86f54bc5-c22c-4ede-b8f9-30e73cae6a2d','bc1ff4dd-8f99-401d-9fc5-87847531f706','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-NetworkerIpListMap-2w44izntwh4j-EnabledServicesValue-nvur2gvzkfp6','state changed','OS::Heat::Value',NULL,632),(859,'3f0c28d9-a1ea-4605-890c-02b5b580eca8','bc1ff4dd-8f99-401d-9fc5-87847531f706','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-NetworkerIpListMap-2w44izntwh4j-EnabledServicesValue-nvur2gvzkfp6','state changed','OS::Heat::Value',NULL,632),(860,'eee20ef1-09fc-42ea-81f6-f9520d2cf0e9','4233db81-2807-4f31-8c2f-621f47117561','2026-06-10 07:59:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx','4233db81-2807-4f31-8c2f-621f47117561','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(861,'67c63ab1-9d2b-4755-90a2-090038928667','bc1ff4dd-8f99-401d-9fc5-87847531f706','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','overcloud-NetworkerIpListMap-2w44izntwh4j','bc1ff4dd-8f99-401d-9fc5-87847531f706','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(862,'df79c41f-1d88-4178-8742-99eb285e55ae','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:29',NULL,'CREATE','COMPLETE','CephStorageIpListMap','3e578826-fb12-4344-87e8-7d4985802045','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,583),(863,'284a1c3f-f6c8-49e0-b1fd-0696185d4024','4233db81-2807-4f31-8c2f-621f47117561','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx-CeilometerServiceBase-twfsz6f6abxu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,634),(864,'5c490d93-6794-4c3e-b29a-e401b89738c6','817f39eb-2845-4f8d-a7b8-7f800de23f31','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','ContainersCommon','575b4f7e-cd2a-4596-b67b-b6e7059fe72d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(865,'ff85b16a-1fb7-4170-aeab-cdf61021c799','817f39eb-2845-4f8d-a7b8-7f800de23f31','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-6-6hk7qpxvy4ke','817f39eb-2845-4f8d-a7b8-7f800de23f31','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(866,'0dd72f83-dc93-4329-abcf-969945e2c3ee','5d11c0a9-ed80-4171-a5d5-d54061c3fe9b','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx-CeilometerServiceBase-twfsz6f6abxu','5d11c0a9-ed80-4171-a5d5-d54061c3fe9b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(867,'bb68fc0d-0d19-45eb-bfb0-132952c4979c','55f99268-25d8-40f1-b1b8-90e0629cdb06','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac-CeilometerServiceBase-ewwpvht6z6ch','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,635),(868,'cd4063f5-2bdf-423d-afc2-89d05707099f','5d11c0a9-ed80-4171-a5d5-d54061c3fe9b','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx-CeilometerServiceBase-twfsz6f6abxu','5d11c0a9-ed80-4171-a5d5-d54061c3fe9b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(869,'562b252a-7ade-477e-b3ed-592206f7ec31','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderCommon-7dxun5vklfql','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(870,'24e28ae9-8a73-4526-9920-f20e5ad5c898','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','0','96e9ebf1-6b4d-4c60-b279-398b946f8d91','state changed','OS::TripleO::Services::BootParams',NULL,608),(871,'1ba4fd82-0200-480d-b910-a4285e771815','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','9','b6f5fa1a-ca0e-4408-bebb-c24e8610e64c','state changed','OS::TripleO::Services::MySQLClient',NULL,613),(872,'a44f5ae5-176b-44d8-acd7-283b6f3e4f6b','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','ContainersCommon','d1c885a1-a75a-433e-9537-bd19ec79f29f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(873,'b939ddba-cb6d-451a-a893-234c17e5b566','e29834ea-4f3b-4ad5-8805-1e12288ddb06','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderCommon-7dxun5vklfql','e29834ea-4f3b-4ad5-8805-1e12288ddb06','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(874,'2fc09298-f437-40f5-8e9b-4efe5e13508a','b1170243-e91c-429d-9474-91142c97de07','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac-CeilometerServiceBase-ewwpvht6z6ch','b1170243-e91c-429d-9474-91142c97de07','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(875,'9e71ab9a-b9f7-48a9-bd76-5479b1716b4d','55f99268-25d8-40f1-b1b8-90e0629cdb06','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','ContainersCommon','3e662c9c-c9d5-41ec-885d-ca23ad8dbd1f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(876,'6431a861-087c-4b0d-a926-126d18cb2b49','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','CeilometerServiceBase','bb9b8271-6aba-40eb-98e2-709be3687e8c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,622),(877,'82a2f9ff-6c93-4054-9bb9-828868cb1167','52d37caa-a0a7-401e-ae0b-edd227ab4245','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-unubgxulgzih-EnabledServicesValue-mc6njz64f6zn','state changed','OS::Heat::Value',NULL,638),(878,'6efcbbcb-745e-46b2-b467-0121b99dd8c7','e29834ea-4f3b-4ad5-8805-1e12288ddb06','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderCommon-7dxun5vklfql-ContainersCommon-37izamtuzpd4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(879,'8a3a002e-de37-41a3-9250-0695d89ce720','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-3-yoqgc6xzwqvd','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(880,'5baf1b69-b018-4def-b4a5-480d08294d10','b1170243-e91c-429d-9474-91142c97de07','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac-CeilometerServiceBase-ewwpvht6z6ch','b1170243-e91c-429d-9474-91142c97de07','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(881,'157c4c44-ad9b-4fd4-af7d-3b60a3f48c26','77be398b-7e23-4193-9d16-f7b02a2f681a','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ObjectStorageIpListMap-dq7n2b6flxeh-NetIpMapValue-kg4piotlbwnd','state changed','OS::Heat::Value',NULL,640),(882,'793a5b5e-75cf-47e0-adfa-a8bfff8568ca','77be398b-7e23-4193-9d16-f7b02a2f681a','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ObjectStorageIpListMap-dq7n2b6flxeh-NetIpMapValue-kg4piotlbwnd','state changed','OS::Heat::Value',NULL,640),(883,'e8531cf6-3ab2-4d98-aa52-42f639d9720f','b823e43c-9bf8-4bf1-8716-79b1d2e5f9bf','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderCommon-7dxun5vklfql-ContainersCommon-37izamtuzpd4','b823e43c-9bf8-4bf1-8716-79b1d2e5f9bf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(884,'f1e80957-9914-4445-ad6f-83df7519482d','77be398b-7e23-4193-9d16-f7b02a2f681a','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageIpListMap-dq7n2b6flxeh','77be398b-7e23-4193-9d16-f7b02a2f681a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(885,'eb78d8d7-2c68-4f6b-8d9d-e29bf5c0141b','b823e43c-9bf8-4bf1-8716-79b1d2e5f9bf','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderCommon-7dxun5vklfql-ContainersCommon-37izamtuzpd4','b823e43c-9bf8-4bf1-8716-79b1d2e5f9bf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(886,'497635ac-da5c-469b-9b54-dd4a5faed17d','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','4','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7','state changed','OS::TripleO::Services::CinderApi',NULL,641),(887,'1e3b7d16-1b2a-4582-b334-2738c243e3a1','9678db07-ac43-4084-a84a-fb914a1e62b1','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-BlockStorageIpListMap-3u2kiwzeaxz2-NetIpMapValue-ibg2mghddgmh','state changed','OS::Heat::Value',NULL,643),(888,'f5eabc73-7c86-45f8-8b77-da7dd1b24add','134de2d6-a72f-4041-8075-fd768d4281fd','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk-RoleParametersValue-3ztgzok3yw74','state changed','OS::Heat::Value',NULL,642),(889,'88f2e708-8d07-4d31-a266-876a27d72a82','9678db07-ac43-4084-a84a-fb914a1e62b1','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-BlockStorageIpListMap-3u2kiwzeaxz2-NetIpMapValue-ibg2mghddgmh','state changed','OS::Heat::Value',NULL,643),(890,'8cfbeb25-9ba7-4ce6-bc9d-f84da6aba17d','9678db07-ac43-4084-a84a-fb914a1e62b1','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-BlockStorageIpListMap-3u2kiwzeaxz2','9678db07-ac43-4084-a84a-fb914a1e62b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(891,'839dcfd2-819b-4a9a-8068-11fd898e757d','52d37caa-a0a7-401e-ae0b-edd227ab4245','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-unubgxulgzih-EnabledServicesValue-mc6njz64f6zn','state changed','OS::Heat::Value',NULL,638),(892,'a1833f37-8e9d-406b-93b1-710bf50dd2ee','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','13','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,644),(893,'f0f82160-52dc-438d-ba09-3e4a46af7e59','134de2d6-a72f-4041-8075-fd768d4281fd','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk-RoleParametersValue-3ztgzok3yw74','state changed','OS::Heat::Value',NULL,642),(894,'7f8cf7da-a1df-4121-8f2d-c5576603a174','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','CellControllerIpListMap','8fd5977e-fc36-4ae5-a819-03e0826c7532','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,592),(895,'0d9c6b1b-728c-49fa-9a47-a2175eaa3565','52d37caa-a0a7-401e-ae0b-edd227ab4245','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeIpListMap-unubgxulgzih','52d37caa-a0a7-401e-ae0b-edd227ab4245','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(896,'6d9181c6-ed87-4c53-b7c5-c3ff1f09dbab','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(897,'1ab39223-37aa-420b-84f1-b08d819ee1f4','134de2d6-a72f-4041-8075-fd768d4281fd','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','ContainersCommon','0e7816ce-3364-44b8-bcad-eefd8af37841','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(898,'45cc3060-ea25-46f8-8961-9e773a211b2f','134de2d6-a72f-4041-8075-fd768d4281fd','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-3-h7kucr75mqgk','134de2d6-a72f-4041-8075-fd768d4281fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(899,'1db9e6d2-0cfe-4640-83f6-6ab2b45e61d1','641c560b-f31b-48a8-b7c7-689bef1bd798','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz','641c560b-f31b-48a8-b7c7-689bef1bd798','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(900,'0e9bc88a-8e4b-4c68-9a28-913e08908787','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','NetworkerIpListMap','bc1ff4dd-8f99-401d-9fc5-87847531f706','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,604),(901,'4e71ce84-c8d9-4fb3-b81c-ca63c6228601','641c560b-f31b-48a8-b7c7-689bef1bd798','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz-ContainersCommon-vcxsc6ibgpmn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(902,'1eb15507-b4d8-4d85-a62e-82cfd0b6524d','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-ContainersCommon-t7jbl2bg33lv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(903,'f79841a6-36c8-485a-81e3-e7fd87007cb9','66b227b1-ff51-4a57-99e5-1e0eff30f408','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz-ContainersCommon-vcxsc6ibgpmn','66b227b1-ff51-4a57-99e5-1e0eff30f408','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(904,'0567d758-91cc-49e6-afb6-dfcb44394730','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','6','817f39eb-2845-4f8d-a7b8-7f800de23f31','state changed','OS::TripleO::Services::Iscsid',NULL,578),(905,'56e89e26-d4f1-475f-be92-b0e6fe955bb0','66b227b1-ff51-4a57-99e5-1e0eff30f408','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz-ContainersCommon-vcxsc6ibgpmn','66b227b1-ff51-4a57-99e5-1e0eff30f408','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(906,'c9d22be9-5afb-4c17-9015-3e69f45af3f0','fafd52b3-97c3-4e49-9174-d2076ba201d3','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-ContainersCommon-t7jbl2bg33lv','fafd52b3-97c3-4e49-9174-d2076ba201d3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(907,'6710c157-4943-4c82-9f8a-d0b7c06f7889','641c560b-f31b-48a8-b7c7-689bef1bd798','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','ContainersCommon','66b227b1-ff51-4a57-99e5-1e0eff30f408','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(908,'e1fb3af7-e12f-4601-91d6-4383a873f22a','fafd52b3-97c3-4e49-9174-d2076ba201d3','2026-06-10 07:59:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-ContainersCommon-t7jbl2bg33lv','fafd52b3-97c3-4e49-9174-d2076ba201d3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(909,'2d0b08c9-3882-494b-9869-f13caf181d70','4233db81-2807-4f31-8c2f-621f47117561','2026-06-10 07:59:30',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx-ContainersCommon-u7kblskmbkui','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(910,'ed1b60b8-edeb-4753-a1f7-7923d297aca6','69c45575-0cb2-46c0-8b0f-1d67e2f9b037','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx-ContainersCommon-u7kblskmbkui','69c45575-0cb2-46c0-8b0f-1d67e2f9b037','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(911,'3ba308a4-ab33-4565-947d-000821937f52','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','3','134de2d6-a72f-4041-8075-fd768d4281fd','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,581),(912,'14070c5b-1103-4051-890c-706ac1425026','69c45575-0cb2-46c0-8b0f-1d67e2f9b037','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx-ContainersCommon-u7kblskmbkui','69c45575-0cb2-46c0-8b0f-1d67e2f9b037','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(913,'e04416f2-9d6e-4e0b-a921-5860e23069d5','55f99268-25d8-40f1-b1b8-90e0629cdb06','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac-RoleParametersValue-pgmyq6ympzjv','state changed','OS::Heat::Value',NULL,648),(914,'e0c31950-e861-452d-b752-9d9152c9fe8e','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','10','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc','state changed','OS::TripleO::Services::NovaCompute',NULL,649),(915,'df9d6063-315d-4b6d-9574-8aa55b5b83da','55f99268-25d8-40f1-b1b8-90e0629cdb06','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac-RoleParametersValue-pgmyq6ympzjv','state changed','OS::Heat::Value',NULL,648),(916,'841670d1-63a6-4f11-a296-240632c77b6c','4233db81-2807-4f31-8c2f-621f47117561','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','CeilometerServiceBase','5d11c0a9-ed80-4171-a5d5-d54061c3fe9b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,634),(917,'225b010d-af12-4486-83ec-a330c483d905','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','3','8cd8a3c6-cec8-4e7b-a217-866fd38fbd49','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,559),(918,'71c6b2b5-7a53-4941-b2ef-bf15f1b2fa80','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','CinderBackupBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,651),(919,'fe0be151-5d6d-4b2e-830e-c4c841b50b62','4233db81-2807-4f31-8c2f-621f47117561','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','ContainersCommon','69c45575-0cb2-46c0-8b0f-1d67e2f9b037','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(920,'f4c79703-4b80-4c9f-9874-71ab01387c7a','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','CellControllerComputeIpListMap','52d37caa-a0a7-401e-ae0b-edd227ab4245','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,618),(921,'76fb86ef-038e-41c1-b2e8-87cc8415a894','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','ObjectStorageIpListMap','77be398b-7e23-4193-9d16-f7b02a2f681a','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,619),(922,'67f408ac-817f-4111-9a08-fa0e605f2d81','55f99268-25d8-40f1-b1b8-90e0629cdb06','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','CeilometerServiceBase','b1170243-e91c-429d-9474-91142c97de07','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,635),(923,'c3df51ad-8156-4b57-bac9-4ccae376997e','55f99268-25d8-40f1-b1b8-90e0629cdb06','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx-CeilometerAgentCentralBase-67o7tlp4dsac','55f99268-25d8-40f1-b1b8-90e0629cdb06','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(924,'8a810efa-2fe6-46dd-8988-cb20659a0e43','e29834ea-4f3b-4ad5-8805-1e12288ddb06','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','ContainersCommon','b823e43c-9bf8-4bf1-8716-79b1d2e5f9bf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(925,'12d3fc82-312b-4723-8fa9-5b8208669a95','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc','5ef675f6-8051-4724-a69d-18427f7316a9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(926,'2aeb4226-cb34-4484-b7b7-d6f1359ab655','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','BlockStorageIpListMap','9678db07-ac43-4084-a84a-fb914a1e62b1','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,626),(927,'a7b4b5e1-6d6d-4566-a05d-000a8e6766d0','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','7','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh','state changed','OS::TripleO::Services::CinderVolume',NULL,658),(928,'604b51ff-6963-48c7-8e3e-fc2d2d85d577','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(929,'fe5b7dfb-baf0-41fe-b3e1-cdbddd571b87','e29834ea-4f3b-4ad5-8805-1e12288ddb06','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderCommon-7dxun5vklfql-CinderNVMeOF-4ati7evyxerr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(930,'dbd419eb-4d3e-4e57-9bd1-b3cae83f588e','e2cafb12-6a84-4867-8a10-343c1f776c4f','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderCommon-7dxun5vklfql-CinderNVMeOF-4ati7evyxerr','e2cafb12-6a84-4867-8a10-343c1f776c4f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(931,'525b57b1-3d90-4025-9418-525d961cd45f','e2cafb12-6a84-4867-8a10-343c1f776c4f','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderCommon-7dxun5vklfql-CinderNVMeOF-4ati7evyxerr','e2cafb12-6a84-4867-8a10-343c1f776c4f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(932,'886696c6-14be-4c4a-b263-e492b791b7e6','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','7','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-7-lo7nx5wpyp7h','state changed','OS::TripleO::Services::Kernel',NULL,660),(933,'66b235ee-ee59-421a-845c-8e8d72d5567b','3b7164b7-04cf-4200-81b4-4578738290ea','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-7-lo7nx5wpyp7h','3b7164b7-04cf-4200-81b4-4578738290ea','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(934,'f1ae7ddd-aeb4-42a5-985a-ad8a1b9ac9ef','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(935,'9fb428b1-76c6-4a83-9a76-3656bb3ae31f','3b7164b7-04cf-4200-81b4-4578738290ea','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-7-lo7nx5wpyp7h-RoleParametersValue-arudhtnpbqri','state changed','OS::Heat::Value',NULL,661),(936,'2cdc18f5-1cad-4356-9c6e-a2f805419e8b','3b7164b7-04cf-4200-81b4-4578738290ea','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-7-lo7nx5wpyp7h-RoleParametersValue-arudhtnpbqri','state changed','OS::Heat::Value',NULL,661),(937,'b1ac2bf2-5251-4b66-b3fd-1c91f7003000','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','CeilometerAgentCentralBase','55f99268-25d8-40f1-b1b8-90e0629cdb06','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,606),(938,'9378b202-858e-40dd-a96f-5fca30193308','3b7164b7-04cf-4200-81b4-4578738290ea','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-7-lo7nx5wpyp7h','3b7164b7-04cf-4200-81b4-4578738290ea','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(939,'38202fdd-7218-4cb5-8463-007c9deb1d45','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderCommon-wxos4jjab57z','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(940,'d66aeb5e-6efd-480b-b8f4-452fac5d38fb','f7f6a884-6171-4851-be71-d7f5cd6edafd','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-4-llyvn5r23uhx','f7f6a884-6171-4851-be71-d7f5cd6edafd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(941,'f99af791-30e0-46e6-9a47-2efc518427a8','641c560b-f31b-48a8-b7c7-689bef1bd798','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','SshdBase','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz-SshdBase-zjmxm3jsb7pq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,662),(942,'8a83c1c9-d24a-4e2d-ba69-1a19894e6f59','d1a93281-15f7-4218-b774-e64f1edcbeb9','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderCommon-wxos4jjab57z','d1a93281-15f7-4218-b774-e64f1edcbeb9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(943,'4ff58284-74aa-4317-8aa2-237ce2aa962c','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:31',NULL,'CREATE','COMPLETE','ContainersCommon','fafd52b3-97c3-4e49-9174-d2076ba201d3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(944,'facb8ea2-4270-4a98-90d6-b134fd6dd5e2','4233db81-2807-4f31-8c2f-621f47117561','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx-RoleParametersValue-lrk7hmhfhiau','state changed','OS::Heat::Value',NULL,663),(945,'c7db35a0-c181-4c19-8c7d-4bfb537deaa6','5fbdbd31-0407-4e07-9eba-351d6271e8ba','2026-06-10 07:59:31',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz-SshdBase-zjmxm3jsb7pq','5fbdbd31-0407-4e07-9eba-351d6271e8ba','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(946,'a5a598d0-d718-4756-b5ee-ae937756002e','4233db81-2807-4f31-8c2f-621f47117561','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx-RoleParametersValue-lrk7hmhfhiau','state changed','OS::Heat::Value',NULL,663),(947,'50b7119f-ca2e-4fa2-9b63-7b80ff941b2b','5fbdbd31-0407-4e07-9eba-351d6271e8ba','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz-SshdBase-zjmxm3jsb7pq','5fbdbd31-0407-4e07-9eba-351d6271e8ba','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(948,'3ac3b884-fa00-4ae6-92c7-0ec903469e03','4233db81-2807-4f31-8c2f-621f47117561','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-2-jilclfcoagdx','4233db81-2807-4f31-8c2f-621f47117561','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(949,'37b78c58-0b0d-4ca3-8700-ae2bc0f46439','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-MySQLClient-tj7lyshcu6di','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(950,'7ef7b3c4-eb63-4b8d-8eb2-8d84e5fbb7b1','d1a93281-15f7-4218-b774-e64f1edcbeb9','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderCommon-wxos4jjab57z-ContainersCommon-kr2tvuycogue','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(951,'c32d6c87-7157-4fa8-9378-64dc8e53ad57','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','NovaComputeCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaComputeCommon-qisu5yivrnxv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,664),(952,'7d81cc23-c682-43ad-9219-72e28546f0d9','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-MySQLClient-qizuy5gxjfzr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(953,'35c6d352-5632-47c8-9a48-0829bfaac085','43774025-38b7-46a3-9f3f-ebeb62099500','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-MySQLClient-tj7lyshcu6di','43774025-38b7-46a3-9f3f-ebeb62099500','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(954,'0d9f3b48-6d3a-4665-9103-0eaf57430640','10ee7c73-508a-4023-9cd3-47e77e180bb6','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderCommon-wxos4jjab57z-ContainersCommon-kr2tvuycogue','10ee7c73-508a-4023-9cd3-47e77e180bb6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(955,'8d0cc583-fa96-4e18-ab99-da5be99cd6ab','10ee7c73-508a-4023-9cd3-47e77e180bb6','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderCommon-wxos4jjab57z-ContainersCommon-kr2tvuycogue','10ee7c73-508a-4023-9cd3-47e77e180bb6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(956,'72234854-7d59-480a-86d1-b89d87a8e997','9b16824f-5eac-4eda-bfc6-5129fefd339f','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaComputeCommon-qisu5yivrnxv','9b16824f-5eac-4eda-bfc6-5129fefd339f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(957,'b27f2d2e-cf5b-4c1b-b9d9-46fb9268e991','43774025-38b7-46a3-9f3f-ebeb62099500','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-MySQLClient-tj7lyshcu6di','43774025-38b7-46a3-9f3f-ebeb62099500','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(958,'84d4e710-14d2-4944-8f47-9f23f092e6be','9b16824f-5eac-4eda-bfc6-5129fefd339f','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaComputeCommon-qisu5yivrnxv','9b16824f-5eac-4eda-bfc6-5129fefd339f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(959,'21ffafcf-6d15-45e1-a6c7-e2b6dfd557bc','d50bad18-2f4f-4cc8-9828-5b8050f84bf5','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-MySQLClient-qizuy5gxjfzr','d50bad18-2f4f-4cc8-9828-5b8050f84bf5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(960,'f8d7d57e-18db-4afe-b843-29f9ed4f64a3','d50bad18-2f4f-4cc8-9828-5b8050f84bf5','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-MySQLClient-qizuy5gxjfzr','d50bad18-2f4f-4cc8-9828-5b8050f84bf5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(961,'595e156f-c993-4994-b234-618adc7ef697','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-RoleParametersValue-hkt6apquhp7n','state changed','OS::Heat::Value',NULL,665),(962,'b3ea5630-dce6-4019-a098-8c616da8b3e5','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-RoleParametersValue-hkt6apquhp7n','state changed','OS::Heat::Value',NULL,665),(963,'644857f7-4685-4449-8cf1-fded6b70263f','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','4','f7f6a884-6171-4851-be71-d7f5cd6edafd','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,346),(964,'6ba229f2-7065-4a23-93cc-eda560ef7c3b','e29834ea-4f3b-4ad5-8805-1e12288ddb06','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','CinderNVMeOF','e2cafb12-6a84-4867-8a10-343c1f776c4f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(965,'e3bb77e3-bcc3-4fc0-9794-e297348295ec','e29834ea-4f3b-4ad5-8805-1e12288ddb06','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderCommon-7dxun5vklfql','e29834ea-4f3b-4ad5-8805-1e12288ddb06','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(966,'35a2d570-1cb5-4cc5-b6ff-1e562bbe8a95','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','7','3b7164b7-04cf-4200-81b4-4578738290ea','state changed','OS::TripleO::Services::Kernel',NULL,660),(967,'d308fef2-6317-4ec0-8ab0-def071c69b00','641c560b-f31b-48a8-b7c7-689bef1bd798','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz-RoleParametersValue-ekcvbfbvehik','state changed','OS::Heat::Value',NULL,671),(968,'355b4ffb-434c-46f7-8cbb-bfb07c1f5e8f','641c560b-f31b-48a8-b7c7-689bef1bd798','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz-RoleParametersValue-ekcvbfbvehik','state changed','OS::Heat::Value',NULL,671),(969,'d73b0b35-0b39-43ef-80de-818befa3c197','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-MySQLClient-lm624qlsilz7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(970,'d550d1ed-583c-47c0-bc3d-98137584e524','6b0a4e3a-fbf9-4f76-ba10-7808aac6d512','2026-06-10 07:59:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-MySQLClient-lm624qlsilz7','6b0a4e3a-fbf9-4f76-ba10-7808aac6d512','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(971,'01c543a8-d72d-4713-b175-e2659dfef522','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','2','4233db81-2807-4f31-8c2f-621f47117561','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,633),(972,'e3a3b551-eb3d-48a3-8c50-c77170e73cdd','6b0a4e3a-fbf9-4f76-ba10-7808aac6d512','2026-06-10 07:59:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-MySQLClient-lm624qlsilz7','6b0a4e3a-fbf9-4f76-ba10-7808aac6d512','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(973,'7eb2b1be-e82d-4364-be9a-9f24ba1a49d1','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','8','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-8-i4okyh5czkdb','state changed','OS::TripleO::Services::MetricsQdr',NULL,673),(974,'e598c0f0-8335-4d14-8b2d-fc8d2d48e23e','641c560b-f31b-48a8-b7c7-689bef1bd798','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','SshdBase','5fbdbd31-0407-4e07-9eba-351d6271e8ba','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,662),(975,'c892b3c8-7550-40b6-8f51-54a165985d55','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-CinderNVMeOF-4iv5vluuwro2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(976,'a8feb0c0-bce0-4dd6-a606-2f0518fa6ff6','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-ContainersCommon-p654on3eikq5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(977,'4b12ca40-3ac3-48eb-ad7c-05d34c24c787','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderCommon-plmid4ydusjx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(978,'ff869940-d842-441c-919b-2bf831e2a6ac','641c560b-f31b-48a8-b7c7-689bef1bd798','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-13-ohii23lhr2fz','641c560b-f31b-48a8-b7c7-689bef1bd798','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(979,'57fc6d2e-dbb4-4108-aa83-0965368dde8e','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','11','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh','state changed','OS::TripleO::Services::NovaLibvirt',NULL,676),(980,'d8732a62-b67d-495a-bd0f-ef45a8497959','34f0c019-db70-4654-888a-9f63e1bc298b','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-CinderNVMeOF-4iv5vluuwro2','34f0c019-db70-4654-888a-9f63e1bc298b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(981,'a099a1c3-7c3f-4118-8a19-a70c5ab4e42c','34f0c019-db70-4654-888a-9f63e1bc298b','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-CinderNVMeOF-4iv5vluuwro2','34f0c019-db70-4654-888a-9f63e1bc298b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(982,'42329634-492b-4965-9ccf-afb11ef6a131','d1a93281-15f7-4218-b774-e64f1edcbeb9','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderCommon-wxos4jjab57z-CinderNVMeOF-wjojozf6yz4d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(983,'cafab280-e83b-4ade-8baa-444d00b2f703','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','NovaComputeCommon','9b16824f-5eac-4eda-bfc6-5129fefd339f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,664),(984,'85933ad4-69fa-4894-ac8b-bc6c409c73ed','d1a93281-15f7-4218-b774-e64f1edcbeb9','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','ContainersCommon','10ee7c73-508a-4023-9cd3-47e77e180bb6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(985,'3062a203-1f18-46ec-832a-e46194995228','82b4d6ff-2141-4c0d-8a47-1854d1f0a8fb','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-8-i4okyh5czkdb','82b4d6ff-2141-4c0d-8a47-1854d1f0a8fb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(986,'2e21ab3b-d4f5-45c0-a20f-210966b83938','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','MySQLClient','d50bad18-2f4f-4cc8-9828-5b8050f84bf5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(987,'cb31d001-ff3e-42d8-8449-b08a4596d1d4','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','MySQLClient','43774025-38b7-46a3-9f3f-ebeb62099500','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(988,'7ec37422-05b4-4636-addc-2b3281a67bec','b6d7af40-9221-43eb-a0ad-c533fc172abd','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-ContainersCommon-p654on3eikq5','b6d7af40-9221-43eb-a0ad-c533fc172abd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(989,'9293797c-0022-4c33-aa8e-82cd6321b17f','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-MySQLClient-jajbxivqx7ms','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(990,'a862409e-e74a-488d-bc30-6438a317f615','b6d7af40-9221-43eb-a0ad-c533fc172abd','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-ContainersCommon-p654on3eikq5','b6d7af40-9221-43eb-a0ad-c533fc172abd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(991,'a309776d-6169-4559-bd33-e177769ba92a','3fd369ad-fbdf-477f-ba93-bbc90cb06f13','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderCommon-plmid4ydusjx','3fd369ad-fbdf-477f-ba93-bbc90cb06f13','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(992,'1b234fe1-7d6f-49f8-8695-1c845f3dff4e','bc407e01-7746-4b46-a701-f13ccaf9cf76','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderCommon-wxos4jjab57z-CinderNVMeOF-wjojozf6yz4d','bc407e01-7746-4b46-a701-f13ccaf9cf76','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(993,'f751a203-8d61-43a0-b4d2-22b35d39c00d','bc407e01-7746-4b46-a701-f13ccaf9cf76','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderCommon-wxos4jjab57z-CinderNVMeOF-wjojozf6yz4d','bc407e01-7746-4b46-a701-f13ccaf9cf76','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(994,'40619796-264f-424e-8410-1500c4d6229a','744506b6-911a-49eb-b173-dc414fb5ed40','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-MySQLClient-jajbxivqx7ms','744506b6-911a-49eb-b173-dc414fb5ed40','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(995,'aeaf25e0-cc11-44ef-a2a6-b885ad13781e','744506b6-911a-49eb-b173-dc414fb5ed40','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-MySQLClient-jajbxivqx7ms','744506b6-911a-49eb-b173-dc414fb5ed40','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(996,'92784375-11a1-4a4e-9636-61b279bdfff7','82b4d6ff-2141-4c0d-8a47-1854d1f0a8fb','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-8-i4okyh5czkdb-RoleParametersValue-7rl7ejjz7ugz','state changed','OS::Heat::Value',NULL,680),(997,'d13bb3ca-7baf-48ce-bfc4-2c7265ecdc31','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','CinderCommon','e29834ea-4f3b-4ad5-8805-1e12288ddb06','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(998,'6de367af-195f-40d8-baa7-851003a45f09','82b4d6ff-2141-4c0d-8a47-1854d1f0a8fb','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-8-i4okyh5czkdb-RoleParametersValue-7rl7ejjz7ugz','state changed','OS::Heat::Value',NULL,680),(999,'64b52b38-4c05-4f41-aeae-17fb9df49a16','3fd369ad-fbdf-477f-ba93-bbc90cb06f13','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderCommon-plmid4ydusjx-CinderNVMeOF-hpcuderkmxrf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1000,'0f2e0491-e115-4465-9284-a63c55486064','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','6','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl','state changed','OS::TripleO::Services::CinderScheduler',NULL,681),(1001,'8039918c-c258-40ad-a9c9-9ba1e1c5a51b','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1002,'50b91dc0-db36-4a8b-af62-10c0806a46f5','e0ecbde5-2c05-4999-9c18-e0d1faf94c6e','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderCommon-plmid4ydusjx-CinderNVMeOF-hpcuderkmxrf','e0ecbde5-2c05-4999-9c18-e0d1faf94c6e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1003,'c731f299-e356-4836-99e8-ebf91f3b350b','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl','2b1846d4-f12e-48f6-a327-6376d5a5c119','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1004,'ae6800ef-7874-472b-8742-7eb2e2bb2318','e0ecbde5-2c05-4999-9c18-e0d1faf94c6e','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderCommon-plmid4ydusjx-CinderNVMeOF-hpcuderkmxrf','e0ecbde5-2c05-4999-9c18-e0d1faf94c6e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1005,'d12efefc-681b-4a3f-819c-4b667d76d171','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-RoleParametersValue-ghoaqbutslur','state changed','OS::Heat::Value',NULL,682),(1006,'1f710b09-da67-4053-8576-891aefc9032a','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-RoleParametersValue-ghoaqbutslur','state changed','OS::Heat::Value',NULL,682),(1007,'f1407f19-0f86-4756-85b1-f961dfaf401c','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-RoleParametersValue-xfbdp35xvpsh','state changed','OS::Heat::Value',NULL,683),(1008,'e34173a5-8897-4d13-98f1-c13788462c63','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','13','641c560b-f31b-48a8-b7c7-689bef1bd798','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,644),(1009,'f20f6cd1-7295-41dd-be24-3612d5973ad9','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-RoleParametersValue-xfbdp35xvpsh','state changed','OS::Heat::Value',NULL,683),(1010,'808adf27-1f44-433b-8ac3-a94abd1fb061','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-RoleParametersValue-apuviw5zorum','state changed','OS::Heat::Value',NULL,685),(1011,'3b3dc95b-3d44-4a7b-800c-4e9378b738a2','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-RoleParametersValue-apuviw5zorum','state changed','OS::Heat::Value',NULL,685),(1012,'8e3c528e-5d4e-4832-b03a-05b4fd2ca44d','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:33',NULL,'CREATE','COMPLETE','MySQLClient','6b0a4e3a-fbf9-4f76-ba10-7808aac6d512','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1013,'278e0ab4-cc76-456f-9cfc-1d3749b53756','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','17','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-17-hzanwppnufsc','state changed','OS::TripleO::Services::Snmp',NULL,689),(1014,'7ac5bb51-47b2-4d70-9317-8446a2d6ba42','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderBase-vn43jrbvy6wr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,690),(1015,'578e4e76-488a-433e-9afa-b38174bd967f','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaBase-fmv4f3jcciey','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,691),(1016,'b74dc19e-286a-410b-96ee-9c5c1e673229','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-ContainersCommon-mjex3eywx2ts','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1017,'b22ef0f1-927d-4a92-bd31-3ffac70fe03d','b16f60da-99a1-4e31-8c62-3be3eb4d6a2d','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-17-hzanwppnufsc','b16f60da-99a1-4e31-8c62-3be3eb4d6a2d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1018,'22e435b3-3e1d-4850-b2a3-a80d7cca2a71','cdf1f079-a022-4651-b1fb-22d80d64eff3','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderBase-vn43jrbvy6wr','cdf1f079-a022-4651-b1fb-22d80d64eff3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1019,'54264c0f-937f-4e0e-8a60-f11f7d2c2ac5','b16f60da-99a1-4e31-8c62-3be3eb4d6a2d','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-17-hzanwppnufsc','b16f60da-99a1-4e31-8c62-3be3eb4d6a2d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1020,'98928968-1843-49e0-9554-dce06690f756','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','CinderNVMeOF','34f0c019-db70-4654-888a-9f63e1bc298b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1021,'a9f044fc-1855-4711-aedf-f9244dd091c9','cdf1f079-a022-4651-b1fb-22d80d64eff3','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderBase-vn43jrbvy6wr','cdf1f079-a022-4651-b1fb-22d80d64eff3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1022,'f3d30fb1-a1d5-422a-8705-53cac610b63f','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','17','b16f60da-99a1-4e31-8c62-3be3eb4d6a2d','state changed','OS::TripleO::Services::Snmp',NULL,689),(1023,'80a72aff-e01f-4cf3-b186-f86a1f2f3bac','dbe44093-fb70-4b87-98d7-156f7401bb92','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaBase-fmv4f3jcciey','dbe44093-fb70-4b87-98d7-156f7401bb92','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1024,'fc49ed6b-48df-4279-8ab9-a5e45d39aa88','53af33ec-021f-4bcc-a8b8-0f2e288bdac8','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-ContainersCommon-mjex3eywx2ts','53af33ec-021f-4bcc-a8b8-0f2e288bdac8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1025,'24662f69-df0c-4c44-a41d-585754928d53','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','ContainersCommon','b6d7af40-9221-43eb-a0ad-c533fc172abd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1026,'f9eba9ee-f167-4e57-8827-edf3a7504e74','d1a93281-15f7-4218-b774-e64f1edcbeb9','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','CinderNVMeOF','bc407e01-7746-4b46-a701-f13ccaf9cf76','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1027,'0a5ac180-3c39-4bc3-abec-204f851e5c85','53af33ec-021f-4bcc-a8b8-0f2e288bdac8','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-ContainersCommon-mjex3eywx2ts','53af33ec-021f-4bcc-a8b8-0f2e288bdac8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1028,'682c541f-1a47-4de6-a50f-de720bec3aa0','82b4d6ff-2141-4c0d-8a47-1854d1f0a8fb','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-8-i4okyh5czkdb-ContainersCommon-jxfjnlr5xb25','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1029,'5b96f424-32e6-47d2-9efc-6e60715c3114','dbe44093-fb70-4b87-98d7-156f7401bb92','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaBase-fmv4f3jcciey-RoleParametersValue-4krldxtdaj2u','state changed','OS::Heat::Value',NULL,693),(1030,'0f7d3477-20d0-4aa3-a3a4-6dc074543560','d1a93281-15f7-4218-b774-e64f1edcbeb9','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderCommon-wxos4jjab57z','d1a93281-15f7-4218-b774-e64f1edcbeb9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1031,'9b779095-756c-427b-bf09-0921b8415bed','dbe44093-fb70-4b87-98d7-156f7401bb92','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaBase-fmv4f3jcciey-RoleParametersValue-4krldxtdaj2u','state changed','OS::Heat::Value',NULL,693),(1032,'e6bd7fa1-6947-45f8-81d9-3bfa3a5421e1','dbe44093-fb70-4b87-98d7-156f7401bb92','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaBase-fmv4f3jcciey','dbe44093-fb70-4b87-98d7-156f7401bb92','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1033,'0a1ae775-951a-4559-bf93-466defd6b24a','b601ed6e-b2b8-4bd0-b359-cbc9bc128035','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-8-i4okyh5czkdb-ContainersCommon-jxfjnlr5xb25','b601ed6e-b2b8-4bd0-b359-cbc9bc128035','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1034,'265a07d2-77a2-4fd5-a078-33aa813d4ad0','b601ed6e-b2b8-4bd0-b359-cbc9bc128035','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-8-i4okyh5czkdb-ContainersCommon-jxfjnlr5xb25','b601ed6e-b2b8-4bd0-b359-cbc9bc128035','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1035,'b5f6c470-71c6-48d1-a867-4410be773163','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','MySQLClient','744506b6-911a-49eb-b173-dc414fb5ed40','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1036,'6b9cc89b-19f3-4689-9d13-6b541b284d07','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','21','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-21-c2itutg54h2c','state changed','OS::TripleO::Services::TripleoFirewall',NULL,694),(1037,'4cefa34f-8860-4c7f-91b7-24a014fbb912','3fd369ad-fbdf-477f-ba93-bbc90cb06f13','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderCommon-plmid4ydusjx-ContainersCommon-suelw64l3hue','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1038,'68488944-55bf-43d5-b053-724208a87dd1','3a4fc066-2ac0-422b-aa5d-34cb16a30b84','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-21-c2itutg54h2c','3a4fc066-2ac0-422b-aa5d-34cb16a30b84','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1039,'a684135f-4259-44f5-83bf-7630f8f65e01','3fd369ad-fbdf-477f-ba93-bbc90cb06f13','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','CinderNVMeOF','e0ecbde5-2c05-4999-9c18-e0d1faf94c6e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1040,'a76cf9a3-a920-436a-a08c-9e23133ba366','c13dccd3-0573-42fc-b4f7-b65647154f9e','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderCommon-plmid4ydusjx-ContainersCommon-suelw64l3hue','c13dccd3-0573-42fc-b4f7-b65647154f9e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1041,'081c0b2f-9e8a-4c6f-9f4d-02026d542e18','c13dccd3-0573-42fc-b4f7-b65647154f9e','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderCommon-plmid4ydusjx-ContainersCommon-suelw64l3hue','c13dccd3-0573-42fc-b4f7-b65647154f9e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1042,'6104a18b-ca73-4ead-b043-400db8bc362a','3a4fc066-2ac0-422b-aa5d-34cb16a30b84','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-21-c2itutg54h2c-RoleParametersValue-vwuivo5c66yj','state changed','OS::Heat::Value',NULL,695),(1043,'fccd4cf6-143f-421e-a5c1-a38993a71a65','3a4fc066-2ac0-422b-aa5d-34cb16a30b84','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-21-c2itutg54h2c-RoleParametersValue-vwuivo5c66yj','state changed','OS::Heat::Value',NULL,695),(1044,'18d2dc2a-45fc-449c-a35e-f14078d9045c','3a4fc066-2ac0-422b-aa5d-34cb16a30b84','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-21-c2itutg54h2c','3a4fc066-2ac0-422b-aa5d-34cb16a30b84','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1045,'f40ef97f-6aad-4c53-a1c3-53197d68a7c7','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaBase-53kpz3zs4yco','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,696),(1046,'74787799-ec80-44a6-8a07-5c29f9e8fbc1','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-MySQLClient-sijzh6yflo2a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1047,'278f56da-f550-4350-950a-c40f0b73de3d','54dd56be-a62d-4e4b-83b7-1ea6dfd01dbc','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaBase-53kpz3zs4yco','54dd56be-a62d-4e4b-83b7-1ea6dfd01dbc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1048,'124e4045-13cd-44b0-86fb-e5317a0d2947','b1085191-dabe-4c9f-9758-735660e17f1e','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-MySQLClient-sijzh6yflo2a','b1085191-dabe-4c9f-9758-735660e17f1e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1049,'d37366f6-7396-4efa-bbf7-9b2c870f8c94','b1085191-dabe-4c9f-9758-735660e17f1e','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-MySQLClient-sijzh6yflo2a','b1085191-dabe-4c9f-9758-735660e17f1e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1050,'b514326b-950c-4afd-a0cb-fc0287e58f1e','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-ApacheServiceBase-vqyyffzeqwc4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,697),(1051,'fc9a8864-370f-4005-8812-4794e61f67ce','54dd56be-a62d-4e4b-83b7-1ea6dfd01dbc','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaBase-53kpz3zs4yco-RoleParametersValue-o56lmkad2lhj','state changed','OS::Heat::Value',NULL,698),(1052,'35bb419a-0cf2-495f-a85c-6d0ecaf90096','54dd56be-a62d-4e4b-83b7-1ea6dfd01dbc','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaBase-53kpz3zs4yco-RoleParametersValue-o56lmkad2lhj','state changed','OS::Heat::Value',NULL,698),(1053,'aad52cb1-5756-4bf0-b568-3ba37a3dfd5e','aa0982b7-5aeb-4ead-a2dd-f5b2b1826345','2026-06-10 07:59:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-ApacheServiceBase-vqyyffzeqwc4','aa0982b7-5aeb-4ead-a2dd-f5b2b1826345','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1054,'d8e811aa-44b0-4f5b-a995-1c029de9ea7f','54dd56be-a62d-4e4b-83b7-1ea6dfd01dbc','2026-06-10 07:59:34',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaBase-53kpz3zs4yco','54dd56be-a62d-4e4b-83b7-1ea6dfd01dbc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1055,'b332bc8e-f2f2-477e-83ec-717b8e2d2f74','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','CinderCommon','d1a93281-15f7-4218-b774-e64f1edcbeb9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1056,'d13a10af-a1c3-4030-ad22-56091d8cdd80','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderCommon-kusawebnnk3u','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1057,'0c24c18f-fd9b-48d7-aeca-e71678fc042e','aa0982b7-5aeb-4ead-a2dd-f5b2b1826345','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-ApacheServiceBase-vqyyffzeqwc4-ApacheNetworks-7orowilxwkrr','state changed','OS::Heat::Value',NULL,699),(1058,'9bb77156-d3db-420f-87d5-61f22fd7d8ac','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-ContainersCommon-qcbbpjf76dmp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1059,'c520533b-78a9-4679-a392-9e4c99f34bec','aa0982b7-5aeb-4ead-a2dd-f5b2b1826345','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-ApacheServiceBase-vqyyffzeqwc4-ApacheNetworks-7orowilxwkrr','state changed','OS::Heat::Value',NULL,699),(1060,'afd7d241-bfdd-48b1-887a-bd03351fe8c8','aa0982b7-5aeb-4ead-a2dd-f5b2b1826345','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-ApacheServiceBase-vqyyffzeqwc4','aa0982b7-5aeb-4ead-a2dd-f5b2b1826345','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1061,'3720aeac-4289-4005-91c3-e429aac400ea','b2c525b9-697c-4517-87d0-dc96828471cc','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-ContainersCommon-qcbbpjf76dmp','b2c525b9-697c-4517-87d0-dc96828471cc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1062,'f71e5495-ea8c-420a-aead-80b6e35b6dad','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,700),(1063,'951aeb88-c066-4158-94f1-1a2795c0fa6e','7db74b41-01c5-4827-bb41-6896b390b0be','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderCommon-kusawebnnk3u','7db74b41-01c5-4827-bb41-6896b390b0be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1064,'557e3247-260a-4450-89c7-0e35ed900dab','b2c525b9-697c-4517-87d0-dc96828471cc','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-ContainersCommon-qcbbpjf76dmp','b2c525b9-697c-4517-87d0-dc96828471cc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1065,'7297d096-9cab-48f4-a6d9-4183afcc7fd1','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','CinderBase','cdf1f079-a022-4651-b1fb-22d80d64eff3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,690),(1066,'f47fb590-517a-4bac-bee1-c7bfb0ab2d4e','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','NovaBase','dbe44093-fb70-4b87-98d7-156f7401bb92','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,691),(1067,'23e9724d-a8d5-425d-ad1c-13e1e0685525','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','ContainersCommon','53af33ec-021f-4bcc-a8b8-0f2e288bdac8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1068,'76cde899-7137-4234-ae82-0144f9c27659','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv','61e50392-9403-4b7d-bd5f-245bf9e98730','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1069,'81e9028d-f41b-40d8-b7b6-595aaf9b9ed3','7db74b41-01c5-4827-bb41-6896b390b0be','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderCommon-kusawebnnk3u-CinderNVMeOF-smczi3muipgt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1070,'d4ed344d-2370-4a41-ab03-68180c3f5193','1434536c-0642-4135-8c10-43af5e6e463f','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderCommon-kusawebnnk3u-CinderNVMeOF-smczi3muipgt','1434536c-0642-4135-8c10-43af5e6e463f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1071,'3c51b89e-35a3-4594-a20d-2ca10ce7b4f7','82b4d6ff-2141-4c0d-8a47-1854d1f0a8fb','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','ContainersCommon','b601ed6e-b2b8-4bd0-b359-cbc9bc128035','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1072,'79d222b3-424c-4d6e-a1c4-4846f853961b','82b4d6ff-2141-4c0d-8a47-1854d1f0a8fb','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-8-i4okyh5czkdb','82b4d6ff-2141-4c0d-8a47-1854d1f0a8fb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1073,'c0b6b721-3d1c-4ac7-adef-c1b78fd8ea7b','1434536c-0642-4135-8c10-43af5e6e463f','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderCommon-kusawebnnk3u-CinderNVMeOF-smczi3muipgt','1434536c-0642-4135-8c10-43af5e6e463f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1074,'b1270e30-fa96-45d7-8c09-db69eeac53c7','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-ContainersCommon-nds3g6reyb7v','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1075,'60c50e49-c6fe-45ae-8477-ab07e2e67eb4','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','21','3a4fc066-2ac0-422b-aa5d-34cb16a30b84','state changed','OS::TripleO::Services::TripleoFirewall',NULL,694),(1076,'16b911f9-f12d-48b4-9546-f246e2c0ed4a','3fd369ad-fbdf-477f-ba93-bbc90cb06f13','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','ContainersCommon','c13dccd3-0573-42fc-b4f7-b65647154f9e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1077,'7db7a45d-e9c7-4958-a07f-eef9e1e61142','effe2675-bf9f-4ad0-81d5-eaa179b50e75','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-ContainersCommon-nds3g6reyb7v','effe2675-bf9f-4ad0-81d5-eaa179b50e75','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1078,'e51b3308-8695-4d60-be0e-3fe9befdc207','3fd369ad-fbdf-477f-ba93-bbc90cb06f13','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderCommon-plmid4ydusjx','3fd369ad-fbdf-477f-ba93-bbc90cb06f13','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1079,'ae32a261-5640-43d2-abc2-76cb7b6f19f5','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','NovaLibvirtLogging','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaLibvirtLogging-3fmgbhnwtidn','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1080,'7f89eb35-5326-4b53-a213-67c9da856f32','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-ContainersCommon-ihwitvl7vjzq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1081,'178f8490-690d-45be-b765-bfc613688a1d','7ec7cdf3-84a1-4dfd-8d4e-264a58b04819','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaLibvirtLogging-3fmgbhnwtidn','7ec7cdf3-84a1-4dfd-8d4e-264a58b04819','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1082,'98fc684e-0d47-49c1-8ef7-c6f1d23566d3','effe2675-bf9f-4ad0-81d5-eaa179b50e75','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-ContainersCommon-nds3g6reyb7v','effe2675-bf9f-4ad0-81d5-eaa179b50e75','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1083,'b2c01b50-f6dd-4791-bb59-f00b9420b845','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','25','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,703),(1084,'c4b7b44b-3d8f-42c9-8da3-53f7ec67972c','7ec7cdf3-84a1-4dfd-8d4e-264a58b04819','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaLibvirtLogging-3fmgbhnwtidn','7ec7cdf3-84a1-4dfd-8d4e-264a58b04819','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1085,'6cb0e630-71d8-408b-9a4d-50e067372bfe','7e5ac9fb-3668-40ac-86b1-eab5b2781faf','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-ContainersCommon-ihwitvl7vjzq','7e5ac9fb-3668-40ac-86b1-eab5b2781faf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1086,'2e8d505b-76a3-4704-9074-cd44297209b4','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','MySQLClient','b1085191-dabe-4c9f-9758-735660e17f1e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1087,'8c81eb16-d455-47a8-a8d7-a0fbb72ed74d','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','NovaBase','54dd56be-a62d-4e4b-83b7-1ea6dfd01dbc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,696),(1088,'0e2ed61a-14be-40f4-94be-242a9b2231a3','7e5ac9fb-3668-40ac-86b1-eab5b2781faf','2026-06-10 07:59:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-ContainersCommon-ihwitvl7vjzq','7e5ac9fb-3668-40ac-86b1-eab5b2781faf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1089,'976e2bc8-7869-4a24-9233-3523111a2e5c','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1090,'95888585-331d-4318-b9e1-f95084e69c49','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:35',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderBase-x7qjpjjsodu7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,704),(1091,'c5ff0a2b-94b5-418f-90c4-275cfbcef0f2','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','ApacheServiceBase','aa0982b7-5aeb-4ead-a2dd-f5b2b1826345','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,697),(1092,'368fc10b-da26-4a1d-948d-5ae8fd1cfead','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-ContainersCommon-jkkmuqcbdz2b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1093,'404e96b8-e6d5-4d65-aefb-bf4c44310107','b68d8625-f8ac-476d-8776-e5938f9ee6c6','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderBase-x7qjpjjsodu7','b68d8625-f8ac-476d-8776-e5938f9ee6c6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1094,'14f1ab5e-c8c7-4bfd-b5a2-42dbfd198586','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-RoleParametersValue-4i2uutelyzyt','state changed','OS::Heat::Value',NULL,705),(1095,'18dc6886-3d79-44a4-a914-f21bec134ce4','b68d8625-f8ac-476d-8776-e5938f9ee6c6','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7-CinderBase-x7qjpjjsodu7','b68d8625-f8ac-476d-8776-e5938f9ee6c6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1096,'087ec0ec-7bee-4196-9633-ea24a53a17b9','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-RoleParametersValue-4i2uutelyzyt','state changed','OS::Heat::Value',NULL,705),(1097,'ab0e91be-da0c-4453-bc0c-0f5991b5e975','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-RoleParametersValue-i65m4j725zif','state changed','OS::Heat::Value',NULL,706),(1098,'d74a0cc4-3b14-4e9c-8da4-64b77494b378','c0bc15cf-757b-4fcf-bc2c-0e3052de0eec','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-ContainersCommon-jkkmuqcbdz2b','c0bc15cf-757b-4fcf-bc2c-0e3052de0eec','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1099,'20bcfec9-8065-4f39-a405-d9ffd47a05b6','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-RoleParametersValue-i65m4j725zif','state changed','OS::Heat::Value',NULL,706),(1100,'a086dcf9-22c6-4e15-943d-7e85a7b0c6ad','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-RoleParametersValue-4xmf4ihnrnoe','state changed','OS::Heat::Value',NULL,707),(1101,'f5f27839-c42b-48e9-8ef5-75dc30fa179f','c0bc15cf-757b-4fcf-bc2c-0e3052de0eec','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-ContainersCommon-jkkmuqcbdz2b','c0bc15cf-757b-4fcf-bc2c-0e3052de0eec','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1102,'e2d4d835-bb4e-4119-860a-b8469053cfc8','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-RoleParametersValue-4xmf4ihnrnoe','state changed','OS::Heat::Value',NULL,707),(1103,'d69908ed-c7a0-4fb4-929e-1b0019baddf5','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','ContainersCommon','b2c525b9-697c-4517-87d0-dc96828471cc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1104,'a662c289-e1cb-49c2-b06d-a86b17ae2cd1','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaLogging-35w7v2ylf3jo','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,709),(1105,'6ff5f150-336a-40da-bbfa-ba70157b928c','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','8','82b4d6ff-2141-4c0d-8a47-1854d1f0a8fb','state changed','OS::TripleO::Services::MetricsQdr',NULL,673),(1106,'0a091b45-7583-41e6-b528-fe9f55559184','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','CinderCommon','3fd369ad-fbdf-477f-ba93-bbc90cb06f13','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1107,'7add20b8-6d3c-4cb4-b7e4-1c3a4626411e','7db74b41-01c5-4827-bb41-6896b390b0be','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderCommon-kusawebnnk3u-ContainersCommon-ty5rfhu5v2h6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1108,'e6693ec0-5b85-4694-a202-25a8ae0eeb05','e4eac2e7-dab9-44b1-9e33-cc3b8c4194fa','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaLogging-35w7v2ylf3jo','e4eac2e7-dab9-44b1-9e33-cc3b8c4194fa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1109,'b4c914a3-9324-4bc2-a935-3bd8bd8749fb','9497a9eb-d717-4a18-b2c4-813cf6dba306','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderCommon-kusawebnnk3u-ContainersCommon-ty5rfhu5v2h6','9497a9eb-d717-4a18-b2c4-813cf6dba306','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1110,'acb976f3-50f8-4842-b6e1-22c1753d7607','9497a9eb-d717-4a18-b2c4-813cf6dba306','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderCommon-kusawebnnk3u-ContainersCommon-ty5rfhu5v2h6','9497a9eb-d717-4a18-b2c4-813cf6dba306','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1111,'f5b98854-9c40-4048-8755-1efac2ff889e','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','12','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-12-xquvslvzsu72','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,713),(1112,'7d1d82c6-e6c8-4219-9ab2-16c22351744f','7db74b41-01c5-4827-bb41-6896b390b0be','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','CinderNVMeOF','1434536c-0642-4135-8c10-43af5e6e463f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1113,'9a4e6f21-a95e-4c39-bacf-7a44e6bce90c','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderCommon-eufz5clyr3wy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1114,'250304ce-504b-427e-a240-778679f32633','e4eac2e7-dab9-44b1-9e33-cc3b8c4194fa','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaLogging-35w7v2ylf3jo-InitLogContainerName-osnrsezhqic7','state changed','OS::Heat::Value',NULL,714),(1115,'07c98439-e4eb-4f93-9b6e-0284046dc6c1','e575d4b2-7190-4c29-89cd-7cfed05dcb31','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-12-xquvslvzsu72','e575d4b2-7190-4c29-89cd-7cfed05dcb31','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1116,'78644d28-f23d-461e-a42d-589f7b0980d3','e4eac2e7-dab9-44b1-9e33-cc3b8c4194fa','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaLogging-35w7v2ylf3jo-InitLogContainerName-osnrsezhqic7','state changed','OS::Heat::Value',NULL,714),(1117,'e32b596b-181a-493a-b52a-0f9307b1b956','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','ContainersCommon','effe2675-bf9f-4ad0-81d5-eaa179b50e75','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1118,'0f580528-e288-4190-ae7d-7628fbe05f13','e575d4b2-7190-4c29-89cd-7cfed05dcb31','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-12-xquvslvzsu72-RoleParametersValue-szcypp6tnmkk','state changed','OS::Heat::Value',NULL,715),(1119,'7b4b60ac-76fb-4374-bac7-423e5dc6c2a8','00756d70-996d-4468-9151-1cdb70dd23dc','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderCommon-eufz5clyr3wy','00756d70-996d-4468-9151-1cdb70dd23dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1120,'6bdd089d-f567-4941-b822-8ae3850cbe7c','e575d4b2-7190-4c29-89cd-7cfed05dcb31','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-12-xquvslvzsu72-RoleParametersValue-szcypp6tnmkk','state changed','OS::Heat::Value',NULL,715),(1121,'58980596-bf3b-40f9-bc85-9e7c693fc169','e575d4b2-7190-4c29-89cd-7cfed05dcb31','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-12-xquvslvzsu72','e575d4b2-7190-4c29-89cd-7cfed05dcb31','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1122,'2b5ccfb6-d4be-4675-b3d5-dd8d9532e34f','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-ContainersCommon-5imdnpyy4ekl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1123,'dc35b0ea-3655-4b98-bae4-de3f9e4aeaee','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderCommon-thgctasd5ccg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1124,'85128420-9354-4a39-8061-8c1c838f755c','473471f6-c411-4b6b-b3e4-c47dbc4932f3','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-ContainersCommon-5imdnpyy4ekl','473471f6-c411-4b6b-b3e4-c47dbc4932f3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1125,'0746ad07-55af-4ee3-abee-6693ccc9fd39','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','NovaLibvirtLogging','7ec7cdf3-84a1-4dfd-8d4e-264a58b04819','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1126,'7880631b-bf45-458e-bf39-865a2ad8f3eb','00756d70-996d-4468-9151-1cdb70dd23dc','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderCommon-eufz5clyr3wy-ContainersCommon-phlnj36lueal','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1127,'3bd44bde-6081-48c4-8a53-4f5dcb75eec3','a51f15ee-5a04-4457-8493-dfa93efd1c9c','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderCommon-thgctasd5ccg','a51f15ee-5a04-4457-8493-dfa93efd1c9c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1128,'56f10e88-ccb3-4efb-b8d1-bc18e8aef9f3','473471f6-c411-4b6b-b3e4-c47dbc4932f3','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-ContainersCommon-5imdnpyy4ekl','473471f6-c411-4b6b-b3e4-c47dbc4932f3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1129,'971d11fb-417b-4674-b55a-e5d6f17065fa','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','ContainersCommon','7e5ac9fb-3668-40ac-86b1-eab5b2781faf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1130,'952636b2-24e0-43f2-b803-b6862bd65c9c','136010c2-ddd2-42cb-8332-6fba4e4bea55','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderCommon-eufz5clyr3wy-ContainersCommon-phlnj36lueal','136010c2-ddd2-42cb-8332-6fba4e4bea55','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1131,'5fa22247-049f-45af-872e-b673a5c61ca3','136010c2-ddd2-42cb-8332-6fba4e4bea55','2026-06-10 07:59:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderCommon-eufz5clyr3wy-ContainersCommon-phlnj36lueal','136010c2-ddd2-42cb-8332-6fba4e4bea55','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1132,'ffcba189-668c-4ea8-a9af-d347a962c71c','a51f15ee-5a04-4457-8493-dfa93efd1c9c','2026-06-10 07:59:36',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderCommon-thgctasd5ccg-CinderNVMeOF-ttrof5hfkten','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1133,'1faae6ac-570a-4e1d-ad5c-76c74a3bfa09','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-RoleParametersValue-vd3nyzyelem3','state changed','OS::Heat::Value',NULL,716),(1134,'394f0fb4-a4ad-42e6-bad2-58a38eefc56a','cd3ee14d-7303-409e-b6cd-70287d3c43f6','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderCommon-thgctasd5ccg-CinderNVMeOF-ttrof5hfkten','cd3ee14d-7303-409e-b6cd-70287d3c43f6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1135,'fa393f7b-e1f5-4819-878f-4f7216c4c564','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-RoleParametersValue-vd3nyzyelem3','state changed','OS::Heat::Value',NULL,716),(1136,'b152dd17-e5ab-45c9-bb03-b0778976580b','cd3ee14d-7303-409e-b6cd-70287d3c43f6','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderCommon-thgctasd5ccg-CinderNVMeOF-ttrof5hfkten','cd3ee14d-7303-409e-b6cd-70287d3c43f6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1137,'cc575426-3bc7-4905-9abf-77baf07f48c2','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','CinderBase','b68d8625-f8ac-476d-8776-e5938f9ee6c6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,704),(1138,'b9d72b48-eed3-4eb7-b5fb-9b163b2213f0','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-4-6acyvnbtxsj7','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1139,'c366374e-931c-4aca-b3a2-6e0bd682d016','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','ContainersCommon','c0bc15cf-757b-4fcf-bc2c-0e3052de0eec','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1140,'de55cb68-67a0-451c-8f9d-9341d2b120a6','7db74b41-01c5-4827-bb41-6896b390b0be','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','ContainersCommon','9497a9eb-d717-4a18-b2c4-813cf6dba306','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1141,'9f71b05d-d219-44ea-b841-895072fa41f6','7db74b41-01c5-4827-bb41-6896b390b0be','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo-CinderCommon-kusawebnnk3u','7db74b41-01c5-4827-bb41-6896b390b0be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1142,'95ec6169-5a2f-4e40-9e13-5c530b1f71a6','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderBase-mgspkkwt7f2m','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,717),(1143,'25bae1ba-6664-4018-8172-455fec7e2f54','e4eac2e7-dab9-44b1-9e33-cc3b8c4194fa','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaLogging-35w7v2ylf3jo-RoleParametersValue-42tkbepyaurk','state changed','OS::Heat::Value',NULL,718),(1144,'2327c389-bf85-4140-bfcc-c18df8533516','e4eac2e7-dab9-44b1-9e33-cc3b8c4194fa','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaLogging-35w7v2ylf3jo-RoleParametersValue-42tkbepyaurk','state changed','OS::Heat::Value',NULL,718),(1145,'de023ee5-3def-46e2-95c9-b1633642b387','99ac0a60-758c-4281-8941-08c75fdfe4fe','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderBase-mgspkkwt7f2m','99ac0a60-758c-4281-8941-08c75fdfe4fe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1146,'e8a459e4-d1bf-4b43-985a-829606f2a94e','e4eac2e7-dab9-44b1-9e33-cc3b8c4194fa','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc-NovaLogging-35w7v2ylf3jo','e4eac2e7-dab9-44b1-9e33-cc3b8c4194fa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1147,'99775830-38ba-43c7-98cd-c05e820a50ad','99ac0a60-758c-4281-8941-08c75fdfe4fe','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderBase-mgspkkwt7f2m','99ac0a60-758c-4281-8941-08c75fdfe4fe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1148,'6b4794fb-22d0-4ab3-bc9f-6670cff2ecfd','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','NovaLibvirtCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaLibvirtCommon-klo4wrih5o3w','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1149,'c15d89ad-9afd-4142-a7e2-603fa84570b0','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','12','e575d4b2-7190-4c29-89cd-7cfed05dcb31','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,713),(1150,'d479a37d-8930-490a-a1c4-097643874c90','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','4','9cf69dd3-ce41-4e1b-8474-db8d9b088b79','state changed','OS::TripleO::Services::CinderApi',NULL,641),(1151,'c7f1fc96-d732-4827-b722-62ee610833f6','ac54b1b3-31ee-4850-a0f3-842b758acaae','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaLibvirtCommon-klo4wrih5o3w','ac54b1b3-31ee-4850-a0f3-842b758acaae','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1152,'9767da87-44a6-4d9d-a08b-05076a30c2cc','00756d70-996d-4468-9151-1cdb70dd23dc','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderCommon-eufz5clyr3wy-CinderNVMeOF-d2h7j5xqovnu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1153,'b047ec51-b028-46f5-a9d1-f513013c7901','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderBase-aufwzdarzii7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,719),(1154,'79648756-e0ac-40bd-8509-dbcdad4c5863','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','ContainersCommon','473471f6-c411-4b6b-b3e4-c47dbc4932f3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1155,'7c77bfbe-eaa7-4f8b-9bc7-716ccc1f22bd','927cfdaa-fd88-4d25-9428-f02d8ed36593','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderCommon-eufz5clyr3wy-CinderNVMeOF-d2h7j5xqovnu','927cfdaa-fd88-4d25-9428-f02d8ed36593','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1156,'adb0cde6-8766-4bff-85a3-73025e6fd6e7','927cfdaa-fd88-4d25-9428-f02d8ed36593','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderCommon-eufz5clyr3wy-CinderNVMeOF-d2h7j5xqovnu','927cfdaa-fd88-4d25-9428-f02d8ed36593','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1157,'210de59a-22f1-466a-a6ca-895fd5bc7abf','ac54b1b3-31ee-4850-a0f3-842b758acaae','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaLibvirtCommon-klo4wrih5o3w-RoleParametersValue-b3sghq67reyg','state changed','OS::Heat::Value',NULL,721),(1158,'579b4153-3895-49a6-ab7e-1eb1ecb0782d','00756d70-996d-4468-9151-1cdb70dd23dc','2026-06-10 07:59:37',NULL,'CREATE','COMPLETE','ContainersCommon','136010c2-ddd2-42cb-8332-6fba4e4bea55','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1159,'5dac0f51-c2e4-4105-bb4e-4afce70be2f6','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','16','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-16-5pfmv6lur5pi','state changed','OS::TripleO::Services::Rsyslog',NULL,723),(1160,'295089be-b9f8-457f-8d8d-e035c5b6dfc8','9a0629fb-1ced-485c-947a-cde7184df5f1','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderBase-aufwzdarzii7','9a0629fb-1ced-485c-947a-cde7184df5f1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1161,'8343b113-b14f-41d9-b388-33a72a72ceec','a51f15ee-5a04-4457-8493-dfa93efd1c9c','2026-06-10 07:59:37',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderCommon-thgctasd5ccg-ContainersCommon-gmxrapu33qfr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1162,'569b31ad-a70c-433b-8adf-5db1bb1d0825','ac54b1b3-31ee-4850-a0f3-842b758acaae','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaLibvirtCommon-klo4wrih5o3w-RoleParametersValue-b3sghq67reyg','state changed','OS::Heat::Value',NULL,721),(1163,'c3a0a3c8-7e12-41c5-9ea4-5e0738ec0be5','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-NeutronLogging-4j3oxw6aknkf','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,725),(1164,'66f61fba-247d-4916-b7d1-0dea5967cc4d','9a0629fb-1ced-485c-947a-cde7184df5f1','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderBase-aufwzdarzii7','9a0629fb-1ced-485c-947a-cde7184df5f1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1165,'cd397e59-3a37-429b-b650-accda5a9607e','ac54b1b3-31ee-4850-a0f3-842b758acaae','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh-NovaLibvirtCommon-klo4wrih5o3w','ac54b1b3-31ee-4850-a0f3-842b758acaae','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1166,'9df54d3c-6279-44f9-a5a2-9d407939b571','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','CinderBase','9a0629fb-1ced-485c-947a-cde7184df5f1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,719),(1167,'915f6e2f-2333-4487-a59c-583c55841bb6','4acdd6cd-b580-4353-aee0-4616fcdb7d7d','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderCommon-thgctasd5ccg-ContainersCommon-gmxrapu33qfr','4acdd6cd-b580-4353-aee0-4616fcdb7d7d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1168,'14369f5f-ad57-47d9-bb40-16c165338c96','ca8a5410-79da-4575-adc2-0c2bd9154a57','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-16-5pfmv6lur5pi','ca8a5410-79da-4575-adc2-0c2bd9154a57','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1169,'ee15cee4-ee3f-4c91-94e5-8322df2394d5','a51f15ee-5a04-4457-8493-dfa93efd1c9c','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','CinderNVMeOF','cd3ee14d-7303-409e-b6cd-70287d3c43f6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1170,'1af530a7-543f-4fca-9a63-1dad44a64576','449dacfa-c969-41dd-8453-4cb57c5afb89','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-NeutronLogging-4j3oxw6aknkf','449dacfa-c969-41dd-8453-4cb57c5afb89','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1171,'23030eb1-b62a-4568-9fe7-bc9f9f2abab1','4acdd6cd-b580-4353-aee0-4616fcdb7d7d','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderCommon-thgctasd5ccg-ContainersCommon-gmxrapu33qfr','4acdd6cd-b580-4353-aee0-4616fcdb7d7d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1172,'ef67aa12-9892-4d29-9c99-897ef43de887','449dacfa-c969-41dd-8453-4cb57c5afb89','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-NeutronLogging-4j3oxw6aknkf','449dacfa-c969-41dd-8453-4cb57c5afb89','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1173,'2a874928-e934-43dc-bf66-f94eec4ce9a7','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','NeutronLogging','449dacfa-c969-41dd-8453-4cb57c5afb89','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,725),(1174,'364d1840-29e8-4394-a760-86761d458e9f','ca8a5410-79da-4575-adc2-0c2bd9154a57','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-16-5pfmv6lur5pi-ContainersCommon-yrc3bwflzx4o','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1175,'278cb71f-ba0e-4e41-b0d2-fdb86acc1227','50875168-fbb9-4f76-b096-85b3c7e62e89','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-16-5pfmv6lur5pi-ContainersCommon-yrc3bwflzx4o','50875168-fbb9-4f76-b096-85b3c7e62e89','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1176,'49e7a55f-fe30-416e-9507-3b1588d788c1','50875168-fbb9-4f76-b096-85b3c7e62e89','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-16-5pfmv6lur5pi-ContainersCommon-yrc3bwflzx4o','50875168-fbb9-4f76-b096-85b3c7e62e89','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1177,'65111f89-0353-4c6e-8e31-3e31e072ac33','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','CinderCommon','7db74b41-01c5-4827-bb41-6896b390b0be','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1178,'ce3d34fa-6c05-4641-bea4-324d0cf44ce9','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu-CinderBackupBase-y3p66m6xzqmo','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1179,'055df42b-2837-4beb-a025-7162d4149866','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','NovaLogging','e4eac2e7-dab9-44b1-9e33-cc3b8c4194fa','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,709),(1180,'19a26bbb-4235-4c4b-be08-e75aedfa2bb8','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','8','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4','state changed','OS::TripleO::Services::Clustercheck',NULL,733),(1181,'da4c000b-d25d-4450-8f23-62c3fa6857e0','5ef675f6-8051-4724-a69d-18427f7316a9','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-10-aszetqg764zc','5ef675f6-8051-4724-a69d-18427f7316a9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1182,'aaffa666-1765-4790-a66f-ae79a8f68427','8a71ff9c-2935-4ac8-af7d-06597963529d','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4','8a71ff9c-2935-4ac8-af7d-06597963529d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1183,'a1e964f5-5b62-4d3b-9e99-ac06bf368740','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-MySQLClient-6ryrdnx2vgvv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1184,'72f58289-9b35-43f2-88b2-b3ae28f6b237','abaabcc6-51b4-4486-8be6-e8b3bc3e3c59','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-MySQLClient-6ryrdnx2vgvv','abaabcc6-51b4-4486-8be6-e8b3bc3e3c59','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1185,'92ad51f4-8548-4c11-8b18-a0d4733e452c','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','10','5ef675f6-8051-4724-a69d-18427f7316a9','state changed','OS::TripleO::Services::NovaCompute',NULL,649),(1186,'b325e8a3-1b13-4daa-b4f9-2289aed107aa','abaabcc6-51b4-4486-8be6-e8b3bc3e3c59','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-MySQLClient-6ryrdnx2vgvv','abaabcc6-51b4-4486-8be6-e8b3bc3e3c59','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1187,'cac51986-8f02-4263-a6a4-f7e360ca6cfc','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','CinderBackupBase','01d0cd3f-dbce-4be9-ba41-cfc5f060fcdf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,651),(1188,'c2ab1acf-ce54-4a32-8919-720eaa2aea52','8a71ff9c-2935-4ac8-af7d-06597963529d','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-ContainersCommon-nlewwtjxbcat','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1189,'dafbb3a3-a9ee-44ee-9ba6-1a92dceec2b3','1daff97e-3488-4459-ad96-1a5a190eb767','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-5-4lo6waactpyu','1daff97e-3488-4459-ad96-1a5a190eb767','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1190,'21613523-8ee1-4893-8968-17d071a52df0','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','CinderBase','99ac0a60-758c-4281-8941-08c75fdfe4fe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,717),(1191,'57d9a237-0bad-445c-b50d-a5ed932621c2','04145615-cd50-4272-972a-dbde53758636','2026-06-10 07:59:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-ContainersCommon-nlewwtjxbcat','04145615-cd50-4272-972a-dbde53758636','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1192,'2f739c55-7604-40c1-8f80-892c46d1b6d4','04145615-cd50-4272-972a-dbde53758636','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-ContainersCommon-nlewwtjxbcat','04145615-cd50-4272-972a-dbde53758636','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1193,'9f5fe0c6-d38e-4999-a7e2-947dbc71087a','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','NovaLibvirtCommon','ac54b1b3-31ee-4850-a0f3-842b758acaae','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1194,'df2be747-9fa2-45ac-84cf-402dd552394f','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-11-cqushhn2n2xh','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1195,'0f0116ea-dd40-4f52-992e-4e2572e724d4','00756d70-996d-4468-9151-1cdb70dd23dc','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','CinderNVMeOF','927cfdaa-fd88-4d25-9428-f02d8ed36593','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1196,'42a4270b-2b53-4527-92f9-6c32dd2a866b','00756d70-996d-4468-9151-1cdb70dd23dc','2026-06-10 07:59:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-CinderCommon-eufz5clyr3wy','00756d70-996d-4468-9151-1cdb70dd23dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1197,'5040e8ed-0cbe-4d39-8320-6d66b85ea760','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','5','1daff97e-3488-4459-ad96-1a5a190eb767','state changed','OS::TripleO::Services::CinderBackup',NULL,598),(1198,'fab6d1af-e4dd-440f-9369-b59521d3a608','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-NeutronBase-s5cle4omuddi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,741),(1199,'ddacae09-ac5b-48cb-a2f1-6a04146401f2','a51f15ee-5a04-4457-8493-dfa93efd1c9c','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','ContainersCommon','4acdd6cd-b580-4353-aee0-4616fcdb7d7d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1200,'181c8c7d-298b-4bc4-aeb4-34219a6cd3bc','a51f15ee-5a04-4457-8493-dfa93efd1c9c','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl-CinderCommon-thgctasd5ccg','a51f15ee-5a04-4457-8493-dfa93efd1c9c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1201,'01d44b1d-0457-44aa-a7cd-1b993b0694b3','4450778d-644b-497e-bc30-9144002a803a','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-NeutronBase-s5cle4omuddi','4450778d-644b-497e-bc30-9144002a803a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1202,'59bb6f1a-fb41-45f4-b976-c1ff48f1fe59','ca8a5410-79da-4575-adc2-0c2bd9154a57','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-16-5pfmv6lur5pi-RoleParametersValue-46qdg2cjqvqd','state changed','OS::Heat::Value',NULL,743),(1203,'3bfe2c87-6050-4e6c-97b7-03e8e584b6e1','ca8a5410-79da-4575-adc2-0c2bd9154a57','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','ContainersCommon','50875168-fbb9-4f76-b096-85b3c7e62e89','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1204,'1148e91b-81c8-49cc-986a-ffe9ae00d3a8','ca8a5410-79da-4575-adc2-0c2bd9154a57','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-16-5pfmv6lur5pi-RoleParametersValue-46qdg2cjqvqd','state changed','OS::Heat::Value',NULL,743),(1205,'49c0346c-4267-414f-9903-981235358550','ca8a5410-79da-4575-adc2-0c2bd9154a57','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-16-5pfmv6lur5pi','ca8a5410-79da-4575-adc2-0c2bd9154a57','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1206,'071ea4fd-357c-4365-81e8-64fc334f941b','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','14','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-14-4rjpaugabrhf','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,746),(1207,'59a2eaa0-4d73-4108-85b8-aa09e6781ccf','4450778d-644b-497e-bc30-9144002a803a','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy-NeutronBase-s5cle4omuddi','4450778d-644b-497e-bc30-9144002a803a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1208,'76b26d7c-cf6c-498e-a1d7-a9460c3d0d41','5931160f-9226-44c2-89a0-9c49d67d8318','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-14-4rjpaugabrhf','5931160f-9226-44c2-89a0-9c49d67d8318','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1209,'e1327c36-428a-4440-bb15-e49efe721e5a','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','11','63dc47bb-8bdd-42b3-a63c-c8f7951e391e','state changed','OS::TripleO::Services::NovaLibvirt',NULL,676),(1210,'aa8152bd-9519-4fe7-a1a0-5c1adb92f9bc','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-RoleParametersValue-otr2otvt6lqy','state changed','OS::Heat::Value',NULL,753),(1211,'9346ebb8-dc1c-4e94-8a13-7ebe2c7cc6a0','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv-RoleParametersValue-otr2otvt6lqy','state changed','OS::Heat::Value',NULL,753),(1212,'30e3c08f-db90-4734-9bd4-52c1479dc6a1','5931160f-9226-44c2-89a0-9c49d67d8318','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-14-4rjpaugabrhf-ContainersCommon-6qisckh536g6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1213,'fe23c671-d437-453c-aa9d-886778ddbc0c','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','MySQLClient','abaabcc6-51b4-4486-8be6-e8b3bc3e3c59','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1214,'e307eb29-598f-4613-b777-1099aa79ae2f','8a71ff9c-2935-4ac8-af7d-06597963529d','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-RoleParametersValue-lzndeiokcwaa','state changed','OS::Heat::Value',NULL,760),(1215,'7fc64c5e-7f8f-4476-ad77-d09348341ca6','d7e32449-841e-49fa-a99d-1e136d3bbffa','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-14-4rjpaugabrhf-ContainersCommon-6qisckh536g6','d7e32449-841e-49fa-a99d-1e136d3bbffa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1216,'6c8b103a-d247-4191-9ee5-cc4a7b7619eb','d7e32449-841e-49fa-a99d-1e136d3bbffa','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-14-4rjpaugabrhf-ContainersCommon-6qisckh536g6','d7e32449-841e-49fa-a99d-1e136d3bbffa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1217,'22f57550-1fd5-4ebd-8721-de428b2b6e47','8a71ff9c-2935-4ac8-af7d-06597963529d','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-RoleParametersValue-lzndeiokcwaa','state changed','OS::Heat::Value',NULL,760),(1218,'2c69c093-b640-44ac-9867-8e5924a569f2','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','CinderCommon','00756d70-996d-4468-9151-1cdb70dd23dc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1219,'d7c34a12-20b2-4b2b-ae94-10119d2c3cdd','61e50392-9403-4b7d-bd5f-245bf9e98730','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh-CinderBase-4i54t4ccykfv','61e50392-9403-4b7d-bd5f-245bf9e98730','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1220,'3d21d7a6-b8eb-4518-913f-0fe361551512','8a71ff9c-2935-4ac8-af7d-06597963529d','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','ContainersCommon','04145615-cd50-4272-972a-dbde53758636','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1221,'9453b9d5-d427-455a-ade5-9e3e1c022ba9','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','CinderCommon','a51f15ee-5a04-4457-8493-dfa93efd1c9c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1222,'220974fc-c89f-4809-b0c3-9e34d378889b','2b1846d4-f12e-48f6-a327-6376d5a5c119','2026-06-10 07:59:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-6-7aralcinbdrl','2b1846d4-f12e-48f6-a327-6376d5a5c119','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1223,'a6e8402b-8cc2-4c97-bbc0-6df7342be7c7','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:39',NULL,'CREATE','IN_PROGRESS','9','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-9-apa3dubgxov4','state changed','OS::TripleO::Services::Collectd',NULL,769),(1224,'f3254d39-cb65-4a56-a6f5-0997be5c137f','53f24a15-bb67-40fe-bfaa-bd0d02a847b3','2026-06-10 07:59:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-9-apa3dubgxov4','53f24a15-bb67-40fe-bfaa-bd0d02a847b3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1225,'f5a00ad8-6a8d-4186-bbe3-6ee136911068','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','16','ca8a5410-79da-4575-adc2-0c2bd9154a57','state changed','OS::TripleO::Services::Rsyslog',NULL,723),(1226,'4e68dd43-d878-4172-a0ae-58e87f9582f4','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:40',NULL,'CREATE','IN_PROGRESS','15','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-15-nkexf6pipkn4','state changed','OS::TripleO::Services::Podman',NULL,772),(1227,'07647380-c352-4a02-8697-aab1f4b3e3c0','53f24a15-bb67-40fe-bfaa-bd0d02a847b3','2026-06-10 07:59:40',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-9-apa3dubgxov4-RoleParametersValue-bp2yhharpwou','state changed','OS::Heat::Value',NULL,774),(1228,'e13d2c1e-01f1-47f6-9db0-b5f76773b3d9','53f24a15-bb67-40fe-bfaa-bd0d02a847b3','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-9-apa3dubgxov4-RoleParametersValue-bp2yhharpwou','state changed','OS::Heat::Value',NULL,774),(1229,'e5cf463c-2f48-4c66-8b17-4d3860ecbbb6','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','NeutronBase','4450778d-644b-497e-bc30-9144002a803a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,741),(1230,'e209b9bd-7ec3-4a8f-95c9-19051985ecf6','b88c6812-172b-430d-b1d1-d6fc9ce773c7','2026-06-10 07:59:40',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-15-nkexf6pipkn4','b88c6812-172b-430d-b1d1-d6fc9ce773c7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1231,'b8515308-fd59-4fb3-b6ea-a018b7e77b1b','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-25-mxgmdwiny5fy','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1232,'a001027e-0da9-479c-be51-a79666969078','b88c6812-172b-430d-b1d1-d6fc9ce773c7','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-15-nkexf6pipkn4','b88c6812-172b-430d-b1d1-d6fc9ce773c7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1233,'f78746e6-20b3-4714-a5ab-d55f701810b1','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:40',NULL,'CREATE','IN_PROGRESS','20','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-20-q47o5al3spwo','state changed','OS::TripleO::Services::Timezone',NULL,777),(1234,'c40247fc-5cc0-459a-8b7e-ac527efa6289','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','CinderBase','61e50392-9403-4b7d-bd5f-245bf9e98730','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,700),(1235,'e020c6e5-e60a-4c6f-ae5b-1a31c4d9e597','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-7-3qtmrgdxpuuh','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1236,'4e3983ac-0961-44f3-b7fc-ebfd38cfa4ff','ba2655e5-ec66-4f5a-8c98-7bd6d647feec','2026-06-10 07:59:40',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-20-q47o5al3spwo','ba2655e5-ec66-4f5a-8c98-7bd6d647feec','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1237,'679197d6-4f03-4ff2-97dd-e6af6ff2ea93','ba2655e5-ec66-4f5a-8c98-7bd6d647feec','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-20-q47o5al3spwo','ba2655e5-ec66-4f5a-8c98-7bd6d647feec','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1238,'f831147c-ea5b-43bb-acd6-567d91416e54','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','6','2b1846d4-f12e-48f6-a327-6376d5a5c119','state changed','OS::TripleO::Services::CinderScheduler',NULL,681),(1239,'37744017-af14-493e-a4b7-8815566d99f2','5931160f-9226-44c2-89a0-9c49d67d8318','2026-06-10 07:59:40',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-14-4rjpaugabrhf-RoleParametersValue-6socsdqqfnvl','state changed','OS::Heat::Value',NULL,778),(1240,'427fd161-7559-4c20-bfa2-10c678813f8d','5931160f-9226-44c2-89a0-9c49d67d8318','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-14-4rjpaugabrhf-RoleParametersValue-6socsdqqfnvl','state changed','OS::Heat::Value',NULL,778),(1241,'1cf55e8c-c507-4a37-b8ea-d7d096a37f1a','5931160f-9226-44c2-89a0-9c49d67d8318','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','ContainersCommon','d7e32449-841e-49fa-a99d-1e136d3bbffa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1242,'eedfe0e2-82f5-490a-a8cc-aa9c87d07ff7','8a71ff9c-2935-4ac8-af7d-06597963529d','2026-06-10 07:59:40',NULL,'CREATE','IN_PROGRESS','MysqlPuppetBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,779),(1243,'5ddfd7b0-fbea-467a-a359-c59c8b8939e3','5931160f-9226-44c2-89a0-9c49d67d8318','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-14-4rjpaugabrhf','5931160f-9226-44c2-89a0-9c49d67d8318','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1244,'304520cf-0e73-40f6-bfba-6187f30dbbf2','3126b43c-6081-4acb-9c3f-3f8798f681b1','2026-06-10 07:59:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7','3126b43c-6081-4acb-9c3f-3f8798f681b1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1245,'222cdb22-9d51-44ed-b443-95bea563f9a5','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','25','7c9a7910-2dc5-45a3-9f2a-172eff3857f5','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,703),(1246,'28eeed79-4eee-47bd-ba5d-5c303c4e4e87','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:40',NULL,'CREATE','COMPLETE','7','11453b49-9b7c-4d0c-aafb-3c7669cba9d0','state changed','OS::TripleO::Services::CinderVolume',NULL,658),(1247,'f3633b9c-5b6b-46f5-a9fe-fcff16dee5fb','3126b43c-6081-4acb-9c3f-3f8798f681b1','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7-RoleParametersValue-rtiapqnjw627','state changed','OS::Heat::Value',NULL,787),(1248,'a0b75eae-8c45-4aab-9038-c79c1442abb7','3126b43c-6081-4acb-9c3f-3f8798f681b1','2026-06-10 07:59:41',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7-RoleParametersValue-rtiapqnjw627','state changed','OS::Heat::Value',NULL,787),(1249,'36656170-f5eb-4864-bc15-0c1adb523d23','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','10','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-10-dhvgmivrsfc3','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,789),(1250,'6f69c326-8388-4852-8637-68f790617085','4b86c3a5-cc37-4ce3-8ef3-808a3f4a61cc','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-10-dhvgmivrsfc3','4b86c3a5-cc37-4ce3-8ef3-808a3f4a61cc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1251,'a9c10e35-e09a-4902-9b89-e8915bbe8418','53f24a15-bb67-40fe-bfaa-bd0d02a847b3','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-9-apa3dubgxov4-ContainersCommon-4vdf2krsdrde','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1252,'48d7ac4c-8160-475d-8291-1d442690ac71','4b86c3a5-cc37-4ce3-8ef3-808a3f4a61cc','2026-06-10 07:59:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-10-dhvgmivrsfc3','4b86c3a5-cc37-4ce3-8ef3-808a3f4a61cc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1253,'b7bb90fc-6736-4230-9380-a23b62f8a705','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:41',NULL,'CREATE','COMPLETE','15','b88c6812-172b-430d-b1d1-d6fc9ce773c7','state changed','OS::TripleO::Services::Podman',NULL,772),(1254,'7d44796b-fe75-40b1-b76c-a9823e1531ba','ad2540ea-6876-40a9-a5a8-8fd075c131d9','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-9-apa3dubgxov4-ContainersCommon-4vdf2krsdrde','ad2540ea-6876-40a9-a5a8-8fd075c131d9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1255,'0859ec21-eef5-45c5-bbd2-639370808c31','ad2540ea-6876-40a9-a5a8-8fd075c131d9','2026-06-10 07:59:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-9-apa3dubgxov4-ContainersCommon-4vdf2krsdrde','ad2540ea-6876-40a9-a5a8-8fd075c131d9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1256,'8e8ded18-89e1-4df3-8640-debd5a21d066','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:41',NULL,'CREATE','COMPLETE','20','ba2655e5-ec66-4f5a-8c98-7bd6d647feec','state changed','OS::TripleO::Services::Timezone',NULL,777),(1257,'ff9850ed-ad56-48a8-abf8-f92ae76552d5','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:41',NULL,'CREATE','COMPLETE','14','5931160f-9226-44c2-89a0-9c49d67d8318','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,746),(1258,'7ebab99b-b320-4996-8c22-f5e47810f910','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','19','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-19-dazsmux5ydat','state changed','OS::TripleO::Services::Timesync',NULL,796),(1259,'07324216-ddd3-45ac-9f96-cf5af336139c','119f304f-6259-405c-b40d-03983fab8ff7','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-19-dazsmux5ydat','119f304f-6259-405c-b40d-03983fab8ff7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1260,'14bceac1-2f93-4d77-b49c-0a6b28b39b41','119f304f-6259-405c-b40d-03983fab8ff7','2026-06-10 07:59:41',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-19-dazsmux5ydat','119f304f-6259-405c-b40d-03983fab8ff7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1261,'f4b75b7e-ff68-410e-b5a1-6aab6a4e138e','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','24','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl','state changed','OS::TripleO::Services::OVNController',NULL,803),(1262,'cb18b4cc-2380-4ffc-8d71-5e014e4141e8','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','18','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-18-f7jyr7fgpfqc','state changed','OS::TripleO::Services::Sshd',NULL,804),(1263,'37623cf7-481b-4e74-8844-624812413871','da526fae-264a-498a-9113-9f1c1156b8ee','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl','da526fae-264a-498a-9113-9f1c1156b8ee','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1264,'34e9fd74-48f5-491a-b023-2fb3e575fd0f','35dcb0e6-c178-4b3b-a9d3-aa76f0a7df25','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-18-f7jyr7fgpfqc','35dcb0e6-c178-4b3b-a9d3-aa76f0a7df25','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1265,'798f0707-68b9-4381-b0aa-1f092da66d28','35dcb0e6-c178-4b3b-a9d3-aa76f0a7df25','2026-06-10 07:59:41',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-18-f7jyr7fgpfqc','35dcb0e6-c178-4b3b-a9d3-aa76f0a7df25','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1266,'251dde0f-1e1b-4875-aad3-09c3b345487a','da526fae-264a-498a-9113-9f1c1156b8ee','2026-06-10 07:59:41',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl-OVNBridgeMappingsValue-qyyr4c2cix2n','state changed','OS::Heat::Value',NULL,812),(1267,'f033eb7f-a9ed-4319-bad2-2d24a854b414','da526fae-264a-498a-9113-9f1c1156b8ee','2026-06-10 07:59:41',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl-OVNBridgeMappingsValue-qyyr4c2cix2n','state changed','OS::Heat::Value',NULL,812),(1268,'1ed7c7fb-1521-4743-8871-287ae1b89287','3126b43c-6081-4acb-9c3f-3f8798f681b1','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7-MysqlBase-5fxe3hepcyuq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,814),(1269,'cd234ad8-afde-4759-9cbc-8043b8e47047','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','11','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6','state changed','OS::TripleO::Services::GlanceApi',NULL,815),(1270,'4da30ec8-468f-4a53-9fd3-750742cab8f8','f7441e6f-c931-4677-af99-93c50fd3ea24','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7-MysqlBase-5fxe3hepcyuq','f7441e6f-c931-4677-af99-93c50fd3ea24','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1271,'42d68e58-5422-4144-a7d8-6afd27418114','f7441e6f-c931-4677-af99-93c50fd3ea24','2026-06-10 07:59:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7-MysqlBase-5fxe3hepcyuq','f7441e6f-c931-4677-af99-93c50fd3ea24','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1272,'ceacfe76-1fa7-4511-ab44-77309eb5b147','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:42',NULL,'CREATE','COMPLETE','10','4b86c3a5-cc37-4ce3-8ef3-808a3f4a61cc','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,789),(1273,'ef39c8df-9a2d-4be9-ae99-87b98293b327','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6','300ccc26-9f80-4da5-a191-24fff06a6dd9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1274,'3007c864-9db8-4083-91ae-c998fddbaf6d','53f24a15-bb67-40fe-bfaa-bd0d02a847b3','2026-06-10 07:59:42',NULL,'CREATE','COMPLETE','ContainersCommon','ad2540ea-6876-40a9-a5a8-8fd075c131d9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1275,'5a8b81af-79be-4ae0-9be5-2400720b40df','53f24a15-bb67-40fe-bfaa-bd0d02a847b3','2026-06-10 07:59:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-9-apa3dubgxov4','53f24a15-bb67-40fe-bfaa-bd0d02a847b3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1276,'4779cbae-662d-4b15-8762-07b815e7f5e2','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-RoleParametersValue-7cdcqtyezbg6','state changed','OS::Heat::Value',NULL,817),(1277,'f2b0ee1a-b2f5-4d3f-85b4-7cc6a897a554','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:42',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-RoleParametersValue-7cdcqtyezbg6','state changed','OS::Heat::Value',NULL,817),(1278,'ca940995-a5bf-4a6d-960e-66b5d907db34','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','14','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong','state changed','OS::TripleO::Services::HeatApi',NULL,818),(1279,'8d0d1078-4305-49b8-86c8-e837089fd26f','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:42',NULL,'CREATE','COMPLETE','19','119f304f-6259-405c-b40d-03983fab8ff7','state changed','OS::TripleO::Services::Timesync',NULL,796),(1280,'09036087-e3c2-43c6-b068-764623d2855b','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong','c1531884-d195-475f-8fd7-5bfe3723f83b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1281,'623f2a33-f70a-43af-b02e-2e340bd4563d','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','23','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-23-2wiyveyp4rl7','state changed','OS::TripleO::Services::Tuned',NULL,820),(1282,'5efaf8f4-9246-4c39-8690-950db5b5ce39','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:42',NULL,'CREATE','COMPLETE','18','35dcb0e6-c178-4b3b-a9d3-aa76f0a7df25','state changed','OS::TripleO::Services::Sshd',NULL,804),(1283,'fbde5e53-16e3-43f1-9615-2abd35f53114','6c72f3a3-5bbb-47a0-8ccc-777e19d0aed6','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-23-2wiyveyp4rl7','6c72f3a3-5bbb-47a0-8ccc-777e19d0aed6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1284,'2f26c696-355d-4481-9314-4ed5b8c20fd7','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-RoleParametersValue-drke5hkonkww','state changed','OS::Heat::Value',NULL,821),(1285,'9d6a5626-5757-44d0-af29-ecb274421ecc','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:42',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-RoleParametersValue-drke5hkonkww','state changed','OS::Heat::Value',NULL,821),(1286,'8d341e88-6f15-4e2e-b602-c0d147d2064c','da526fae-264a-498a-9113-9f1c1156b8ee','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl-RoleParametersValue-qvbzyqejfz6v','state changed','OS::Heat::Value',NULL,822),(1287,'ce8014fa-f2b3-488d-b411-8187138d1499','da526fae-264a-498a-9113-9f1c1156b8ee','2026-06-10 07:59:42',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl-RoleParametersValue-qvbzyqejfz6v','state changed','OS::Heat::Value',NULL,822),(1288,'9f6a8ffe-c4b1-49da-99fe-a706616de032','6c72f3a3-5bbb-47a0-8ccc-777e19d0aed6','2026-06-10 07:59:42',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-23-2wiyveyp4rl7-RoleParametersValue-fddayrndslcm','state changed','OS::Heat::Value',NULL,824),(1289,'e1a1c726-cfe7-421e-8b6c-3a8193cdc92b','6c72f3a3-5bbb-47a0-8ccc-777e19d0aed6','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-23-2wiyveyp4rl7-RoleParametersValue-fddayrndslcm','state changed','OS::Heat::Value',NULL,824),(1290,'2817c0b2-0ae4-4705-adf6-072293633170','6c72f3a3-5bbb-47a0-8ccc-777e19d0aed6','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-23-2wiyveyp4rl7','6c72f3a3-5bbb-47a0-8ccc-777e19d0aed6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1291,'72501a36-0be2-4845-be9b-004bab3e8db7','3126b43c-6081-4acb-9c3f-3f8798f681b1','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7-ContainersCommon-uzclfhy5ogmx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1292,'ae350138-a7f1-4047-bac5-00b7e53dd93c','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','22','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-22-7ziy4thzeaof','state changed','OS::TripleO::Services::TripleoPackages',NULL,825),(1293,'79615189-ee14-4a96-81eb-e9f75db9f450','112649bf-4974-49b8-93fa-944d319fa606','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7-ContainersCommon-uzclfhy5ogmx','112649bf-4974-49b8-93fa-944d319fa606','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1294,'8930fe87-5c0b-44ca-9335-7312aaf1e0e1','112649bf-4974-49b8-93fa-944d319fa606','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7-ContainersCommon-uzclfhy5ogmx','112649bf-4974-49b8-93fa-944d319fa606','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1295,'9b436392-e9ee-4a96-8280-47658180b317','7b34a40a-c5c9-4585-938d-f0b482f11df4','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-22-7ziy4thzeaof','7b34a40a-c5c9-4585-938d-f0b482f11df4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1296,'9c639e0d-8b1f-4800-a3a7-0e6cd22381d2','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','9','53f24a15-bb67-40fe-bfaa-bd0d02a847b3','state changed','OS::TripleO::Services::Collectd',NULL,769),(1297,'4f208b3e-9452-4c00-86c4-1c3595dae746','3126b43c-6081-4acb-9c3f-3f8798f681b1','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','ContainersCommon','112649bf-4974-49b8-93fa-944d319fa606','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1298,'58c49ee2-a9a4-44f8-a4cd-218bc7e45607','3126b43c-6081-4acb-9c3f-3f8798f681b1','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','MysqlBase','f7441e6f-c931-4677-af99-93c50fd3ea24','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,814),(1299,'84d95e66-186f-476d-87f8-a4d5df57d7d7','3126b43c-6081-4acb-9c3f-3f8798f681b1','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4-MysqlPuppetBase-iqy42vjugzz7','3126b43c-6081-4acb-9c3f-3f8798f681b1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1300,'5018e7a4-de18-4f01-aa6b-42cee50c64ae','7b34a40a-c5c9-4585-938d-f0b482f11df4','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-22-7ziy4thzeaof-RoleParametersValue-haltskzpf7o6','state changed','OS::Heat::Value',NULL,827),(1301,'22c809d6-ecca-4e1c-8813-1866fc56791f','7b34a40a-c5c9-4585-938d-f0b482f11df4','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-22-7ziy4thzeaof-RoleParametersValue-haltskzpf7o6','state changed','OS::Heat::Value',NULL,827),(1302,'a7fbf57e-5f82-4d22-9e20-b1ef5a4a9041','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','13','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv','state changed','OS::TripleO::Services::HAproxy',NULL,830),(1303,'130d6a60-f9dc-4310-b197-712f04437e59','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-GlanceLogging-av33jo4kzlwf','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1304,'b63a83cf-f3df-4c0a-8f43-fd824a70a513','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv','10bbc01f-8cda-4ca8-a325-f43d65c647d1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1305,'09d448fd-39eb-44eb-8391-4b22a3b5dc62','546259c4-80ea-4bd2-85f6-b7d2dbc12512','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-GlanceLogging-av33jo4kzlwf','546259c4-80ea-4bd2-85f6-b7d2dbc12512','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1306,'23b261d0-69fa-40b8-95b7-f9b82619c731','546259c4-80ea-4bd2-85f6-b7d2dbc12512','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-GlanceLogging-av33jo4kzlwf-RoleParametersValue-ulucfy723dul','state changed','OS::Heat::Value',NULL,831),(1307,'419cda85-8ff6-4d8e-b711-b3bfa21fb10f','546259c4-80ea-4bd2-85f6-b7d2dbc12512','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-GlanceLogging-av33jo4kzlwf-RoleParametersValue-ulucfy723dul','state changed','OS::Heat::Value',NULL,831),(1308,'8fea57ce-fdbc-4d9e-8af8-6fa301e8f7f6','546259c4-80ea-4bd2-85f6-b7d2dbc12512','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-GlanceLogging-av33jo4kzlwf','546259c4-80ea-4bd2-85f6-b7d2dbc12512','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1309,'3f77043d-b33b-4f10-9cb2-88c92202ceae','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyPublicTLS-ow2jldkia2gg','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,832),(1310,'eeed7fce-e01e-4c38-9193-cf0d6195adfd','8a71ff9c-2935-4ac8-af7d-06597963529d','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','MysqlPuppetBase','3126b43c-6081-4acb-9c3f-3f8798f681b1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,779),(1311,'b97f3400-366b-4010-abea-40d198d03118','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','23','6c72f3a3-5bbb-47a0-8ccc-777e19d0aed6','state changed','OS::TripleO::Services::Tuned',NULL,820),(1312,'92d12ab8-0438-4438-a914-8810fecd507b','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-ContainersCommon-tj5tsc4cpna3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1313,'7402d65b-1749-4321-b6a5-5e18d2354c3b','9479eea6-f600-4e3d-8e85-e5e009a1da3a','2026-06-10 07:59:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyPublicTLS-ow2jldkia2gg','9479eea6-f600-4e3d-8e85-e5e009a1da3a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1314,'53c84411-36d4-45ca-8012-19b3a354b877','9479eea6-f600-4e3d-8e85-e5e009a1da3a','2026-06-10 07:59:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyPublicTLS-ow2jldkia2gg','9479eea6-f600-4e3d-8e85-e5e009a1da3a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1315,'0a475ea6-9c30-4a5f-9778-2421e87be324','da526fae-264a-498a-9113-9f1c1156b8ee','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl-ContainersCommon-rc2fvws5o6rt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1316,'b8325cda-06bc-482d-9524-9e44048ff9c2','8a71ff9c-2935-4ac8-af7d-06597963529d','2026-06-10 07:59:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-8-boxi5g6msgb4','8a71ff9c-2935-4ac8-af7d-06597963529d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1317,'0cd199d3-1562-4618-b4e5-f3704660c0c7','103a9f01-899c-4a56-bc30-f120740e82e0','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-ContainersCommon-tj5tsc4cpna3','103a9f01-899c-4a56-bc30-f120740e82e0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1318,'331bc641-a2e1-428e-9daf-c12caf90d170','103a9f01-899c-4a56-bc30-f120740e82e0','2026-06-10 07:59:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-ContainersCommon-tj5tsc4cpna3','103a9f01-899c-4a56-bc30-f120740e82e0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1319,'6385fd28-0e56-4e82-8216-89c69598e6f5','b60f7a3d-2d05-4c5f-9854-04f661c64468','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl-ContainersCommon-rc2fvws5o6rt','b60f7a3d-2d05-4c5f-9854-04f661c64468','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1320,'1d690832-6c62-4a1f-b386-e86e55b4fae4','b60f7a3d-2d05-4c5f-9854-04f661c64468','2026-06-10 07:59:44',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl-ContainersCommon-rc2fvws5o6rt','b60f7a3d-2d05-4c5f-9854-04f661c64468','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1321,'42fbf2ca-d48b-4356-a3aa-83666da5c87f','7b34a40a-c5c9-4585-938d-f0b482f11df4','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-22-7ziy4thzeaof-Podman-ufhfd4fbbfrq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,833),(1322,'144586f6-885a-4d4e-9bd1-49a0166b7124','4e9c7319-f2ef-4f07-9947-6a97345dec0a','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-22-7ziy4thzeaof-Podman-ufhfd4fbbfrq','4e9c7319-f2ef-4f07-9947-6a97345dec0a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1323,'c2e4c5ce-7802-4790-afbc-e3d2f9e7f772','4e9c7319-f2ef-4f07-9947-6a97345dec0a','2026-06-10 07:59:44',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-22-7ziy4thzeaof-Podman-ufhfd4fbbfrq','4e9c7319-f2ef-4f07-9947-6a97345dec0a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1324,'29d65151-1ce7-480a-a3b8-0846a8333416','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-MySQLClient-hhcxnbxym246','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1325,'f3d820ab-e991-495a-b539-d58d17786c64','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:44',NULL,'CREATE','COMPLETE','8','8a71ff9c-2935-4ac8-af7d-06597963529d','state changed','OS::TripleO::Services::Clustercheck',NULL,733),(1326,'d4f6fcaa-4ae8-40f7-846a-182aef8a7d37','33f61b9b-10e3-4f0f-bc1a-d1d844ed5826','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-MySQLClient-hhcxnbxym246','33f61b9b-10e3-4f0f-bc1a-d1d844ed5826','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1327,'8c168f5a-0fae-4e39-aedb-cf410895b1df','33f61b9b-10e3-4f0f-bc1a-d1d844ed5826','2026-06-10 07:59:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-MySQLClient-hhcxnbxym246','33f61b9b-10e3-4f0f-bc1a-d1d844ed5826','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1328,'03eb690f-5bb7-4a49-8476-5da29a76609f','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:44',NULL,'CREATE','COMPLETE','GlanceLogging','546259c4-80ea-4bd2-85f6-b7d2dbc12512','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1329,'5b4e6d85-27e1-4a23-ac79-67b4926df468','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:44',NULL,'CREATE','COMPLETE','MySQLClient','33f61b9b-10e3-4f0f-bc1a-d1d844ed5826','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1330,'54e9a9ed-a5fd-4110-8a3a-cbe8bd833e5f','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','HAProxyBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,836),(1331,'22bf4327-f283-404b-b032-a8142b7b8753','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','HeatApiLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-HeatApiLogging-oh7ec24lgl5x','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1332,'c75ac489-13b2-44a5-b732-51bd335ac649','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1333,'afb715b8-3cd0-4968-85a2-f07e455373c4','4d0f4304-676b-4e79-9934-72b702fdf699','2026-06-10 07:59:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-HeatApiLogging-oh7ec24lgl5x','4d0f4304-676b-4e79-9934-72b702fdf699','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1334,'c5ae765a-8bb5-486b-b65f-12405057c38c','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','9479eea6-f600-4e3d-8e85-e5e009a1da3a','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,832),(1335,'62120360-7483-4fb8-8670-18b80961aa54','4d0f4304-676b-4e79-9934-72b702fdf699','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-HeatApiLogging-oh7ec24lgl5x','4d0f4304-676b-4e79-9934-72b702fdf699','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1336,'af0c6db8-df08-4198-b24f-f88c973ee10d','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','ContainersCommon','103a9f01-899c-4a56-bc30-f120740e82e0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1337,'9a9bc182-b41f-4915-9723-8e39671f7674','da526fae-264a-498a-9113-9f1c1156b8ee','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','ContainersCommon','b60f7a3d-2d05-4c5f-9854-04f661c64468','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1338,'5799f961-4d91-40ef-af18-46625c36ccf1','da526fae-264a-498a-9113-9f1c1156b8ee','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-24-zf7q7i4a4anl','da526fae-264a-498a-9113-9f1c1156b8ee','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1339,'0aa0a83d-36a0-48b1-ad1d-e60bee8114ca','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyPublicTLS-cii6f53qrwic','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,842),(1340,'eba899e8-2bab-44da-8278-a979bcd5dae8','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','12','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,843),(1341,'4df8034c-53ca-49c5-b70c-9e1d96ac7508','048f181e-b35a-440d-8239-1db99a955997','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyPublicTLS-cii6f53qrwic','048f181e-b35a-440d-8239-1db99a955997','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1342,'04b86a7a-07c8-4dd2-8ef6-caa64663bc56','048f181e-b35a-440d-8239-1db99a955997','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyPublicTLS-cii6f53qrwic','048f181e-b35a-440d-8239-1db99a955997','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1343,'b367456c-dd4c-4038-bc73-ae5d6c538791','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','048f181e-b35a-440d-8239-1db99a955997','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,842),(1344,'074db354-988f-4735-8af2-89e1b8ce3995','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg','761065fe-255a-45ab-9904-eb2765819a4a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1345,'1048af07-861b-472f-8292-bc80f914a356','7b34a40a-c5c9-4585-938d-f0b482f11df4','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','Podman','4e9c7319-f2ef-4f07-9947-6a97345dec0a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,833),(1346,'8ffa76da-a735-4649-abf0-4014d47fabb9','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-RoleParametersValue-olazt5n3jk7n','state changed','OS::Heat::Value',NULL,844),(1347,'b7fb6cfc-52f7-461d-abbb-86bacc897207','7b34a40a-c5c9-4585-938d-f0b482f11df4','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4-22-7ziy4thzeaof','7b34a40a-c5c9-4585-938d-f0b482f11df4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1348,'93f76432-a6ed-42cd-89a0-22ad27538200','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-RoleParametersValue-olazt5n3jk7n','state changed','OS::Heat::Value',NULL,844),(1349,'9242d7c8-be8d-46fb-b99a-212d5510f749','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-CinderNVMeOF-tg3fsrxg3mor','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1350,'4c231c37-99d9-4eab-a6a9-9ee480fa63fa','765ea374-467a-4ab6-aa12-4715d0a7763b','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-CinderNVMeOF-tg3fsrxg3mor','765ea374-467a-4ab6-aa12-4715d0a7763b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1351,'96dfb725-afe2-4979-ac0b-7263793f79f1','765ea374-467a-4ab6-aa12-4715d0a7763b','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-CinderNVMeOF-tg3fsrxg3mor','765ea374-467a-4ab6-aa12-4715d0a7763b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1352,'3038ccb7-a271-41aa-9c59-2183b36a2d8d','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyInternalTLS-y5xzsqmvkfdj','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,845),(1353,'2b86e40c-d2a4-43d2-952f-3662d4a4a2c1','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:45',NULL,'CREATE','COMPLETE','24','da526fae-264a-498a-9113-9f1c1156b8ee','state changed','OS::TripleO::Services::OVNController',NULL,803),(1354,'bd12a3f5-1a90-4d8f-b7cf-d1f945a9cd38','fe5d7a75-3b73-4857-a2b1-49f0b91cc3ff','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyInternalTLS-y5xzsqmvkfdj','fe5d7a75-3b73-4857-a2b1-49f0b91cc3ff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1355,'a456f973-5142-4081-8fca-f457895b68ec','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-HeatBase-oz45jrjde7tn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,846),(1356,'1f353201-de5d-4a1a-95e0-2e297a9ecdc8','fe5d7a75-3b73-4857-a2b1-49f0b91cc3ff','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','HAProxyNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyInternalTLS-y5xzsqmvkfdj-HAProxyNetworks-c2juex264i7t','state changed','OS::Heat::Value',NULL,847),(1357,'03ec592c-459a-4e1c-b4d9-84982063864d','b89cab59-9d1a-479d-b930-f83274896878','2026-06-10 07:59:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-HeatBase-oz45jrjde7tn','b89cab59-9d1a-479d-b930-f83274896878','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1358,'a470a9b3-6f7d-4007-9c1f-d7af155e964b','b89cab59-9d1a-479d-b930-f83274896878','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-HeatBase-oz45jrjde7tn','b89cab59-9d1a-479d-b930-f83274896878','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1359,'d1a9e6ef-0a3d-4b74-b8e9-9234a97b5d59','fe5d7a75-3b73-4857-a2b1-49f0b91cc3ff','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','HAProxyNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyInternalTLS-y5xzsqmvkfdj-HAProxyNetworks-c2juex264i7t','state changed','OS::Heat::Value',NULL,847),(1360,'f2fd1a3f-f5a0-4553-bb39-0967b404dbf0','fe5d7a75-3b73-4857-a2b1-49f0b91cc3ff','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyInternalTLS-y5xzsqmvkfdj','fe5d7a75-3b73-4857-a2b1-49f0b91cc3ff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1361,'c8821114-6444-4113-8e42-c74b75f6d779','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','HeatApiLogging','4d0f4304-676b-4e79-9934-72b702fdf699','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1362,'89689776-66f0-4b37-88d2-5da4a691d18d','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:46',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-RoleParametersValue-huhnynkkdmbl','state changed','OS::Heat::Value',NULL,848),(1363,'78f5a82f-02d6-41b4-b730-f612198a1977','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-RoleParametersValue-huhnynkkdmbl','state changed','OS::Heat::Value',NULL,848),(1364,'f86706d9-894b-4d6a-aec8-fbf9ea351018','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','22','7b34a40a-c5c9-4585-938d-f0b482f11df4','state changed','OS::TripleO::Services::TripleoPackages',NULL,825),(1365,'5baa34a6-b578-4047-9337-bc449a627388','aa8926d6-afc6-4776-8293-07e5a80e1326','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceChain-ziqptyyjf4u4','aa8926d6-afc6-4776-8293-07e5a80e1326','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1366,'5eb2d888-4a35-435c-8c03-f224f8dc5ed4','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','ServiceChain','aa8926d6-afc6-4776-8293-07e5a80e1326','state changed','OS::Heat::ResourceChain',NULL,94),(1367,'dfcc79ac-b69b-48e2-b8dc-0d64237a8cf6','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:46',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-MySQLClient-sj42och3kdrt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1368,'1cebea5d-7afe-4050-b4fa-517f803bf270','12c6ffc0-c287-4961-aca8-e1d6d2cee68d','2026-06-10 07:59:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-MySQLClient-sj42och3kdrt','12c6ffc0-c287-4961-aca8-e1d6d2cee68d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1369,'44e812ee-f84b-41b5-a6e3-90affd3e7bb4','12c6ffc0-c287-4961-aca8-e1d6d2cee68d','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-MySQLClient-sj42och3kdrt','12c6ffc0-c287-4961-aca8-e1d6d2cee68d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1370,'b129e8d4-f7ae-4667-8107-2710f33dc1c4','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:46',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-TLSProxyBase-ztqvdjwoc5os','state changed','OS::TripleO::Services::TLSProxyBase',NULL,849),(1371,'29df5dcf-d5f4-4800-8b36-993c9aa2f7c3','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','CinderNVMeOF','765ea374-467a-4ab6-aa12-4715d0a7763b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1372,'c3576425-03e1-41bd-8308-6653f890c708','5eed9386-3e95-420f-9bca-b313974f9841','2026-06-10 07:59:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-TLSProxyBase-ztqvdjwoc5os','5eed9386-3e95-420f-9bca-b313974f9841','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1373,'086da3a0-c2da-450c-b381-7391730a2d76','5eed9386-3e95-420f-9bca-b313974f9841','2026-06-10 07:59:46',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-TLSProxyBase-ztqvdjwoc5os-ApacheNetworks-3k7yjk6ly47e','state changed','OS::Heat::Value',NULL,857),(1374,'8ce32eea-a099-43b6-99e5-d1333e0d27fc','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:46',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-RoleParametersValue-pe3duv6nbwli','state changed','OS::Heat::Value',NULL,856),(1375,'e2dd5ce8-9559-4be8-98f3-15bd9b96e84a','5eed9386-3e95-420f-9bca-b313974f9841','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-TLSProxyBase-ztqvdjwoc5os-ApacheNetworks-3k7yjk6ly47e','state changed','OS::Heat::Value',NULL,857),(1376,'20451464-f761-4a17-91bf-c7c5be1752df','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-RoleParametersValue-pe3duv6nbwli','state changed','OS::Heat::Value',NULL,856),(1377,'f01aa634-ce91-4ae7-ae24-f7d6b752bc0e','5eed9386-3e95-420f-9bca-b313974f9841','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-TLSProxyBase-ztqvdjwoc5os','5eed9386-3e95-420f-9bca-b313974f9841','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1378,'9637027a-d45c-443a-ad07-959d133cdfac','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:46',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','fe5d7a75-3b73-4857-a2b1-49f0b91cc3ff','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,845),(1379,'c6d6646f-c2a5-4148-bece-85d645cc4356','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:46',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-ApacheServiceBase-27snelkmk2dh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,861),(1380,'2b31aeb1-e81a-49bb-bc9f-80b53df5824d','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','HeatBase','b89cab59-9d1a-479d-b930-f83274896878','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,846),(1381,'f323f54d-9b9d-4f9d-897c-a0a0b4d3518d','5a39ff98-ae53-4d00-9922-98c65c75194c','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-ApacheServiceBase-27snelkmk2dh','5a39ff98-ae53-4d00-9922-98c65c75194c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1382,'67eeaeb2-f1b2-4a59-b672-ab5f58c254c1','5a39ff98-ae53-4d00-9922-98c65c75194c','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-ApacheServiceBase-27snelkmk2dh-ApacheNetworks-muh3in3a7z5f','state changed','OS::Heat::Value',NULL,865),(1383,'c0ac59a7-284d-4577-88c0-8291ce5bf325','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','HAProxyLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyLogging-b5zob2y4h5uw','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1384,'f1668244-109e-4daa-a0d6-a0ce4f6ee8ce','5a39ff98-ae53-4d00-9922-98c65c75194c','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-ApacheServiceBase-27snelkmk2dh-ApacheNetworks-muh3in3a7z5f','state changed','OS::Heat::Value',NULL,865),(1385,'bcf16cc4-f20d-4513-ad81-1b8cb07509ea','5a39ff98-ae53-4d00-9922-98c65c75194c','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong-ApacheServiceBase-27snelkmk2dh','5a39ff98-ae53-4d00-9922-98c65c75194c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1386,'dc59dee6-bb09-48ab-a083-afb87aae0edb','c2132f67-de7d-43ce-b908-1e53d6ea6916','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyLogging-b5zob2y4h5uw','c2132f67-de7d-43ce-b908-1e53d6ea6916','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1387,'e95e9ea7-1bc9-4d6d-8d25-e6ccb864206c','c2132f67-de7d-43ce-b908-1e53d6ea6916','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyLogging-b5zob2y4h5uw','c2132f67-de7d-43ce-b908-1e53d6ea6916','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1388,'47951066-ca51-4cbc-9523-25af5dc2cf83','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-4wlndewsilqw-PreUpgradeRollingTasks-2josvikebtc2','state changed','OS::Heat::Value',NULL,868),(1389,'8c8cefbc-27d0-45e1-b5f0-810d10d1a079','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','GlanceApi','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,869),(1390,'5c6f8102-6528-4531-8bf1-8f2ce2595729','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-ContainersCommon-n6sf3vpdufcp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1391,'d8a137c0-165a-49f5-b7a7-fcf2fe652819','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ExternalDeployTasks-vekp2myh7yai','state changed','OS::Heat::Value',NULL,870),(1392,'d53c6d30-2798-423e-a561-b7d1107cc2ce','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ExternalDeployTasks-vekp2myh7yai','state changed','OS::Heat::Value',NULL,870),(1393,'8676e5e7-36ef-4391-9b50-5d17959c979b','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','MySQLClient','12c6ffc0-c287-4961-aca8-e1d6d2cee68d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1394,'f5633014-f5a1-4132-97fc-b3f46f773c6b','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5','b6435493-469a-4083-994a-5f32d8731944','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1395,'6efe22b1-38c5-43bc-9496-801b0ebec3d6','3b8ac5bc-1c49-4a4c-9e35-eff8ecb2bba1','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-ContainersCommon-n6sf3vpdufcp','3b8ac5bc-1c49-4a4c-9e35-eff8ecb2bba1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1396,'609d7a64-2d3a-49b7-9db2-ee30e2cbfd9c','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-4wlndewsilqw-PreUpgradeRollingTasks-2josvikebtc2','state changed','OS::Heat::Value',NULL,868),(1397,'e4b7b89b-87c0-4bd7-ad64-3de587c6603e','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ComputeServiceChain-4wlndewsilqw-AnsibleGroupVars-jyhqllmw2y5i','state changed','OS::Heat::Value',NULL,871),(1398,'7765c3b6-2e12-4d90-be3f-e81d51decc59','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceNames-ivjsb2orhf7g','state changed','OS::Heat::Value',NULL,872),(1399,'b5387499-2624-4b8a-a836-fae251d05f90','3b8ac5bc-1c49-4a4c-9e35-eff8ecb2bba1','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6-ContainersCommon-n6sf3vpdufcp','3b8ac5bc-1c49-4a4c-9e35-eff8ecb2bba1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1400,'af7f6e82-ed30-43a5-bf28-033dfcb3c511','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceNames-ivjsb2orhf7g','state changed','OS::Heat::Value',NULL,872),(1401,'3e93cbc0-fa2b-46d9-a9f8-0e41e7fe19d1','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ComputeServiceChain-4wlndewsilqw-AnsibleGroupVars-jyhqllmw2y5i','state changed','OS::Heat::Value',NULL,871),(1402,'a0935a59-9388-409c-99dd-8e999410ea08','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','TLSProxyBase','5eed9386-3e95-420f-9bca-b313974f9841','state changed','OS::TripleO::Services::TLSProxyBase',NULL,849),(1403,'02ab4775-e2b5-4104-9b02-90775ec42caa','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-ContainersCommon-jm22gamnt5c5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1404,'04073347-172d-4f5e-94b8-3ea8e9372b16','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ComputeServiceChain-4wlndewsilqw-PuppetConfig-ih3rnupveqma','state changed','OS::Heat::Value',NULL,873),(1405,'238d4138-e506-49ad-8ce8-ee5b9dbf7c12','f22c24dc-3d7a-45b8-a6a3-bfca1f39a491','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-ContainersCommon-jm22gamnt5c5','f22c24dc-3d7a-45b8-a6a3-bfca1f39a491','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1406,'378bb809-91a8-4e03-ad57-112365fd728f','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ComputeServiceChain-4wlndewsilqw-PuppetConfig-ih3rnupveqma','state changed','OS::Heat::Value',NULL,873),(1407,'dd8fd86b-634e-4efd-be94-28943c995ca9','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-GlanceLogging-rzsv5fabdny4','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1408,'2f739ed7-603a-4658-a605-e27d85e43101','f22c24dc-3d7a-45b8-a6a3-bfca1f39a491','2026-06-10 07:59:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-ContainersCommon-jm22gamnt5c5','f22c24dc-3d7a-45b8-a6a3-bfca1f39a491','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1409,'284b58e3-f303-40ff-b93d-ce53f4ebf556','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:47',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ComputeServiceChain-4wlndewsilqw-HostFirewallTasks-kodmrzl5tzgk','state changed','OS::Heat::Value',NULL,874),(1410,'54e32845-aa51-40a5-a37c-c2cbc5c78ba2','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ComputeServiceChain-4wlndewsilqw-DockerPuppetTasks-4hybtqupefyb','state changed','OS::Heat::Value',NULL,875),(1411,'9380ba0a-7939-4a22-bfaa-d0469465b988','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ComputeServiceChain-4wlndewsilqw-DockerPuppetTasks-4hybtqupefyb','state changed','OS::Heat::Value',NULL,875),(1412,'6eab28d4-06fe-494d-8902-6c91e446c07c','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','ApacheServiceBase','5a39ff98-ae53-4d00-9922-98c65c75194c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,861),(1413,'65734191-89df-4fb2-abcf-988a933eb7ca','c1531884-d195-475f-8fd7-5bfe3723f83b','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-14-um5sjyqoiong','c1531884-d195-475f-8fd7-5bfe3723f83b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1414,'e05cbe5b-da5c-436b-96a8-9f2b9ecc83b3','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ComputeServiceChain-4wlndewsilqw-FirewallRules-zkitp5w54xal','state changed','OS::Heat::Value',NULL,876),(1415,'eda1e776-60e8-4582-9c06-409e5eefadf6','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyInternalTLS-fbmwgmdgfejv','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,877),(1416,'d64f94c2-b5f4-4703-b0aa-7a81ce778626','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ComputeServiceChain-4wlndewsilqw-FirewallRules-zkitp5w54xal','state changed','OS::Heat::Value',NULL,876),(1417,'e80a08d8-e53c-4803-8d60-89dea0b2e4d3','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ComputeServiceChain-4wlndewsilqw-HostFirewallTasks-kodmrzl5tzgk','state changed','OS::Heat::Value',NULL,874),(1418,'dcebda20-d74c-4996-9d4c-67595eeccf2e','85e31fb2-51e6-4365-850c-39cb77263283','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-GlanceLogging-rzsv5fabdny4','85e31fb2-51e6-4365-850c-39cb77263283','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1419,'f3d601db-7559-4402-8b79-fbca13dbe0a5','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ComputeServiceChain-4wlndewsilqw-PuppetStepConfig-saykpptlsfgg','state changed','OS::Heat::Value',NULL,878),(1420,'5559485a-f342-4cc9-8b88-e3e0909585a6','e9d25778-9aef-48da-a33c-a01881aaa5a6','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyInternalTLS-fbmwgmdgfejv','e9d25778-9aef-48da-a33c-a01881aaa5a6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1421,'1b455084-b0fe-44f3-85de-48a6a18d2ed7','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','HAProxyLogging','c2132f67-de7d-43ce-b908-1e53d6ea6916','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1422,'28236268-7e69-4f52-ae6c-3c72b0140cc7','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceConfigSettings-to52edektmtr','state changed','OS::Heat::Value',NULL,879),(1423,'7481bb68-4fb8-4709-aa2c-f504ad71aa72','e9d25778-9aef-48da-a33c-a01881aaa5a6','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','HAProxyNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyInternalTLS-fbmwgmdgfejv-HAProxyNetworks-24zcl54pgjrg','state changed','OS::Heat::Value',NULL,880),(1424,'e21c992f-fff1-4d98-a1a3-923b23f46dc2','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceConfigSettings-to52edektmtr','state changed','OS::Heat::Value',NULL,879),(1425,'c08f129a-53e0-492d-ab1a-38e06159f28e','e9d25778-9aef-48da-a33c-a01881aaa5a6','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','HAProxyNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyInternalTLS-fbmwgmdgfejv-HAProxyNetworks-24zcl54pgjrg','state changed','OS::Heat::Value',NULL,880),(1426,'d276d526-8eeb-49b8-bd50-5c383ba80bc6','e9d25778-9aef-48da-a33c-a01881aaa5a6','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-HAProxyInternalTLS-fbmwgmdgfejv','e9d25778-9aef-48da-a33c-a01881aaa5a6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1427,'568f0e22-8384-4b42-bcc7-7dca8afacdaa','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ComputeServiceChain-4wlndewsilqw-PuppetStepConfig-saykpptlsfgg','state changed','OS::Heat::Value',NULL,878),(1428,'a7c6c73a-a94b-4b79-ae15-f830689ee9c9','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ComputeServiceChain-4wlndewsilqw-UpgradeBatchTasks-j2xwi6ns7yde','state changed','OS::Heat::Value',NULL,881),(1429,'ed4b49ab-0398-457a-9ffc-7a701fa89171','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceLogging-cvy5zdocczzb','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1430,'58ca5671-323e-4622-8cff-d098267d0790','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ComputeServiceChain-4wlndewsilqw-UpdateTasks-xse2lg2iwv7b','state changed','OS::Heat::Value',NULL,882),(1431,'f19cad48-17b7-4c99-ba26-7f407246a20e','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ComputeServiceChain-4wlndewsilqw-UpgradeBatchTasks-j2xwi6ns7yde','state changed','OS::Heat::Value',NULL,881),(1432,'622fe918-cc7c-42c9-b620-dcf7c30b9f8d','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ComputeServiceChain-4wlndewsilqw-UpdateTasks-xse2lg2iwv7b','state changed','OS::Heat::Value',NULL,882),(1433,'3c23f4bd-0f17-4854-8e5c-f0405a584f9c','d50f3c1f-8809-4a79-9495-cf85d32d920d','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceLogging-cvy5zdocczzb','d50f3c1f-8809-4a79-9495-cf85d32d920d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1434,'0508ac45-8939-4d66-8f79-5a4c1a389e58','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ComputeServiceChain-4wlndewsilqw-GlobalConfigSettings-ued5cqxpfsn6','state changed','OS::Heat::Value',NULL,884),(1435,'74e386c8-afee-4558-9b20-983ea9abf0ea','85e31fb2-51e6-4365-850c-39cb77263283','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-GlanceLogging-rzsv5fabdny4-RoleParametersValue-hlzt4qveibod','state changed','OS::Heat::Value',NULL,883),(1436,'1046631c-347a-4003-9e79-1f7e2ed869ff','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ComputeServiceChain-4wlndewsilqw-GlobalConfigSettings-ued5cqxpfsn6','state changed','OS::Heat::Value',NULL,884),(1437,'0585027f-4554-4ced-a971-f374b6dd70f5','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ExternalUpdateTasks-dnuur5dzag6t','state changed','OS::Heat::Value',NULL,885),(1438,'5aa44e78-7282-49b1-a45c-e54168d311a4','85e31fb2-51e6-4365-850c-39cb77263283','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-GlanceLogging-rzsv5fabdny4-RoleParametersValue-hlzt4qveibod','state changed','OS::Heat::Value',NULL,883),(1439,'9c0566dd-71bf-4dc4-9a4c-76ec5a129381','85e31fb2-51e6-4365-850c-39cb77263283','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-GlanceLogging-rzsv5fabdny4','85e31fb2-51e6-4365-850c-39cb77263283','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1440,'d6204f64-6a07-42ca-bfb8-bbf0567739ad','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ExternalUpdateTasks-dnuur5dzag6t','state changed','OS::Heat::Value',NULL,885),(1441,'bd21a4b9-e6d9-4385-90be-fd2a09c89e5a','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','ContainersCommon','3b8ac5bc-1c49-4a4c-9e35-eff8ecb2bba1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1442,'38756ea5-1a13-4975-9233-0fb243c318f3','d50f3c1f-8809-4a79-9495-cf85d32d920d','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceLogging-cvy5zdocczzb-RoleParametersValue-7aiagl5ujcrj','state changed','OS::Heat::Value',NULL,886),(1443,'6e18a233-9fcd-4aa2-a05a-76b99c0ea718','300ccc26-9f80-4da5-a191-24fff06a6dd9','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-11-mdhxnrecoex6','300ccc26-9f80-4da5-a191-24fff06a6dd9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1444,'0f2641e9-856a-4452-ad47-b5855f383fa9','d50f3c1f-8809-4a79-9495-cf85d32d920d','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceLogging-cvy5zdocczzb-RoleParametersValue-7aiagl5ujcrj','state changed','OS::Heat::Value',NULL,886),(1445,'ee45801c-f129-465e-bef7-3efd8194e97c','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','14','c1531884-d195-475f-8fd7-5bfe3723f83b','state changed','OS::TripleO::Services::HeatApi',NULL,818),(1446,'f71de1bc-d1be-44d6-b006-3a406f6b9843','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ComputeServiceChain-4wlndewsilqw-PostUpgradeTasks-wx7ex43ga4ww','state changed','OS::Heat::Value',NULL,887),(1447,'b2e75a79-c1d2-413e-810f-c25d4c0b52e1','d50f3c1f-8809-4a79-9495-cf85d32d920d','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceLogging-cvy5zdocczzb','d50f3c1f-8809-4a79-9495-cf85d32d920d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1448,'5249d3e4-21ad-4f47-863e-4c060e0b2310','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ComputeServiceChain-4wlndewsilqw-DockerConfig-v5tevaxuirz3','state changed','OS::Heat::Value',NULL,888),(1449,'70ccb83c-076e-42b6-aa0a-536c9c67286c','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ComputeServiceChain-4wlndewsilqw-PostUpgradeTasks-wx7ex43ga4ww','state changed','OS::Heat::Value',NULL,887),(1450,'83e4e835-bec6-4b5d-a960-cadde6cd19d8','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-ContainersCommon-pm5vxbxvffms','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1451,'c1fc236a-1d2c-46fc-aa4c-3a6ebd1f91fd','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-4wlndewsilqw-KeystoneResourcesConfigs-czqan3xhfziv','state changed','OS::Heat::Value',NULL,889),(1452,'17e02ddf-a732-4138-8076-ddbc6eedede2','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ComputeServiceChain-4wlndewsilqw-DockerConfig-v5tevaxuirz3','state changed','OS::Heat::Value',NULL,888),(1453,'1d4e28fe-8faa-41e1-bf37-e6fcdb1e6bf8','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','ContainersCommon','f22c24dc-3d7a-45b8-a6a3-bfca1f39a491','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1454,'0a3813c7-4522-4918-813a-8f1d78123b3c','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:48',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-4wlndewsilqw-KeystoneResourcesConfigs-czqan3xhfziv','state changed','OS::Heat::Value',NULL,889),(1455,'c8d04733-b139-418c-93cb-2aa9af4266d4','0c9af231-bfd8-456c-8bdc-9863a28a95bd','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-ContainersCommon-pm5vxbxvffms','0c9af231-bfd8-456c-8bdc-9863a28a95bd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1456,'80931fe6-d17b-402f-b346-f386e40c6bcf','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ComputeServiceChain-4wlndewsilqw-UpgradeTasks-4onylo7vu74r','state changed','OS::Heat::Value',NULL,891),(1457,'91b82c1a-9e5f-49c3-85db-c07129aa3adc','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ComputeServiceChain-4wlndewsilqw-UpgradeTasks-4onylo7vu74r','state changed','OS::Heat::Value',NULL,891),(1458,'b339dfaf-db73-4021-9db3-2d3dd18340b0','0c9af231-bfd8-456c-8bdc-9863a28a95bd','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-ContainersCommon-pm5vxbxvffms','0c9af231-bfd8-456c-8bdc-9863a28a95bd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1459,'a731ca93-34db-4116-9807-434f59c46c22','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ComputeServiceChain-4wlndewsilqw-PreDeployStepTasks-pokrovp7ihqr','state changed','OS::Heat::Value',NULL,895),(1460,'80da3f7d-a6d2-4f39-82ab-b4673e0b4cae','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-ContainersCommon-tq7d25sl4dqg','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1461,'edc938c9-767e-4f9c-babf-a44b8d9d8af1','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ComputeServiceChain-4wlndewsilqw-DockerConfigScripts-f6sldkg6uom2','state changed','OS::Heat::Value',NULL,898),(1462,'c445656b-aa5f-4e2b-bf71-d9ab5f326e03','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ComputeServiceChain-4wlndewsilqw-PreDeployStepTasks-pokrovp7ihqr','state changed','OS::Heat::Value',NULL,895),(1463,'2ac8be59-0b7a-40a4-885c-70a93d273136','287cd7b8-adeb-4a79-9e2b-b20858fc829d','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-ContainersCommon-tq7d25sl4dqg','287cd7b8-adeb-4a79-9e2b-b20858fc829d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1464,'7aaf3af1-64ee-4f16-9429-0c34bef45ba5','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ComputeServiceChain-4wlndewsilqw-DockerConfigScripts-f6sldkg6uom2','state changed','OS::Heat::Value',NULL,898),(1465,'88a52c68-dee6-403e-b634-fee2f3b3b8cd','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','GlanceLogging','85e31fb2-51e6-4365-850c-39cb77263283','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1466,'3a7bdce2-5390-4a20-b430-34e7e87db000','287cd7b8-adeb-4a79-9e2b-b20858fc829d','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh-ContainersCommon-tq7d25sl4dqg','287cd7b8-adeb-4a79-9e2b-b20858fc829d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1467,'8d981570-6e5d-4ab6-9593-4b362dd4d93f','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','e9d25778-9aef-48da-a33c-a01881aaa5a6','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,877),(1468,'ba0d94f4-63f4-4bd8-bbe8-70052d1b22a9','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ComputeServiceChain-4wlndewsilqw-FirewallFrontendRules-6poly44wo52h','state changed','OS::Heat::Value',NULL,900),(1469,'b77496a7-87a9-4997-bb66-08fb17de5b10','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','11','300ccc26-9f80-4da5-a191-24fff06a6dd9','state changed','OS::TripleO::Services::GlanceApi',NULL,815),(1470,'b1cd62e1-0f95-43a7-b525-fef6a7d93a99','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ComputeServiceChain-4wlndewsilqw-FirewallFrontendRules-6poly44wo52h','state changed','OS::Heat::Value',NULL,900),(1471,'7f009f79-313e-46a0-bb8c-40acbcc1d0c7','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','18','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-18-ucm65pbznnns','state changed','OS::TripleO::Services::Horizon',NULL,901),(1472,'0001db2c-b1e8-418b-b2d0-225a91836255','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ExternalUpgradeTasks-73sunyrlcxa2','state changed','OS::Heat::Value',NULL,902),(1473,'9a93507b-59aa-4078-bc9f-ccbc5cdf8bda','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ExternalUpgradeTasks-73sunyrlcxa2','state changed','OS::Heat::Value',NULL,902),(1474,'3e60a667-e7c0-40bf-882f-cb827b4e4186','df945adc-7187-4949-895c-9e5a65025244','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-18-ucm65pbznnns','df945adc-7187-4949-895c-9e5a65025244','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1475,'41b647f2-bc92-49f4-b683-d14c7209f09e','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','GlanceLogging','d50f3c1f-8809-4a79-9495-cf85d32d920d','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1476,'2bfa2176-dad3-4261-865e-40d4f7f6dee6','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-4wlndewsilqw-MonitoringSubscriptionsConfig-lgj7tgnkvcx5','state changed','OS::Heat::Value',NULL,904),(1477,'b55b946a-641e-4b13-a631-becf34e2abd8','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-4wlndewsilqw-MonitoringSubscriptionsConfig-lgj7tgnkvcx5','state changed','OS::Heat::Value',NULL,904),(1478,'e0bfc07b-45d8-4315-b8d4-942eb262b593','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ComputeServiceChain-4wlndewsilqw-PostUpdateTasks-zow3i5jnlik4','state changed','OS::Heat::Value',NULL,908),(1479,'92379fcf-278c-4b7b-bb0d-b0a79e5f608a','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ComputeServiceChain-4wlndewsilqw-PostUpdateTasks-zow3i5jnlik4','state changed','OS::Heat::Value',NULL,908),(1480,'40787fdb-08c6-4d46-9476-1347825dca4a','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ExternalPostDeployTasks-q37yrf4ktpdc','state changed','OS::Heat::Value',NULL,912),(1481,'1a465f59-dc0d-464d-b44d-49e50f0577c4','df945adc-7187-4949-895c-9e5a65025244','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-18-ucm65pbznnns-RoleParametersValue-w64cgv7bd6g5','state changed','OS::Heat::Value',NULL,910),(1482,'e2271fd1-421f-4551-bea8-d0c0e73b4f8e','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ExternalPostDeployTasks-q37yrf4ktpdc','state changed','OS::Heat::Value',NULL,912),(1483,'99149874-5704-460a-89eb-f25fb9b380c7','df945adc-7187-4949-895c-9e5a65025244','2026-06-10 07:59:49',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-18-ucm65pbznnns-RoleParametersValue-w64cgv7bd6g5','state changed','OS::Heat::Value',NULL,910),(1484,'cdfcb667-ea7d-4ba5-8fe8-a4d081d29a2c','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-MySQLClient-oom4coqkntvj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1485,'68f01754-af1f-4aa7-9f65-884c39a59cb0','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceServerMetadataHook-7ahl3jq5knu5','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,914),(1486,'bbd33832-817a-43ff-8ad9-06775a408349','b587f756-9399-4392-9a23-1d8a7c916414','2026-06-10 07:59:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-MySQLClient-oom4coqkntvj','b587f756-9399-4392-9a23-1d8a7c916414','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1487,'3e72b0a2-b6d1-433e-b38f-aed056d74200','b587f756-9399-4392-9a23-1d8a7c916414','2026-06-10 07:59:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-MySQLClient-oom4coqkntvj','b587f756-9399-4392-9a23-1d8a7c916414','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1488,'648a0cdc-3a5b-4bfe-b4e0-e0a763d3b0a4','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:50',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ComputeServiceChain-4wlndewsilqw-KollaConfig-vekv75lw57w4','state changed','OS::Heat::Value',NULL,915),(1489,'8a756e2e-567a-4224-8ecd-1b3329205850','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:50',NULL,'CREATE','COMPLETE','ContainersCommon','0c9af231-bfd8-456c-8bdc-9863a28a95bd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1490,'d9e49daf-7605-4e52-b67f-1480451bc3bb','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:50',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ContainerPuppetTasks-pncyw4b5oizq','state changed','OS::Heat::Value',NULL,917),(1491,'d1883e9b-3655-40ec-b064-5738fa35933d','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:50',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ContainerPuppetTasks-pncyw4b5oizq','state changed','OS::Heat::Value',NULL,917),(1492,'65f12744-af90-4c87-923e-1b5e9b1fc667','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:50',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ComputeServiceChain-4wlndewsilqw-KollaConfig-vekv75lw57w4','state changed','OS::Heat::Value',NULL,915),(1493,'0fab9ba5-1049-4d98-8869-a7bad7c8b45c','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:50',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ComputeServiceChain-4wlndewsilqw-IpaRegistrationTasks-neutjd2ogihs','state changed','OS::Heat::Value',NULL,919),(1494,'5c5d2517-d1cf-44dc-9475-825da757af70','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:50',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ComputeServiceChain-4wlndewsilqw-IpaRegistrationTasks-neutjd2ogihs','state changed','OS::Heat::Value',NULL,919),(1495,'1d653e2c-00ff-4585-abe3-b7a21eec7926','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:50',NULL,'CREATE','COMPLETE','ContainersCommon','287cd7b8-adeb-4a79-9e2b-b20858fc829d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1496,'afd0fd62-b8dd-43f7-a141-469d9a651dee','c5d30b7a-c705-4242-ae9c-4d44bb116539','2026-06-10 07:59:50',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceServerMetadataHook-7ahl3jq5knu5','c5d30b7a-c705-4242-ae9c-4d44bb116539','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1497,'fbce4c8d-91bf-4654-95bc-1abdc65afef7','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','2026-06-10 07:59:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv-HAProxyBase-q7kxipb4z5wh','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1498,'071b22f1-cbc1-4768-b74e-bec9d369cfee','df945adc-7187-4949-895c-9e5a65025244','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-18-ucm65pbznnns-ContainersCommon-lw64rlh4q6g6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1499,'34e8901d-a1d8-4d7d-be7d-6eec429f9e36','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','MySQLClient','b587f756-9399-4392-9a23-1d8a7c916414','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1500,'06b74780-d489-488e-9709-70b26ae7d724','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-CinderNVMeOF-bcmcrsazijbs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1501,'3e296b0f-3095-4f55-9418-cb56d712e29b','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','15','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-15-3xs2xvwn53tp','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,921),(1502,'3cde2edb-9ec9-4181-a8aa-2342ba2d7657','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ScaleTasks-tpmuvwmfl32f','state changed','OS::Heat::Value',NULL,920),(1503,'341a3769-bf7e-47d4-a827-e109823e6293','30b5670e-679e-4d55-8540-4afb7713fd69','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-15-3xs2xvwn53tp','30b5670e-679e-4d55-8540-4afb7713fd69','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1504,'1ff7d9b3-96aa-4694-a9bd-e2bd9416608c','7faa8185-cd7c-43d2-8793-a37a2b0b5b13','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-18-ucm65pbznnns-ContainersCommon-lw64rlh4q6g6','7faa8185-cd7c-43d2-8793-a37a2b0b5b13','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1505,'2fd5134a-6b22-4609-ba6a-6a26246e7a27','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','HAProxyBase','4d2e7c8e-44d8-46c2-afd5-fed31cdfc371','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,836),(1506,'2ffee03f-ca8c-4eeb-998f-5adb4eb4bb3b','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ComputeServiceChain-4wlndewsilqw-DeployStepsTasks-lvj7sussdbnj','state changed','OS::Heat::Value',NULL,922),(1507,'22e594de-465a-470f-b878-ddfb938373b0','30b5670e-679e-4d55-8540-4afb7713fd69','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-15-3xs2xvwn53tp','30b5670e-679e-4d55-8540-4afb7713fd69','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1508,'591b2ac1-83b7-4f9b-acbe-7e984afb4ba9','7faa8185-cd7c-43d2-8793-a37a2b0b5b13','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-18-ucm65pbznnns-ContainersCommon-lw64rlh4q6g6','7faa8185-cd7c-43d2-8793-a37a2b0b5b13','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1509,'b5295a52-6d83-410d-80c1-1f6e16830fe1','0b3cb5e3-b29c-4a92-a9b5-986833f95c05','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-CinderNVMeOF-bcmcrsazijbs','0b3cb5e3-b29c-4a92-a9b5-986833f95c05','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1510,'5e4abb44-eeff-486f-8f80-ea3d70a9182e','10bbc01f-8cda-4ca8-a325-f43d65c647d1','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-13-rl7d4yikmebv','10bbc01f-8cda-4ca8-a325-f43d65c647d1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1511,'eadc0d40-1122-4f76-9f30-42ad39665a1e','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ComputeServiceChain-4wlndewsilqw-DeployStepsTasks-lvj7sussdbnj','state changed','OS::Heat::Value',NULL,922),(1512,'4c0f0634-cf06-4e1f-b0b8-30d35305aef2','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','15','30b5670e-679e-4d55-8540-4afb7713fd69','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,921),(1513,'06f964f1-d4c7-41eb-8b37-a1db3c0e2595','0b3cb5e3-b29c-4a92-a9b5-986833f95c05','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-CinderNVMeOF-bcmcrsazijbs','0b3cb5e3-b29c-4a92-a9b5-986833f95c05','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1514,'8b8a8afe-dbfc-4389-85cf-fc03a0e841a0','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ComputeServiceChain-4wlndewsilqw-ScaleTasks-tpmuvwmfl32f','state changed','OS::Heat::Value',NULL,920),(1515,'a9f8fbc8-8fe9-4f8b-8859-d59cb03a862e','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ComputeServiceChain-4wlndewsilqw-HostPrepTasks-3zidoz4oj3lr','state changed','OS::Heat::Value',NULL,924),(1516,'66e99f05-3034-4729-9344-71741c338554','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ComputeServiceChain-4wlndewsilqw-HostPrepTasks-3zidoz4oj3lr','state changed','OS::Heat::Value',NULL,924),(1517,'c05fb6a3-94ac-4949-9ee5-47033f7ee301','c5d30b7a-c705-4242-ae9c-4d44bb116539','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceServerMetadataHook-7ahl3jq5knu5-IncomingMetadataSettings-hn2cdihbxsaw','state changed','OS::Heat::Value',NULL,926),(1518,'c59d1774-b999-4c40-9df2-347e849f3fe3','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','19','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-19-g2hbfoaeypw2','state changed','OS::TripleO::Services::IpaClient',NULL,927),(1519,'6f5fd40c-abdf-45e0-a91c-a29966ca6e06','c5d30b7a-c705-4242-ae9c-4d44bb116539','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceServerMetadataHook-7ahl3jq5knu5-IncomingMetadataSettings-hn2cdihbxsaw','state changed','OS::Heat::Value',NULL,926),(1520,'6c356889-86a3-4e6c-a1aa-946f593e7f42','c5d30b7a-c705-4242-ae9c-4d44bb116539','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceServerMetadataHook-7ahl3jq5knu5-IndividualServices-k6zoksysqbgp','state changed','OS::Heat::Value',NULL,928),(1521,'57107312-4178-4b8d-a15c-29e25a116ba1','c5d30b7a-c705-4242-ae9c-4d44bb116539','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceServerMetadataHook-7ahl3jq5knu5-IndividualServices-k6zoksysqbgp','state changed','OS::Heat::Value',NULL,928),(1522,'ca8ed69c-ed29-4b3e-94a3-c4f4b3679f9c','01755cef-1591-4d2c-a60c-af3d018f8c7f','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-19-g2hbfoaeypw2','01755cef-1591-4d2c-a60c-af3d018f8c7f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1523,'59709508-e3ca-4b93-a3da-d472a178e351','c5d30b7a-c705-4242-ae9c-4d44bb116539','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceServerMetadataHook-7ahl3jq5knu5-CompactServices-76qoxd7nme4n','state changed','OS::Heat::Value',NULL,930),(1524,'c3872a07-5297-443e-80f7-74a2840b409c','01755cef-1591-4d2c-a60c-af3d018f8c7f','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-19-g2hbfoaeypw2','01755cef-1591-4d2c-a60c-af3d018f8c7f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1525,'9cdb93b5-3206-4f0b-a9fd-a6c3c926a1a4','c5d30b7a-c705-4242-ae9c-4d44bb116539','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceServerMetadataHook-7ahl3jq5knu5-CompactServices-76qoxd7nme4n','state changed','OS::Heat::Value',NULL,930),(1526,'34c81ce2-e4ce-4f84-894f-18e0e5e04c3e','c5d30b7a-c705-4242-ae9c-4d44bb116539','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw-ServiceServerMetadataHook-7ahl3jq5knu5','c5d30b7a-c705-4242-ae9c-4d44bb116539','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1527,'1f5048d7-077c-41c5-9d5a-a8b43575d11d','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:51',NULL,'CREATE','COMPLETE','13','10bbc01f-8cda-4ca8-a325-f43d65c647d1','state changed','OS::TripleO::Services::HAproxy',NULL,830),(1528,'390ae99c-97b1-4f10-b1ff-0790d8090a67','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:51',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-TLSProxyBase-cjr7px4uqqrj','state changed','OS::TripleO::Services::TLSProxyBase',NULL,931),(1529,'e5d1a794-1bad-487a-ab47-0f9b5cf01a24','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','c5d30b7a-c705-4242-ae9c-4d44bb116539','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,914),(1530,'da68adb8-7982-4691-8925-a84e6f7275c4','192bc52b-8be1-4a88-a26c-a5194cce46a2','2026-06-10 07:59:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-TLSProxyBase-cjr7px4uqqrj','192bc52b-8be1-4a88-a26c-a5194cce46a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1531,'acd8a7b7-b43c-4bda-a112-7406d469a051','a5c071db-18d0-4b8e-bf6b-5841cb648922','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-4wlndewsilqw','a5c071db-18d0-4b8e-bf6b-5841cb648922','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1532,'cb77840d-ed70-4086-9193-834bf920152d','df945adc-7187-4949-895c-9e5a65025244','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','ContainersCommon','7faa8185-cd7c-43d2-8793-a37a2b0b5b13','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1533,'dcc581c5-80f4-4d4b-8419-313343b12ac0','df945adc-7187-4949-895c-9e5a65025244','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-18-ucm65pbznnns','df945adc-7187-4949-895c-9e5a65025244','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1534,'d19ed96c-3938-48e4-b3f2-b7ac3a16bcd3','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','CinderNVMeOF','0b3cb5e3-b29c-4a92-a9b5-986833f95c05','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1535,'8cc0a46b-bc46-42f0-aef0-ca54d1d38c79','192bc52b-8be1-4a88-a26c-a5194cce46a2','2026-06-10 07:59:52',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-TLSProxyBase-cjr7px4uqqrj-ApacheNetworks-nhyxjnre4wbc','state changed','OS::Heat::Value',NULL,939),(1536,'fe3ffafe-1b39-4d33-b289-40673888565b','192bc52b-8be1-4a88-a26c-a5194cce46a2','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-TLSProxyBase-cjr7px4uqqrj-ApacheNetworks-nhyxjnre4wbc','state changed','OS::Heat::Value',NULL,939),(1537,'9f8a5f7d-3ec0-4148-aafa-3a7bd45fca80','192bc52b-8be1-4a88-a26c-a5194cce46a2','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-TLSProxyBase-cjr7px4uqqrj','192bc52b-8be1-4a88-a26c-a5194cce46a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1538,'dad1a003-8e4e-4d58-a4cc-ca241ed1999b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','ComputeServiceChain','a5c071db-18d0-4b8e-bf6b-5841cb648922','state changed','OS::TripleO::ComputeServices',NULL,74),(1539,'7332f84b-d2bd-491b-806a-e37e212f1eea','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','19','01755cef-1591-4d2c-a60c-af3d018f8c7f','state changed','OS::TripleO::Services::IpaClient',NULL,927),(1540,'80555c89-27b5-417f-9aa9-c027a98d6ac4','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','18','df945adc-7187-4949-895c-9e5a65025244','state changed','OS::TripleO::Services::Horizon',NULL,901),(1541,'8f8d6b92-994c-46e4-8b82-f9286e7a74d0','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:52',NULL,'CREATE','IN_PROGRESS','17','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d','state changed','OS::TripleO::Services::HeatEngine',NULL,950),(1542,'4130d402-2b4d-44dd-9293-50da5178fa9d','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1543,'d541d559-6bc5-4721-b0a7-0fe134d6d00b','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:52',NULL,'CREATE','IN_PROGRESS','23','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq','state changed','OS::TripleO::Services::ManilaApi',NULL,954),(1544,'5416c6b0-f02d-447e-afcd-e5690b39977d','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-RoleParametersValue-pzhxfosqtyqf','state changed','OS::Heat::Value',NULL,955),(1545,'511e42d8-3b5e-46c7-86e8-eba9fbed50e0','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5-RoleParametersValue-pzhxfosqtyqf','state changed','OS::Heat::Value',NULL,955),(1546,'5ff3cb98-8160-4d62-b0b4-7c11bdaa3c75','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq','029aeb55-e0c5-4ce9-98c9-28c1862645f1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1547,'dbd17e6c-2054-45a5-9e75-d69dd80d94b9','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','HeatEngineLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-HeatEngineLogging-sl3q4ylgqbxo','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1548,'1dd1fc4d-839d-461c-b65b-d5534b49b477','a53d3985-c397-49e4-8a8e-876fec16a744','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-HeatEngineLogging-sl3q4ylgqbxo','a53d3985-c397-49e4-8a8e-876fec16a744','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1549,'2249567b-18ca-4796-9202-bf630182bc24','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','22','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo','state changed','OS::TripleO::Services::Keystone',NULL,963),(1550,'e9f3f80a-3863-415d-9b12-6a710be696ef','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','TLSProxyBase','192bc52b-8be1-4a88-a26c-a5194cce46a2','state changed','OS::TripleO::Services::TLSProxyBase',NULL,931),(1551,'16f0620f-e450-4078-b841-a85905bf30ee','b6435493-469a-4083-994a-5f32d8731944','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg-GlanceApi-w5u373rosby5','b6435493-469a-4083-994a-5f32d8731944','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1552,'651b9317-d6c6-4cef-bca4-bc885b56c8f9','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ApacheServiceBase-fkxcljtikfdb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,966),(1553,'1c03a4fc-f34b-4b47-bfe1-c9c56687d561','a53d3985-c397-49e4-8a8e-876fec16a744','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-HeatEngineLogging-sl3q4ylgqbxo-RoleParametersValue-ow7k2eairlwg','state changed','OS::Heat::Value',NULL,967),(1554,'8cd1b91d-bbf3-4eea-9e74-8d4ab87af9b0','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo','4a2e0133-c744-4479-bd7a-869dabd3b7a5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1555,'618d36d4-d630-4f31-964d-cbf11b5be45a','a53d3985-c397-49e4-8a8e-876fec16a744','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-HeatEngineLogging-sl3q4ylgqbxo-RoleParametersValue-ow7k2eairlwg','state changed','OS::Heat::Value',NULL,967),(1556,'09a7da1e-2e2f-4f1a-9082-ddc66ab40762','9561d3b4-59a0-40f6-9e72-629223376083','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ApacheServiceBase-fkxcljtikfdb','9561d3b4-59a0-40f6-9e72-629223376083','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1557,'7d545a33-5b69-4d4a-ac09-4c02658805ed','a53d3985-c397-49e4-8a8e-876fec16a744','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-HeatEngineLogging-sl3q4ylgqbxo','a53d3985-c397-49e4-8a8e-876fec16a744','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1558,'0e470693-b6f2-40eb-a24b-dbfd585d22ea','9561d3b4-59a0-40f6-9e72-629223376083','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ApacheServiceBase-fkxcljtikfdb-ApacheNetworks-btpvv5eblzc3','state changed','OS::Heat::Value',NULL,978),(1559,'0c999515-2c13-40ef-84b8-38b9f2681a6a','9561d3b4-59a0-40f6-9e72-629223376083','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ApacheServiceBase-fkxcljtikfdb-ApacheNetworks-btpvv5eblzc3','state changed','OS::Heat::Value',NULL,978),(1560,'259c0c71-f97e-4067-989d-9ab5e7162404','9561d3b4-59a0-40f6-9e72-629223376083','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ApacheServiceBase-fkxcljtikfdb','9561d3b4-59a0-40f6-9e72-629223376083','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1561,'0807caf1-df4e-4604-a3f3-66f5814c200a','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-ContainersCommon-n5oyzk526y7m','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1562,'a8c18beb-468f-49ce-bd58-c514da02e1e5','aaca8c15-3c08-4b5d-ba89-8e708b5bceba','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-ContainersCommon-n5oyzk526y7m','aaca8c15-3c08-4b5d-ba89-8e708b5bceba','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1563,'b27f668d-da8e-4cc2-8ca2-64c92e8b611c','aaca8c15-3c08-4b5d-ba89-8e708b5bceba','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-ContainersCommon-n5oyzk526y7m','aaca8c15-3c08-4b5d-ba89-8e708b5bceba','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1564,'b0dd02a4-7d28-4036-9a91-7bbbb2b0ba9c','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','GlanceApi','b6435493-469a-4083-994a-5f32d8731944','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,869),(1565,'4056c64b-bd0a-4677-bdd9-a0b928ebce96','761065fe-255a-45ab-9904-eb2765819a4a','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-12-kucvpupxworg','761065fe-255a-45ab-9904-eb2765819a4a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1566,'868f3eb3-8a32-46fa-b5e5-3c128a5d1d28','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:53',NULL,'CREATE','IN_PROGRESS','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-7ankh7zz656n','state changed','OS::Heat::Value',NULL,992),(1567,'0ec9a75c-e32e-4ee3-8688-b90d77c955a8','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:53',NULL,'CREATE','COMPLETE','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-7ankh7zz656n','state changed','OS::Heat::Value',NULL,992),(1568,'436ad7f1-03b3-4322-abc8-9b5a49548764','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:54',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-RoleParametersValue-2ayaogpfd5eb','state changed','OS::Heat::Value',NULL,993),(1569,'0582436c-14c0-4b9a-bb40-6e0acc8d17f0','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-RoleParametersValue-2ayaogpfd5eb','state changed','OS::Heat::Value',NULL,993),(1570,'3f11be3c-6cf6-4f92-ac42-092fb0dbe530','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:54',NULL,'CREATE','IN_PROGRESS','ComputeServiceNames','overcloud-ComputeServiceNames-mguocyqc6ofm','state changed','OS::Heat::Value',NULL,994),(1571,'1432202e-7f00-4831-b3b1-03913cad130b','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','HeatEngineLogging','a53d3985-c397-49e4-8a8e-876fec16a744','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1572,'acff61bd-8c9f-4b75-9d1f-0e5dda622131','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','ComputeServiceNames','overcloud-ComputeServiceNames-mguocyqc6ofm','state changed','OS::Heat::Value',NULL,994),(1573,'e9409888-643e-4556-b436-cbd739203d59','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:54',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ManilaBase-ckoi4tvb6up3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,995),(1574,'b4953d8a-833e-4e89-99e7-be6caeda0c3f','d6586e5d-274d-4134-a59a-cd05f32ef486','2026-06-10 07:59:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ManilaBase-ckoi4tvb6up3','d6586e5d-274d-4134-a59a-cd05f32ef486','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1575,'b0806a0c-b601-41f3-9959-e7a721fc9c6a','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','ApacheServiceBase','9561d3b4-59a0-40f6-9e72-629223376083','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,966),(1576,'e7962b4d-78fc-4ca8-a0b1-70bc3b159d81','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','12','761065fe-255a-45ab-9904-eb2765819a4a','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,843),(1577,'ef65f4ba-1de5-4ee9-afc4-a6eea2d7cc15','d6586e5d-274d-4134-a59a-cd05f32ef486','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ManilaBase-ckoi4tvb6up3','d6586e5d-274d-4134-a59a-cd05f32ef486','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1578,'6b734b72-5731-4598-bf6b-16d5b5e13131','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 07:59:54',NULL,'CREATE','IN_PROGRESS','Compute','overcloud-Compute-vqvy3wbs6fij','state changed','OS::Heat::ResourceGroup',NULL,996),(1579,'ffc92b27-462f-41ad-aa39-58278330e135','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:54',NULL,'CREATE','IN_PROGRESS','KeystoneLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-KeystoneLogging-6qzgiwoh454p','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1580,'8171e8bf-c4c7-4a73-bd71-a4262e2bac1f','ce8cb998-a99c-4289-a9cd-af4eefb205f8','2026-06-10 07:59:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-KeystoneLogging-6qzgiwoh454p','ce8cb998-a99c-4289-a9cd-af4eefb205f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1581,'e241d8d8-289a-4ca2-878b-c8f9fca00d13','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','ContainersCommon','aaca8c15-3c08-4b5d-ba89-8e708b5bceba','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1582,'70363d14-a7a3-4c92-8846-6c83c5bbd9d2','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 07:59:54',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij','40b7a703-a52e-4f7b-b893-335fd1fe5280','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1583,'742ca0c2-3782-4794-b3cc-2c171e472914','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij','40b7a703-a52e-4f7b-b893-335fd1fe5280','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1584,'2adeb7f6-f905-4b19-b929-6a868c7c8a51','ce8cb998-a99c-4289-a9cd-af4eefb205f8','2026-06-10 07:59:54',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-KeystoneLogging-6qzgiwoh454p-RoleParametersValue-uhq5jlkryqjx','state changed','OS::Heat::Value',NULL,1005),(1585,'87c4eb32-338d-4341-972d-53d84bc94f03','ce8cb998-a99c-4289-a9cd-af4eefb205f8','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-KeystoneLogging-6qzgiwoh454p-RoleParametersValue-uhq5jlkryqjx','state changed','OS::Heat::Value',NULL,1005),(1586,'da22632e-1802-410e-b753-b1654fb72faf','ce8cb998-a99c-4289-a9cd-af4eefb205f8','2026-06-10 07:59:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-KeystoneLogging-6qzgiwoh454p','ce8cb998-a99c-4289-a9cd-af4eefb205f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1587,'61b93891-38c7-4f0f-a4aa-2ba0dc5a66d6','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:55',NULL,'CREATE','IN_PROGRESS','16','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1014),(1588,'419322f3-a252-438d-9d3a-495cc634b686','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:55',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-MySQLClient-o6xer23ttslq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1589,'44d8a612-13c4-400a-8358-6b9ef8527b08','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3','4f41d9c5-c936-45b1-8554-a150460d3077','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1590,'391aa0c8-283e-4632-a2d4-3f24e7d852e7','4f7f8cc6-7d7d-4f25-96db-7b3c37901144','2026-06-10 07:59:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-MySQLClient-o6xer23ttslq','4f7f8cc6-7d7d-4f25-96db-7b3c37901144','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1591,'562695bb-72bd-4664-86d9-de28b617f5fe','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:55',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-RoleParametersValue-bf5lihcx6zqi','state changed','OS::Heat::Value',NULL,1015),(1592,'39914d46-8a5c-4abb-824b-6d41e1b14686','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:55',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-RoleParametersValue-bf5lihcx6zqi','state changed','OS::Heat::Value',NULL,1015),(1593,'9b28e547-0da9-4d52-bf82-0fee8b264566','4f7f8cc6-7d7d-4f25-96db-7b3c37901144','2026-06-10 07:59:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-MySQLClient-o6xer23ttslq','4f7f8cc6-7d7d-4f25-96db-7b3c37901144','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1594,'af42234f-cf5d-4faa-8f1f-22c5947fcd95','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:55',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-RoleParametersValue-hvyw2vw4nxda','state changed','OS::Heat::Value',NULL,1016),(1595,'c519c90c-2d54-4b35-8e27-7488a11c272c','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:55',NULL,'CREATE','COMPLETE','ManilaBase','d6586e5d-274d-4134-a59a-cd05f32ef486','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,995),(1596,'035b873d-b477-4084-94e1-e865608efe0a','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:55',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-RoleParametersValue-hvyw2vw4nxda','state changed','OS::Heat::Value',NULL,1016),(1597,'b403d162-2fb5-4105-ab9f-f129b80b5931','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:55',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-MySQLClient-bhsdvplas2pr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1598,'8a310f71-2a14-4a1d-b5a1-3f8610847ece','b7162a93-c48a-405c-9f20-49f898296884','2026-06-10 07:59:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-MySQLClient-bhsdvplas2pr','b7162a93-c48a-405c-9f20-49f898296884','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1599,'e731937e-ba74-4002-bbc4-95fc03bd5088','b7162a93-c48a-405c-9f20-49f898296884','2026-06-10 07:59:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-MySQLClient-bhsdvplas2pr','b7162a93-c48a-405c-9f20-49f898296884','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1600,'4407f8b5-a3b9-41fc-a736-5b78e2edf82f','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:55',NULL,'CREATE','COMPLETE','KeystoneLogging','ce8cb998-a99c-4289-a9cd-af4eefb205f8','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1601,'dfa58daa-5ba2-4385-92d9-273c30239436','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 07:59:55',NULL,'UPDATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij','40b7a703-a52e-4f7b-b893-335fd1fe5280','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(1602,'51c9355e-25bd-4dd3-ad29-1d0b85196cc3','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 07:59:55',NULL,'CREATE','IN_PROGRESS','0','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via','state changed','OS::TripleO::Compute',NULL,1017),(1603,'92990510-c59e-45d7-a34e-b9aa20f19da6','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1604,'609039f6-c1b9-4fb5-bb0c-d192a7ebe4cb','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-HeatBase-k2lbwd4y3bxb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1018),(1605,'245dbe4d-fd67-4ae3-b2b8-5646ee05b995','25337694-5e7b-465b-9c30-43f820abdf30','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-HeatBase-k2lbwd4y3bxb','25337694-5e7b-465b-9c30-43f820abdf30','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1606,'92869d5c-8fcf-484c-920e-04b98562508d','25337694-5e7b-465b-9c30-43f820abdf30','2026-06-10 07:59:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-HeatBase-k2lbwd4y3bxb','25337694-5e7b-465b-9c30-43f820abdf30','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1607,'96be7098-297f-48ea-b5c5-10e822183ae2','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ContainersCommon-spnllsn735g3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1608,'4b0f68a9-2301-42cd-9ce7-c56e1852e326','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:56',NULL,'CREATE','COMPLETE','MySQLClient','4f7f8cc6-7d7d-4f25-96db-7b3c37901144','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1609,'181b88d2-502c-494c-a639-789017e8c9de','7931d945-2658-4c1c-8cc3-5556bc544127','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ContainersCommon-spnllsn735g3','7931d945-2658-4c1c-8cc3-5556bc544127','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1610,'9018bd49-916a-4dcf-b35f-6786bc6cead2','7931d945-2658-4c1c-8cc3-5556bc544127','2026-06-10 07:59:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-ContainersCommon-spnllsn735g3','7931d945-2658-4c1c-8cc3-5556bc544127','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1611,'b55c14c5-53bf-4a93-91df-aab565e1fe12','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-HeatBase-jvkqvfgeohik','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1019),(1612,'a2a33db9-0ed6-45e1-a389-e7b7427c1cb6','92738c0f-6beb-4d1e-85b7-67681cc8aa6b','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-HeatBase-jvkqvfgeohik','92738c0f-6beb-4d1e-85b7-67681cc8aa6b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1613,'c03ec324-9507-48ce-bdd5-ec93965bac18','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-ApacheServiceBase-uriagweewmtt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1020),(1614,'f1e09898-d955-427d-9f1b-4a9c512cc377','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NovaCompute-zl4pwojjb4je','state changed','OS::TripleO::ComputeServer',NULL,1021),(1615,'53b04280-0074-4325-8c44-f68c8652b8ec','92738c0f-6beb-4d1e-85b7-67681cc8aa6b','2026-06-10 07:59:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-HeatBase-jvkqvfgeohik','92738c0f-6beb-4d1e-85b7-67681cc8aa6b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1616,'6b54ae79-53cd-4a5f-9dd3-dbf737ff1f9c','8ffbb0b5-7af0-4233-b208-072ff387c52b','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-ApacheServiceBase-uriagweewmtt','8ffbb0b5-7af0-4233-b208-072ff387c52b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1617,'2ba5b44f-711b-4bf0-a3b2-bd31579567bb','ef66ae85-e9b5-4666-ba90-ceb9126b6a56','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NovaCompute-zl4pwojjb4je','ef66ae85-e9b5-4666-ba90-ceb9126b6a56','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1618,'1af3a040-461a-482c-954c-3fc825ad81ac','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:56',NULL,'CREATE','COMPLETE','MySQLClient','b7162a93-c48a-405c-9f20-49f898296884','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1619,'b287e285-9254-4360-8f73-d6694aab8e2d','8ffbb0b5-7af0-4233-b208-072ff387c52b','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-ApacheServiceBase-uriagweewmtt-ApacheNetworks-pze4vnx2equg','state changed','OS::Heat::Value',NULL,1022),(1620,'df3e8da4-cdb2-402a-8375-f8da710481f5','8ffbb0b5-7af0-4233-b208-072ff387c52b','2026-06-10 07:59:56',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-ApacheServiceBase-uriagweewmtt-ApacheNetworks-pze4vnx2equg','state changed','OS::Heat::Value',NULL,1022),(1621,'dbd1a650-67ca-4051-a9c5-29fee8219b0a','8ffbb0b5-7af0-4233-b208-072ff387c52b','2026-06-10 07:59:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-ApacheServiceBase-uriagweewmtt','8ffbb0b5-7af0-4233-b208-072ff387c52b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1622,'e6bacd28-a502-4353-a454-3cd36b95ea51','ef66ae85-e9b5-4666-ba90-ceb9126b6a56','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NovaCompute-zl4pwojjb4je-ControlPlanePort-jt64r5kizptu','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1023),(1623,'5313b007-9052-439e-bd7c-935469199bff','a3e8b6f3-da5e-4098-9cbe-447b06b03d79','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NovaCompute-zl4pwojjb4je-ControlPlanePort-jt64r5kizptu','a3e8b6f3-da5e-4098-9cbe-447b06b03d79','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1624,'049fa9a8-4e48-4759-bdf4-586bc0777f66','a3e8b6f3-da5e-4098-9cbe-447b06b03d79','2026-06-10 07:59:56',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NovaCompute-zl4pwojjb4je-ControlPlanePort-jt64r5kizptu','a3e8b6f3-da5e-4098-9cbe-447b06b03d79','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1625,'b5d8c1e1-d34b-4fc9-bc7d-cf8f8abeb751','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 07:59:56',NULL,'CREATE','IN_PROGRESS','1','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb','state changed','OS::TripleO::Compute',NULL,1024),(1626,'5849061a-b038-411c-8701-334cb865c740','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1627,'77a3bd41-d9c0-4966-99a9-c74e8e98ff73','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-ContainersCommon-dtm2xnrduv7y','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1628,'9c94cabb-ebd2-41c8-8660-05b123451028','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','HeatBase','25337694-5e7b-465b-9c30-43f820abdf30','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1018),(1629,'e1a67c8c-3b72-429e-9ca6-435bfdbfa284','fe768a64-ace9-4d4d-ba17-74851756d3b2','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-ContainersCommon-dtm2xnrduv7y','fe768a64-ace9-4d4d-ba17-74851756d3b2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1630,'02720b55-a623-449e-bf39-c71676520a3e','fe768a64-ace9-4d4d-ba17-74851756d3b2','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d-ContainersCommon-dtm2xnrduv7y','fe768a64-ace9-4d4d-ba17-74851756d3b2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1631,'73f9c814-8f99-4d3b-82da-a13e591f8c92','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-MySQLClient-2wjkoositijp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1632,'ebed3f7f-953c-4012-8f4e-ed276ecf4ffd','5b7bfc1c-769e-4188-9d9d-f3011d557fad','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-MySQLClient-2wjkoositijp','5b7bfc1c-769e-4188-9d9d-f3011d557fad','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1633,'b45e490f-e86b-4838-9010-4b6ce261bf45','5b7bfc1c-769e-4188-9d9d-f3011d557fad','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq-MySQLClient-2wjkoositijp','5b7bfc1c-769e-4188-9d9d-f3011d557fad','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1634,'d114d633-c9e0-48b5-afb5-df1d501c5a1d','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','ContainersCommon','7931d945-2658-4c1c-8cc3-5556bc544127','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1635,'5f9aee13-3f3a-4cda-8b78-6dffe57a1bd4','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-ContainersCommon-uaub5ctndn6r','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1636,'8a91ede5-f50e-422a-a7c5-8278f4825d29','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-DeploymentActions-oagpm3pfzuiy','state changed','OS::Heat::Value',NULL,1025),(1637,'521d2419-0c6e-4e17-b853-7b637d332384','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-DeploymentActions-oagpm3pfzuiy','state changed','OS::Heat::Value',NULL,1025),(1638,'3e6684de-267e-4fff-b97c-e098e9ec7d0a','e609446b-7759-4d0e-b398-18f72f1498e0','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-ContainersCommon-uaub5ctndn6r','e609446b-7759-4d0e-b398-18f72f1498e0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1639,'8490911f-a3b8-48df-b9dc-b19cac50a5be','e609446b-7759-4d0e-b398-18f72f1498e0','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-ContainersCommon-uaub5ctndn6r','e609446b-7759-4d0e-b398-18f72f1498e0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1640,'ca576590-8fe1-4c1e-8cd8-68681df6c2e0','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-DeploymentActions-ljvbqub5iyzj','state changed','OS::Heat::Value',NULL,1027),(1641,'5df7daac-5bfc-4a3e-8541-abc2388a1cd7','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-RoleParametersValue-g7l6q6y2ezyr','state changed','OS::Heat::Value',NULL,1028),(1642,'18a6a326-6ccf-4f73-b9d1-820deab30f1a','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-DeploymentActions-ljvbqub5iyzj','state changed','OS::Heat::Value',NULL,1027),(1643,'5c16bb11-b2b8-4e73-bea1-687b7db69d59','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo-RoleParametersValue-g7l6q6y2ezyr','state changed','OS::Heat::Value',NULL,1028),(1644,'069b2caf-1659-487d-882d-382460e9680e','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','HeatBase','92738c0f-6beb-4d1e-85b7-67681cc8aa6b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1019),(1645,'5bbcc96d-8980-4383-adcf-0a4a36ba904b','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','ApacheServiceBase','8ffbb0b5-7af0-4233-b208-072ff387c52b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1020),(1646,'73bea952-4143-4431-bd97-c263c18f7a0b','4a2e0133-c744-4479-bd7a-869dabd3b7a5','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-22-eenrauy2gkbo','4a2e0133-c744-4479-bd7a-869dabd3b7a5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1647,'424aad69-7a35-40ea-b683-2208752a6825','ef66ae85-e9b5-4666-ba90-ceb9126b6a56','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-zl4pwojjb4je-deployed-server-rbvl2oyn3zad','state changed','OS::Heat::DeployedServer',NULL,1030),(1648,'5f174278-b385-47c1-92ad-94608e2ee550','ef66ae85-e9b5-4666-ba90-ceb9126b6a56','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','ControlPlanePort','a3e8b6f3-da5e-4098-9cbe-447b06b03d79','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1023),(1649,'37e3d348-0daf-4e28-828a-ef4c4e8ec6bc','ef66ae85-e9b5-4666-ba90-ceb9126b6a56','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','deployed-server','b0dde403-abd3-4886-9c43-7e33b8aa1a6b','state changed','OS::Heat::DeployedServer',NULL,1030),(1650,'19e01e16-7d24-49e0-92f7-e83ccdd448b3','ef66ae85-e9b5-4666-ba90-ceb9126b6a56','2026-06-10 07:59:57',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NovaCompute-zl4pwojjb4je','ef66ae85-e9b5-4666-ba90-ceb9126b6a56','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1651,'1b8170db-cff9-4827-8913-2e26cbf70b2d','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 07:59:57',NULL,'CREATE','IN_PROGRESS','2','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu','state changed','OS::TripleO::Compute',NULL,1031),(1652,'df9e21b9-2316-46cd-9060-8872154575c7','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1653,'36748fc5-7ccd-46ba-a337-3b348a4eecab','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','ContainersCommon','fe768a64-ace9-4d4d-ba17-74851756d3b2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1654,'3ff17016-23fb-406b-babb-2540305f9262','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-17-i3myj2erex6d','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1655,'1a2538bd-61ff-40f8-ad96-7d9c4b043046','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NovaCompute-brpwg66vq7dy','state changed','OS::TripleO::ComputeServer',NULL,1032),(1656,'14d7909e-97c6-42f7-8b18-1f8d1de71977','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','22','4a2e0133-c744-4479-bd7a-869dabd3b7a5','state changed','OS::TripleO::Services::Keystone',NULL,963),(1657,'ca3938a9-7d8d-4625-abe8-7bc173a994ad','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NovaCompute-d5d6s6nwjdym','state changed','OS::TripleO::ComputeServer',NULL,1033),(1658,'571c4f8d-f5d9-4e40-b75a-67e54ec03376','fb3670b4-3938-4f9d-bf9f-2ceaa1677182','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NovaCompute-brpwg66vq7dy','fb3670b4-3938-4f9d-bf9f-2ceaa1677182','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1659,'9d1efedc-d904-4a4e-aec6-48f62fd2d4b3','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','ContainersCommon','e609446b-7759-4d0e-b398-18f72f1498e0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1660,'ab04ed17-609c-4a5f-abec-92097320b125','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','MySQLClient','5b7bfc1c-769e-4188-9d9d-f3011d557fad','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1661,'3ed4b3b0-94b5-4acd-89e2-b0e6127fd027','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-ApacheServiceBase-nlw2g7vn4ma6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1034),(1662,'98e6c321-64a3-482e-9ded-2b4e6427ff6d','029aeb55-e0c5-4ce9-98c9-28c1862645f1','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-23-3s4wpqquyhvq','029aeb55-e0c5-4ce9-98c9-28c1862645f1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1663,'e258ef40-245e-455f-9476-381ec26f7556','b77bd376-7920-4f02-8952-7da301cc6073','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NovaCompute-d5d6s6nwjdym','b77bd376-7920-4f02-8952-7da301cc6073','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1664,'1e4f6512-c619-4ee6-8764-e606d05768c4','fb3670b4-3938-4f9d-bf9f-2ceaa1677182','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NovaCompute-brpwg66vq7dy-ControlPlanePort-e62udv7hau5c','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1036),(1665,'3bd3ab90-dda5-43a4-b382-a9c1e190260d','7f0d477c-290d-422d-8073-9b7a84c55e5b','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-ApacheServiceBase-nlw2g7vn4ma6','7f0d477c-290d-422d-8073-9b7a84c55e5b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1666,'46261a2d-dce1-44ec-be52-a6bc53df9ce4','4dbf7b36-2920-4f38-862e-d009a9082583','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NovaCompute-brpwg66vq7dy-ControlPlanePort-e62udv7hau5c','4dbf7b36-2920-4f38-862e-d009a9082583','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1667,'ed94a279-8dac-4ba6-94ba-c75337852b1f','b77bd376-7920-4f02-8952-7da301cc6073','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-d5d6s6nwjdym-deployed-server-c2qxr5vyjnwc','state changed','OS::Heat::DeployedServer',NULL,1039),(1668,'b0917013-a6c6-4c28-8d98-57c467a2fe71','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','NovaCompute','ef66ae85-e9b5-4666-ba90-ceb9126b6a56','state changed','OS::TripleO::ComputeServer',NULL,1021),(1669,'dff2bc50-4758-41d4-904e-d8167dc0a115','7f0d477c-290d-422d-8073-9b7a84c55e5b','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-ApacheServiceBase-nlw2g7vn4ma6-ApacheNetworks-s2gwf3eyet4i','state changed','OS::Heat::Value',NULL,1040),(1670,'aa43b00d-46be-4733-bc5f-8b5f82724f27','4dbf7b36-2920-4f38-862e-d009a9082583','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NovaCompute-brpwg66vq7dy-ControlPlanePort-e62udv7hau5c','4dbf7b36-2920-4f38-862e-d009a9082583','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1671,'2c8d0383-ba19-444c-a5a4-621f08ae47dd','7f0d477c-290d-422d-8073-9b7a84c55e5b','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-ApacheServiceBase-nlw2g7vn4ma6-ApacheNetworks-s2gwf3eyet4i','state changed','OS::Heat::Value',NULL,1040),(1672,'432b8754-a5ed-4cfb-b5e1-1d4deeff8d05','7f0d477c-290d-422d-8073-9b7a84c55e5b','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-ApacheServiceBase-nlw2g7vn4ma6','7f0d477c-290d-422d-8073-9b7a84c55e5b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1673,'f907e9e3-248c-4764-9276-11d681e63226','b77bd376-7920-4f02-8952-7da301cc6073','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','deployed-server','6b84b6c2-178f-416a-8933-3b6c45bfb735','state changed','OS::Heat::DeployedServer',NULL,1039),(1674,'8bc41b0c-deea-472b-a9d8-c2a66f56ffb4','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-PreNetworkConfig-aianv2t6q67z','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1675,'a0f77f36-e08a-47b6-acc9-5ea08fd0d79a','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NetHostMap-zuq44xprjpjq','state changed','OS::Heat::Value',NULL,1045),(1676,'1216f828-4c8d-4dfa-8b45-d59514e0b572','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-TenantPort-xguqe2oks6po','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1046),(1677,'69b0346a-4d10-4278-87f7-e116cee3d8a1','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','PreNetworkConfig','2f9098fd-5f2f-4dce-873f-9503a5b3e73b','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1678,'3f53202b-54b7-4be8-8774-038d62d9d07e','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NetHostMap-zuq44xprjpjq','state changed','OS::Heat::Value',NULL,1045),(1679,'81d64501-436e-4125-bc22-ce6ff5577bc7','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NovaComputeAnsibleHostVars-etfujae3ecz6','state changed','OS::Heat::Value',NULL,1049),(1680,'7f441350-0ab5-4aa7-ab20-1244938c542c','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NovaComputeAnsibleHostVars-etfujae3ecz6','state changed','OS::Heat::Value',NULL,1049),(1681,'9207909e-e639-4277-aa08-01c0a8884d50','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-InternalApiPort-2fvhrwm2tsti','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1050),(1682,'9f760e0a-b27d-422c-9468-c92d212043ef','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NodeTLSCAData-hu22cpsjlr2g','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1683,'3f581846-89e8-4f4b-90ef-9b34b3d94479','5eed1bc4-5c2f-45c4-afd8-ec1b1b774688','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-TenantPort-xguqe2oks6po','5eed1bc4-5c2f-45c4-afd8-ec1b1b774688','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1684,'4357f064-e9cf-4add-8f06-06df0ddf4a92','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:58',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-ComputeExtraConfigPre-pcglwx34odc5','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1052),(1685,'19caf1ac-b3fa-44a6-9f70-d6cbd8117f74','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-StoragePort-mosz3oqmiirg','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1054),(1686,'e688b3ee-5b25-434f-9e15-4eb03dff7b2d','171254a8-a241-4fd9-a82e-c7acbd022040','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-ComputeExtraConfigPre-pcglwx34odc5','171254a8-a241-4fd9-a82e-c7acbd022040','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1687,'3fcac74e-b4ed-4c16-9ec6-aa7300e1e6a5','e2ae3a4f-03eb-4568-8079-20fb0ec64aef','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-StoragePort-mosz3oqmiirg','e2ae3a4f-03eb-4568-8079-20fb0ec64aef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1688,'c326b614-94c0-42f1-bfb4-abb65f73bfb8','171254a8-a241-4fd9-a82e-c7acbd022040','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-ComputeExtraConfigPre-pcglwx34odc5','171254a8-a241-4fd9-a82e-c7acbd022040','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1689,'baefddae-414e-4052-8e89-6d40c08ca252','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','171254a8-a241-4fd9-a82e-c7acbd022040','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1052),(1690,'66f4f994-050a-406c-b4df-a0741272561f','5eed1bc4-5c2f-45c4-afd8-ec1b1b774688','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-TenantPort-xguqe2oks6po-TenantDeployedPort-hklljeo3trez','state changed','OS::Heat::Value',NULL,1055),(1691,'58f60b0f-ee16-49b5-82b2-ad688c06634b','5eed1bc4-5c2f-45c4-afd8-ec1b1b774688','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-TenantPort-xguqe2oks6po-TenantDeployedPort-hklljeo3trez','state changed','OS::Heat::Value',NULL,1055),(1692,'1277ae76-4d45-4ba7-a2e8-61ff1f9d0753','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','23','029aeb55-e0c5-4ce9-98c9-28c1862645f1','state changed','OS::TripleO::Services::ManilaApi',NULL,954),(1693,'2ccc9a68-39fd-4a3c-b511-f43257bd3b72','5eed1bc4-5c2f-45c4-afd8-ec1b1b774688','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-TenantPort-xguqe2oks6po','5eed1bc4-5c2f-45c4-afd8-ec1b1b774688','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1694,'8d4f7843-1ffe-463a-8525-a9431f7ce160','e2ae3a4f-03eb-4568-8079-20fb0ec64aef','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-StoragePort-mosz3oqmiirg-StorageDeployedPort-naq4hshuc5gx','state changed','OS::Heat::Value',NULL,1058),(1695,'3ac39801-1d68-4585-be72-e3de6922e9af','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','26','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp','state changed','OS::TripleO::Services::ManilaShare',NULL,1057),(1696,'d8f90ee1-90b3-4f53-aee4-7ff570ebf4df','e2ae3a4f-03eb-4568-8079-20fb0ec64aef','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-StoragePort-mosz3oqmiirg-StorageDeployedPort-naq4hshuc5gx','state changed','OS::Heat::Value',NULL,1058),(1697,'d943da52-061a-491b-a3c3-f2b53e71e0d0','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','17','f26b30b6-8e78-4f3f-88bb-a2a9a2e906de','state changed','OS::TripleO::Services::HeatEngine',NULL,950),(1698,'2028fb9f-14c1-474d-acf2-a756982a950c','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','NodeTLSCAData','674ed1b4-40d9-4c54-9e45-8d0209effd6c','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1699,'0cbdf797-c94a-456a-8ac6-285854144a89','e2ae3a4f-03eb-4568-8079-20fb0ec64aef','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-StoragePort-mosz3oqmiirg','e2ae3a4f-03eb-4568-8079-20fb0ec64aef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1700,'b8cb9a11-1871-4075-befd-c5541de05ba1','ca40623b-bc72-45e2-8987-50ba6d6363c4','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-InternalApiPort-2fvhrwm2tsti','ca40623b-bc72-45e2-8987-50ba6d6363c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1701,'d7f68591-fc25-49b9-bab7-2dd5fced394b','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp','2bf84f06-75d2-4e09-9b56-f7ca6e942882','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1702,'7005a2ad-919b-4cf4-815d-cb76445d5d2d','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NodeExtraConfig-wr3j5xmwrknd','state changed','OS::TripleO::NodeExtraConfig',NULL,1059),(1703,'2ce88520-bdaf-4608-b1cc-04558a9bddb2','cf9496a3-8f45-48e2-8525-b47665868793','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NodeExtraConfig-wr3j5xmwrknd','cf9496a3-8f45-48e2-8525-b47665868793','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1704,'e603932a-24aa-4d84-86a9-8fdbb3763313','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-DeploymentActions-p4grklydzcey','state changed','OS::Heat::Value',NULL,1066),(1705,'40d39af0-0851-4dba-80d5-6f52ffc84650','cf9496a3-8f45-48e2-8525-b47665868793','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NodeExtraConfig-wr3j5xmwrknd','cf9496a3-8f45-48e2-8525-b47665868793','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1706,'a5b2f2ce-cb32-4edc-ad5b-f4874f325e93','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-DeploymentActions-p4grklydzcey','state changed','OS::Heat::Value',NULL,1066),(1707,'5af3cc49-119c-4b7d-a579-297ff9a49c39','ca40623b-bc72-45e2-8987-50ba6d6363c4','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-InternalApiPort-2fvhrwm2tsti-InternalApiDeployedPort-fhv4e6zhfgbp','state changed','OS::Heat::Value',NULL,1063),(1708,'5d021e90-f69c-4fe1-8de5-25efb1061551','ca40623b-bc72-45e2-8987-50ba6d6363c4','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-InternalApiPort-2fvhrwm2tsti-InternalApiDeployedPort-fhv4e6zhfgbp','state changed','OS::Heat::Value',NULL,1063),(1709,'d05d9648-86d1-4b37-aa9a-b1760aa58d50','ca40623b-bc72-45e2-8987-50ba6d6363c4','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-InternalApiPort-2fvhrwm2tsti','ca40623b-bc72-45e2-8987-50ba6d6363c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1710,'8db0aa9d-d687-4d98-9a91-386809844ad6','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','HeatApiCfnLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-HeatApiCfnLogging-b5aql2enpguc','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1711,'81bf70d8-bd74-4589-9ae2-48f561655dee','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ContainersCommon-2im7lkqdb3qn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1712,'30e86266-50a9-45a4-b529-e48ef7477cf4','141309ac-253a-43ca-b6c9-139a9987e0d2','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-HeatApiCfnLogging-b5aql2enpguc','141309ac-253a-43ca-b6c9-139a9987e0d2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1713,'1afd9b78-124e-4809-9095-fd545181441b','141309ac-253a-43ca-b6c9-139a9987e0d2','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3-HeatApiCfnLogging-b5aql2enpguc','141309ac-253a-43ca-b6c9-139a9987e0d2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1714,'a80fed14-6315-4ea0-a136-55fa62a49999','20414572-2c57-41a8-bcce-e63876663fd8','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ContainersCommon-2im7lkqdb3qn','20414572-2c57-41a8-bcce-e63876663fd8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1715,'48415bf6-8521-40de-9da9-7cb279a710a1','20414572-2c57-41a8-bcce-e63876663fd8','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ContainersCommon-2im7lkqdb3qn','20414572-2c57-41a8-bcce-e63876663fd8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1716,'1b6c2e8f-13e3-4574-b05c-049031b6abc7','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','27','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-27-3ugm6hcbgbmd','state changed','OS::TripleO::Services::Memcached',NULL,1075),(1717,'39014f73-471b-4627-a839-b30794d8122c','fb3670b4-3938-4f9d-bf9f-2ceaa1677182','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-brpwg66vq7dy-deployed-server-ttwgjdim5uro','state changed','OS::Heat::DeployedServer',NULL,1076),(1718,'a5fd9b41-7e62-4930-9f01-3632e021b6ed','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','ApacheServiceBase','7f0d477c-290d-422d-8073-9b7a84c55e5b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1034),(1719,'45118902-3619-4e0a-919e-084fe73132e5','b77bd376-7920-4f02-8952-7da301cc6073','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NovaCompute-d5d6s6nwjdym-ControlPlanePort-33vpp5g2gt67','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1079),(1720,'05044cc9-eeee-4772-a090-5cf79f06462c','767a702b-52b5-489a-89df-32fed2fd44df','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-27-3ugm6hcbgbmd','767a702b-52b5-489a-89df-32fed2fd44df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1721,'d03af13f-f537-48d0-9516-0caf3fac42ed','fb3670b4-3938-4f9d-bf9f-2ceaa1677182','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','ControlPlanePort','4dbf7b36-2920-4f38-862e-d009a9082583','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1036),(1722,'5c9e3fa3-d0f0-415a-a76c-0d2598eef5c7','fb3670b4-3938-4f9d-bf9f-2ceaa1677182','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','deployed-server','d0ced22e-c648-49ce-9c1e-8585f9c8d08e','state changed','OS::Heat::DeployedServer',NULL,1076),(1723,'17e00d43-7f64-4e08-98ec-b941fccdbe81','fb3670b4-3938-4f9d-bf9f-2ceaa1677182','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NovaCompute-brpwg66vq7dy','fb3670b4-3938-4f9d-bf9f-2ceaa1677182','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1724,'95e1b646-c3a6-43ec-a166-59372eafb15b','d2f06c62-ef68-4e3b-be74-94f42ba6fcd1','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NovaCompute-d5d6s6nwjdym-ControlPlanePort-33vpp5g2gt67','d2f06c62-ef68-4e3b-be74-94f42ba6fcd1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1725,'98218e47-5905-4c84-8d49-f7e703848f7c','d2f06c62-ef68-4e3b-be74-94f42ba6fcd1','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NovaCompute-d5d6s6nwjdym-ControlPlanePort-33vpp5g2gt67','d2f06c62-ef68-4e3b-be74-94f42ba6fcd1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1726,'c1d8b98a-81cb-401d-9241-97aa7ae34cd4','767a702b-52b5-489a-89df-32fed2fd44df','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-27-3ugm6hcbgbmd-RoleParametersValue-3ukih3t5kk45','state changed','OS::Heat::Value',NULL,1080),(1727,'4ca548d7-de2a-4f95-858d-9816775e1640','767a702b-52b5-489a-89df-32fed2fd44df','2026-06-10 07:59:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-27-3ugm6hcbgbmd-RoleParametersValue-3ukih3t5kk45','state changed','OS::Heat::Value',NULL,1080),(1728,'5ef7c172-c453-47bb-8670-52fdcb280f4b','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','21','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-21-j5tjdzq7nkp4','state changed','OS::TripleO::Services::Kernel',NULL,1081),(1729,'fde72641-30d8-4fb5-8ae6-58b5e09b2010','9441e22e-0738-4a3c-82a6-3bbd5aaf28c6','2026-06-10 07:59:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-21-j5tjdzq7nkp4','9441e22e-0738-4a3c-82a6-3bbd5aaf28c6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1730,'c736dd42-c118-4672-9b49-be2b4581ba51','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','TenantPort','5eed1bc4-5c2f-45c4-afd8-ec1b1b774688','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1046),(1731,'034d6768-031d-4d62-8397-b688d2ebf819','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','StoragePort','e2ae3a4f-03eb-4568-8079-20fb0ec64aef','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1054),(1732,'46eda82b-19e7-4537-89d7-f4bb0e76f096','9441e22e-0738-4a3c-82a6-3bbd5aaf28c6','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-21-j5tjdzq7nkp4-RoleParametersValue-ctspmyyesryu','state changed','OS::Heat::Value',NULL,1082),(1733,'5efaec9c-5878-4740-b6b0-36f20f4d5ed5','9441e22e-0738-4a3c-82a6-3bbd5aaf28c6','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-21-j5tjdzq7nkp4-RoleParametersValue-ctspmyyesryu','state changed','OS::Heat::Value',NULL,1082),(1734,'611956f3-0d2d-4518-8f42-376c0e0aa710','9441e22e-0738-4a3c-82a6-3bbd5aaf28c6','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-21-j5tjdzq7nkp4','9441e22e-0738-4a3c-82a6-3bbd5aaf28c6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1735,'fdb2f6d8-c893-49fe-9f31-b8033d35d362','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','InternalApiPort','ca40623b-bc72-45e2-8987-50ba6d6363c4','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1050),(1736,'468d3811-56f9-49fc-bce3-eca00bc8c4a9','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NetIpMap-cbmvxkqz3cqo','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1089),(1737,'ba15f690-7023-43e9-961d-f197b956250e','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','NodeExtraConfig','cf9496a3-8f45-48e2-8525-b47665868793','state changed','OS::TripleO::NodeExtraConfig',NULL,1059),(1738,'a14162e8-9548-47b8-a665-ecd2b8d0e519','3880188e-1a6b-4a09-ac49-b2821e6fe2be','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NetIpMap-cbmvxkqz3cqo','3880188e-1a6b-4a09-ac49-b2821e6fe2be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1739,'d5510c95-f749-4d28-a207-d0c641c0c5f1','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-MySQLClient-eczdw2ajf6m7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1740,'68ef5cf7-b7f6-4380-a11a-2eb86a376262','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','HeatApiCfnLogging','141309ac-253a-43ca-b6c9-139a9987e0d2','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1741,'f370ad2b-31d9-4036-ac16-18aba6a1a049','4f41d9c5-c936-45b1-8554-a150460d3077','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-16-evowt2uvcrh3','4f41d9c5-c936-45b1-8554-a150460d3077','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1742,'60fbd5ec-340f-4af5-b3ca-63d0cd5b3a5d','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','ContainersCommon','20414572-2c57-41a8-bcce-e63876663fd8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1743,'83990bc9-8a59-41d0-a3b2-a697abaf81ea','d08ddcf0-ad48-4c34-8f67-e680eee22498','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-MySQLClient-eczdw2ajf6m7','d08ddcf0-ad48-4c34-8f67-e680eee22498','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1744,'8168b0d0-5186-4734-baf1-9ec1f5db97c4','3880188e-1a6b-4a09-ac49-b2821e6fe2be','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NetIpMap-cbmvxkqz3cqo-NetIpMapValue-kegtimdctgaj','state changed','OS::Heat::Value',NULL,1090),(1745,'5d41c49d-29d3-4daf-8e37-103e2b97973d','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','NovaCompute','fb3670b4-3938-4f9d-bf9f-2ceaa1677182','state changed','OS::TripleO::ComputeServer',NULL,1032),(1746,'c51eb0e3-7a68-48f5-83f8-e9dcc542178d','d08ddcf0-ad48-4c34-8f67-e680eee22498','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-MySQLClient-eczdw2ajf6m7','d08ddcf0-ad48-4c34-8f67-e680eee22498','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1747,'6b3ab429-bc90-46d7-ae06-c7552a9ddc4a','3880188e-1a6b-4a09-ac49-b2821e6fe2be','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NetIpMap-cbmvxkqz3cqo-NetIpMapValue-kegtimdctgaj','state changed','OS::Heat::Value',NULL,1090),(1748,'b3339cd1-0063-4b99-8255-0333364dc20a','3880188e-1a6b-4a09-ac49-b2821e6fe2be','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via-NetIpMap-cbmvxkqz3cqo','3880188e-1a6b-4a09-ac49-b2821e6fe2be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1749,'88263d04-9bb1-4c4b-843f-b1effae16fca','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-PreNetworkConfig-3wumioijijr3','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1750,'07af44ca-21b2-4c8e-9bd5-3cb5fff3614b','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NetHostMap-46zjzj6ezhyg','state changed','OS::Heat::Value',NULL,1092),(1751,'2fd97b45-5145-475b-beda-0bd6266dcf27','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','PreNetworkConfig','729c836d-029d-4e09-b7b1-ed23f13f1807','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1752,'ee638b07-e866-4660-8caf-ccb45d8ce6e5','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NetHostMap-46zjzj6ezhyg','state changed','OS::Heat::Value',NULL,1092),(1753,'71568613-a69a-4a8a-9c15-4f8ad85e77ea','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-TenantPort-v5d4p2be2s2p','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1094),(1754,'f6cddd18-8a50-410e-a1cd-5c75a9b10d48','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NodeTLSCAData-wo4mld6a7rzw','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1755,'bd4e0add-a0b4-44b1-ac95-abae0ae7259a','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-InternalApiPort-l6noylxqeivd','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1095),(1756,'8da1888c-b91d-4476-ab1c-636e2226466b','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NovaComputeAnsibleHostVars-hh3kybjnuqny','state changed','OS::Heat::Value',NULL,1096),(1757,'caf669ed-71c3-433b-8fa2-57c4bc667b1a','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NovaComputeAnsibleHostVars-hh3kybjnuqny','state changed','OS::Heat::Value',NULL,1096),(1758,'1433d5cd-99f1-4f0e-9935-a3a18181b08d','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-ComputeExtraConfigPre-mhnm622medib','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1098),(1759,'ce25ff62-8a47-4baf-81a5-0f6d682ea720','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','NodeTLSCAData','d80ad491-05c5-40e1-956d-0af327673d23','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1760,'174b1ab1-cf1c-4de4-85bf-f014250374b6','b77bd376-7920-4f02-8952-7da301cc6073','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','ControlPlanePort','d2f06c62-ef68-4e3b-be74-94f42ba6fcd1','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1079),(1761,'b71a1104-40b2-4b7f-9a9b-b11ff9338c18','c09872be-0978-462c-8752-6e436036595b','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-InternalApiPort-l6noylxqeivd','c09872be-0978-462c-8752-6e436036595b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1762,'5c2fe662-7348-4b55-8e4f-de804abd67ec','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-StoragePort-hraczmyhdss4','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1099),(1763,'e5218edd-c892-4e62-a077-c01509fd0243','da3afb85-49d1-46d5-a195-73536bd003ad','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-TenantPort-v5d4p2be2s2p','da3afb85-49d1-46d5-a195-73536bd003ad','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1764,'393c5569-fed5-4a5e-a371-20e76c1d9dd7','b77bd376-7920-4f02-8952-7da301cc6073','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NovaCompute-d5d6s6nwjdym','b77bd376-7920-4f02-8952-7da301cc6073','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1765,'0c029bb1-cc8d-4a22-abf6-c777a5132b29','767a702b-52b5-489a-89df-32fed2fd44df','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-27-3ugm6hcbgbmd-ContainersCommon-rwbwedyfy47c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1766,'08814510-c248-4a51-9b53-b71423249c5a','560b6a60-3b1b-4ce5-bc5a-52ebd5d3660e','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-ComputeExtraConfigPre-mhnm622medib','560b6a60-3b1b-4ce5-bc5a-52ebd5d3660e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1767,'78596675-3cd1-4b5d-910f-3b2bb134836f','560b6a60-3b1b-4ce5-bc5a-52ebd5d3660e','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-ComputeExtraConfigPre-mhnm622medib','560b6a60-3b1b-4ce5-bc5a-52ebd5d3660e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1768,'c60b7ea4-2972-4ccd-86f0-15af224b9d92','d4f6fa28-cd41-4b6e-8cde-336fbe6d1d43','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-StoragePort-hraczmyhdss4','d4f6fa28-cd41-4b6e-8cde-336fbe6d1d43','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1769,'ab459c90-083c-4b24-8390-3397179d5160','da3afb85-49d1-46d5-a195-73536bd003ad','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-TenantPort-v5d4p2be2s2p-TenantDeployedPort-ef6tlweakido','state changed','OS::Heat::Value',NULL,1100),(1770,'5041023a-a303-4075-82c0-cb6285d7a394','4e8d3b51-defc-4114-88b2-0751a08835a4','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-27-3ugm6hcbgbmd-ContainersCommon-rwbwedyfy47c','4e8d3b51-defc-4114-88b2-0751a08835a4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1771,'f8a6dded-386d-41d4-8f64-6b41704c4c90','da3afb85-49d1-46d5-a195-73536bd003ad','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-TenantPort-v5d4p2be2s2p-TenantDeployedPort-ef6tlweakido','state changed','OS::Heat::Value',NULL,1100),(1772,'c3e2b391-09a9-4850-8955-c769cdce9220','c09872be-0978-462c-8752-6e436036595b','2026-06-10 08:00:00',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-InternalApiPort-l6noylxqeivd-InternalApiDeployedPort-3da6qau5puli','state changed','OS::Heat::Value',NULL,1101),(1773,'2509b21c-68c2-4829-88d4-06fec628db05','c09872be-0978-462c-8752-6e436036595b','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-InternalApiPort-l6noylxqeivd-InternalApiDeployedPort-3da6qau5puli','state changed','OS::Heat::Value',NULL,1101),(1774,'23b76d89-152e-47fc-a1b3-1a107af5f942','da3afb85-49d1-46d5-a195-73536bd003ad','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-TenantPort-v5d4p2be2s2p','da3afb85-49d1-46d5-a195-73536bd003ad','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1775,'e38daceb-f425-4027-a91a-cbe898d0b3e4','4e8d3b51-defc-4114-88b2-0751a08835a4','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-27-3ugm6hcbgbmd-ContainersCommon-rwbwedyfy47c','4e8d3b51-defc-4114-88b2-0751a08835a4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1776,'93f007be-9d8f-45b7-bd7c-5df58990d2d7','c09872be-0978-462c-8752-6e436036595b','2026-06-10 08:00:00',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-InternalApiPort-l6noylxqeivd','c09872be-0978-462c-8752-6e436036595b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1777,'3706004d-6fa3-4d6e-9250-be6103193e99','d4f6fa28-cd41-4b6e-8cde-336fbe6d1d43','2026-06-10 08:00:01',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-StoragePort-hraczmyhdss4-StorageDeployedPort-opi3mjkcn63h','state changed','OS::Heat::Value',NULL,1102),(1778,'ee4064ea-9458-4e29-9ad9-2ee44603d331','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','21','9441e22e-0738-4a3c-82a6-3bbd5aaf28c6','state changed','OS::TripleO::Services::Kernel',NULL,1081),(1779,'482d4a22-9908-43f5-9470-8f10d860d770','d4f6fa28-cd41-4b6e-8cde-336fbe6d1d43','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-StoragePort-hraczmyhdss4-StorageDeployedPort-opi3mjkcn63h','state changed','OS::Heat::Value',NULL,1102),(1780,'60d87f0f-7ef9-45af-95c4-9526927cffa3','d4f6fa28-cd41-4b6e-8cde-336fbe6d1d43','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-StoragePort-hraczmyhdss4','d4f6fa28-cd41-4b6e-8cde-336fbe6d1d43','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1781,'4b0dff04-e14b-4f9e-969e-4792a5fe3b45','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','16','4f41d9c5-c936-45b1-8554-a150460d3077','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1014),(1782,'ec42a351-f12b-4b40-9e87-dd371ef9035c','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:01',NULL,'CREATE','IN_PROGRESS','25','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1105),(1783,'35ccacec-715e-45ab-b835-cf7a2a90c0c8','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','NetIpMap','3880188e-1a6b-4a09-ac49-b2821e6fe2be','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1089),(1784,'d4b4a576-91d8-4c25-8342-846edbc30da6','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:01',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-RoleParametersValue-c3lpvj4rjnev','state changed','OS::Heat::Value',NULL,1107),(1785,'37867269-cf53-4eba-a342-bc87fd40d7db','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq','b1ac000b-cd1a-460d-bc52-57d789fd322a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1786,'11904f2d-7025-4485-a5e7-0efbab3a9473','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-0-vaibbjag2via','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1787,'3475078c-9411-4150-9318-a60acbe493cd','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-RoleParametersValue-c3lpvj4rjnev','state changed','OS::Heat::Value',NULL,1107),(1788,'90be8752-4453-4d64-a11b-8a4fd57a1386','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','MySQLClient','d08ddcf0-ad48-4c34-8f67-e680eee22498','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1789,'28a2825d-25ba-4855-b50e-0bfb360fe109','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:01',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-MySQLClient-ocq5hk4kmrkv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1790,'7e16be99-d2d8-4a25-a58f-e8eb1fc79e1e','4d65abe2-334a-407c-865a-1838da4c75ff','2026-06-10 08:00:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-MySQLClient-ocq5hk4kmrkv','4d65abe2-334a-407c-865a-1838da4c75ff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1791,'e3995b0f-e849-472f-93e2-d0137933985c','4d65abe2-334a-407c-865a-1838da4c75ff','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-MySQLClient-ocq5hk4kmrkv','4d65abe2-334a-407c-865a-1838da4c75ff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1792,'650a7302-6eeb-4a28-81fc-86b08968252f','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','NovaCompute','b77bd376-7920-4f02-8952-7da301cc6073','state changed','OS::TripleO::ComputeServer',NULL,1033),(1793,'a3041d2d-812d-4cd7-beb1-f667e10a18b5','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:01',NULL,'CREATE','IN_PROGRESS','20','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-20-ady7del57p22','state changed','OS::TripleO::Services::Iscsid',NULL,1114),(1794,'ae5a89b3-2637-4f6e-a107-7192a0c0efaf','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','TenantPort','da3afb85-49d1-46d5-a195-73536bd003ad','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1094),(1795,'45bec376-3b0d-4855-bf80-bb15b347b77e','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','InternalApiPort','c09872be-0978-462c-8752-6e436036595b','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1095),(1796,'40fdf7d1-e01e-4b11-8f44-a63bbc786ab3','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','560b6a60-3b1b-4ce5-bc5a-52ebd5d3660e','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1098),(1797,'2bf5cf23-b655-4105-a761-d06e3c9e3bff','e2eb0cb5-669a-4b8c-9780-5a59b49f874f','2026-06-10 08:00:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-20-ady7del57p22','e2eb0cb5-669a-4b8c-9780-5a59b49f874f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1798,'765ad717-10dd-48b4-a5cf-9817cd3b0cb9','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:01',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NodeExtraConfig-cpzifkbjjoob','state changed','OS::TripleO::NodeExtraConfig',NULL,1118),(1799,'5238b73b-c0b5-48a0-a9af-ccf82497943f','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','StoragePort','d4f6fa28-cd41-4b6e-8cde-336fbe6d1d43','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1099),(1800,'c3b84152-d441-40a2-b9dc-8518e34e78f6','767a702b-52b5-489a-89df-32fed2fd44df','2026-06-10 08:00:01',NULL,'CREATE','COMPLETE','ContainersCommon','4e8d3b51-defc-4114-88b2-0751a08835a4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1801,'4f15d837-8be4-4996-a92e-e84afa1c2723','767a702b-52b5-489a-89df-32fed2fd44df','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-27-3ugm6hcbgbmd','767a702b-52b5-489a-89df-32fed2fd44df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1802,'8d5659a7-e429-4ed4-8bca-71d1445eda96','e2eb0cb5-669a-4b8c-9780-5a59b49f874f','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-20-ady7del57p22-RoleParametersValue-zrmzkjguowqi','state changed','OS::Heat::Value',NULL,1121),(1803,'fecd35b1-6b85-40be-b98c-ae2cfc59e2fa','34104283-1516-46e8-95e0-d57743f930f3','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NodeExtraConfig-cpzifkbjjoob','34104283-1516-46e8-95e0-d57743f930f3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1804,'b57c5052-bd44-4f33-a94c-151a0717c7b5','e2eb0cb5-669a-4b8c-9780-5a59b49f874f','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-20-ady7del57p22-RoleParametersValue-zrmzkjguowqi','state changed','OS::Heat::Value',NULL,1121),(1805,'af285b43-f7ad-42df-a46b-f9c0f7afddf8','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-InternalApiPort-hoxco2z67n4c','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1124),(1806,'9a8a46cb-0975-4875-81dd-a5c9e2f9912d','34104283-1516-46e8-95e0-d57743f930f3','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NodeExtraConfig-cpzifkbjjoob','34104283-1516-46e8-95e0-d57743f930f3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1807,'dcd267d2-bd1d-4715-9ec8-38ef0a2855b0','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-StoragePort-fedjur2w2w6g','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1125),(1808,'defb0105-8ee5-4d8f-b2cd-c54d6280b1ab','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-TenantPort-vmcbzojnpyku','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1126),(1809,'38366630-916e-4db0-b095-9396b0a8abcc','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NetIpMap-w5xoccx4ycxp','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1128),(1810,'24458d58-405f-4bb2-ad22-914b69a9b140','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NodeTLSCAData-fr2odejkgm73','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1811,'56eadbd6-9313-4030-811e-94cea2759360','21cdefce-61a1-45c5-95f9-a5c3a114a76d','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-InternalApiPort-hoxco2z67n4c','21cdefce-61a1-45c5-95f9-a5c3a114a76d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1812,'e6e67624-4368-40a1-b066-9668f4cbdcf9','46a2340e-6c4c-4199-b1a9-d9cec247596f','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-TenantPort-vmcbzojnpyku','46a2340e-6c4c-4199-b1a9-d9cec247596f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1813,'32467fb5-c083-4919-bc1e-9986dc5cdefa','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','NodeTLSCAData','21844320-71c5-422a-bd93-8a49433901cc','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1814,'d79b1ce1-5280-46f8-aecd-0a79497bde3b','8892fdbb-4791-4ba2-8a88-f887c0fd3044','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NetIpMap-w5xoccx4ycxp','8892fdbb-4791-4ba2-8a88-f887c0fd3044','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1815,'eab9bb0c-4b26-40df-a39f-55fe27482305','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','0','5ebc93c2-051a-4c1a-b3d5-6affcef7d2fc','state changed','OS::TripleO::Compute',NULL,1017),(1816,'28e90898-bb68-4847-9f8d-5b430e07f478','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-ComputeExtraConfigPre-jfmr274v5ifu','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1129),(1817,'92dc3959-28fa-4b69-bf08-d17bbd862b13','9b4789f6-a650-4732-8493-0c12bf856a4e','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-StoragePort-fedjur2w2w6g','9b4789f6-a650-4732-8493-0c12bf856a4e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1818,'bf379ab4-992f-4218-a973-de6903f19594','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NetHostMap-sqyapj6aaxxz','state changed','OS::Heat::Value',NULL,1131),(1819,'4ac58d05-f0ac-4789-9839-8937349ab972','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-PreNetworkConfig-ckdcl6lfajcl','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1820,'85d0c4c1-9ffe-4058-ae72-a6eb5baa3c1a','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NetHostMap-sqyapj6aaxxz','state changed','OS::Heat::Value',NULL,1131),(1821,'67104d4b-1143-400d-8bdf-3aa6eddfd97b','8892fdbb-4791-4ba2-8a88-f887c0fd3044','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NetIpMap-w5xoccx4ycxp-NetIpMapValue-7pzz3lltnwe2','state changed','OS::Heat::Value',NULL,1132),(1822,'0cea919f-731d-4d5a-920f-199cefc9be25','8892fdbb-4791-4ba2-8a88-f887c0fd3044','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NetIpMap-w5xoccx4ycxp-NetIpMapValue-7pzz3lltnwe2','state changed','OS::Heat::Value',NULL,1132),(1823,'348d83f6-a4ed-4273-8a6e-5921af4404ac','6ac66694-2147-46e7-9111-c439071bf69f','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-ComputeExtraConfigPre-jfmr274v5ifu','6ac66694-2147-46e7-9111-c439071bf69f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1824,'ad9c64b6-73f7-4e6d-9daa-33a3f1464c67','21cdefce-61a1-45c5-95f9-a5c3a114a76d','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-InternalApiPort-hoxco2z67n4c-InternalApiDeployedPort-kpdnmovzli7m','state changed','OS::Heat::Value',NULL,1135),(1825,'17dc4145-eb8a-460d-84d6-291ccd78bc3b','8892fdbb-4791-4ba2-8a88-f887c0fd3044','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu-NetIpMap-w5xoccx4ycxp','8892fdbb-4791-4ba2-8a88-f887c0fd3044','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1826,'d6cec52c-847c-4df1-aa08-5d0028efcc7b','46a2340e-6c4c-4199-b1a9-d9cec247596f','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-TenantPort-vmcbzojnpyku-TenantDeployedPort-nvayfzpljicp','state changed','OS::Heat::Value',NULL,1134),(1827,'271e4efe-56e0-49dd-b922-26faf0c48643','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','PreNetworkConfig','e550a9cd-2be5-438b-acf6-0733f2d1ca45','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1828,'a8425ab2-0e24-4f3e-a6dd-95108cf1a0e4','21cdefce-61a1-45c5-95f9-a5c3a114a76d','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-InternalApiPort-hoxco2z67n4c-InternalApiDeployedPort-kpdnmovzli7m','state changed','OS::Heat::Value',NULL,1135),(1829,'1deb966c-5401-4e92-bc08-9fb51767f0fa','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NovaComputeAnsibleHostVars-wcd5avdxdlmq','state changed','OS::Heat::Value',NULL,1136),(1830,'ae95f290-35ca-47d4-9b64-f6df5ae6d466','46a2340e-6c4c-4199-b1a9-d9cec247596f','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-TenantPort-vmcbzojnpyku-TenantDeployedPort-nvayfzpljicp','state changed','OS::Heat::Value',NULL,1134),(1831,'3e55fc1e-33f8-4382-8316-4ee46a5b4372','21cdefce-61a1-45c5-95f9-a5c3a114a76d','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-InternalApiPort-hoxco2z67n4c','21cdefce-61a1-45c5-95f9-a5c3a114a76d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1832,'366e7085-a89a-4138-8361-52347539dc43','46a2340e-6c4c-4199-b1a9-d9cec247596f','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-TenantPort-vmcbzojnpyku','46a2340e-6c4c-4199-b1a9-d9cec247596f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1833,'f47a7034-57ff-490e-89ba-23d03c441fb0','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NovaComputeAnsibleHostVars-wcd5avdxdlmq','state changed','OS::Heat::Value',NULL,1136),(1834,'ea73c0f0-d94d-45a4-8cb4-14e76c66718d','6ac66694-2147-46e7-9111-c439071bf69f','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-ComputeExtraConfigPre-jfmr274v5ifu','6ac66694-2147-46e7-9111-c439071bf69f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1835,'3b1dd5d0-35d1-4a9c-9e69-d8dde046601a','9b4789f6-a650-4732-8493-0c12bf856a4e','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-StoragePort-fedjur2w2w6g-StorageDeployedPort-s434yddadwzm','state changed','OS::Heat::Value',NULL,1137),(1836,'8c8d37c0-26dd-4a01-9582-4edf37df2739','9b4789f6-a650-4732-8493-0c12bf856a4e','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-StoragePort-fedjur2w2w6g-StorageDeployedPort-s434yddadwzm','state changed','OS::Heat::Value',NULL,1137),(1837,'513aa05a-21c0-4a7c-9d2b-7b831d7792f1','9b4789f6-a650-4732-8493-0c12bf856a4e','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-StoragePort-fedjur2w2w6g','9b4789f6-a650-4732-8493-0c12bf856a4e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1838,'b4f9e9e8-e912-4eb3-99b6-f65fd368d526','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','ManilaCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaCommon-5sa4wlqzyh3d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1839,'f96f571c-ced8-4050-b8ba-8d141169261d','abadde76-07eb-4ff2-b1f1-5a02240c3210','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaCommon-5sa4wlqzyh3d','abadde76-07eb-4ff2-b1f1-5a02240c3210','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1840,'563d8ff3-cd8e-4d0d-a212-77d85c020b86','abadde76-07eb-4ff2-b1f1-5a02240c3210','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaCommon-5sa4wlqzyh3d-ContainersCommon-5bbpr7akrmob','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1841,'c839ce0d-3553-4ebd-a8f9-58056ade121a','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-ManilaBase-c3ywgzjc7ypp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1138),(1842,'881effd1-7793-44c4-bd07-e1802c25c428','fee5f12b-bba3-4e89-a352-00506a0d1985','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaCommon-5sa4wlqzyh3d-ContainersCommon-5bbpr7akrmob','fee5f12b-bba3-4e89-a352-00506a0d1985','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1843,'e4b1293a-3384-44b0-9fff-387f9314b2ca','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','MySQLClient','4d65abe2-334a-407c-865a-1838da4c75ff','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1844,'dbe85654-81db-4c15-8041-dc938f2afd35','fee5f12b-bba3-4e89-a352-00506a0d1985','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaCommon-5sa4wlqzyh3d-ContainersCommon-5bbpr7akrmob','fee5f12b-bba3-4e89-a352-00506a0d1985','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1845,'05e3c263-4777-4659-852f-a9acfc28bb3f','ca6068e2-8f97-440e-9f26-65678e000b27','2026-06-10 08:00:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-ManilaBase-c3ywgzjc7ypp','ca6068e2-8f97-440e-9f26-65678e000b27','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1846,'52d0235f-5721-4ee5-adfa-b60a2b0c17db','ca6068e2-8f97-440e-9f26-65678e000b27','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-ManilaBase-c3ywgzjc7ypp','ca6068e2-8f97-440e-9f26-65678e000b27','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1847,'d7ffc09a-4fbd-4f18-854d-a41b363b637e','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:02',NULL,'CREATE','COMPLETE','27','767a702b-52b5-489a-89df-32fed2fd44df','state changed','OS::TripleO::Services::Memcached',NULL,1075),(1848,'82bd4371-6104-4c17-8b1f-b2a6b7808c8c','e2eb0cb5-669a-4b8c-9780-5a59b49f874f','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-20-ady7del57p22-ContainersCommon-rwpechjzajl4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1849,'74ad3163-441b-4cbe-a6d2-bb79367caf90','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','NodeExtraConfig','34104283-1516-46e8-95e0-d57743f930f3','state changed','OS::TripleO::NodeExtraConfig',NULL,1118),(1850,'52814607-1e1b-4c5d-a34c-2d82cb52db19','55d83593-561e-4c16-a651-0cb385870e54','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-20-ady7del57p22-ContainersCommon-rwpechjzajl4','55d83593-561e-4c16-a651-0cb385870e54','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1851,'42493abd-c7ca-4e4d-a762-e45ecbd81c8a','55d83593-561e-4c16-a651-0cb385870e54','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-20-ady7del57p22-ContainersCommon-rwpechjzajl4','55d83593-561e-4c16-a651-0cb385870e54','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1852,'cdf7feb6-4c0e-43bb-ba13-a2ef5b211826','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','31','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k','state changed','OS::TripleO::Services::NeutronApi',NULL,1142),(1853,'96d4796b-bd72-41ab-8330-bc3f16c7c082','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','InternalApiPort','21cdefce-61a1-45c5-95f9-a5c3a114a76d','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1124),(1854,'cb15d69d-63a5-4033-b1ed-8a46099f93e6','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','NetIpMap','8892fdbb-4791-4ba2-8a88-f887c0fd3044','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1128),(1855,'485f30bb-056c-46a9-b66a-64cb503e1580','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','StoragePort','9b4789f6-a650-4732-8493-0c12bf856a4e','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1125),(1856,'e6957be2-c759-416d-95f6-7d04214bd96d','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-2-5hydhdnylscu','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1857,'dde8d019-4084-4c5f-b016-a31944771c7e','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','TenantPort','46a2340e-6c4c-4199-b1a9-d9cec247596f','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1126),(1858,'ec2edad7-8e09-4db4-8edf-8411ce2d1c11','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k','cf8ed91a-a7e0-45df-b494-eab7b0070dff','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1859,'2e0eb9c3-2342-4a50-9a15-26238a492d49','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','6ac66694-2147-46e7-9111-c439071bf69f','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1129),(1860,'b0ba201b-b18e-4788-a71c-e37c69048e01','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NodeExtraConfig-tp4vwspjbpod','state changed','OS::TripleO::NodeExtraConfig',NULL,1149),(1861,'3a7f7371-2c53-4e2e-b57d-ee81f86da886','b0dabe84-1354-4309-a2ec-ab0a8e0567b5','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NodeExtraConfig-tp4vwspjbpod','b0dabe84-1354-4309-a2ec-ab0a8e0567b5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1862,'d7ebb972-0278-436d-b967-223a52ed46dd','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NetIpMap-xfjyym4scku5','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1151),(1863,'41d9ebe5-90fe-4a63-9013-f1a6e00a347d','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','ManilaShareContainerBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1152),(1864,'35eb6829-253a-40b0-8957-8797e902eac8','b0dabe84-1354-4309-a2ec-ab0a8e0567b5','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NodeExtraConfig-tp4vwspjbpod','b0dabe84-1354-4309-a2ec-ab0a8e0567b5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1865,'030151de-644f-4afa-ba90-c76f1332f0d8','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1866,'59cb60b7-a7cb-4fb3-a37e-42d57d0370ca','632f536c-3814-4368-8fc9-50f0b9d477f8','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NetIpMap-xfjyym4scku5','632f536c-3814-4368-8fc9-50f0b9d477f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1867,'95a64fec-a530-4578-b882-2711622790a3','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-RoleParametersValue-pxbccbnlhxf3','state changed','OS::Heat::Value',NULL,1153),(1868,'40fb8b37-8674-4153-b003-6c358d25a653','632f536c-3814-4368-8fc9-50f0b9d477f8','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NetIpMap-xfjyym4scku5-NetIpMapValue-azj4g22kkd67','state changed','OS::Heat::Value',NULL,1154),(1869,'09236c8a-6111-4413-bfe6-505eef884e74','632f536c-3814-4368-8fc9-50f0b9d477f8','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NetIpMap-xfjyym4scku5-NetIpMapValue-azj4g22kkd67','state changed','OS::Heat::Value',NULL,1154),(1870,'509c5410-309c-4dff-872f-870b1a1a384d','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-RoleParametersValue-pxbccbnlhxf3','state changed','OS::Heat::Value',NULL,1153),(1871,'58cb1a89-f304-4b8b-a82c-eb1f4078e101','632f536c-3814-4368-8fc9-50f0b9d477f8','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb-NetIpMap-xfjyym4scku5','632f536c-3814-4368-8fc9-50f0b9d477f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1872,'fc6ee085-b4e5-4781-944e-78b6c1d4babf','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-ContainersCommon-wpyuywav5qb5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1873,'40a8ece5-9ce4-42bb-b429-1c55d07de11a','dcf4aef1-e6e9-4c65-8520-92826707260c','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-ContainersCommon-wpyuywav5qb5','dcf4aef1-e6e9-4c65-8520-92826707260c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1874,'f315c3a4-9939-4eda-9034-487ed0588643','dcf4aef1-e6e9-4c65-8520-92826707260c','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-ContainersCommon-wpyuywav5qb5','dcf4aef1-e6e9-4c65-8520-92826707260c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1875,'1d54f8ff-fe9e-495f-8beb-e507e6189690','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-MySQLClient-m5tlfvk7u6su','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1876,'2a47ba5d-e779-40a1-abf1-ab206a53b9d6','abadde76-07eb-4ff2-b1f1-5a02240c3210','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','ContainersCommon','fee5f12b-bba3-4e89-a352-00506a0d1985','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1877,'3832a07b-f7b5-4b1d-a799-db3b19a9592c','abadde76-07eb-4ff2-b1f1-5a02240c3210','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaCommon-5sa4wlqzyh3d','abadde76-07eb-4ff2-b1f1-5a02240c3210','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1878,'73dd488b-c404-4a2d-93b6-6025a75daff3','adb14d42-3f67-4325-ac05-e5555c8feea1','2026-06-10 08:00:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-MySQLClient-m5tlfvk7u6su','adb14d42-3f67-4325-ac05-e5555c8feea1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1879,'e11cc116-30e7-4db9-8ad7-17d9101e479f','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','ManilaBase','ca6068e2-8f97-440e-9f26-65678e000b27','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1138),(1880,'64fb604e-548d-41f0-92fc-eefb7e9a67d7','adb14d42-3f67-4325-ac05-e5555c8feea1','2026-06-10 08:00:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-MySQLClient-m5tlfvk7u6su','adb14d42-3f67-4325-ac05-e5555c8feea1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1881,'18021543-8ed6-46ac-81cb-a9ccd21322e5','e2eb0cb5-669a-4b8c-9780-5a59b49f874f','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','ContainersCommon','55d83593-561e-4c16-a651-0cb385870e54','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1882,'a374d416-164c-4036-8a13-1a14af29f4e2','e2eb0cb5-669a-4b8c-9780-5a59b49f874f','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-20-ady7del57p22','e2eb0cb5-669a-4b8c-9780-5a59b49f874f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1883,'6eb7680b-138c-4894-b4c0-05d8f3265ecb','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','2','01f1c7cb-bdd3-4ac3-8e85-2b013965f290','state changed','OS::TripleO::Compute',NULL,1031),(1884,'48f1bec1-2f26-4e85-afc5-fdb0e686f495','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','NodeExtraConfig','b0dabe84-1354-4309-a2ec-ab0a8e0567b5','state changed','OS::TripleO::NodeExtraConfig',NULL,1149),(1885,'75ddb08f-d442-4310-a9d4-8ce56ec74442','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','NetIpMap','632f536c-3814-4368-8fc9-50f0b9d477f8','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1151),(1886,'48a8185d-a54a-41fd-8eea-aa783f1d9a5f','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij-1-tu73m6qnz5hb','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1887,'9867c1d8-ea76-4db8-9849-bc7934c297c0','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','ManilaCommon','abadde76-07eb-4ff2-b1f1-5a02240c3210','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1888,'fd704cf4-c2ef-4542-8e91-cf21b9d0ca32','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:04',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-NeutronBase-c6apcu7qphh3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1155),(1889,'3b951eb7-c7d2-4a3c-a3ab-7757fb677d73','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:04',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-RoleParametersValue-f4w43x6b2hha','state changed','OS::Heat::Value',NULL,1156),(1890,'0dc8a2b6-8fa6-4106-b75f-d3dfcdcf17ec','7a49f181-9fab-43b5-b0a0-dc16a0e62d13','2026-06-10 08:00:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-NeutronBase-c6apcu7qphh3','7a49f181-9fab-43b5-b0a0-dc16a0e62d13','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1891,'a00652c2-83fd-476e-aceb-4faebcf2222e','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq-RoleParametersValue-f4w43x6b2hha','state changed','OS::Heat::Value',NULL,1156),(1892,'17814dcf-6646-4f71-9b66-40cc25a60022','7a49f181-9fab-43b5-b0a0-dc16a0e62d13','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-NeutronBase-c6apcu7qphh3','7a49f181-9fab-43b5-b0a0-dc16a0e62d13','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1893,'7b719bf3-d9d3-45d1-bb34-6a5a0fc267a5','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','ContainersCommon','dcf4aef1-e6e9-4c65-8520-92826707260c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1894,'a9782986-909e-4967-92d3-ed5706c88b37','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:04',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ManilaBase-oifqksxoblux','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1157),(1895,'fba59398-d143-4f3e-b763-80713e8fc2fe','b1ac000b-cd1a-460d-bc52-57d789fd322a','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-25-k5qwp3xqpopq','b1ac000b-cd1a-460d-bc52-57d789fd322a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1896,'daa57042-b3a4-416e-b583-00f53df34287','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','MySQLClient','adb14d42-3f67-4325-ac05-e5555c8feea1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1897,'751cb9ed-8543-41bc-b78c-3a96078fa8e4','7028b127-2fb5-4ded-8117-0f5aaa2ed1d5','2026-06-10 08:00:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ManilaBase-oifqksxoblux','7028b127-2fb5-4ded-8117-0f5aaa2ed1d5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1898,'6317a720-907c-42d4-93e7-f07e452b2919','7028b127-2fb5-4ded-8117-0f5aaa2ed1d5','2026-06-10 08:00:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ManilaBase-oifqksxoblux','7028b127-2fb5-4ded-8117-0f5aaa2ed1d5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1899,'dc9eee07-1a5f-4583-8e27-4131af7cec1d','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:05',NULL,'CREATE','COMPLETE','20','e2eb0cb5-669a-4b8c-9780-5a59b49f874f','state changed','OS::TripleO::Services::Iscsid',NULL,1114),(1900,'1b2d7b4e-5415-4414-be19-07b95409ff70','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 08:00:05',NULL,'CREATE','COMPLETE','1','e7ef7200-b90f-4cf5-9381-2ba91a4a9a48','state changed','OS::TripleO::Compute',NULL,1024),(1901,'a596650b-293b-4ae5-8253-b77d60e2c255','40b7a703-a52e-4f7b-b893-335fd1fe5280','2026-06-10 08:00:05',NULL,'UPDATE','COMPLETE','overcloud-Compute-vqvy3wbs6fij','40b7a703-a52e-4f7b-b893-335fd1fe5280','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(1902,'1e8520bc-3218-4f23-9537-ebfa92243f39','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:05',NULL,'CREATE','IN_PROGRESS','24','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-24-ahaduraylbvg','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1161),(1903,'7ced7277-2692-43c3-8a17-3e05d16ddf63','846b81e6-5d14-409c-a7d5-61a16d1d4551','2026-06-10 08:00:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-24-ahaduraylbvg','846b81e6-5d14-409c-a7d5-61a16d1d4551','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1904,'fad38594-7ac8-43b9-b9ee-329a54f4b4ef','846b81e6-5d14-409c-a7d5-61a16d1d4551','2026-06-10 08:00:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-24-ahaduraylbvg','846b81e6-5d14-409c-a7d5-61a16d1d4551','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1905,'0f0718ad-28cc-45ec-8f84-5bacd23197a5','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:05',NULL,'CREATE','COMPLETE','25','b1ac000b-cd1a-460d-bc52-57d789fd322a','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1105),(1906,'a5e389dd-4009-4698-b1b4-e7fccc4f4bcc','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:05',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-TLSProxyBase-lxt5g3i46yvi','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1162),(1907,'75aaf00b-342d-4f25-bfd0-547a2154949d','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:05',NULL,'CREATE','COMPLETE','NeutronBase','7a49f181-9fab-43b5-b0a0-dc16a0e62d13','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1155),(1908,'32492492-2a94-406c-a8f5-eeef86e9dadc','8644ca0c-3723-4085-8f93-93e687eaeb08','2026-06-10 08:00:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-TLSProxyBase-lxt5g3i46yvi','8644ca0c-3723-4085-8f93-93e687eaeb08','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1909,'456306a8-00db-4271-8f52-ce21309d8fb4','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-RoleParametersValue-svrphgjkd625','state changed','OS::Heat::Value',NULL,1167),(1910,'107ae6d0-4bef-4f49-915e-24fc8f07a49c','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:05',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-RoleParametersValue-svrphgjkd625','state changed','OS::Heat::Value',NULL,1167),(1911,'fbc72de1-2098-4f55-bf63-f87edffcba5d','8644ca0c-3723-4085-8f93-93e687eaeb08','2026-06-10 08:00:05',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-TLSProxyBase-lxt5g3i46yvi-ApacheNetworks-hut23s54u5vf','state changed','OS::Heat::Value',NULL,1169),(1912,'15bf34de-6b0b-4faf-a705-c8f28fb3f9bc','8644ca0c-3723-4085-8f93-93e687eaeb08','2026-06-10 08:00:05',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-TLSProxyBase-lxt5g3i46yvi-ApacheNetworks-hut23s54u5vf','state changed','OS::Heat::Value',NULL,1169),(1913,'29e2b750-973b-4f3e-a6d3-2c064dd79797','8644ca0c-3723-4085-8f93-93e687eaeb08','2026-06-10 08:00:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-TLSProxyBase-lxt5g3i46yvi','8644ca0c-3723-4085-8f93-93e687eaeb08','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1914,'a0e7ff11-6f60-4859-ab9f-d96a14aa5325','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:05',NULL,'CREATE','COMPLETE','Compute','40b7a703-a52e-4f7b-b893-335fd1fe5280','state changed','OS::Heat::ResourceGroup',NULL,996),(1915,'289ac2bf-8ea5-412f-8a6c-5d472c4e099d','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:06',NULL,'CREATE','COMPLETE','ManilaBase','7028b127-2fb5-4ded-8117-0f5aaa2ed1d5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1157),(1916,'9a04bd65-1d11-43d1-8674-f3fb8745e9ba','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','29','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb','state changed','OS::TripleO::Services::MySQL',NULL,1170),(1917,'28f5f2be-fbf4-4379-8d33-1d8916cb4aad','ed962270-9a69-4f0c-931d-a798ebfb9f29','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb','ed962270-9a69-4f0c-931d-a798ebfb9f29','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1918,'4a6b948d-0c73-44f1-897d-964724cf11e8','ed962270-9a69-4f0c-931d-a798ebfb9f29','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb-MysqlBase-256esd6ckpow','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1176),(1919,'a6f8625a-f6ad-4db5-8ac5-65a8e290f7ee','d63713f9-ba05-4d7a-a573-830dde9f99b5','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb-MysqlBase-256esd6ckpow','d63713f9-ba05-4d7a-a573-830dde9f99b5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1920,'48a049d6-c44f-4705-b761-c5f21a2c278b','d63713f9-ba05-4d7a-a573-830dde9f99b5','2026-06-10 08:00:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb-MysqlBase-256esd6ckpow','d63713f9-ba05-4d7a-a573-830dde9f99b5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1921,'77cb0542-e53f-4f05-8ef2-bfb74f867af6','ed962270-9a69-4f0c-931d-a798ebfb9f29','2026-06-10 08:00:06',NULL,'CREATE','COMPLETE','MysqlBase','d63713f9-ba05-4d7a-a573-830dde9f99b5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1176),(1922,'2b547222-0c3f-4f09-8d67-ac3662282b3c','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:06',NULL,'CREATE','COMPLETE','24','846b81e6-5d14-409c-a7d5-61a16d1d4551','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1161),(1923,'adf155d7-f42b-464a-abdd-884a7ab8b2c6','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-NeutronLogging-o72f3ienrsy4','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1184),(1924,'bd8efa97-1af2-42a5-98d0-48fec59fc216','fa53ba9f-f5b1-42ae-bda2-66e1cf171a3d','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-NeutronLogging-o72f3ienrsy4','fa53ba9f-f5b1-42ae-bda2-66e1cf171a3d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1925,'d74eced4-2fa5-4270-ac01-b0cb9f5a9fa5','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','ManilaShareCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ManilaShareCommon-3ssyccsespk3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1926,'b0d036bd-da62-4817-b0d1-944f0d362cf1','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:06',NULL,'CREATE','COMPLETE','TLSProxyBase','8644ca0c-3723-4085-8f93-93e687eaeb08','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1162),(1927,'feae72a3-dfd6-4bcc-ace1-fb7c2742a101','fa53ba9f-f5b1-42ae-bda2-66e1cf171a3d','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-NeutronLogging-o72f3ienrsy4-RoleParametersValue-2sjimujl334c','state changed','OS::Heat::Value',NULL,1188),(1928,'84b7b29f-1698-42ee-b09a-81c4d1cc5521','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','28','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-28-m3s44qz3ugn3','state changed','OS::TripleO::Services::MetricsQdr',NULL,1189),(1929,'583993d5-cc47-4694-9deb-4cfc560446f4','fa53ba9f-f5b1-42ae-bda2-66e1cf171a3d','2026-06-10 08:00:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-NeutronLogging-o72f3ienrsy4-RoleParametersValue-2sjimujl334c','state changed','OS::Heat::Value',NULL,1188),(1930,'a068b099-87cc-495c-afd8-23166e91c41f','fa53ba9f-f5b1-42ae-bda2-66e1cf171a3d','2026-06-10 08:00:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-NeutronLogging-o72f3ienrsy4','fa53ba9f-f5b1-42ae-bda2-66e1cf171a3d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1931,'864b7373-4cf0-424f-b531-7d76f995baf9','c50a065c-7c70-43a2-9a22-cf87fe508c29','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ManilaShareCommon-3ssyccsespk3','c50a065c-7c70-43a2-9a22-cf87fe508c29','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1932,'8617b986-6eb7-4369-bd76-ca3f6280e1e7','79cd13ee-f1b2-4b88-940e-08188d80415e','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-28-m3s44qz3ugn3','79cd13ee-f1b2-4b88-940e-08188d80415e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1933,'ed4c38c3-317e-4a1c-a25d-9ad90353d5ed','c50a065c-7c70-43a2-9a22-cf87fe508c29','2026-06-10 08:00:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ManilaShareCommon-3ssyccsespk3-ContainersCommon-ndtib2eik5i7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1934,'4e4e9faa-080f-46b4-b4bf-9451a08dbbc7','79cd13ee-f1b2-4b88-940e-08188d80415e','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-28-m3s44qz3ugn3-ContainersCommon-5ngvi3se5d6k','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1935,'1c20d399-ba73-4540-b2c8-37cf1f06caf0','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','ComputeServers','overcloud-ComputeServers-c35f7c2tf37e','state changed','OS::Heat::Value',NULL,1191),(1936,'101c6c4c-087c-4b48-87ea-a281cb7f4d80','31051a17-854c-4578-870e-84ed6a1912cc','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ManilaShareCommon-3ssyccsespk3-ContainersCommon-ndtib2eik5i7','31051a17-854c-4578-870e-84ed6a1912cc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1937,'0e25ee41-e3f1-4ef1-9c7c-0b0ae055c562','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:07',NULL,'CREATE','COMPLETE','ComputeServers','overcloud-ComputeServers-c35f7c2tf37e','state changed','OS::Heat::Value',NULL,1191),(1938,'371641e9-b5bd-4bba-bbc3-66d69c71ba24','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-zxvzkzevzxoa','state changed','OS::Heat::Value',NULL,1192),(1939,'9fc66e7a-2871-4d3e-bb86-611857e62065','31051a17-854c-4578-870e-84ed6a1912cc','2026-06-10 08:00:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ManilaShareCommon-3ssyccsespk3-ContainersCommon-ndtib2eik5i7','31051a17-854c-4578-870e-84ed6a1912cc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1940,'95d1ac1b-8beb-4de9-95c7-b520e67e4c29','6567e051-cf11-4354-a49d-0e646ad71b91','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-28-m3s44qz3ugn3-ContainersCommon-5ngvi3se5d6k','6567e051-cf11-4354-a49d-0e646ad71b91','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1941,'a70b3f9d-71a0-44d8-b759-da99bd7434bc','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:07',NULL,'CREATE','COMPLETE','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-zxvzkzevzxoa','state changed','OS::Heat::Value',NULL,1192),(1942,'d8a89c5b-006e-4d52-a9a9-e9b62206b4fd','6567e051-cf11-4354-a49d-0e646ad71b91','2026-06-10 08:00:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-28-m3s44qz3ugn3-ContainersCommon-5ngvi3se5d6k','6567e051-cf11-4354-a49d-0e646ad71b91','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1943,'25e0a77a-7437-45fc-a9e8-ed43834fee2b','ed962270-9a69-4f0c-931d-a798ebfb9f29','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb-ContainersCommon-x4qlhrparweb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1944,'68174d0f-9acf-4d30-b5d1-2cc821a3ee3c','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','ComputeIpListMap','overcloud-ComputeIpListMap-ryruagqxoox4','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1196),(1945,'429e5c19-a722-45a3-b4a6-5b81930eeceb','272c9c1c-cc92-41cf-a977-e3dad37749a0','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb-ContainersCommon-x4qlhrparweb','272c9c1c-cc92-41cf-a977-e3dad37749a0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1946,'75b9b259-6aea-4538-bcf8-36e9552dc04f','272c9c1c-cc92-41cf-a977-e3dad37749a0','2026-06-10 08:00:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb-ContainersCommon-x4qlhrparweb','272c9c1c-cc92-41cf-a977-e3dad37749a0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1947,'db6d4fad-800b-456b-8c2b-d2126da81604','05485910-4352-4f4b-900b-a1d1e3372c80','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeIpListMap-ryruagqxoox4','05485910-4352-4f4b-900b-a1d1e3372c80','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1948,'47fc0d86-c8a4-4531-a4fa-808e6f1a2e4e','05485910-4352-4f4b-900b-a1d1e3372c80','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ComputeIpListMap-ryruagqxoox4-EnabledServicesValue-f3esm6dgpfu4','state changed','OS::Heat::Value',NULL,1197),(1949,'d2e093cb-8e82-4570-a4d7-38c3e78f191f','05485910-4352-4f4b-900b-a1d1e3372c80','2026-06-10 08:00:07',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ComputeIpListMap-ryruagqxoox4-EnabledServicesValue-f3esm6dgpfu4','state changed','OS::Heat::Value',NULL,1197),(1950,'7fa06a0f-a6ad-4a59-901a-5150db97b3a2','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-ContainersCommon-drxi6yulnmf7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1951,'7fd39618-c7dc-4ac2-8e38-8170eb73ab0a','3abd50df-2b94-44e4-9f31-6458db534d22','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-ContainersCommon-drxi6yulnmf7','3abd50df-2b94-44e4-9f31-6458db534d22','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1952,'bc05bfb2-3dab-4716-9607-0e60de0c3eaf','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ContainersCommon-glofaa6qb3na','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1953,'00148584-77de-42fb-b95d-22bf0783af7c','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:07',NULL,'CREATE','COMPLETE','NeutronLogging','fa53ba9f-f5b1-42ae-bda2-66e1cf171a3d','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1184),(1954,'9b6d12cd-09ce-4431-8843-73bd94779559','3abd50df-2b94-44e4-9f31-6458db534d22','2026-06-10 08:00:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-ContainersCommon-drxi6yulnmf7','3abd50df-2b94-44e4-9f31-6458db534d22','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1955,'848010d1-8864-44d2-8dc8-86a4adf75666','24a62e8d-47c9-4132-b828-11ef15a8cf2c','2026-06-10 08:00:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ContainersCommon-glofaa6qb3na','24a62e8d-47c9-4132-b828-11ef15a8cf2c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1956,'31cc8acf-4281-4445-9c73-14e8a4242e18','24a62e8d-47c9-4132-b828-11ef15a8cf2c','2026-06-10 08:00:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ContainersCommon-glofaa6qb3na','24a62e8d-47c9-4132-b828-11ef15a8cf2c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1957,'35f8b91e-3263-48ea-ba50-6328b5f7dcb3','79cd13ee-f1b2-4b88-940e-08188d80415e','2026-06-10 08:00:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-28-m3s44qz3ugn3-RoleParametersValue-4or5pgqcs4gz','state changed','OS::Heat::Value',NULL,1198),(1958,'d4f35973-31a4-4c92-8336-99e2d47f5e84','79cd13ee-f1b2-4b88-940e-08188d80415e','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-28-m3s44qz3ugn3-RoleParametersValue-4or5pgqcs4gz','state changed','OS::Heat::Value',NULL,1198),(1959,'68c743b8-4a47-4a6b-8d76-d9fbe1a40104','c50a065c-7c70-43a2-9a22-cf87fe508c29','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','ContainersCommon','31051a17-854c-4578-870e-84ed6a1912cc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1960,'fce507e3-0db0-4065-8c23-632be455670c','c50a065c-7c70-43a2-9a22-cf87fe508c29','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr-ManilaShareCommon-3ssyccsespk3','c50a065c-7c70-43a2-9a22-cf87fe508c29','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1961,'c924790e-28f8-4ad7-8006-3f9cc92ecbd0','79cd13ee-f1b2-4b88-940e-08188d80415e','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','ContainersCommon','6567e051-cf11-4354-a49d-0e646ad71b91','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1962,'c9ac73fb-021f-4c30-bb76-38d9003fd1bc','ed962270-9a69-4f0c-931d-a798ebfb9f29','2026-06-10 08:00:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb-RoleParametersValue-zaum657gknr4','state changed','OS::Heat::Value',NULL,1199),(1963,'560c5c74-bdc9-4df5-9a3b-b1bc6e1f7b5d','79cd13ee-f1b2-4b88-940e-08188d80415e','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-28-m3s44qz3ugn3','79cd13ee-f1b2-4b88-940e-08188d80415e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1964,'17fbfee1-050e-4dfd-9b19-43d1945818f6','ed962270-9a69-4f0c-931d-a798ebfb9f29','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb-RoleParametersValue-zaum657gknr4','state changed','OS::Heat::Value',NULL,1199),(1965,'2b384b64-0977-4f3a-bccb-42a48342e7a8','ed962270-9a69-4f0c-931d-a798ebfb9f29','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','ContainersCommon','272c9c1c-cc92-41cf-a977-e3dad37749a0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1966,'9794af03-cdeb-405d-aa5d-10436348be3d','ed962270-9a69-4f0c-931d-a798ebfb9f29','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-29-2kb4b5sw3xyb','ed962270-9a69-4f0c-931d-a798ebfb9f29','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1967,'42db86fe-3881-4e0d-993d-27202938fcb0','05485910-4352-4f4b-900b-a1d1e3372c80','2026-06-10 08:00:08',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeIpListMap-ryruagqxoox4-NetIpMapValue-pvel4maznzu5','state changed','OS::Heat::Value',NULL,1200),(1968,'f090f626-b433-4d74-8ff6-ad2158fd0b2a','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:08',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-MySQLClient-7ixmx2u4dh5d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1969,'4764d8e2-5126-4b7f-8349-3b027001e548','05485910-4352-4f4b-900b-a1d1e3372c80','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeIpListMap-ryruagqxoox4-NetIpMapValue-pvel4maznzu5','state changed','OS::Heat::Value',NULL,1200),(1970,'ddd707d2-a21e-4c2e-b138-b179d42a57ac','05485910-4352-4f4b-900b-a1d1e3372c80','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','overcloud-ComputeIpListMap-ryruagqxoox4','05485910-4352-4f4b-900b-a1d1e3372c80','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1971,'c1a6aebd-9fff-4c9b-83b1-2051170906a5','90e818f0-63ad-44dc-a043-35f0b110861f','2026-06-10 08:00:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-MySQLClient-7ixmx2u4dh5d','90e818f0-63ad-44dc-a043-35f0b110861f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1972,'751eefa0-b9d2-4a3d-aa12-2e57a795569d','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','ContainersCommon','3abd50df-2b94-44e4-9f31-6458db534d22','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1973,'9f4af550-69c5-400e-9205-eb261f7dff34','90e818f0-63ad-44dc-a043-35f0b110861f','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k-MySQLClient-7ixmx2u4dh5d','90e818f0-63ad-44dc-a043-35f0b110861f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1974,'3f5babfc-b774-4cb0-a011-de60b334484a','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','ContainersCommon','24a62e8d-47c9-4132-b828-11ef15a8cf2c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1975,'c47d8847-d1fa-4386-88d0-e1fb60dbba44','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','ManilaShareCommon','c50a065c-7c70-43a2-9a22-cf87fe508c29','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1976,'727372c5-9ac2-424a-8ed9-b3c636fd198f','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp-ManilaShareContainerBase-7s77uqom4wkr','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1977,'8a0571c4-866a-485f-ad0f-36ea8d51fed7','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:08',NULL,'CREATE','COMPLETE','28','79cd13ee-f1b2-4b88-940e-08188d80415e','state changed','OS::TripleO::Services::MetricsQdr',NULL,1189),(1978,'eb970148-d972-41b6-bc0b-0dc3a2244013','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:09',NULL,'CREATE','COMPLETE','29','ed962270-9a69-4f0c-931d-a798ebfb9f29','state changed','OS::TripleO::Services::MySQL',NULL,1170),(1979,'6c0427b7-19ba-4904-99d1-b215b5d8ffa4','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:09',NULL,'CREATE','IN_PROGRESS','32','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1204),(1980,'a32a74a2-0ba1-4fdd-96be-1022e265a0fd','e18e0e25-7aaa-4701-af84-30309b7b1790','2026-06-10 08:00:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau','e18e0e25-7aaa-4701-af84-30309b7b1790','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1981,'9c886f83-3749-4b45-906f-402f626300a9','e18e0e25-7aaa-4701-af84-30309b7b1790','2026-06-10 08:00:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-RoleParametersValue-7oksxcdxixg5','state changed','OS::Heat::Value',NULL,1207),(1982,'e856d9fe-28a7-4136-aa71-06c605382b52','e18e0e25-7aaa-4701-af84-30309b7b1790','2026-06-10 08:00:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-RoleParametersValue-7oksxcdxixg5','state changed','OS::Heat::Value',NULL,1207),(1983,'d74309c0-33a2-40f1-976b-fbc3a81502af','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:09',NULL,'CREATE','COMPLETE','ComputeIpListMap','05485910-4352-4f4b-900b-a1d1e3372c80','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1196),(1984,'7d70ffda-e1ad-451c-8a62-f66431ba2ccf','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:09',NULL,'CREATE','COMPLETE','ManilaShareContainerBase','9c5f1a4e-0bc3-496c-8504-eb575fca0f62','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1152),(1985,'b0d83ce7-45f1-4256-aad3-e630a1542dba','2bf84f06-75d2-4e09-9b56-f7ca6e942882','2026-06-10 08:00:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-26-ipbpxcpo62bp','2bf84f06-75d2-4e09-9b56-f7ca6e942882','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1986,'6cca5889-1989-4298-a318-f2c123fb203e','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:09',NULL,'CREATE','IN_PROGRESS','33','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7','state changed','OS::TripleO::Services::NovaApi',NULL,1210),(1987,'28dc98a6-157a-4ac2-9415-45a6c04e95ef','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:09',NULL,'CREATE','COMPLETE','MySQLClient','90e818f0-63ad-44dc-a043-35f0b110861f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1988,'372dddf4-0fa3-4dd8-9bd3-fcfb37a00ead','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7','21ff318f-54c5-498a-b396-0b13595eccce','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1989,'0e3ff0a2-05cc-4b0e-a0ff-47feec225ed5','cf8ed91a-a7e0-45df-b494-eab7b0070dff','2026-06-10 08:00:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-31-lnl2wt6xrg5k','cf8ed91a-a7e0-45df-b494-eab7b0070dff','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1990,'708af4e4-809e-48c8-ba5d-18abbce5b1d2','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:10',NULL,'CREATE','IN_PROGRESS','NovaApiLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaApiLogging-7uephd42o5s4','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(1991,'55ed4c18-5c94-446f-83a8-74ca24e15f9e','3bcab8be-50e1-4093-83f8-a991c7bd3fa1','2026-06-10 08:00:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaApiLogging-7uephd42o5s4','3bcab8be-50e1-4093-83f8-a991c7bd3fa1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1992,'a6400bc2-7ad0-4810-ab14-63e1486e1d54','3bcab8be-50e1-4093-83f8-a991c7bd3fa1','2026-06-10 08:00:10',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaApiLogging-7uephd42o5s4-RoleParametersValue-rhmrrakt6egw','state changed','OS::Heat::Value',NULL,1211),(1993,'4d948e63-5618-4fbb-9e7b-3fe112094c3f','3bcab8be-50e1-4093-83f8-a991c7bd3fa1','2026-06-10 08:00:10',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaApiLogging-7uephd42o5s4-RoleParametersValue-rhmrrakt6egw','state changed','OS::Heat::Value',NULL,1211),(1994,'3643a403-a812-424b-b264-c6e55c0365ac','3bcab8be-50e1-4093-83f8-a991c7bd3fa1','2026-06-10 08:00:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaApiLogging-7uephd42o5s4','3bcab8be-50e1-4093-83f8-a991c7bd3fa1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1995,'f46cf764-f3c2-4f4b-a978-e33aa25a6deb','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:10',NULL,'CREATE','COMPLETE','26','2bf84f06-75d2-4e09-9b56-f7ca6e942882','state changed','OS::TripleO::Services::ManilaShare',NULL,1057),(1996,'51c32e80-b007-4b2e-aca1-cdbf55704a2f','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:10',NULL,'CREATE','COMPLETE','31','cf8ed91a-a7e0-45df-b494-eab7b0070dff','state changed','OS::TripleO::Services::NeutronApi',NULL,1142),(1997,'2fb3caca-2ba0-4530-9722-db9d2e4a7266','e18e0e25-7aaa-4701-af84-30309b7b1790','2026-06-10 08:00:10',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-NeutronBase-6x3txpjoziaf','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1212),(1998,'2222a7e9-dc9a-436c-9e7a-eb64d3eb2fbb','dc34db53-8407-4995-a99a-c52ca99a8b5d','2026-06-10 08:00:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-NeutronBase-6x3txpjoziaf','dc34db53-8407-4995-a99a-c52ca99a8b5d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1999,'f82a147f-dc14-49a9-9d1f-d74f1544168e','dc34db53-8407-4995-a99a-c52ca99a8b5d','2026-06-10 08:00:10',NULL,'CREATE','IN_PROGRESS','NeutronMl2Base','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-NeutronBase-6x3txpjoziaf-NeutronMl2Base-pjmwwnpjlajl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1218),(2000,'65b0c0b6-0ff4-4d67-94d2-8cc38e99e43a','e4f43c2d-66ec-4803-a85b-432ad1f06f08','2026-06-10 08:00:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-NeutronBase-6x3txpjoziaf-NeutronMl2Base-pjmwwnpjlajl','e4f43c2d-66ec-4803-a85b-432ad1f06f08','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2001,'1fe811da-2396-4e59-86e1-9451c9209891','e4f43c2d-66ec-4803-a85b-432ad1f06f08','2026-06-10 08:00:10',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-NeutronBase-6x3txpjoziaf-NeutronMl2Base-pjmwwnpjlajl-NeutronBase-pcxvrqr3eh5r','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1230),(2002,'303c7f0a-c0c8-4259-a37e-f099c1f7db0b','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-ContainersCommon-n5nlttflcua7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2003,'c1d8ddcb-a5d6-495c-beb6-2241b6d6c518','d2139f5a-6e22-424f-9b96-a0e22635903b','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-NeutronBase-6x3txpjoziaf-NeutronMl2Base-pjmwwnpjlajl-NeutronBase-pcxvrqr3eh5r','d2139f5a-6e22-424f-9b96-a0e22635903b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2004,'d1f8be2f-9cea-4160-b2ac-445893671935','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','35','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t','state changed','OS::TripleO::Services::NovaMetadata',NULL,1237),(2005,'7804645c-956d-4cad-a961-b91528690661','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:11',NULL,'CREATE','COMPLETE','NovaApiLogging','3bcab8be-50e1-4093-83f8-a991c7bd3fa1','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(2006,'89719cb7-d194-4173-a3a3-51d54304b24e','ed5c4fb8-f584-4d1b-a03a-7679ad3ad1e8','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-ContainersCommon-n5nlttflcua7','ed5c4fb8-f584-4d1b-a03a-7679ad3ad1e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2007,'5d10846d-0924-4bf5-96b7-e2280229f9c8','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','30','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-30-bj63vl52s7mz','state changed','OS::TripleO::Services::MySQLClient',NULL,1238),(2008,'929bd3c5-5cf5-4cb6-a3a7-ba9315809fe1','d2139f5a-6e22-424f-9b96-a0e22635903b','2026-06-10 08:00:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-NeutronBase-6x3txpjoziaf-NeutronMl2Base-pjmwwnpjlajl-NeutronBase-pcxvrqr3eh5r','d2139f5a-6e22-424f-9b96-a0e22635903b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2009,'a7d9e252-59b4-4b59-b6df-b1856c172cf6','ed5c4fb8-f584-4d1b-a03a-7679ad3ad1e8','2026-06-10 08:00:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-ContainersCommon-n5nlttflcua7','ed5c4fb8-f584-4d1b-a03a-7679ad3ad1e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2010,'c0ac88b0-197b-474f-a546-d4b149d9e459','2f441ef8-6ad6-4466-8877-5a9939306fb8','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-30-bj63vl52s7mz','2f441ef8-6ad6-4466-8877-5a9939306fb8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2011,'f1487fb8-ef1f-40b3-8141-353b884f3856','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:11',NULL,'CREATE','COMPLETE','ContainersCommon','ed5c4fb8-f584-4d1b-a03a-7679ad3ad1e8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2012,'1638e405-d178-438f-a6cd-7d7d60ac3cf9','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t','16a6ebcb-bb10-4928-a7cc-794422beb0a1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2013,'99663667-9fb6-4132-a0e3-7873cbfbc717','2f441ef8-6ad6-4466-8877-5a9939306fb8','2026-06-10 08:00:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-30-bj63vl52s7mz','2f441ef8-6ad6-4466-8877-5a9939306fb8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2014,'2dde56d1-33e5-4d64-b172-2d74372f100a','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','NovaMetadataLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaMetadataLogging-z6txpyj4uqaq','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2015,'e03878bd-1d25-43ca-8609-2ef4b917841a','7ca5ebb6-1d86-48fd-a6db-607b3d2f1ff3','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaMetadataLogging-z6txpyj4uqaq','7ca5ebb6-1d86-48fd-a6db-607b3d2f1ff3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2016,'a08b9dc2-6ad7-4081-b85d-2ec5f67e5d43','7ca5ebb6-1d86-48fd-a6db-607b3d2f1ff3','2026-06-10 08:00:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaMetadataLogging-z6txpyj4uqaq-RoleParametersValue-xxkicq4oxb63','state changed','OS::Heat::Value',NULL,1239),(2017,'0d529adc-c098-40f9-9dad-5b78e9870837','7ca5ebb6-1d86-48fd-a6db-607b3d2f1ff3','2026-06-10 08:00:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaMetadataLogging-z6txpyj4uqaq-RoleParametersValue-xxkicq4oxb63','state changed','OS::Heat::Value',NULL,1239),(2018,'0b4f45b3-3606-4f10-a920-bcbd18dd4cd3','7ca5ebb6-1d86-48fd-a6db-607b3d2f1ff3','2026-06-10 08:00:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaMetadataLogging-z6txpyj4uqaq','7ca5ebb6-1d86-48fd-a6db-607b3d2f1ff3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2019,'2ffc7e83-53e8-4f7d-baa3-2c4919d2f8ac','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:12',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-ApacheServiceBase-5g4i5g2ufhhu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1240),(2020,'c9183670-3140-46e1-8145-1d3d6006adbf','f934aac0-6b00-427d-a213-4e78e02bcd1a','2026-06-10 08:00:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-ApacheServiceBase-5g4i5g2ufhhu','f934aac0-6b00-427d-a213-4e78e02bcd1a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2021,'db2c493f-ad95-4fb4-bd92-a1ce9dc24b75','e4f43c2d-66ec-4803-a85b-432ad1f06f08','2026-06-10 08:00:12',NULL,'CREATE','COMPLETE','NeutronBase','d2139f5a-6e22-424f-9b96-a0e22635903b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1230),(2022,'88792cd4-46b3-4307-8ea0-19f5fb701833','e4f43c2d-66ec-4803-a85b-432ad1f06f08','2026-06-10 08:00:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-NeutronBase-6x3txpjoziaf-NeutronMl2Base-pjmwwnpjlajl','e4f43c2d-66ec-4803-a85b-432ad1f06f08','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2023,'a5066e55-e64d-41dd-9762-079d067ff6a9','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:12',NULL,'CREATE','COMPLETE','30','2f441ef8-6ad6-4466-8877-5a9939306fb8','state changed','OS::TripleO::Services::MySQLClient',NULL,1238),(2024,'c9986a12-46c5-47f1-9c70-7b2835ef2a00','f934aac0-6b00-427d-a213-4e78e02bcd1a','2026-06-10 08:00:12',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-ApacheServiceBase-5g4i5g2ufhhu-ApacheNetworks-6uf7m62g4agy','state changed','OS::Heat::Value',NULL,1241),(2025,'04433f3d-5497-435e-9229-9b3f789f0fda','f934aac0-6b00-427d-a213-4e78e02bcd1a','2026-06-10 08:00:12',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-ApacheServiceBase-5g4i5g2ufhhu-ApacheNetworks-6uf7m62g4agy','state changed','OS::Heat::Value',NULL,1241),(2026,'f3205cef-3626-4fe3-a5fb-7c4fc6e0945f','f934aac0-6b00-427d-a213-4e78e02bcd1a','2026-06-10 08:00:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-ApacheServiceBase-5g4i5g2ufhhu','f934aac0-6b00-427d-a213-4e78e02bcd1a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2027,'2d60dd74-f9fb-4ca1-a3cf-a6f923d53846','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:12',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-RoleParametersValue-ciida2nammot','state changed','OS::Heat::Value',NULL,1243),(2028,'d372cddd-27ec-475a-90df-61e7f7c7c4dc','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:12',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-RoleParametersValue-ciida2nammot','state changed','OS::Heat::Value',NULL,1243),(2029,'db2e5879-41d1-44f4-8df2-de54fe9c7081','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:12',NULL,'CREATE','IN_PROGRESS','34','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp','state changed','OS::TripleO::Services::NovaConductor',NULL,1244),(2030,'5cac9370-3ad4-477c-9b58-21eb4617c344','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:12',NULL,'CREATE','COMPLETE','NovaMetadataLogging','7ca5ebb6-1d86-48fd-a6db-607b3d2f1ff3','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2031,'ff940976-2691-4c77-b6b1-0a2b706ad2ec','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp','3533dff3-e837-48e2-ac77-d7023438f433','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2032,'28cdfa9e-1df9-488e-958c-f06c59c95241','dc34db53-8407-4995-a99a-c52ca99a8b5d','2026-06-10 08:00:12',NULL,'CREATE','COMPLETE','NeutronMl2Base','e4f43c2d-66ec-4803-a85b-432ad1f06f08','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1218),(2033,'ee3a99f5-48d8-42da-92c3-e139fa35e176','dc34db53-8407-4995-a99a-c52ca99a8b5d','2026-06-10 08:00:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau-NeutronBase-6x3txpjoziaf','dc34db53-8407-4995-a99a-c52ca99a8b5d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2034,'ef2001f9-5736-439a-8427-32007e8f8813','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:12',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaDBClient-2yxavkt27a6r','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1245),(2035,'ad0a489a-2804-4442-8191-6d41973a381e','735479b9-e4a3-4deb-9a48-43c6d0e3db9e','2026-06-10 08:00:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaDBClient-2yxavkt27a6r','735479b9-e4a3-4deb-9a48-43c6d0e3db9e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2036,'a37c4f9f-9f6c-48d1-bd12-edf5809a286d','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:13',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-MySQLClient-wdzjluxa2kun','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2037,'8c1c30b6-f9a9-4d95-a29e-a241e3efa9f4','735479b9-e4a3-4deb-9a48-43c6d0e3db9e','2026-06-10 08:00:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaDBClient-2yxavkt27a6r','735479b9-e4a3-4deb-9a48-43c6d0e3db9e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2038,'0bf46a7f-de81-44a9-84f6-2d9d08591daa','31e85587-3bb0-4cc3-aa0a-44047819d59d','2026-06-10 08:00:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-MySQLClient-wdzjluxa2kun','31e85587-3bb0-4cc3-aa0a-44047819d59d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2039,'74a94a83-a9e5-44bc-b6af-dbe033339d53','31e85587-3bb0-4cc3-aa0a-44047819d59d','2026-06-10 08:00:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-MySQLClient-wdzjluxa2kun','31e85587-3bb0-4cc3-aa0a-44047819d59d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2040,'711b4009-b49c-4c82-ae61-fa5d6b501f11','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:13',NULL,'CREATE','COMPLETE','ApacheServiceBase','f934aac0-6b00-427d-a213-4e78e02bcd1a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1240),(2041,'9627ea8e-915a-4220-803b-cd0e275fb74d','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:13',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaBase-hufhjpi42nda','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1246),(2042,'20f19d03-e46f-46bd-b965-899c589f2349','7d112d4e-85e8-4645-87c6-0ebbbdb2b9e4','2026-06-10 08:00:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaBase-hufhjpi42nda','7d112d4e-85e8-4645-87c6-0ebbbdb2b9e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2043,'14187fba-559d-406b-b882-5824599ac689','e18e0e25-7aaa-4701-af84-30309b7b1790','2026-06-10 08:00:13',NULL,'CREATE','COMPLETE','NeutronBase','dc34db53-8407-4995-a99a-c52ca99a8b5d','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1212),(2044,'e6b42192-e195-41c5-a4a4-79ba7384d541','e18e0e25-7aaa-4701-af84-30309b7b1790','2026-06-10 08:00:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-32-yxr2mxxs7eau','e18e0e25-7aaa-4701-af84-30309b7b1790','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2045,'e51fab0a-2a09-4eb7-aaa7-4eff0716ba3a','7d112d4e-85e8-4645-87c6-0ebbbdb2b9e4','2026-06-10 08:00:13',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaBase-hufhjpi42nda-RoleParametersValue-pb77zqcln7mw','state changed','OS::Heat::Value',NULL,1247),(2046,'6a2a48ad-563b-4658-84a7-2f8f8862494c','7d112d4e-85e8-4645-87c6-0ebbbdb2b9e4','2026-06-10 08:00:13',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaBase-hufhjpi42nda-RoleParametersValue-pb77zqcln7mw','state changed','OS::Heat::Value',NULL,1247),(2047,'23c1d36b-f8fb-4133-8ee3-e2c53b8b8b2f','7d112d4e-85e8-4645-87c6-0ebbbdb2b9e4','2026-06-10 08:00:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaBase-hufhjpi42nda','7d112d4e-85e8-4645-87c6-0ebbbdb2b9e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2048,'89f175d6-0b1c-4804-bc41-4191be43012c','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:13',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaBase-mnppqod6pxfo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1248),(2049,'7690ab29-f545-4fad-aa4f-d8f8e30c8c09','9924a128-ef6f-4f8e-94bc-6fbdfee147fd','2026-06-10 08:00:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaBase-mnppqod6pxfo','9924a128-ef6f-4f8e-94bc-6fbdfee147fd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2050,'4ee045af-e340-4b9d-bf26-f8a5cf891c9a','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-RoleParametersValue-gpc3jwuie4ri','state changed','OS::Heat::Value',NULL,1249),(2051,'8c8ba75f-95de-43f3-8d24-dff98455f4cf','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:14',NULL,'CREATE','COMPLETE','NovaDBClient','735479b9-e4a3-4deb-9a48-43c6d0e3db9e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1245),(2052,'650fcc78-4696-4f64-8dff-5ec31388999b','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-RoleParametersValue-gpc3jwuie4ri','state changed','OS::Heat::Value',NULL,1249),(2053,'ec94df75-152a-4236-bcb7-7ea115900997','9924a128-ef6f-4f8e-94bc-6fbdfee147fd','2026-06-10 08:00:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaBase-mnppqod6pxfo-RoleParametersValue-ihe7mhu5hdir','state changed','OS::Heat::Value',NULL,1250),(2054,'d70741b4-d6a5-49a5-a8f6-cc498fc36e9f','9924a128-ef6f-4f8e-94bc-6fbdfee147fd','2026-06-10 08:00:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaBase-mnppqod6pxfo-RoleParametersValue-ihe7mhu5hdir','state changed','OS::Heat::Value',NULL,1250),(2055,'0904e4da-9d7f-4b5a-b737-f17bbd2b5ac9','9924a128-ef6f-4f8e-94bc-6fbdfee147fd','2026-06-10 08:00:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaBase-mnppqod6pxfo','9924a128-ef6f-4f8e-94bc-6fbdfee147fd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2056,'8e5eb8cd-da7a-41b3-a70d-646140e16319','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:14',NULL,'CREATE','COMPLETE','MySQLClient','31e85587-3bb0-4cc3-aa0a-44047819d59d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2057,'8812c6b9-6e83-4ea6-8305-19f8efd09cb6','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:14',NULL,'CREATE','COMPLETE','32','e18e0e25-7aaa-4701-af84-30309b7b1790','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1204),(2058,'e08ed240-faef-46de-90b7-411a3db10af4','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:14',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaDBClient-5frwsqkmkgzq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1251),(2059,'2aba89c8-bb01-4405-bddc-82bb8370a813','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:14',NULL,'CREATE','COMPLETE','NovaBase','7d112d4e-85e8-4645-87c6-0ebbbdb2b9e4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1246),(2060,'d0a90081-8a57-46ad-aeb3-a289393214e1','9cbb9010-5f5d-495e-8cdd-d3860acc4d7d','2026-06-10 08:00:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaDBClient-5frwsqkmkgzq','9cbb9010-5f5d-495e-8cdd-d3860acc4d7d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2061,'a73e60a0-916c-48de-a78b-b6e15ce3a570','9cbb9010-5f5d-495e-8cdd-d3860acc4d7d','2026-06-10 08:00:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaDBClient-5frwsqkmkgzq','9cbb9010-5f5d-495e-8cdd-d3860acc4d7d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2062,'7ebf140c-7b04-40d6-9346-5065360da62e','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:14',NULL,'CREATE','COMPLETE','NovaDBClient','9cbb9010-5f5d-495e-8cdd-d3860acc4d7d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1251),(2063,'5eea99a8-3c22-4fee-8baa-18adf4be47e6','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:14',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-MySQLClient-lrpopoz5xz35','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2064,'792532d2-c7ac-4909-9a72-45555f96e737','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','36','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo','state changed','OS::TripleO::Services::NovaScheduler',NULL,1257),(2065,'4bfab714-56c3-46a5-9ef8-bbab5d272b3f','70117377-4ce1-4cd7-b777-abce95323c4d','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-MySQLClient-lrpopoz5xz35','70117377-4ce1-4cd7-b777-abce95323c4d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2066,'94364cbe-f53c-41fc-b71d-3b247f2bdd03','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:15',NULL,'CREATE','COMPLETE','NovaBase','9924a128-ef6f-4f8e-94bc-6fbdfee147fd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1248),(2067,'cd1a7037-f7a9-4c5e-9373-d76409f37ce3','70117377-4ce1-4cd7-b777-abce95323c4d','2026-06-10 08:00:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-MySQLClient-lrpopoz5xz35','70117377-4ce1-4cd7-b777-abce95323c4d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2068,'411e0a82-1ac7-46f7-a2a0-307abff4f12e','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaBase-am6jkr5hyolk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1258),(2069,'f684bcc5-347d-4454-b908-ebf1288f1ee4','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2070,'c464b9d5-bc9e-48ed-8ef6-71d050235ac5','c0c6bae7-31e2-436c-8e71-ed050deb471d','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaBase-am6jkr5hyolk','c0c6bae7-31e2-436c-8e71-ed050deb471d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2071,'469f10f6-185d-48b0-90ac-d73d6f5f2345','c0c6bae7-31e2-436c-8e71-ed050deb471d','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaBase-am6jkr5hyolk-RoleParametersValue-3hmwtmbx4r2r','state changed','OS::Heat::Value',NULL,1259),(2072,'11a070e6-6134-4099-bac2-3941562b8eff','c0c6bae7-31e2-436c-8e71-ed050deb471d','2026-06-10 08:00:15',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaBase-am6jkr5hyolk-RoleParametersValue-3hmwtmbx4r2r','state changed','OS::Heat::Value',NULL,1259),(2073,'8b748c3c-0ded-466f-a84c-fdc85f118083','c0c6bae7-31e2-436c-8e71-ed050deb471d','2026-06-10 08:00:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaBase-am6jkr5hyolk','c0c6bae7-31e2-436c-8e71-ed050deb471d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2074,'289b4dc0-f841-466a-8f3b-c84160aa28b0','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-ContainersCommon-phrfasanfq3a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2075,'fe59608f-b2a6-4cb8-b8d7-0e301e7dcdd4','ac5cd650-f86c-4313-bc75-14ff78ec809b','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-ContainersCommon-phrfasanfq3a','ac5cd650-f86c-4313-bc75-14ff78ec809b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2076,'ec7e8c8e-3d20-4237-a255-0dedfa4afb37','ac5cd650-f86c-4313-bc75-14ff78ec809b','2026-06-10 08:00:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-ContainersCommon-phrfasanfq3a','ac5cd650-f86c-4313-bc75-14ff78ec809b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2077,'9cd0c9c5-6caa-46be-919f-37a8b5c4a30d','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-ContainersCommon-6mybsduupaoq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2078,'fc873e70-6f01-41ec-876f-4296d79650dd','235af9da-14c9-4010-9522-17887ac8b8b7','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-ContainersCommon-6mybsduupaoq','235af9da-14c9-4010-9522-17887ac8b8b7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2079,'9db6ddfe-37cf-4bf7-96dd-60aaee3bad11','235af9da-14c9-4010-9522-17887ac8b8b7','2026-06-10 08:00:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-ContainersCommon-6mybsduupaoq','235af9da-14c9-4010-9522-17887ac8b8b7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2080,'4fdbe835-fd59-453d-91bf-24bf9f0e6c96','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:15',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaApiDBClient-wqlgagxyxjzx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1260),(2081,'d4b74655-1ad8-46d9-9bdc-ee64e1fa50cf','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:16',NULL,'CREATE','COMPLETE','MySQLClient','70117377-4ce1-4cd7-b777-abce95323c4d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2082,'3c635732-0b21-44f3-a1cc-772f0db039cd','6d23bc8b-3abe-4ade-b2d0-38ab3bfe066b','2026-06-10 08:00:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaApiDBClient-wqlgagxyxjzx','6d23bc8b-3abe-4ade-b2d0-38ab3bfe066b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2083,'d867a311-4135-4a3e-9988-826a896d18f8','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:16',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaDBClient-owgllol266bq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1261),(2084,'07101aec-9ac7-40b7-827a-2c3d942eb425','6d23bc8b-3abe-4ade-b2d0-38ab3bfe066b','2026-06-10 08:00:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaApiDBClient-wqlgagxyxjzx','6d23bc8b-3abe-4ade-b2d0-38ab3bfe066b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2085,'c958c998-8d48-4af9-af70-ada7d06a1c04','e28c3148-8501-4484-b18c-1d7f3d832975','2026-06-10 08:00:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaDBClient-owgllol266bq','e28c3148-8501-4484-b18c-1d7f3d832975','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2086,'28f3e2f8-79ad-4112-b4b7-d016900f4fc1','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:16',NULL,'CREATE','COMPLETE','NovaBase','c0c6bae7-31e2-436c-8e71-ed050deb471d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1258),(2087,'b4d83d05-d618-4c5d-baaa-690108d706e9','e28c3148-8501-4484-b18c-1d7f3d832975','2026-06-10 08:00:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaDBClient-owgllol266bq','e28c3148-8501-4484-b18c-1d7f3d832975','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2088,'81aa7bde-1725-4a16-80f7-ae2b6eafd137','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:16',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaApiDBClient-xjc7gpexdrjy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1262),(2089,'46fd4374-0310-46e1-aff0-f554c901d899','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:16',NULL,'CREATE','COMPLETE','ContainersCommon','ac5cd650-f86c-4313-bc75-14ff78ec809b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2090,'89160b79-5206-46d5-9391-aa1717788a17','18a2c7ea-def0-4eab-a5a8-45f4e40a956e','2026-06-10 08:00:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaApiDBClient-xjc7gpexdrjy','18a2c7ea-def0-4eab-a5a8-45f4e40a956e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2091,'4ebd1cf7-c6b0-4fd3-849b-2cdf92be489f','18a2c7ea-def0-4eab-a5a8-45f4e40a956e','2026-06-10 08:00:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaApiDBClient-xjc7gpexdrjy','18a2c7ea-def0-4eab-a5a8-45f4e40a956e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2092,'1db26a95-2df8-4bd9-b4e2-c7277641444c','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:16',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-ApacheServiceBase-iruljayfr46a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1263),(2093,'9943a550-3bae-4db9-adb1-5e32cb4e8439','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:16',NULL,'CREATE','COMPLETE','ContainersCommon','235af9da-14c9-4010-9522-17887ac8b8b7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2094,'fe273d49-5436-43c8-925d-e022fb39e8c3','0da01b13-ba93-4b21-976b-1eb2728bbde7','2026-06-10 08:00:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-ApacheServiceBase-iruljayfr46a','0da01b13-ba93-4b21-976b-1eb2728bbde7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2095,'91f3bd3f-c424-4447-84dc-0b1590182ed7','0da01b13-ba93-4b21-976b-1eb2728bbde7','2026-06-10 08:00:16',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-ApacheServiceBase-iruljayfr46a-ApacheNetworks-a2jk55ktsgkg','state changed','OS::Heat::Value',NULL,1264),(2096,'92f6a8a4-f844-4d3a-b15b-426f0f73536a','0da01b13-ba93-4b21-976b-1eb2728bbde7','2026-06-10 08:00:16',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-ApacheServiceBase-iruljayfr46a-ApacheNetworks-a2jk55ktsgkg','state changed','OS::Heat::Value',NULL,1264),(2097,'3bcca1ff-1db8-4fbd-9ffc-494892d88281','0da01b13-ba93-4b21-976b-1eb2728bbde7','2026-06-10 08:00:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-ApacheServiceBase-iruljayfr46a','0da01b13-ba93-4b21-976b-1eb2728bbde7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2098,'bb1153a2-b563-4282-850d-787fe93bf0af','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:16',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-ContainersCommon-janvev7edorm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2099,'d99b758f-53cb-4e47-a116-e099d0d79377','cd552a93-8cb1-412e-b041-6020d0f97cf8','2026-06-10 08:00:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-ContainersCommon-janvev7edorm','cd552a93-8cb1-412e-b041-6020d0f97cf8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2100,'740b8222-cf1c-4cb8-954e-4e0079026ccd','cd552a93-8cb1-412e-b041-6020d0f97cf8','2026-06-10 08:00:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-ContainersCommon-janvev7edorm','cd552a93-8cb1-412e-b041-6020d0f97cf8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2101,'b8fdf975-98d6-4b46-8ddd-2471272a696d','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:17',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaApiDBClient-vjcmtkorbrd3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1265),(2102,'914403b8-3742-4db2-9b55-113d7b2150e5','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:17',NULL,'CREATE','COMPLETE','NovaApiDBClient','6d23bc8b-3abe-4ade-b2d0-38ab3bfe066b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1260),(2103,'10b03576-77ac-4923-b9e4-2a46b506717a','545f7789-3525-4fd0-92ea-b11373f854d8','2026-06-10 08:00:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaApiDBClient-vjcmtkorbrd3','545f7789-3525-4fd0-92ea-b11373f854d8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2104,'d6b0c97e-1e2d-4437-bc06-125d4717d8eb','545f7789-3525-4fd0-92ea-b11373f854d8','2026-06-10 08:00:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7-NovaApiDBClient-vjcmtkorbrd3','545f7789-3525-4fd0-92ea-b11373f854d8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2105,'68a6cf04-3955-4ef3-b49a-14403ccf53c3','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:17',NULL,'CREATE','COMPLETE','NovaDBClient','e28c3148-8501-4484-b18c-1d7f3d832975','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1261),(2106,'da89a0fb-0c5e-44d8-bd59-6de4e1de7b7d','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:17',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-MySQLClient-djvsctonrs7l','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2107,'54260cf1-e2cd-48ae-90aa-d27a055cb481','a6425811-c71c-4109-a88d-d6a07511630d','2026-06-10 08:00:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-MySQLClient-djvsctonrs7l','a6425811-c71c-4109-a88d-d6a07511630d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2108,'0059e049-9b20-4b60-9917-9561126be1a0','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:17',NULL,'CREATE','COMPLETE','NovaApiDBClient','18a2c7ea-def0-4eab-a5a8-45f4e40a956e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1262),(2109,'88416e3c-0b3c-41dd-bb77-b56230f13375','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:17',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-MySQLClient-d6v2mynxqvtv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2110,'bd56408d-771a-4ca3-945e-a190352c89b0','a6425811-c71c-4109-a88d-d6a07511630d','2026-06-10 08:00:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-MySQLClient-djvsctonrs7l','a6425811-c71c-4109-a88d-d6a07511630d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2111,'9384b0b1-55de-43ab-99c2-6924f11379a4','a15cf430-c684-4fa0-9a8c-148472c1c15c','2026-06-10 08:00:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-MySQLClient-d6v2mynxqvtv','a15cf430-c684-4fa0-9a8c-148472c1c15c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2112,'66733dec-c4f6-4816-80cc-0ba2cd9122f2','a15cf430-c684-4fa0-9a8c-148472c1c15c','2026-06-10 08:00:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-MySQLClient-d6v2mynxqvtv','a15cf430-c684-4fa0-9a8c-148472c1c15c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2113,'b7b3b1f0-210c-4692-b688-b288660b0ea3','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:17',NULL,'CREATE','COMPLETE','ApacheServiceBase','0da01b13-ba93-4b21-976b-1eb2728bbde7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1263),(2114,'10763ad7-4f33-4f94-a890-958a6c9956c3','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:17',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-RoleParametersValue-7rra5i2pzaxs','state changed','OS::Heat::Value',NULL,1266),(2115,'7ef580a6-f9e7-47df-8709-8bd807d2ee2a','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:17',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-RoleParametersValue-7rra5i2pzaxs','state changed','OS::Heat::Value',NULL,1266),(2116,'87d2b9c0-9419-4c1e-9bb0-9a947eb0e587','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:18',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaLogging-h5xgwnz4zmfd','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1268),(2117,'6609f8b2-1c10-487b-b96e-ec769521b1e2','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:18',NULL,'CREATE','COMPLETE','ContainersCommon','cd552a93-8cb1-412e-b041-6020d0f97cf8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2118,'2819b93c-26e5-4f76-a810-7a7f5234766d','7e02c8a6-9777-4ab4-93a0-2d88a107ecfa','2026-06-10 08:00:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaLogging-h5xgwnz4zmfd','7e02c8a6-9777-4ab4-93a0-2d88a107ecfa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2119,'2bb9701c-c3d8-46e4-af0c-a68e2d87da07','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:18',NULL,'CREATE','COMPLETE','NovaApiDBClient','545f7789-3525-4fd0-92ea-b11373f854d8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1265),(2120,'b25f8f63-684f-40ea-a22a-b29a4bf880a4','21ff318f-54c5-498a-b396-0b13595eccce','2026-06-10 08:00:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-33-zajzohdw7ct7','21ff318f-54c5-498a-b396-0b13595eccce','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2121,'274c25db-67a4-404f-a01f-ee5216280f6d','7e02c8a6-9777-4ab4-93a0-2d88a107ecfa','2026-06-10 08:00:18',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaLogging-h5xgwnz4zmfd-RoleParametersValue-xg4iniqkuxlu','state changed','OS::Heat::Value',NULL,1269),(2122,'1d49a82c-729a-4b83-9dee-f8557c24e4c3','7e02c8a6-9777-4ab4-93a0-2d88a107ecfa','2026-06-10 08:00:18',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaLogging-h5xgwnz4zmfd-RoleParametersValue-xg4iniqkuxlu','state changed','OS::Heat::Value',NULL,1269),(2123,'69844ad8-e673-425f-8a62-9b48def4a74b','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:18',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaDBClient-mz527mxysker','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1270),(2124,'93db0d0b-c6f9-471d-a97b-0afc43c5ddc6','edd79b1c-23a6-4dae-b442-c2553a42eee0','2026-06-10 08:00:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaDBClient-mz527mxysker','edd79b1c-23a6-4dae-b442-c2553a42eee0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2125,'93f4ce18-e200-4646-b05f-b99f118bd1f4','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:18',NULL,'CREATE','COMPLETE','MySQLClient','a6425811-c71c-4109-a88d-d6a07511630d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2126,'443a70f9-8823-4d05-984e-5812c9634b22','edd79b1c-23a6-4dae-b442-c2553a42eee0','2026-06-10 08:00:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaDBClient-mz527mxysker','edd79b1c-23a6-4dae-b442-c2553a42eee0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2127,'6789a92c-e59a-4b0c-9555-5190b8409bb7','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:18',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaApiDBClient-o37xvhtn672h','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1271),(2128,'0e5a75f7-ee33-4d11-95f3-d6e9ea6e75d5','26205b95-191d-4a3b-9fe6-9cdfcbc2b0c3','2026-06-10 08:00:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaApiDBClient-o37xvhtn672h','26205b95-191d-4a3b-9fe6-9cdfcbc2b0c3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2129,'2c28e7c7-ff6b-4471-b2bc-002b227cd10d','26205b95-191d-4a3b-9fe6-9cdfcbc2b0c3','2026-06-10 08:00:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t-NovaApiDBClient-o37xvhtn672h','26205b95-191d-4a3b-9fe6-9cdfcbc2b0c3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2130,'ddc22fec-2a89-4e6d-824d-9970c34c9673','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:18',NULL,'CREATE','COMPLETE','MySQLClient','a15cf430-c684-4fa0-9a8c-148472c1c15c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2131,'dbc753a1-3218-46b1-81da-569df37bf8e0','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:18',NULL,'CREATE','COMPLETE','33','21ff318f-54c5-498a-b396-0b13595eccce','state changed','OS::TripleO::Services::NovaApi',NULL,1210),(2132,'33b902ba-c0a3-4335-a621-8c8a5ae0a73f','7e02c8a6-9777-4ab4-93a0-2d88a107ecfa','2026-06-10 08:00:19',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaLogging-h5xgwnz4zmfd-InitLogContainerName-am25dyv4aflf','state changed','OS::Heat::Value',NULL,1277),(2133,'ae57bb86-eb2d-452b-8325-f0b9476255af','7e02c8a6-9777-4ab4-93a0-2d88a107ecfa','2026-06-10 08:00:19',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaLogging-h5xgwnz4zmfd-InitLogContainerName-am25dyv4aflf','state changed','OS::Heat::Value',NULL,1277),(2134,'ab8bd335-79d2-4d10-9d5f-9a43fae1ccd6','7e02c8a6-9777-4ab4-93a0-2d88a107ecfa','2026-06-10 08:00:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp-NovaLogging-h5xgwnz4zmfd','7e02c8a6-9777-4ab4-93a0-2d88a107ecfa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2135,'7f734456-aa48-462a-9a10-91811c62d7c4','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:19',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-RoleParametersValue-yowebi54ymbt','state changed','OS::Heat::Value',NULL,1280),(2136,'ebd4766e-3ec1-4ea1-a3d3-3c2f07e023fc','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:19',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-RoleParametersValue-yowebi54ymbt','state changed','OS::Heat::Value',NULL,1280),(2137,'533e08e9-4bfe-4368-af71-8fee0aab7418','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:19',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaLogging-vbfxayg3xsjw','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1285),(2138,'f351c7ce-a319-4147-bd6c-6c74f2b0bada','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:19',NULL,'CREATE','COMPLETE','NovaDBClient','edd79b1c-23a6-4dae-b442-c2553a42eee0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1270),(2139,'72655ffe-37cf-40e0-9cb3-74ae6281f99f','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:19',NULL,'CREATE','COMPLETE','NovaApiDBClient','26205b95-191d-4a3b-9fe6-9cdfcbc2b0c3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1271),(2140,'45e16192-f97d-4672-846e-8402a6ba9fc7','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:19',NULL,'CREATE','IN_PROGRESS','37','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1288),(2141,'2d0b993b-9207-4dc3-a498-1294138c4b8e','2eb5c62b-75a8-4f5e-9f68-f1ce31e2d171','2026-06-10 08:00:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaLogging-vbfxayg3xsjw','2eb5c62b-75a8-4f5e-9f68-f1ce31e2d171','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2142,'60879710-26ea-4a2a-80ca-d5645ad85146','16a6ebcb-bb10-4928-a7cc-794422beb0a1','2026-06-10 08:00:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-35-h4c6i463ky3t','16a6ebcb-bb10-4928-a7cc-794422beb0a1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2143,'609e9441-76de-4cec-bf99-1531a21cf60e','2eb5c62b-75a8-4f5e-9f68-f1ce31e2d171','2026-06-10 08:00:19',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaLogging-vbfxayg3xsjw-InitLogContainerName-hlsnwkr3vdcd','state changed','OS::Heat::Value',NULL,1289),(2144,'79e219a3-0c71-4697-b0bf-5da8cf5e9da3','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij','19254d2b-d5ae-4f81-a650-9d5cc0e17805','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2145,'0b5892b7-08e4-438d-85c8-18b2944d40a8','2eb5c62b-75a8-4f5e-9f68-f1ce31e2d171','2026-06-10 08:00:19',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaLogging-vbfxayg3xsjw-InitLogContainerName-hlsnwkr3vdcd','state changed','OS::Heat::Value',NULL,1289),(2146,'4c0297ee-3dcc-4321-8e23-418d718fd38a','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:20',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-MySQLClient-x2blvtweyahu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2147,'94dea80b-c8ba-4804-a580-5feae47d5418','29338078-8be6-42c9-ae61-e43c6283001d','2026-06-10 08:00:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-MySQLClient-x2blvtweyahu','29338078-8be6-42c9-ae61-e43c6283001d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2148,'394e1ba6-55d1-41ac-8a6e-03376ad8d01b','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:20',NULL,'CREATE','COMPLETE','NovaLogging','7e02c8a6-9777-4ab4-93a0-2d88a107ecfa','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1268),(2149,'1c7915c0-d8e7-462f-ae62-a474e50e08c7','3533dff3-e837-48e2-ac77-d7023438f433','2026-06-10 08:00:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-34-fkwz6r3anzkp','3533dff3-e837-48e2-ac77-d7023438f433','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2150,'c2e84991-bb72-4dd7-b2b9-7a85c13943be','29338078-8be6-42c9-ae61-e43c6283001d','2026-06-10 08:00:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-MySQLClient-x2blvtweyahu','29338078-8be6-42c9-ae61-e43c6283001d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2151,'5bb3a1ed-ac33-4608-9fff-cfa799504056','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:20',NULL,'CREATE','COMPLETE','35','16a6ebcb-bb10-4928-a7cc-794422beb0a1','state changed','OS::TripleO::Services::NovaMetadata',NULL,1237),(2152,'7421f9b7-730c-423f-b998-306b8e3b121f','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:20',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaBase-lzdbbqp7nzfn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1290),(2153,'4f480db9-166d-49de-8d72-6723e352a6da','9e1770e4-bbc4-45b4-9aea-4d78759f41f6','2026-06-10 08:00:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaBase-lzdbbqp7nzfn','9e1770e4-bbc4-45b4-9aea-4d78759f41f6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2154,'e0ee7e96-c9a4-4ff3-96ea-9fd60885c1ea','9e1770e4-bbc4-45b4-9aea-4d78759f41f6','2026-06-10 08:00:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaBase-lzdbbqp7nzfn-RoleParametersValue-mfhzxvd2qd3j','state changed','OS::Heat::Value',NULL,1296),(2155,'1353d2a0-0ab5-4e99-aea6-61a515ce65ad','9e1770e4-bbc4-45b4-9aea-4d78759f41f6','2026-06-10 08:00:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaBase-lzdbbqp7nzfn-RoleParametersValue-mfhzxvd2qd3j','state changed','OS::Heat::Value',NULL,1296),(2156,'deb40b08-f0e2-4e13-bbc7-ede9a9ae55a4','9e1770e4-bbc4-45b4-9aea-4d78759f41f6','2026-06-10 08:00:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaBase-lzdbbqp7nzfn','9e1770e4-bbc4-45b4-9aea-4d78759f41f6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2157,'5585033c-7dec-48ef-b33f-7a161a3fe5d7','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:20',NULL,'CREATE','COMPLETE','34','3533dff3-e837-48e2-ac77-d7023438f433','state changed','OS::TripleO::Services::NovaConductor',NULL,1244),(2158,'f4cd34d3-bf1a-4968-800b-bfe51248c05b','2eb5c62b-75a8-4f5e-9f68-f1ce31e2d171','2026-06-10 08:00:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaLogging-vbfxayg3xsjw-RoleParametersValue-pizo6h2vbzt6','state changed','OS::Heat::Value',NULL,1306),(2159,'e13bf057-d834-4214-b1cf-92132b4b5188','2eb5c62b-75a8-4f5e-9f68-f1ce31e2d171','2026-06-10 08:00:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaLogging-vbfxayg3xsjw-RoleParametersValue-pizo6h2vbzt6','state changed','OS::Heat::Value',NULL,1306),(2160,'1aad5ff9-f48d-4498-95fa-5e8b10e92874','2eb5c62b-75a8-4f5e-9f68-f1ce31e2d171','2026-06-10 08:00:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo-NovaLogging-vbfxayg3xsjw','2eb5c62b-75a8-4f5e-9f68-f1ce31e2d171','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2161,'bc2b1cfb-330d-4c0b-9001-e4e303ea7daf','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:21',NULL,'CREATE','IN_PROGRESS','39','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-39-pdib4blgkxx3','state changed','OS::TripleO::Services::OVNDBs',NULL,1308),(2162,'11d13277-34ba-4f58-bf1c-e52df7aa9efb','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:21',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaBase-jxobeumki2by','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1311),(2163,'97615e23-33a4-498b-850f-ae1263a57fa1','55c51646-2826-4705-963e-0b5a43295e84','2026-06-10 08:00:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-39-pdib4blgkxx3','55c51646-2826-4705-963e-0b5a43295e84','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2164,'9d9a504f-65b0-4f32-8c25-25327c68ce43','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:21',NULL,'CREATE','COMPLETE','MySQLClient','29338078-8be6-42c9-ae61-e43c6283001d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2165,'ad46280d-c921-45f4-a1d9-0f1eb626e3b5','41d0f9f6-ea66-451b-8897-d95020f120e4','2026-06-10 08:00:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaBase-jxobeumki2by','41d0f9f6-ea66-451b-8897-d95020f120e4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2166,'6fcaf538-f648-4c67-bcea-1af75253d922','41d0f9f6-ea66-451b-8897-d95020f120e4','2026-06-10 08:00:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaBase-jxobeumki2by-RoleParametersValue-7uw5vak32evy','state changed','OS::Heat::Value',NULL,1316),(2167,'49d84b24-38e2-4224-bf0e-a380b03ded61','55c51646-2826-4705-963e-0b5a43295e84','2026-06-10 08:00:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-39-pdib4blgkxx3-RoleParametersValue-lyfqekf7wnk6','state changed','OS::Heat::Value',NULL,1317),(2168,'30a14f4e-6ab0-4985-9bba-381b64cfc79e','41d0f9f6-ea66-451b-8897-d95020f120e4','2026-06-10 08:00:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaBase-jxobeumki2by-RoleParametersValue-7uw5vak32evy','state changed','OS::Heat::Value',NULL,1316),(2169,'8df5cf4d-5179-4ea5-a1d5-e914eb714ce1','55c51646-2826-4705-963e-0b5a43295e84','2026-06-10 08:00:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-39-pdib4blgkxx3-RoleParametersValue-lyfqekf7wnk6','state changed','OS::Heat::Value',NULL,1317),(2170,'cbef6f20-2957-402a-83d1-f99b9b4f06ab','41d0f9f6-ea66-451b-8897-d95020f120e4','2026-06-10 08:00:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaBase-jxobeumki2by','41d0f9f6-ea66-451b-8897-d95020f120e4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2171,'b5eed87a-d563-4248-8cf1-8d14b81925b2','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:21',NULL,'CREATE','IN_PROGRESS','38','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-38-jdhgmy4ulnch','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1319),(2172,'54a678a6-9720-4c41-b399-e4cb39d9780a','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:21',NULL,'CREATE','COMPLETE','NovaBase','9e1770e4-bbc4-45b4-9aea-4d78759f41f6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1290),(2173,'55fb2d7a-8af0-4668-be4b-062482f26091','a63e5c69-00a7-488b-a0d1-7e3832c5fda4','2026-06-10 08:00:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-38-jdhgmy4ulnch','a63e5c69-00a7-488b-a0d1-7e3832c5fda4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2174,'920f0741-bcc8-4f89-9d7f-ee2d2f9548bf','a63e5c69-00a7-488b-a0d1-7e3832c5fda4','2026-06-10 08:00:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-38-jdhgmy4ulnch-RoleParametersValue-gyfwkmaboaak','state changed','OS::Heat::Value',NULL,1320),(2175,'2534ed2e-b0fe-4573-8976-6850c30d8ae7','a63e5c69-00a7-488b-a0d1-7e3832c5fda4','2026-06-10 08:00:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-38-jdhgmy4ulnch-RoleParametersValue-gyfwkmaboaak','state changed','OS::Heat::Value',NULL,1320),(2176,'ebe644a4-1505-4e55-87bc-66b4d860499d','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:21',NULL,'CREATE','COMPLETE','NovaLogging','2eb5c62b-75a8-4f5e-9f68-f1ce31e2d171','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1285),(2177,'8562f1c9-41ab-40c8-a8dd-ab0034dcd07b','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','2026-06-10 08:00:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-36-2wg7vyyw3kfo','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2178,'5a600fa5-6d2c-4eb7-bdf5-961d79677aa7','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-ContainersCommon-w64icecsszxh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2179,'df950b62-53c1-4b95-ac52-5c2b1f9848a4','6eb91376-ff45-4c56-9d05-2ec6620ec572','2026-06-10 08:00:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-ContainersCommon-w64icecsszxh','6eb91376-ff45-4c56-9d05-2ec6620ec572','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2180,'3deab709-9b52-4408-89f1-0ba173726829','6eb91376-ff45-4c56-9d05-2ec6620ec572','2026-06-10 08:00:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-ContainersCommon-w64icecsszxh','6eb91376-ff45-4c56-9d05-2ec6620ec572','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2181,'541675b6-236d-4c2b-8a8e-90c926c4c4fd','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:22',NULL,'CREATE','COMPLETE','36','6c5d4d88-deba-4f4a-8b62-3c408fa42cfa','state changed','OS::TripleO::Services::NovaScheduler',NULL,1257),(2182,'e9f13610-0eef-42ba-9780-a07b41f3cd7b','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:22',NULL,'CREATE','COMPLETE','NovaBase','41d0f9f6-ea66-451b-8897-d95020f120e4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1311),(2183,'844e31a9-6e07-4dbe-ab22-8aa1c3d0e86b','55c51646-2826-4705-963e-0b5a43295e84','2026-06-10 08:00:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-39-pdib4blgkxx3-ContainersCommon-mekrauxhkq44','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2184,'90fe810d-4810-4ccd-a0b0-8ad40cbeca16','18c1ebd7-27db-4177-bc6c-78b4db7eb7a1','2026-06-10 08:00:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-39-pdib4blgkxx3-ContainersCommon-mekrauxhkq44','18c1ebd7-27db-4177-bc6c-78b4db7eb7a1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2185,'54545f7d-cd2f-4c6a-9ff5-e18f620eb109','18c1ebd7-27db-4177-bc6c-78b4db7eb7a1','2026-06-10 08:00:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-39-pdib4blgkxx3-ContainersCommon-mekrauxhkq44','18c1ebd7-27db-4177-bc6c-78b4db7eb7a1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2186,'0535aeb8-00a7-4bd9-8fd3-f27fcfeb6ceb','a63e5c69-00a7-488b-a0d1-7e3832c5fda4','2026-06-10 08:00:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-38-jdhgmy4ulnch-ContainersCommon-pvmnj3fducdh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2187,'9313078d-017d-453e-8678-d378c56e95e6','5e22ded7-721c-44d8-930a-55661a4a6a50','2026-06-10 08:00:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-38-jdhgmy4ulnch-ContainersCommon-pvmnj3fducdh','5e22ded7-721c-44d8-930a-55661a4a6a50','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2188,'aaa7d56a-6898-4130-87fb-194830f03705','5e22ded7-721c-44d8-930a-55661a4a6a50','2026-06-10 08:00:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-38-jdhgmy4ulnch-ContainersCommon-pvmnj3fducdh','5e22ded7-721c-44d8-930a-55661a4a6a50','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2189,'3e41f9f0-78f2-4562-9507-e555e6014526','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:22',NULL,'CREATE','IN_PROGRESS','40','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl','state changed','OS::TripleO::Services::OVNController',NULL,1331),(2190,'d2a6e195-fa96-4852-921d-5ff35fee8e54','7f225463-a64c-4dfe-8020-f8fc85d1dd72','2026-06-10 08:00:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl','7f225463-a64c-4dfe-8020-f8fc85d1dd72','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2191,'b9fc1e9b-12d1-4163-8108-8bf69374f7ec','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-RoleParametersValue-nggor5zt7c3t','state changed','OS::Heat::Value',NULL,1332),(2192,'a719e6ab-367b-44c5-a5b1-b852b9ce09e1','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-RoleParametersValue-nggor5zt7c3t','state changed','OS::Heat::Value',NULL,1332),(2193,'0edc5841-c911-49f6-afc0-3437e6800ccb','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:23',NULL,'CREATE','COMPLETE','ContainersCommon','6eb91376-ff45-4c56-9d05-2ec6620ec572','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2194,'9f12423f-d294-4631-a838-d07baa44ac66','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:23',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaLogging-hgvxusqqy3ly','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1334),(2195,'7ce4e9d6-d5cd-4820-ba7a-495b20e3e3b8','7f225463-a64c-4dfe-8020-f8fc85d1dd72','2026-06-10 08:00:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl-RoleParametersValue-d7xvjoc5bpvq','state changed','OS::Heat::Value',NULL,1335),(2196,'a2f8f138-1909-4af9-b6ad-159c59a9bb86','7f225463-a64c-4dfe-8020-f8fc85d1dd72','2026-06-10 08:00:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl-RoleParametersValue-d7xvjoc5bpvq','state changed','OS::Heat::Value',NULL,1335),(2197,'956ba044-81b6-4d96-8ac3-50796968a6a7','1cef0694-43c8-4fbf-b874-9a6240f8694d','2026-06-10 08:00:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaLogging-hgvxusqqy3ly','1cef0694-43c8-4fbf-b874-9a6240f8694d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2198,'a34d466c-5ba9-48d8-ba41-d201b5122add','1cef0694-43c8-4fbf-b874-9a6240f8694d','2026-06-10 08:00:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaLogging-hgvxusqqy3ly-RoleParametersValue-nmzuoa2td34g','state changed','OS::Heat::Value',NULL,1336),(2199,'ef9431ac-5211-4657-902e-62c1a9f93fa9','1cef0694-43c8-4fbf-b874-9a6240f8694d','2026-06-10 08:00:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaLogging-hgvxusqqy3ly-RoleParametersValue-nmzuoa2td34g','state changed','OS::Heat::Value',NULL,1336),(2200,'5d0d4db1-6ece-43b0-adb6-dff64bbf38d6','55c51646-2826-4705-963e-0b5a43295e84','2026-06-10 08:00:23',NULL,'CREATE','COMPLETE','ContainersCommon','18c1ebd7-27db-4177-bc6c-78b4db7eb7a1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2201,'c97e1df2-a0b4-4933-9e4a-77b1fabb8bf7','55c51646-2826-4705-963e-0b5a43295e84','2026-06-10 08:00:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-39-pdib4blgkxx3','55c51646-2826-4705-963e-0b5a43295e84','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2202,'468f970d-a153-4903-9c58-5604a89b9497','a63e5c69-00a7-488b-a0d1-7e3832c5fda4','2026-06-10 08:00:23',NULL,'CREATE','COMPLETE','ContainersCommon','5e22ded7-721c-44d8-930a-55661a4a6a50','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2203,'4d930902-72db-402b-868c-5223d86e9d15','a63e5c69-00a7-488b-a0d1-7e3832c5fda4','2026-06-10 08:00:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-38-jdhgmy4ulnch','a63e5c69-00a7-488b-a0d1-7e3832c5fda4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2204,'c18ea12c-fec2-4df6-85f2-0aebfd8a7c92','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:24',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaDBClient-6j5nqrxz6o5j','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1337),(2205,'0b293449-0ff9-4710-b5c0-37f900f3c8e5','8f49d3a1-c963-4941-a7db-284bf7f9897c','2026-06-10 08:00:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaDBClient-6j5nqrxz6o5j','8f49d3a1-c963-4941-a7db-284bf7f9897c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2206,'ba7509c4-6a7c-4047-a517-41960ea13b27','7f225463-a64c-4dfe-8020-f8fc85d1dd72','2026-06-10 08:00:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl-ContainersCommon-54jueixbfprz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2207,'c84a132b-1937-4eb0-807a-00546698e279','8f49d3a1-c963-4941-a7db-284bf7f9897c','2026-06-10 08:00:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaDBClient-6j5nqrxz6o5j','8f49d3a1-c963-4941-a7db-284bf7f9897c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2208,'c9efd610-83be-4d5c-9c0d-2bc01f697f77','e0880a55-cc83-422e-9980-cd9642f31c9a','2026-06-10 08:00:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl-ContainersCommon-54jueixbfprz','e0880a55-cc83-422e-9980-cd9642f31c9a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2209,'3f0fb1bf-67b4-4dfc-b35b-cb9ad4af9b52','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:24',NULL,'CREATE','COMPLETE','39','55c51646-2826-4705-963e-0b5a43295e84','state changed','OS::TripleO::Services::OVNDBs',NULL,1308),(2210,'9913444e-aac4-49c1-88cf-9efd6bb3ea6f','e0880a55-cc83-422e-9980-cd9642f31c9a','2026-06-10 08:00:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl-ContainersCommon-54jueixbfprz','e0880a55-cc83-422e-9980-cd9642f31c9a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2211,'72d4e042-febc-4b06-966b-c3d9ef8192f3','7f225463-a64c-4dfe-8020-f8fc85d1dd72','2026-06-10 08:00:24',NULL,'CREATE','COMPLETE','ContainersCommon','e0880a55-cc83-422e-9980-cd9642f31c9a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2212,'068e7568-7caf-41e5-9578-50208d7cbb44','1cef0694-43c8-4fbf-b874-9a6240f8694d','2026-06-10 08:00:24',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaLogging-hgvxusqqy3ly-InitLogContainerName-axyaonxauote','state changed','OS::Heat::Value',NULL,1338),(2213,'80ee09fd-d578-4827-9951-9e88174f5c7e','1cef0694-43c8-4fbf-b874-9a6240f8694d','2026-06-10 08:00:24',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaLogging-hgvxusqqy3ly-InitLogContainerName-axyaonxauote','state changed','OS::Heat::Value',NULL,1338),(2214,'18c662e4-d1d9-4209-95c5-af2b54878016','1cef0694-43c8-4fbf-b874-9a6240f8694d','2026-06-10 08:00:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij-NovaLogging-hgvxusqqy3ly','1cef0694-43c8-4fbf-b874-9a6240f8694d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2215,'f30e41e7-f999-4f96-9049-648eb67b8931','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:24',NULL,'CREATE','COMPLETE','38','a63e5c69-00a7-488b-a0d1-7e3832c5fda4','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1319),(2216,'1b73867b-aca4-45db-a16e-480f0d0b7dae','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:24',NULL,'CREATE','IN_PROGRESS','43','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1342),(2217,'e7d7acec-7737-48f7-9bd5-c268ec669b6d','b8c88db2-53c5-465a-ab47-ea1018faf86f','2026-06-10 08:00:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a','b8c88db2-53c5-465a-ab47-ea1018faf86f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2218,'dccc315d-2361-482c-b18a-8ee0c62932b6','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:24',NULL,'CREATE','IN_PROGRESS','42','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i','state changed','OS::TripleO::Services::PlacementApi',NULL,1346),(2219,'0b768af6-b40f-434a-bdaf-fb649603f6a5','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i','c5f318a8-9308-48c5-b6b4-4add98a3d277','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2220,'27bbce16-6599-4f31-9f73-63377bd02177','b8c88db2-53c5-465a-ab47-ea1018faf86f','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','RabbitmqBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1347),(2221,'ca638a85-0d67-401c-8139-9e1b83baf1b5','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','PlacementLogging','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-PlacementLogging-k2i2z4sx5t4k','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2222,'f70da488-9136-42f4-8a67-d58e1bdbf16a','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:25',NULL,'CREATE','COMPLETE','NovaDBClient','8f49d3a1-c963-4941-a7db-284bf7f9897c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1337),(2223,'b8ac2dc5-8246-4f7f-bd65-60877ef9ee5e','7f225463-a64c-4dfe-8020-f8fc85d1dd72','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl-OVNBridgeMappingsValue-kit3h5sqphit','state changed','OS::Heat::Value',NULL,1348),(2224,'5b987d17-02a0-43a8-b94b-210ca80e1d8b','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2225,'66440539-94f9-4502-836a-ace6eb943c3d','7f225463-a64c-4dfe-8020-f8fc85d1dd72','2026-06-10 08:00:25',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl-OVNBridgeMappingsValue-kit3h5sqphit','state changed','OS::Heat::Value',NULL,1348),(2226,'26452c08-af2a-4089-9b84-98b09516239b','2c2fb937-5591-4609-952d-c831661c08cc','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-PlacementLogging-k2i2z4sx5t4k','2c2fb937-5591-4609-952d-c831661c08cc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2227,'05dd943d-b219-4946-99d2-b8be53fb2bab','7f225463-a64c-4dfe-8020-f8fc85d1dd72','2026-06-10 08:00:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-40-alz22lnhmekl','7f225463-a64c-4dfe-8020-f8fc85d1dd72','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2228,'ddfac706-6069-45bb-a885-8f22c3033824','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:25',NULL,'CREATE','COMPLETE','NovaLogging','1cef0694-43c8-4fbf-b874-9a6240f8694d','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1334),(2229,'4c7fb2ee-bd70-4cfe-812a-94ee4e59f65a','19254d2b-d5ae-4f81-a650-9d5cc0e17805','2026-06-10 08:00:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-37-7rk66hf73tij','19254d2b-d5ae-4f81-a650-9d5cc0e17805','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2230,'ced7404b-9bde-4367-8492-7f6d49c4baea','2c2fb937-5591-4609-952d-c831661c08cc','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-PlacementLogging-k2i2z4sx5t4k-RoleParametersValue-y56psnlw5i7y','state changed','OS::Heat::Value',NULL,1349),(2231,'a57425d3-0758-45ef-a9ef-28c1992d6622','2c2fb937-5591-4609-952d-c831661c08cc','2026-06-10 08:00:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-PlacementLogging-k2i2z4sx5t4k-RoleParametersValue-y56psnlw5i7y','state changed','OS::Heat::Value',NULL,1349),(2232,'b01ec78e-66c8-4bfd-87aa-f95fff37dabb','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','RabbitMQServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RabbitMQServiceBase-nip3hlno5yvn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1350),(2233,'c5acd9f9-5dc5-454a-8c91-1b0ead419c86','2c2fb937-5591-4609-952d-c831661c08cc','2026-06-10 08:00:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-PlacementLogging-k2i2z4sx5t4k','2c2fb937-5591-4609-952d-c831661c08cc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2234,'2e1e35fa-c472-492e-b30f-cd518206c66f','30410c79-72ca-4f99-b5ef-0f3eb09ba745','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RabbitMQServiceBase-nip3hlno5yvn','30410c79-72ca-4f99-b5ef-0f3eb09ba745','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2235,'001447e0-e8d6-4c10-b260-ae8aea981edf','30410c79-72ca-4f99-b5ef-0f3eb09ba745','2026-06-10 08:00:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RabbitMQServiceBase-nip3hlno5yvn-RoleParametersValue-aalav3myr5pl','state changed','OS::Heat::Value',NULL,1351),(2236,'0a98c62c-77ce-4b25-8b7e-a1a250da2478','30410c79-72ca-4f99-b5ef-0f3eb09ba745','2026-06-10 08:00:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RabbitMQServiceBase-nip3hlno5yvn-RoleParametersValue-aalav3myr5pl','state changed','OS::Heat::Value',NULL,1351),(2237,'f7542e80-2a8d-49c9-a3a0-655ee5f438c1','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:26',NULL,'CREATE','COMPLETE','37','19254d2b-d5ae-4f81-a650-9d5cc0e17805','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1288),(2238,'c3ebff6d-e967-4628-b005-9dc5d32f7af8','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:26',NULL,'CREATE','COMPLETE','40','7f225463-a64c-4dfe-8020-f8fc85d1dd72','state changed','OS::TripleO::Services::OVNController',NULL,1331),(2239,'520b95e2-3154-4867-a7e5-5386678e4eff','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-ContainersCommon-zdab6z2vtf67','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2240,'db8a1318-1223-4992-8e89-7890d0964365','b8c88db2-53c5-465a-ab47-ea1018faf86f','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-ContainersCommon-uha6qndiuavs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2241,'cf7a8f08-c3b4-4312-ac69-88f96e6fbece','f304383e-0a7b-4209-84fc-e87838a93086','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-ContainersCommon-uha6qndiuavs','f304383e-0a7b-4209-84fc-e87838a93086','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2242,'03d32397-775d-4064-bebd-2c4f5187a4f0','f304383e-0a7b-4209-84fc-e87838a93086','2026-06-10 08:00:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-ContainersCommon-uha6qndiuavs','f304383e-0a7b-4209-84fc-e87838a93086','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2243,'773238b7-06ca-4634-b113-aba4b0e43ebf','644801e2-a04b-4316-8422-feb378b1fffd','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-ContainersCommon-zdab6z2vtf67','644801e2-a04b-4316-8422-feb378b1fffd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2244,'cc1f8f0d-eb1a-47bc-97e3-2d1450bf3ee5','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:26',NULL,'CREATE','COMPLETE','PlacementLogging','2c2fb937-5591-4609-952d-c831661c08cc','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2245,'d334c2ab-24a0-4ddd-9c34-9fb984ac311f','644801e2-a04b-4316-8422-feb378b1fffd','2026-06-10 08:00:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-ContainersCommon-zdab6z2vtf67','644801e2-a04b-4316-8422-feb378b1fffd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2246,'13d7b472-ba97-41fe-920a-49dafeec380f','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-ContainersCommon-sa64dimm7nil','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2247,'35e76bc2-c56c-4373-acb2-29974f371dcf','7ecebb54-c7d2-4eab-97e6-e22047758197','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-ContainersCommon-sa64dimm7nil','7ecebb54-c7d2-4eab-97e6-e22047758197','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2248,'bf10a485-5c3f-493d-b42f-5bc6a679e52f','7ecebb54-c7d2-4eab-97e6-e22047758197','2026-06-10 08:00:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-ContainersCommon-sa64dimm7nil','7ecebb54-c7d2-4eab-97e6-e22047758197','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2249,'f29a8eed-081d-4e53-872c-d14912f43f64','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','44','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-44-4zpk5a3coetj','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1360),(2250,'102a4b8b-8af5-4930-95cb-8cf1880fcd02','dfea6e08-8ba5-4479-b122-b9c498bb5a15','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-44-4zpk5a3coetj','dfea6e08-8ba5-4479-b122-b9c498bb5a15','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2251,'c748d527-f737-48bb-8578-c73d6652522c','30410c79-72ca-4f99-b5ef-0f3eb09ba745','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RabbitMQServiceBase-nip3hlno5yvn-ContainersCommon-udop5mr4ekpv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2252,'f2fd3a17-30b9-492f-96e3-e185dcc90ac6','dfea6e08-8ba5-4479-b122-b9c498bb5a15','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-44-4zpk5a3coetj-ContainersCommon-bvqu4idnkjiu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2253,'e74a0764-ee6b-4b37-90f4-0412bd533f00','d31ce228-8a19-47ce-8845-0bc4d8d10fa7','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RabbitMQServiceBase-nip3hlno5yvn-ContainersCommon-udop5mr4ekpv','d31ce228-8a19-47ce-8845-0bc4d8d10fa7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2254,'dc739751-156a-4869-8f22-ecc2b9f801bc','98ac702e-199a-431b-8ae2-590659f824ed','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-44-4zpk5a3coetj-ContainersCommon-bvqu4idnkjiu','98ac702e-199a-431b-8ae2-590659f824ed','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2255,'8eb117f8-ba7e-4702-8133-1d43956041bb','d31ce228-8a19-47ce-8845-0bc4d8d10fa7','2026-06-10 08:00:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RabbitMQServiceBase-nip3hlno5yvn-ContainersCommon-udop5mr4ekpv','d31ce228-8a19-47ce-8845-0bc4d8d10fa7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2256,'a21c8e85-8f69-41a4-a25a-91c0bd43a37a','98ac702e-199a-431b-8ae2-590659f824ed','2026-06-10 08:00:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-44-4zpk5a3coetj-ContainersCommon-bvqu4idnkjiu','98ac702e-199a-431b-8ae2-590659f824ed','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2257,'46c9f97c-602f-4be0-8711-d0cfe671066c','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','41','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-41-hnihmbh544q6','state changed','OS::TripleO::Services::Pacemaker',NULL,1366),(2258,'ede595c9-fec0-4813-8ceb-307dada52b0c','e57dd364-a831-4134-85fc-57b2877f68f5','2026-06-10 08:00:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-41-hnihmbh544q6','e57dd364-a831-4134-85fc-57b2877f68f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2259,'88badb0c-b0b9-4538-b703-a7d7db7ac468','e57dd364-a831-4134-85fc-57b2877f68f5','2026-06-10 08:00:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-41-hnihmbh544q6','e57dd364-a831-4134-85fc-57b2877f68f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2260,'5d89d061-263e-4ec5-a1a4-525e187d2909','b8c88db2-53c5-465a-ab47-ea1018faf86f','2026-06-10 08:00:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RoleParametersValue-fgjz65uetoq6','state changed','OS::Heat::Value',NULL,1367),(2261,'732f09d9-0cca-4728-93d5-7e5da38f32cb','b8c88db2-53c5-465a-ab47-ea1018faf86f','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RoleParametersValue-fgjz65uetoq6','state changed','OS::Heat::Value',NULL,1367),(2262,'552c9f6a-4f88-45a6-8624-8ac2fff0daa2','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-RoleParametersValue-hpqmvw3mhb4p','state changed','OS::Heat::Value',NULL,1368),(2263,'8dbcdd62-e4ec-4c66-86c4-ab810b1f87d0','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-RoleParametersValue-hpqmvw3mhb4p','state changed','OS::Heat::Value',NULL,1368),(2264,'2faea7c9-40f1-44b4-a513-c9d31d479a46','b8c88db2-53c5-465a-ab47-ea1018faf86f','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','ContainersCommon','f304383e-0a7b-4209-84fc-e87838a93086','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2265,'df2219d9-8047-4479-882f-19f365810e45','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','ContainersCommon','644801e2-a04b-4316-8422-feb378b1fffd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2266,'acbf1327-981b-41b3-be50-8842388155c8','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','2026-06-10 08:00:27',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RoleParametersValue-cwgstx46o7eu','state changed','OS::Heat::Value',NULL,1369),(2267,'d900f165-92bb-475b-89ac-fe939ff47aa8','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RoleParametersValue-cwgstx46o7eu','state changed','OS::Heat::Value',NULL,1369),(2268,'3df4f1c6-7233-4205-a028-7bed86388f7d','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','ContainersCommon','7ecebb54-c7d2-4eab-97e6-e22047758197','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2269,'3fde39d5-cd06-4343-aa70-9a761e3ba46f','30410c79-72ca-4f99-b5ef-0f3eb09ba745','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','ContainersCommon','d31ce228-8a19-47ce-8845-0bc4d8d10fa7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2270,'2e0dbaa4-5247-47fc-bcf5-fabb9824dd5b','dfea6e08-8ba5-4479-b122-b9c498bb5a15','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','ContainersCommon','98ac702e-199a-431b-8ae2-590659f824ed','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2271,'8f21d2ad-cbdb-47fd-a32d-8f1cf1e4d226','30410c79-72ca-4f99-b5ef-0f3eb09ba745','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug-RabbitMQServiceBase-nip3hlno5yvn','30410c79-72ca-4f99-b5ef-0f3eb09ba745','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2272,'6ccaa98d-2bbc-4de7-b990-69388cc7c5c6','dfea6e08-8ba5-4479-b122-b9c498bb5a15','2026-06-10 08:00:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-44-4zpk5a3coetj','dfea6e08-8ba5-4479-b122-b9c498bb5a15','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2273,'12db9ed7-591a-4266-9953-8cede4a626bc','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:28',NULL,'CREATE','COMPLETE','41','e57dd364-a831-4134-85fc-57b2877f68f5','state changed','OS::TripleO::Services::Pacemaker',NULL,1366),(2274,'29d87807-b0b8-4a90-addf-7e95b91fdcad','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:28',NULL,'CREATE','IN_PROGRESS','45','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-45-6ryjfrab4n3y','state changed','OS::TripleO::Services::Podman',NULL,1371),(2275,'c04d9031-00fd-4948-90f9-96e6ec0917d0','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:28',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-MySQLClient-pjpohklhlepq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2276,'c8d3daf9-9f49-4e01-8635-cee08a2bad62','12a99d21-4462-4bf7-a00d-bc4136061953','2026-06-10 08:00:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-45-6ryjfrab4n3y','12a99d21-4462-4bf7-a00d-bc4136061953','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2277,'fa381762-38c2-4e22-a5f4-7194846cc96e','12a99d21-4462-4bf7-a00d-bc4136061953','2026-06-10 08:00:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-45-6ryjfrab4n3y','12a99d21-4462-4bf7-a00d-bc4136061953','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2278,'0e733eb6-b78d-4f9f-a915-f4fdd145b442','eb3a0441-17ca-4a8a-8117-5d203f13cc56','2026-06-10 08:00:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-MySQLClient-pjpohklhlepq','eb3a0441-17ca-4a8a-8117-5d203f13cc56','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2279,'27268015-3abc-46a1-8832-309c5ef26bcc','eb3a0441-17ca-4a8a-8117-5d203f13cc56','2026-06-10 08:00:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-MySQLClient-pjpohklhlepq','eb3a0441-17ca-4a8a-8117-5d203f13cc56','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2280,'f286785c-08b9-4122-8993-e651c55fc0dd','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','2026-06-10 08:00:28',NULL,'CREATE','COMPLETE','RabbitMQServiceBase','30410c79-72ca-4f99-b5ef-0f3eb09ba745','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1350),(2281,'bb5d68b5-e909-472c-b0bf-9a11866f60b7','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','2026-06-10 08:00:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a-RabbitmqBase-xwq4eq6cwyug','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2282,'56c29fa4-e4cd-4a86-b756-e45fa50e93cf','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:28',NULL,'CREATE','COMPLETE','44','dfea6e08-8ba5-4479-b122-b9c498bb5a15','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1360),(2283,'1752f627-9d74-491a-88b6-16a7823abf5f','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:28',NULL,'CREATE','IN_PROGRESS','48','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-48-wd4ar65osxix','state changed','OS::TripleO::Services::Snmp',NULL,1374),(2284,'c9f117bc-4cec-42e7-9a98-170122615419','d636ea61-065c-4ab6-8790-984431c3cb95','2026-06-10 08:00:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-48-wd4ar65osxix','d636ea61-065c-4ab6-8790-984431c3cb95','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2285,'dfff4272-7425-4eed-b709-55563f435c3e','d636ea61-065c-4ab6-8790-984431c3cb95','2026-06-10 08:00:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-48-wd4ar65osxix','d636ea61-065c-4ab6-8790-984431c3cb95','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2286,'4bf647bf-a16a-497c-a599-328072e1cbf9','b8c88db2-53c5-465a-ab47-ea1018faf86f','2026-06-10 08:00:29',NULL,'CREATE','COMPLETE','RabbitmqBase','159ed4c8-6c65-4dbb-bac9-5863d9168e5a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1347),(2287,'3a301a6c-6c04-49ee-b3ea-56073dda1bbb','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:29',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-ApacheServiceBase-bof3op3ctub3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1375),(2288,'32f82e40-f3b0-47de-919a-55be90a46417','b8c88db2-53c5-465a-ab47-ea1018faf86f','2026-06-10 08:00:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-43-hmd5ex6bn73a','b8c88db2-53c5-465a-ab47-ea1018faf86f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2289,'2242f350-f0fb-403c-a571-72fda8b1b831','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:29',NULL,'CREATE','COMPLETE','45','12a99d21-4462-4bf7-a00d-bc4136061953','state changed','OS::TripleO::Services::Podman',NULL,1371),(2290,'b156a0d4-6dd3-47b3-9bee-cd96cb24c2e3','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:29',NULL,'CREATE','COMPLETE','MySQLClient','eb3a0441-17ca-4a8a-8117-5d203f13cc56','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2291,'e227f8fd-430d-4b3a-ab9a-e073d8adcae7','c1cef6ac-b8a0-4ac0-aa5d-51c6a20446f3','2026-06-10 08:00:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-ApacheServiceBase-bof3op3ctub3','c1cef6ac-b8a0-4ac0-aa5d-51c6a20446f3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2292,'b7632a84-3d93-4ffb-b2a1-64184bdd0f09','c1cef6ac-b8a0-4ac0-aa5d-51c6a20446f3','2026-06-10 08:00:29',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-ApacheServiceBase-bof3op3ctub3-ApacheNetworks-5gmip67oem6f','state changed','OS::Heat::Value',NULL,1377),(2293,'7ee61d02-1c1b-4399-bc42-73c0aecd215e','c1cef6ac-b8a0-4ac0-aa5d-51c6a20446f3','2026-06-10 08:00:29',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-ApacheServiceBase-bof3op3ctub3-ApacheNetworks-5gmip67oem6f','state changed','OS::Heat::Value',NULL,1377),(2294,'aefe4e78-f034-4e3f-8a93-aa24a357425c','c1cef6ac-b8a0-4ac0-aa5d-51c6a20446f3','2026-06-10 08:00:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i-ApacheServiceBase-bof3op3ctub3','c1cef6ac-b8a0-4ac0-aa5d-51c6a20446f3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2295,'03386df8-225b-4b2d-ba10-42f0381763c4','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:29',NULL,'CREATE','IN_PROGRESS','49','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-49-vcfccasnzuin','state changed','OS::TripleO::Services::Sshd',NULL,1378),(2296,'32b34d13-a11e-4a14-8265-db12e1fc62f7','c7e59186-38d9-4de3-8989-2eb0fe528d83','2026-06-10 08:00:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-49-vcfccasnzuin','c7e59186-38d9-4de3-8989-2eb0fe528d83','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2297,'c470e804-2d2a-42a7-9156-35bd0a5edb81','c7e59186-38d9-4de3-8989-2eb0fe528d83','2026-06-10 08:00:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-49-vcfccasnzuin','c7e59186-38d9-4de3-8989-2eb0fe528d83','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2298,'68f5c051-7a50-4d7d-a0cc-a63609d400d4','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:30',NULL,'CREATE','COMPLETE','43','b8c88db2-53c5-465a-ab47-ea1018faf86f','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1342),(2299,'68d40239-5c02-46a4-92a4-80b88ee723c1','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:30',NULL,'CREATE','COMPLETE','48','d636ea61-065c-4ab6-8790-984431c3cb95','state changed','OS::TripleO::Services::Snmp',NULL,1374),(2300,'90c628ac-c93b-416b-8a60-de194ede15a0','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:30',NULL,'CREATE','IN_PROGRESS','52','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco','state changed','OS::TripleO::Services::SwiftStorage',NULL,1382),(2301,'865508aa-f9fa-487e-95a1-c3c92e243b6a','d334d149-cbb3-48ed-902d-8a79799e8864','2026-06-10 08:00:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco','d334d149-cbb3-48ed-902d-8a79799e8864','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2302,'2a92409f-0611-47d3-b3b6-22bedac955e3','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:30',NULL,'CREATE','COMPLETE','ApacheServiceBase','c1cef6ac-b8a0-4ac0-aa5d-51c6a20446f3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1375),(2303,'68325a46-5819-477c-a790-cd6aeba4e449','c5f318a8-9308-48c5-b6b4-4add98a3d277','2026-06-10 08:00:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-42-fsmny6pi2r7i','c5f318a8-9308-48c5-b6b4-4add98a3d277','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2304,'84d66464-367d-4d06-bfb8-92c71d2efb92','d334d149-cbb3-48ed-902d-8a79799e8864','2026-06-10 08:00:30',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco-RoleParametersValue-edbsjkofl44z','state changed','OS::Heat::Value',NULL,1390),(2305,'615ba96d-ad5a-40a0-93fd-0c6543219bee','d334d149-cbb3-48ed-902d-8a79799e8864','2026-06-10 08:00:30',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco-RoleParametersValue-edbsjkofl44z','state changed','OS::Heat::Value',NULL,1390),(2306,'6887eaac-208e-4249-a91f-38db46f28f1f','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:30',NULL,'CREATE','IN_PROGRESS','47','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-47-zw6ypoxfrdxi','state changed','OS::TripleO::Services::Rsyslog',NULL,1391),(2307,'43c2fbb8-e05c-4ec0-8957-d51a7f0c2775','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:30',NULL,'CREATE','COMPLETE','49','c7e59186-38d9-4de3-8989-2eb0fe528d83','state changed','OS::TripleO::Services::Sshd',NULL,1378),(2308,'b12ecd4f-6d00-47ab-afa6-ab0aec733d46','9e81dadc-25ac-4654-9559-0db407589c20','2026-06-10 08:00:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-47-zw6ypoxfrdxi','9e81dadc-25ac-4654-9559-0db407589c20','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2309,'c91171a9-9c83-430d-a5eb-f6eda41d295a','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:31',NULL,'CREATE','COMPLETE','42','c5f318a8-9308-48c5-b6b4-4add98a3d277','state changed','OS::TripleO::Services::PlacementApi',NULL,1346),(2310,'0005a772-60bb-4978-a891-043bb499923f','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:31',NULL,'CREATE','IN_PROGRESS','53','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-53-u6nwugi7ytox','state changed','OS::TripleO::Services::Timesync',NULL,1393),(2311,'781605c6-4516-40cd-a20f-c4eefa349e2d','00d12b32-82a4-4fa4-9ce4-497aaf9a598d','2026-06-10 08:00:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-53-u6nwugi7ytox','00d12b32-82a4-4fa4-9ce4-497aaf9a598d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2312,'1446ce6a-284c-4719-97dd-718d4e018bf5','00d12b32-82a4-4fa4-9ce4-497aaf9a598d','2026-06-10 08:00:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-53-u6nwugi7ytox','00d12b32-82a4-4fa4-9ce4-497aaf9a598d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2313,'122cd5ed-c0ee-43f2-a1b3-7d25ce449210','9e81dadc-25ac-4654-9559-0db407589c20','2026-06-10 08:00:31',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-47-zw6ypoxfrdxi-ContainersCommon-qgj7idzcdtrl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2314,'d1bfa76d-029e-4642-8b54-a31495310022','160dc4df-e97b-44e0-ac6a-3a5215a1966c','2026-06-10 08:00:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-47-zw6ypoxfrdxi-ContainersCommon-qgj7idzcdtrl','160dc4df-e97b-44e0-ac6a-3a5215a1966c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2315,'76580c9e-66d4-4668-8337-ae849eda7427','160dc4df-e97b-44e0-ac6a-3a5215a1966c','2026-06-10 08:00:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-47-zw6ypoxfrdxi-ContainersCommon-qgj7idzcdtrl','160dc4df-e97b-44e0-ac6a-3a5215a1966c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2316,'d2116944-1ee3-4f4e-899a-e68c84aac214','9e81dadc-25ac-4654-9559-0db407589c20','2026-06-10 08:00:31',NULL,'CREATE','COMPLETE','ContainersCommon','160dc4df-e97b-44e0-ac6a-3a5215a1966c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2317,'182acaa0-c9c8-45d9-9874-2c44fec0970e','d334d149-cbb3-48ed-902d-8a79799e8864','2026-06-10 08:00:31',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco-ContainersCommon-a7fzpqght4gn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2318,'c1ae1118-633f-4704-921b-612398c02221','dce35571-0e15-47dc-8c3a-8f346909f35e','2026-06-10 08:00:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco-ContainersCommon-a7fzpqght4gn','dce35571-0e15-47dc-8c3a-8f346909f35e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2319,'d283fd64-53a0-457b-857f-8f298a554541','dce35571-0e15-47dc-8c3a-8f346909f35e','2026-06-10 08:00:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco-ContainersCommon-a7fzpqght4gn','dce35571-0e15-47dc-8c3a-8f346909f35e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2320,'c0fe41e7-abcb-4050-9b95-36270c069315','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:31',NULL,'CREATE','IN_PROGRESS','46','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl','state changed','OS::TripleO::Services::Redis',NULL,1402),(2321,'197df788-9da1-4b6e-8fca-41c42d3e2946','5d104b4c-9761-4d0e-84db-df98c2e22784','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl','5d104b4c-9761-4d0e-84db-df98c2e22784','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2322,'3a0b5e6c-a84c-480d-bca4-a0ebc5fe9965','5d104b4c-9761-4d0e-84db-df98c2e22784','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1403),(2323,'f3d9f35a-80f9-40b3-8cbe-e1d477df6d7c','69677bcd-33cc-4d68-8bbe-dae2a66343d5','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3','69677bcd-33cc-4d68-8bbe-dae2a66343d5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2324,'8c3dbb2d-0dcc-4f13-9ad1-94091598fd8d','9e81dadc-25ac-4654-9559-0db407589c20','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-47-zw6ypoxfrdxi-RoleParametersValue-qt7d2rkjqyj2','state changed','OS::Heat::Value',NULL,1404),(2325,'c2539886-9ae8-46d8-b521-c587bbcb4241','9e81dadc-25ac-4654-9559-0db407589c20','2026-06-10 08:00:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-47-zw6ypoxfrdxi-RoleParametersValue-qt7d2rkjqyj2','state changed','OS::Heat::Value',NULL,1404),(2326,'6df478f8-5f4e-43e1-8f94-4ac1b65cd1f8','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:32',NULL,'CREATE','COMPLETE','53','00d12b32-82a4-4fa4-9ce4-497aaf9a598d','state changed','OS::TripleO::Services::Timesync',NULL,1393),(2327,'dd0a3311-e7a5-4727-93a6-314d87584613','9e81dadc-25ac-4654-9559-0db407589c20','2026-06-10 08:00:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-47-zw6ypoxfrdxi','9e81dadc-25ac-4654-9559-0db407589c20','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2328,'c5302e09-6548-4d30-a885-b81921192747','69677bcd-33cc-4d68-8bbe-dae2a66343d5','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3-RedisBase-67dlrvfiry6b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1405),(2329,'ad0b8d81-cee6-4aaa-b5a2-0c97729b9079','4f8fa5d9-3dd6-49b1-a701-8e5e3810d3b5','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3-RedisBase-67dlrvfiry6b','4f8fa5d9-3dd6-49b1-a701-8e5e3810d3b5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2330,'d8502c28-d4b1-43c3-8e23-1894c190613b','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','57','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-57-ohcuegpyxezt','state changed','OS::TripleO::Services::Tuned',NULL,1407),(2331,'4000ebe8-ef21-4a94-9ee7-6edb4668380c','d334d149-cbb3-48ed-902d-8a79799e8864','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco-SwiftBase-xlvy57herkkh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1408),(2332,'ac8fe7ed-be79-4bee-8674-dd921271c3a3','4f8fa5d9-3dd6-49b1-a701-8e5e3810d3b5','2026-06-10 08:00:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3-RedisBase-67dlrvfiry6b','4f8fa5d9-3dd6-49b1-a701-8e5e3810d3b5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2333,'a503acb9-9001-4b42-9f0b-4bca9bef72fa','0b2c483e-ca09-46ba-801b-c146e2557352','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-57-ohcuegpyxezt','0b2c483e-ca09-46ba-801b-c146e2557352','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2334,'4dcc5114-7af4-4f53-8777-39d9b0f16f65','e977ffa6-8999-4dd5-af95-5da8795ed18b','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco-SwiftBase-xlvy57herkkh','e977ffa6-8999-4dd5-af95-5da8795ed18b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2335,'b0fd5755-ec94-4349-bcce-632878c9e88f','e977ffa6-8999-4dd5-af95-5da8795ed18b','2026-06-10 08:00:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco-SwiftBase-xlvy57herkkh','e977ffa6-8999-4dd5-af95-5da8795ed18b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2336,'a764fdf0-f741-4206-9744-8a2711e51c9f','0b2c483e-ca09-46ba-801b-c146e2557352','2026-06-10 08:00:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-57-ohcuegpyxezt-RoleParametersValue-5vyovq7wzb5f','state changed','OS::Heat::Value',NULL,1409),(2337,'af4d9244-cb24-46cb-81ad-49466bd167db','d334d149-cbb3-48ed-902d-8a79799e8864','2026-06-10 08:00:32',NULL,'CREATE','COMPLETE','ContainersCommon','dce35571-0e15-47dc-8c3a-8f346909f35e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2338,'cf752d86-c3e3-4e27-a5c9-95680fa4b893','0b2c483e-ca09-46ba-801b-c146e2557352','2026-06-10 08:00:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-57-ohcuegpyxezt-RoleParametersValue-5vyovq7wzb5f','state changed','OS::Heat::Value',NULL,1409),(2339,'28eed29d-624f-4fa7-8c00-b7c70e97416d','0b2c483e-ca09-46ba-801b-c146e2557352','2026-06-10 08:00:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-57-ohcuegpyxezt','0b2c483e-ca09-46ba-801b-c146e2557352','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2340,'e952a663-fda1-4e82-b98c-f9c0aaa12ce2','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:33',NULL,'CREATE','COMPLETE','47','9e81dadc-25ac-4654-9559-0db407589c20','state changed','OS::TripleO::Services::Rsyslog',NULL,1391),(2341,'63664368-ad36-4911-bfab-cf7e3203a563','5d104b4c-9761-4d0e-84db-df98c2e22784','2026-06-10 08:00:33',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-ContainersCommon-hmwowdnwf6n2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2342,'92bed7f4-068c-4698-abdc-e7363c45d016','d0da7f12-a81e-4e68-a109-ed1e58a79b65','2026-06-10 08:00:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-ContainersCommon-hmwowdnwf6n2','d0da7f12-a81e-4e68-a109-ed1e58a79b65','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2343,'6a7f8d9f-9ab3-4a25-baa8-e994ace397cc','d0da7f12-a81e-4e68-a109-ed1e58a79b65','2026-06-10 08:00:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-ContainersCommon-hmwowdnwf6n2','d0da7f12-a81e-4e68-a109-ed1e58a79b65','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2344,'07de803a-bffd-4084-becd-2d73a48638be','69677bcd-33cc-4d68-8bbe-dae2a66343d5','2026-06-10 08:00:33',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3-ContainersCommon-jupi7coqk2j4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2345,'1615d2af-ec3f-4917-aac8-6fd2ef2effde','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:33',NULL,'CREATE','IN_PROGRESS','51','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-51-6cxjgbosgyww','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1413),(2346,'616fec54-e57b-4ff5-8b73-f682171b8f7a','359e0e61-52a9-4cbd-8b05-f39647e345fc','2026-06-10 08:00:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3-ContainersCommon-jupi7coqk2j4','359e0e61-52a9-4cbd-8b05-f39647e345fc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2347,'abd81cc1-103a-4481-95df-288c8ab7df3e','359e0e61-52a9-4cbd-8b05-f39647e345fc','2026-06-10 08:00:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3-ContainersCommon-jupi7coqk2j4','359e0e61-52a9-4cbd-8b05-f39647e345fc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2348,'ec898961-6eef-4b20-b359-a363e216e34f','39b62904-6fae-4453-ab69-39ff92876ef8','2026-06-10 08:00:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-51-6cxjgbosgyww','39b62904-6fae-4453-ab69-39ff92876ef8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2349,'32330e83-2df5-414b-934c-e6b25719c7f9','39b62904-6fae-4453-ab69-39ff92876ef8','2026-06-10 08:00:33',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-51-6cxjgbosgyww-RoleParametersValue-nwu76ubbe22t','state changed','OS::Heat::Value',NULL,1414),(2350,'6107eb73-b533-4798-bc9e-8cf895b43a85','39b62904-6fae-4453-ab69-39ff92876ef8','2026-06-10 08:00:33',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-51-6cxjgbosgyww-RoleParametersValue-nwu76ubbe22t','state changed','OS::Heat::Value',NULL,1414),(2351,'1667169a-c088-4b32-9b8c-b67f19fdb3bf','39b62904-6fae-4453-ab69-39ff92876ef8','2026-06-10 08:00:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-51-6cxjgbosgyww','39b62904-6fae-4453-ab69-39ff92876ef8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2352,'604c6d46-7cc1-4363-a9e9-a331e2010a3d','69677bcd-33cc-4d68-8bbe-dae2a66343d5','2026-06-10 08:00:33',NULL,'CREATE','COMPLETE','RedisBase','4f8fa5d9-3dd6-49b1-a701-8e5e3810d3b5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1405),(2353,'08f33592-71e7-4c1f-bc40-68c2f818800b','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:33',NULL,'CREATE','COMPLETE','57','0b2c483e-ca09-46ba-801b-c146e2557352','state changed','OS::TripleO::Services::Tuned',NULL,1407),(2354,'e18bd312-932a-443f-9cd2-e0e6ea9bb8c3','d334d149-cbb3-48ed-902d-8a79799e8864','2026-06-10 08:00:33',NULL,'CREATE','COMPLETE','SwiftBase','e977ffa6-8999-4dd5-af95-5da8795ed18b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1408),(2355,'479ad0b9-308a-42a7-9dcb-6dc102d4f211','d334d149-cbb3-48ed-902d-8a79799e8864','2026-06-10 08:00:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-52-7yeiupn5ctco','d334d149-cbb3-48ed-902d-8a79799e8864','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2356,'130d9997-a479-4683-a313-d368d8daad59','5d104b4c-9761-4d0e-84db-df98c2e22784','2026-06-10 08:00:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RoleParametersValue-uy367qfl6gfh','state changed','OS::Heat::Value',NULL,1415),(2357,'566f81eb-1970-497b-a01a-0497c7f89459','5d104b4c-9761-4d0e-84db-df98c2e22784','2026-06-10 08:00:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RoleParametersValue-uy367qfl6gfh','state changed','OS::Heat::Value',NULL,1415),(2358,'36c29f4a-46a4-42a1-a895-4f29d8b6ab42','5d104b4c-9761-4d0e-84db-df98c2e22784','2026-06-10 08:00:34',NULL,'CREATE','COMPLETE','ContainersCommon','d0da7f12-a81e-4e68-a109-ed1e58a79b65','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2359,'22bf4db5-20dc-4985-84eb-fc496e10819c','69677bcd-33cc-4d68-8bbe-dae2a66343d5','2026-06-10 08:00:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3-RoleParametersValue-xc4wblxoccen','state changed','OS::Heat::Value',NULL,1416),(2360,'3b445f5e-0193-40a8-9ff2-af85b4778e49','69677bcd-33cc-4d68-8bbe-dae2a66343d5','2026-06-10 08:00:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3-RoleParametersValue-xc4wblxoccen','state changed','OS::Heat::Value',NULL,1416),(2361,'6d130905-d886-43d1-a3b5-c446e50284e6','69677bcd-33cc-4d68-8bbe-dae2a66343d5','2026-06-10 08:00:34',NULL,'CREATE','COMPLETE','ContainersCommon','359e0e61-52a9-4cbd-8b05-f39647e345fc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2362,'bbca2468-3dbc-45e4-9565-dc64ceaede91','69677bcd-33cc-4d68-8bbe-dae2a66343d5','2026-06-10 08:00:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl-RedisBase-swvlieszrux3','69677bcd-33cc-4d68-8bbe-dae2a66343d5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2363,'db88214a-07ef-41c5-a486-cd7c213414d4','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:34',NULL,'CREATE','COMPLETE','52','d334d149-cbb3-48ed-902d-8a79799e8864','state changed','OS::TripleO::Services::SwiftStorage',NULL,1382),(2364,'2d66ec79-1955-4826-bf1b-9b03b60c6de1','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:34',NULL,'CREATE','COMPLETE','51','39b62904-6fae-4453-ab69-39ff92876ef8','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1413),(2365,'ae79322c-6b6f-408b-b277-8743c77a6d50','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:34',NULL,'CREATE','IN_PROGRESS','55','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-55-5um7krfbnd4q','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1423),(2366,'79c11945-9c27-433c-837b-844e41bc9d7b','694edad5-5cca-4eef-a05b-84b0cfd618b9','2026-06-10 08:00:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-55-5um7krfbnd4q','694edad5-5cca-4eef-a05b-84b0cfd618b9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2367,'c5aed722-e331-4508-9368-0371b033696a','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:34',NULL,'CREATE','IN_PROGRESS','56','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-56-bctpefuldins','state changed','OS::TripleO::Services::TripleoPackages',NULL,1424),(2368,'99fe1b9d-1ffb-4224-b968-189f6cda465f','694edad5-5cca-4eef-a05b-84b0cfd618b9','2026-06-10 08:00:35',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-55-5um7krfbnd4q-RoleParametersValue-ahvmesyxipez','state changed','OS::Heat::Value',NULL,1425),(2369,'5282de93-b1cb-45da-a18d-0dd54bba0b0b','5c30a4b3-09c2-4db4-bdb9-ac4df56ae23e','2026-06-10 08:00:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-56-bctpefuldins','5c30a4b3-09c2-4db4-bdb9-ac4df56ae23e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2370,'c9a9a998-eec8-459e-8119-6d4779aac7da','694edad5-5cca-4eef-a05b-84b0cfd618b9','2026-06-10 08:00:35',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-55-5um7krfbnd4q-RoleParametersValue-ahvmesyxipez','state changed','OS::Heat::Value',NULL,1425),(2371,'83e0539d-b3b0-43a0-8f4a-5b0f40c5cd32','694edad5-5cca-4eef-a05b-84b0cfd618b9','2026-06-10 08:00:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-55-5um7krfbnd4q','694edad5-5cca-4eef-a05b-84b0cfd618b9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2372,'355640cd-34af-470a-9173-5e892ae4f341','5c30a4b3-09c2-4db4-bdb9-ac4df56ae23e','2026-06-10 08:00:35',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-56-bctpefuldins-RoleParametersValue-n6k7iumulq74','state changed','OS::Heat::Value',NULL,1426),(2373,'ba5dc77b-6081-465b-817d-2d7f48d0abd1','5c30a4b3-09c2-4db4-bdb9-ac4df56ae23e','2026-06-10 08:00:35',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-56-bctpefuldins-RoleParametersValue-n6k7iumulq74','state changed','OS::Heat::Value',NULL,1426),(2374,'16aa8a91-6944-43c2-9f1c-c9399223189a','5d104b4c-9761-4d0e-84db-df98c2e22784','2026-06-10 08:00:35',NULL,'CREATE','COMPLETE','RedisBase','69677bcd-33cc-4d68-8bbe-dae2a66343d5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1403),(2375,'c6668b4e-8758-43a8-87c4-d8baa1604880','5d104b4c-9761-4d0e-84db-df98c2e22784','2026-06-10 08:00:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-46-l2feytqqmxgl','5d104b4c-9761-4d0e-84db-df98c2e22784','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2376,'66b56a2e-bc8f-4b58-b0c4-0a441d848c8b','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:35',NULL,'CREATE','COMPLETE','55','694edad5-5cca-4eef-a05b-84b0cfd618b9','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1423),(2377,'c4254ae5-bbd0-48e3-a24d-60b14b425f73','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:36',NULL,'CREATE','COMPLETE','46','5d104b4c-9761-4d0e-84db-df98c2e22784','state changed','OS::TripleO::Services::Redis',NULL,1402),(2378,'73676b0a-1ca5-4023-b480-254c9759c435','5c30a4b3-09c2-4db4-bdb9-ac4df56ae23e','2026-06-10 08:00:36',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-56-bctpefuldins-Podman-fkijco5uuds2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1427),(2379,'0283698d-de0e-45f2-83f3-b6adeb65d66e','d11ee363-9792-46d5-8ef7-ce327d974663','2026-06-10 08:00:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-56-bctpefuldins-Podman-fkijco5uuds2','d11ee363-9792-46d5-8ef7-ce327d974663','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2380,'a75d7ebe-e7ae-4e18-8a7c-6a75c1a056f8','d11ee363-9792-46d5-8ef7-ce327d974663','2026-06-10 08:00:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-56-bctpefuldins-Podman-fkijco5uuds2','d11ee363-9792-46d5-8ef7-ce327d974663','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2381,'510809eb-6f06-4832-bdb4-c4336c9a5aaf','5c30a4b3-09c2-4db4-bdb9-ac4df56ae23e','2026-06-10 08:00:36',NULL,'CREATE','COMPLETE','Podman','d11ee363-9792-46d5-8ef7-ce327d974663','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1427),(2382,'e5ff1982-f497-4b90-bd1b-cd759d32b3ea','5c30a4b3-09c2-4db4-bdb9-ac4df56ae23e','2026-06-10 08:00:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-56-bctpefuldins','5c30a4b3-09c2-4db4-bdb9-ac4df56ae23e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2383,'35b9d63d-80ad-48d9-8043-4e8998f55d23','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:36',NULL,'CREATE','IN_PROGRESS','50','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n','state changed','OS::TripleO::Services::SwiftProxy',NULL,1435),(2384,'6c3f408f-0f2e-4bd0-bc50-b07d0d69f8b4','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2385,'e05c7900-5ca0-4882-8c92-88cd0c6c7451','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-RoleParametersValue-lotgmtr6tsmm','state changed','OS::Heat::Value',NULL,1436),(2386,'2e7e9a9b-b79f-4be6-9ae4-55d37de83b60','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-RoleParametersValue-lotgmtr6tsmm','state changed','OS::Heat::Value',NULL,1436),(2387,'d55d81fe-91d9-4f43-a440-3a6a87e25f62','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:37',NULL,'CREATE','COMPLETE','56','5c30a4b3-09c2-4db4-bdb9-ac4df56ae23e','state changed','OS::TripleO::Services::TripleoPackages',NULL,1424),(2388,'18dedae6-0617-4f35-bdce-0691db218b7d','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:37',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-ContainersCommon-m5wyge2nlcla','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2389,'4e2a7d22-1c58-487f-a41d-886ccbac93d1','5345eca5-dd0f-48e8-bd5a-850179328bfc','2026-06-10 08:00:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-ContainersCommon-m5wyge2nlcla','5345eca5-dd0f-48e8-bd5a-850179328bfc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2390,'eae2e461-ef39-451e-9413-fe6c8647257f','5345eca5-dd0f-48e8-bd5a-850179328bfc','2026-06-10 08:00:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-ContainersCommon-m5wyge2nlcla','5345eca5-dd0f-48e8-bd5a-850179328bfc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2391,'59143ba3-26db-457e-9989-d0f975281070','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:38',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-SwiftBase-az5xwb644vqs','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1437),(2392,'4782c75e-13d1-4efa-9d33-7459dd7ff15b','569b1c63-46ab-451d-8dd2-552be23d317e','2026-06-10 08:00:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-SwiftBase-az5xwb644vqs','569b1c63-46ab-451d-8dd2-552be23d317e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2393,'e4169e0a-5600-4f19-86fd-57de5610f46c','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:39',NULL,'CREATE','COMPLETE','ContainersCommon','5345eca5-dd0f-48e8-bd5a-850179328bfc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2394,'75ffd69c-01ab-43df-8936-cfb44aa1ef13','569b1c63-46ab-451d-8dd2-552be23d317e','2026-06-10 08:00:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-SwiftBase-az5xwb644vqs','569b1c63-46ab-451d-8dd2-552be23d317e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2395,'8e083160-f3c8-46cf-9f3c-f14f5ee331e8','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:39',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-TLSProxyBase-uu47h5ypswnx','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1438),(2396,'7bdd1ca3-fdc7-4455-8d9a-16289eeee831','8c3d1bfa-f953-401b-96b7-97b0ab2a515a','2026-06-10 08:00:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-TLSProxyBase-uu47h5ypswnx','8c3d1bfa-f953-401b-96b7-97b0ab2a515a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2397,'ade634b7-36d5-4353-bc39-a3f263e74780','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:40',NULL,'CREATE','COMPLETE','SwiftBase','569b1c63-46ab-451d-8dd2-552be23d317e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1437),(2398,'9bfafc96-8d00-49bc-adca-a33abfe0890e','8c3d1bfa-f953-401b-96b7-97b0ab2a515a','2026-06-10 08:00:40',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-TLSProxyBase-uu47h5ypswnx-ApacheNetworks-k5oruzblusjm','state changed','OS::Heat::Value',NULL,1439),(2399,'35ac11de-ee23-4f89-91ef-e8b85d94d694','8c3d1bfa-f953-401b-96b7-97b0ab2a515a','2026-06-10 08:00:40',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-TLSProxyBase-uu47h5ypswnx-ApacheNetworks-k5oruzblusjm','state changed','OS::Heat::Value',NULL,1439),(2400,'2cdc7f0b-7bda-43bb-8397-838328cdb8ed','8c3d1bfa-f953-401b-96b7-97b0ab2a515a','2026-06-10 08:00:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n-TLSProxyBase-uu47h5ypswnx','8c3d1bfa-f953-401b-96b7-97b0ab2a515a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2401,'c9640c61-b33c-490a-9ebe-0e5465a08088','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:41',NULL,'CREATE','COMPLETE','TLSProxyBase','8c3d1bfa-f953-401b-96b7-97b0ab2a515a','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1438),(2402,'797c880b-dfcf-4442-9f83-f65553a258b0','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','2026-06-10 08:00:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-50-tt5jx6mnjg5n','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2403,'0bc8c1b5-afbb-45c7-8a2c-c7897215a27f','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:41',NULL,'CREATE','COMPLETE','50','fecf0dd7-b3a8-4bdd-9709-73dc123747a7','state changed','OS::TripleO::Services::SwiftProxy',NULL,1435),(2404,'c29e8470-6744-4b6f-9cb9-8c362f099162','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:42',NULL,'CREATE','IN_PROGRESS','54','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-54-ud3igkidm7j3','state changed','OS::TripleO::Services::Timezone',NULL,1446),(2405,'9f7529cc-e76b-4db6-acd8-64dce8876806','1067d766-2ba4-4156-bd6e-971f6fc79b34','2026-06-10 08:00:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-54-ud3igkidm7j3','1067d766-2ba4-4156-bd6e-971f6fc79b34','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2406,'102d2be8-1182-45d7-afb9-13398056ff3e','1067d766-2ba4-4156-bd6e-971f6fc79b34','2026-06-10 08:00:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33-54-ud3igkidm7j3','1067d766-2ba4-4156-bd6e-971f6fc79b34','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2407,'82b3eddd-ec0a-4988-a1f8-e86f2ab69022','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:43',NULL,'CREATE','COMPLETE','54','1067d766-2ba4-4156-bd6e-971f6fc79b34','state changed','OS::TripleO::Services::Timezone',NULL,1446),(2408,'708f77d0-743f-4964-a381-76a48bd046a0','90e79527-4e38-430d-8d4e-d2687a4894e3','2026-06-10 08:00:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceChain-gwmm2zlegx33','90e79527-4e38-430d-8d4e-d2687a4894e3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2409,'f1f9966c-b6bb-4da7-af5b-aa0154ba9447','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:43',NULL,'CREATE','COMPLETE','ServiceChain','90e79527-4e38-430d-8d4e-d2687a4894e3','state changed','OS::Heat::ResourceChain',NULL,93),(2410,'0b03a348-c95b-4fd2-8a8d-cda8c5e210e5','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:45',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ControllerServiceChain-prlzcjjdciyj-GlobalConfigSettings-uhpwdisqi3i7','state changed','OS::Heat::Value',NULL,1456),(2411,'e87e3620-cb2f-4edc-9bf4-1390e4ac3a1c','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:45',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ControllerServiceChain-prlzcjjdciyj-FirewallRules-4q2fvowdfxio','state changed','OS::Heat::Value',NULL,1455),(2412,'49f23906-f2ac-436b-aa0e-49a06fa269c4','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:45',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ControllerServiceChain-prlzcjjdciyj-GlobalConfigSettings-uhpwdisqi3i7','state changed','OS::Heat::Value',NULL,1456),(2413,'d526ca7d-da14-4cf2-8265-a5fe6817326e','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:46',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ControllerServiceChain-prlzcjjdciyj-FirewallRules-4q2fvowdfxio','state changed','OS::Heat::Value',NULL,1455),(2414,'db0d00d8-fa23-47d6-8790-b02662a05f49','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:46',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ExternalUpdateTasks-ivd4abvzuxdd','state changed','OS::Heat::Value',NULL,1457),(2415,'75327d5d-eeb5-42f7-b039-7fcb39d226c4','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:46',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ExternalUpdateTasks-ivd4abvzuxdd','state changed','OS::Heat::Value',NULL,1457),(2416,'956780ce-c421-4d4e-aae4-fef017e429c0','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:46',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceConfigSettings-ncslzcserdh4','state changed','OS::Heat::Value',NULL,1458),(2417,'38a6dd09-1a5b-40bd-9fc7-0caa3007d6e5','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:46',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceConfigSettings-ncslzcserdh4','state changed','OS::Heat::Value',NULL,1458),(2418,'aa9637ce-0a4b-48aa-85f7-2f1c2fc01b21','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:46',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-PostUpgradeTasks-vdot4mbtyizn','state changed','OS::Heat::Value',NULL,1459),(2419,'b2c7d249-9ec7-4a97-acf1-bd58bfaf709a','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:46',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ExternalDeployTasks-4wcihlc5bwnf','state changed','OS::Heat::Value',NULL,1460),(2420,'ff8d728e-aa77-41d5-b389-e30ba3178498','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:47',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ExternalDeployTasks-4wcihlc5bwnf','state changed','OS::Heat::Value',NULL,1460),(2421,'2d888bd5-91ad-4167-b274-a19057d4f627','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:47',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-PostUpgradeTasks-vdot4mbtyizn','state changed','OS::Heat::Value',NULL,1459),(2422,'78be52fa-aa8d-4e88-8a2d-709bfb529fe2','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:47',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ExternalPostDeployTasks-o6jh2fml3eu6','state changed','OS::Heat::Value',NULL,1461),(2423,'43001a6b-06c6-4811-b917-fb65c00bd103','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:47',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ExternalPostDeployTasks-o6jh2fml3eu6','state changed','OS::Heat::Value',NULL,1461),(2424,'3441690a-5ebd-43ad-b8ff-96d8320ef0d4','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:47',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-prlzcjjdciyj-KeystoneResourcesConfigs-5xj43k6doeyg','state changed','OS::Heat::Value',NULL,1462),(2425,'c4da547a-0061-445c-8324-c81f8153ad06','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:47',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-prlzcjjdciyj-KeystoneResourcesConfigs-5xj43k6doeyg','state changed','OS::Heat::Value',NULL,1462),(2426,'dcdc17a8-5ce4-4283-b05b-cbeb7b5032a5','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:47',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-DockerConfig-ijs5ojlm4nbf','state changed','OS::Heat::Value',NULL,1463),(2427,'9932dbb7-4ce7-4eae-ba2d-7ad0c0b816ad','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:48',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-PostUpdateTasks-eh4tyztmh7ie','state changed','OS::Heat::Value',NULL,1464),(2428,'415714a0-518d-4617-b7bf-d8610528d977','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:48',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-PostUpdateTasks-eh4tyztmh7ie','state changed','OS::Heat::Value',NULL,1464),(2429,'885666fe-4166-4488-a211-d93f8488552d','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:48',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-DockerConfig-ijs5ojlm4nbf','state changed','OS::Heat::Value',NULL,1463),(2430,'fdb371d7-1924-46a0-94e0-6a5954c32443','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:48',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-IpaRegistrationTasks-irvyaxhfqj7d','state changed','OS::Heat::Value',NULL,1465),(2431,'4c9e402b-2bea-4e90-b0b0-7598cdebab2c','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:48',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-IpaRegistrationTasks-irvyaxhfqj7d','state changed','OS::Heat::Value',NULL,1465),(2432,'9b92d0e8-72fb-40ab-b32c-5e1a0ef21045','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:48',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-UpgradeBatchTasks-rezpoqgwr67o','state changed','OS::Heat::Value',NULL,1466),(2433,'ee1c7cbb-0ef6-4036-b593-382409690a2c','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:48',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-UpgradeBatchTasks-rezpoqgwr67o','state changed','OS::Heat::Value',NULL,1466),(2434,'def555b0-0a19-498b-a85a-87eb8e07b121','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:48',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-UpdateTasks-5fval3bsb3al','state changed','OS::Heat::Value',NULL,1467),(2435,'c92167dc-d2d7-4d49-8922-d2c7dc936899','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:48',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ExternalUpgradeTasks-4dxmmim7gt53','state changed','OS::Heat::Value',NULL,1468),(2436,'f073a4fc-4785-4fd4-9653-eb2af1cc659e','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:49',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ExternalUpgradeTasks-4dxmmim7gt53','state changed','OS::Heat::Value',NULL,1468),(2437,'cbc304b6-8a8f-48b9-8e47-7c7d22382a4c','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:49',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-UpdateTasks-5fval3bsb3al','state changed','OS::Heat::Value',NULL,1467),(2438,'b503d48b-7815-4c57-9b1e-0a1412a37a32','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:49',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-PreUpgradeRollingTasks-44r5dgjrblnw','state changed','OS::Heat::Value',NULL,1469),(2439,'407b46bb-c5be-43eb-9447-e5dbb327f675','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:49',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-PreUpgradeRollingTasks-44r5dgjrblnw','state changed','OS::Heat::Value',NULL,1469),(2440,'c3a1b4eb-c05d-4b16-8333-9f4c631ef36c','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:49',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ContainerPuppetTasks-hvcbwdxbopnu','state changed','OS::Heat::Value',NULL,1470),(2441,'13b53213-57fa-4f41-af3d-f25059626571','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:49',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ContainerPuppetTasks-hvcbwdxbopnu','state changed','OS::Heat::Value',NULL,1470),(2442,'9799a298-1e9c-46ad-bb8f-156205864ce2','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:49',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-PreDeployStepTasks-2mt5yfr4o56v','state changed','OS::Heat::Value',NULL,1471),(2443,'e9f95e13-38d4-4ebe-bca2-21e4c3434606','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:49',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-KollaConfig-jsfwmkii43uf','state changed','OS::Heat::Value',NULL,1472),(2444,'48e1ba7b-7974-4115-b411-62c6de2ce469','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:49',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-PreDeployStepTasks-2mt5yfr4o56v','state changed','OS::Heat::Value',NULL,1471),(2445,'9300e9d0-76b7-48c9-b43c-ae2848cb6363','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:50',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-KollaConfig-jsfwmkii43uf','state changed','OS::Heat::Value',NULL,1472),(2446,'7e22b173-1f87-4f14-b000-8323faf98d6b','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:50',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-UpgradeTasks-wugu3paopxgp','state changed','OS::Heat::Value',NULL,1473),(2447,'b10fa0ca-4ba4-40cc-aa6a-7f0114e2c3dc','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:50',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-UpgradeTasks-wugu3paopxgp','state changed','OS::Heat::Value',NULL,1473),(2448,'5208756e-7d91-4fa5-adcf-0e5fc5c1f1a2','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:50',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-DeployStepsTasks-s7iuvmunm6k3','state changed','OS::Heat::Value',NULL,1474),(2449,'be03310d-f5dd-470b-983f-afdcd9626f44','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:50',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-DeployStepsTasks-s7iuvmunm6k3','state changed','OS::Heat::Value',NULL,1474),(2450,'6e2f1a20-7144-480c-996a-4253ae4fd7fb','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:50',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceServerMetadataHook-vozfizxwkand','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,1475),(2451,'94b44b83-d852-4eec-918b-fa71064ce78c','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:50',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-HostFirewallTasks-o75hiesszmrd','state changed','OS::Heat::Value',NULL,1476),(2452,'484a5773-0fd8-4a9b-b3d7-145a3fb40be5','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:50',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-HostFirewallTasks-o75hiesszmrd','state changed','OS::Heat::Value',NULL,1476),(2453,'3c5f60bf-678e-448e-a522-e03003881de8','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:50',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ScaleTasks-ac4vchb5kiad','state changed','OS::Heat::Value',NULL,1477),(2454,'06404102-c9af-406d-a997-7231b60ea89f','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','2026-06-10 08:00:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceServerMetadataHook-vozfizxwkand','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2455,'1c36271a-6822-497e-a563-a735c816be65','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:51',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-ScaleTasks-ac4vchb5kiad','state changed','OS::Heat::Value',NULL,1477),(2456,'36b14599-2819-44ae-ab37-3a928f0d6222','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:51',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-HostPrepTasks-upbd7cuogoyb','state changed','OS::Heat::Value',NULL,1478),(2457,'2e7f5157-18ef-4381-9780-df019810e613','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:51',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-HostPrepTasks-upbd7cuogoyb','state changed','OS::Heat::Value',NULL,1478),(2458,'31e7f159-6ad0-4191-8d67-235d2733c4bb','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','2026-06-10 08:00:51',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceServerMetadataHook-vozfizxwkand-IncomingMetadataSettings-7n3wqougugmk','state changed','OS::Heat::Value',NULL,1479),(2459,'56bb4719-48e4-4910-9263-240b35eee229','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:51',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-PuppetConfig-br656mpijqnd','state changed','OS::Heat::Value',NULL,1480),(2460,'b0981954-4fd5-4c73-9a44-c5df346ec4c2','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:51',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-PuppetConfig-br656mpijqnd','state changed','OS::Heat::Value',NULL,1480),(2461,'cc58c9d1-9b64-47fe-95e8-7402f21a97d3','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','2026-06-10 08:00:51',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceServerMetadataHook-vozfizxwkand-IncomingMetadataSettings-7n3wqougugmk','state changed','OS::Heat::Value',NULL,1479),(2462,'746796ce-589b-4ab1-b717-26ef2b57f165','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:51',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-PuppetStepConfig-fn6zrqicbili','state changed','OS::Heat::Value',NULL,1481),(2463,'9a060430-d20c-4e22-968c-d19d37b9b5f9','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','2026-06-10 08:00:51',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceServerMetadataHook-vozfizxwkand-IndividualServices-lefuszy2narz','state changed','OS::Heat::Value',NULL,1482),(2464,'db5f2b90-f00e-439f-9af9-bada6273a58d','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:51',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-PuppetStepConfig-fn6zrqicbili','state changed','OS::Heat::Value',NULL,1481),(2465,'2d02bde2-a62d-460b-b1b0-1c7d6238216d','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','2026-06-10 08:00:51',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceServerMetadataHook-vozfizxwkand-IndividualServices-lefuszy2narz','state changed','OS::Heat::Value',NULL,1482),(2466,'1cba470f-2368-4193-9c62-952b39ec7cf0','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','2026-06-10 08:00:52',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceServerMetadataHook-vozfizxwkand-CompactServices-r5irirrxpads','state changed','OS::Heat::Value',NULL,1485),(2467,'ea2becd8-4a85-45e2-97a6-0022809061d3','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:52',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ControllerServiceChain-prlzcjjdciyj-FirewallFrontendRules-dlc5rvegrilh','state changed','OS::Heat::Value',NULL,1483),(2468,'e5374c70-9c14-4835-a4b5-b921301b90ef','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','2026-06-10 08:00:52',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceServerMetadataHook-vozfizxwkand-CompactServices-r5irirrxpads','state changed','OS::Heat::Value',NULL,1485),(2469,'4e086d78-a0bd-4081-8eeb-fc4150a9f970','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:52',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceNames-rqqnbsftbgkz','state changed','OS::Heat::Value',NULL,1486),(2470,'706e4801-0291-472b-b3ae-0c542a2faef1','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','2026-06-10 08:00:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceServerMetadataHook-vozfizxwkand','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2471,'78ac52d2-70ad-4e43-9900-6e0ce4ab1a7f','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:52',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ControllerServiceChain-prlzcjjdciyj-ServiceNames-rqqnbsftbgkz','state changed','OS::Heat::Value',NULL,1486),(2472,'86cd8c42-d995-4029-b75b-a2beb961f66f','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:52',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','b8768eac-244c-44f7-96eb-4dcbce0a3b2f','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,1475),(2473,'9ad9b720-6366-459f-9a67-a926dddd08d4','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:52',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ControllerServiceChain-prlzcjjdciyj-FirewallFrontendRules-dlc5rvegrilh','state changed','OS::Heat::Value',NULL,1483),(2474,'f23c7d1b-b5d3-4da9-8258-8b506112f6db','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:52',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ControllerServiceChain-prlzcjjdciyj-AnsibleGroupVars-b2icosegmgst','state changed','OS::Heat::Value',NULL,1487),(2475,'98eff19d-df5d-41c3-9e1c-6cd1f235508a','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:52',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ControllerServiceChain-prlzcjjdciyj-AnsibleGroupVars-b2icosegmgst','state changed','OS::Heat::Value',NULL,1487),(2476,'89377b33-3119-4f56-bffd-7a13f17994f5','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:53',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-DockerPuppetTasks-xv3ldxzffzu5','state changed','OS::Heat::Value',NULL,1488),(2477,'aa55f03f-d739-4a46-b16d-94ff7188651a','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:53',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ControllerServiceChain-prlzcjjdciyj-DockerConfigScripts-5mgjjcuf6voc','state changed','OS::Heat::Value',NULL,1489),(2478,'219a509a-aa00-4920-81ca-3def30d4b674','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:53',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ControllerServiceChain-prlzcjjdciyj-DockerConfigScripts-5mgjjcuf6voc','state changed','OS::Heat::Value',NULL,1489),(2479,'419af2e7-96ab-47f1-8f66-543cc48d6f22','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:53',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ControllerServiceChain-prlzcjjdciyj-DockerPuppetTasks-xv3ldxzffzu5','state changed','OS::Heat::Value',NULL,1488),(2480,'8e826593-b5c2-43cd-a277-5408e71ea84e','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:53',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-MonitoringSubscriptionsConfig-qg6evg4jboz5','state changed','OS::Heat::Value',NULL,1491),(2481,'00f09534-3f84-4516-92a1-54a7865f6f49','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:53',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-prlzcjjdciyj-MonitoringSubscriptionsConfig-qg6evg4jboz5','state changed','OS::Heat::Value',NULL,1491),(2482,'326775cd-a43b-4bd5-8af5-564e3e127fc7','c3125286-a4ec-445d-a8c0-75dff7f0790d','2026-06-10 08:00:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-prlzcjjdciyj','c3125286-a4ec-445d-a8c0-75dff7f0790d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2483,'df4881e9-31d5-48e7-83a3-7f1dd38fc253','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:54',NULL,'CREATE','COMPLETE','ControllerServiceChain','c3125286-a4ec-445d-a8c0-75dff7f0790d','state changed','OS::TripleO::ControllerServices',NULL,71),(2484,'62f91ca6-c398-4c6d-870c-36c138b8b6c8','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:55',NULL,'CREATE','IN_PROGRESS','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-lx4gicp6u27z','state changed','OS::Heat::Value',NULL,1527),(2485,'5a8c07e6-1877-4633-8194-a140df09d61f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:55',NULL,'CREATE','COMPLETE','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-lx4gicp6u27z','state changed','OS::Heat::Value',NULL,1527),(2486,'1f59fb18-aa34-4344-b69e-9ddef713ef86','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:55',NULL,'CREATE','IN_PROGRESS','GlobalConfig','overcloud-GlobalConfig-ijpfbrnlev3k','state changed','OS::Heat::Value',NULL,1528),(2487,'5300b51b-cd78-4f5b-b5cd-0f47a352c0a7','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:55',NULL,'CREATE','COMPLETE','GlobalConfig','overcloud-GlobalConfig-ijpfbrnlev3k','state changed','OS::Heat::Value',NULL,1528),(2488,'9540818f-1b23-484c-b5a2-9bb7629a3163','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:55',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-7u7bw7y2477k','state changed','OS::Heat::Value',NULL,1529),(2489,'6917b3d9-f5e9-4661-8886-255714866bf0','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:55',NULL,'CREATE','COMPLETE','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-7u7bw7y2477k','state changed','OS::Heat::Value',NULL,1529),(2490,'7bcf96e3-c300-4894-8aed-1971eace4bfb','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-elm4vzrbbfqt','state changed','OS::Heat::Value',NULL,1531),(2491,'139447e0-ae8d-44c0-8f78-f24d2a1db789','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','COMPLETE','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-elm4vzrbbfqt','state changed','OS::Heat::Value',NULL,1531),(2492,'2ade7fb7-aab8-4df3-a1c7-ada40c825cf5','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','IN_PROGRESS','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-56n3bsrzlhcd','state changed','OS::Heat::Value',NULL,1532),(2493,'34471f3b-7ac5-49fe-aad5-aaa2a0d5fb0e','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','COMPLETE','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-56n3bsrzlhcd','state changed','OS::Heat::Value',NULL,1532),(2494,'c1891dc5-1ab1-4683-9013-3df0d9224a58','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','IN_PROGRESS','BlockStorageConfigData','overcloud-BlockStorageConfigData-vdc26h36mqef','state changed','OS::Heat::Value',NULL,1534),(2495,'88fc2d18-d2d6-4123-b690-83b314c94986','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','COMPLETE','BlockStorageConfigData','overcloud-BlockStorageConfigData-vdc26h36mqef','state changed','OS::Heat::Value',NULL,1534),(2496,'3c359d13-768c-44d5-9c3f-606f9acdb08f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','IN_PROGRESS','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-crq6tbnzvtkt','state changed','OS::Heat::Value',NULL,1535),(2497,'a9fde2db-331d-4e59-a918-5e0f6b0dd54e','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','COMPLETE','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-crq6tbnzvtkt','state changed','OS::Heat::Value',NULL,1535),(2498,'6ea0257d-6539-4d50-89b7-9c20d159e48f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','IN_PROGRESS','ControllerServiceNames','overcloud-ControllerServiceNames-m3q5kra4wydv','state changed','OS::Heat::Value',NULL,1537),(2499,'036757d3-14c6-40d8-b76b-36d87ba098e2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','COMPLETE','ControllerServiceNames','overcloud-ControllerServiceNames-m3q5kra4wydv','state changed','OS::Heat::Value',NULL,1537),(2500,'e8aeb9be-ee60-4c16-a30d-11f5877a460b','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','IN_PROGRESS','ComputeConfigData','overcloud-ComputeConfigData-bll4tj3nzjel','state changed','OS::Heat::Value',NULL,1538),(2501,'14077b38-1954-4b9e-995b-d6b2980625ef','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','COMPLETE','ComputeConfigData','overcloud-ComputeConfigData-bll4tj3nzjel','state changed','OS::Heat::Value',NULL,1538),(2502,'0a2c0736-5c9d-42db-9ce5-58e0541a1a7c','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-55zuh23vqxrs','state changed','OS::Heat::ResourceGroup',NULL,1539),(2503,'ec84430e-0c6c-43cf-aa31-36ad2ff884bb','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:56',NULL,'CREATE','IN_PROGRESS','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-c3ya4upffwd4','state changed','OS::Heat::Value',NULL,1540),(2504,'6c3a37a9-0890-4f0c-ad59-0be4babf6e19','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-c3ya4upffwd4','state changed','OS::Heat::Value',NULL,1540),(2505,'134b4b0c-dfa5-4cb2-8b40-ced13855a395','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs','90c90c4b-219a-4516-bc79-f3dae115cb29','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2506,'89f48a08-51c2-47d4-91c7-4afadf54f6e2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-bimvcscfol6d','state changed','OS::Heat::Value',NULL,1542),(2507,'9fd5b41b-bfef-479c-977f-c32aca10c856','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-bimvcscfol6d','state changed','OS::Heat::Value',NULL,1542),(2508,'b3f88edd-22af-4a05-9639-ea3666dcb0f6','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs','90c90c4b-219a-4516-bc79-f3dae115cb29','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2509,'3fe82be8-25ca-4fde-b97c-f545883e51d7','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-lj6igtus23gt','state changed','OS::Heat::Value',NULL,1545),(2510,'231d9458-8cc9-461b-8589-a0103b34f49d','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','CephStorageConfigData','overcloud-CephStorageConfigData-hvfuze3ty4de','state changed','OS::Heat::Value',NULL,1543),(2511,'b98ba920-c1bd-4755-b858-6ef1cb7e16b5','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','CephStorageConfigData','overcloud-CephStorageConfigData-hvfuze3ty4de','state changed','OS::Heat::Value',NULL,1543),(2512,'2801c351-60d2-4b52-bfdc-929244651b35','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-lj6igtus23gt','state changed','OS::Heat::Value',NULL,1545),(2513,'f89fe7a2-b65a-43f8-a04f-a19cda15bc83','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-g7eivqr76g2u','state changed','OS::Heat::Value',NULL,1548),(2514,'7a91b63c-5a02-413a-a9eb-72809f76b191','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','ControllerConfigData','overcloud-ControllerConfigData-kq2sbx6diyz5','state changed','OS::Heat::Value',NULL,1549),(2515,'987a89a0-7a80-4334-988a-ba50fa169bb7','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','ControllerConfigData','overcloud-ControllerConfigData-kq2sbx6diyz5','state changed','OS::Heat::Value',NULL,1549),(2516,'ac19f90c-e737-439e-bf6a-8d308547f273','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-g7eivqr76g2u','state changed','OS::Heat::Value',NULL,1548),(2517,'44e5cd6e-611f-4d56-8608-a51114d65da5','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-iews4a2pds3z','state changed','OS::Heat::Value',NULL,1550),(2518,'3b7fd601-3d89-4c4b-b33e-fccb3fd474be','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-iews4a2pds3z','state changed','OS::Heat::Value',NULL,1550),(2519,'3ce4ae4c-a94d-4daf-9666-aeab094f0c84','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','NetworkerConfigData','overcloud-NetworkerConfigData-r3t7yd7f7x3l','state changed','OS::Heat::Value',NULL,1552),(2520,'cb8cea29-69a1-40fb-b30d-70047047b271','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','NetworkerConfigData','overcloud-NetworkerConfigData-r3t7yd7f7x3l','state changed','OS::Heat::Value',NULL,1552),(2521,'f1ca2cee-014a-4f44-8744-83adc229b256','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-FirewallFrontendRules-yqac424dxhx6','state changed','OS::Heat::Value',NULL,1553),(2522,'99a24a13-f348-4599-b8a0-9ab1fe911336','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-FirewallFrontendRules-yqac424dxhx6','state changed','OS::Heat::Value',NULL,1553),(2523,'065335be-c225-4756-9a12-b35bb5d7a1ac','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-6rg543kphx7j','state changed','OS::Heat::Value',NULL,1555),(2524,'8bab8369-3b91-40af-9975-092bb802de7f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','NetworkerGroupVars','overcloud-NetworkerGroupVars-prs53v34lwnb','state changed','OS::Heat::Value',NULL,1556),(2525,'6e721f58-ee90-4d34-a2b8-3f997dcc5b29','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','NetworkerGroupVars','overcloud-NetworkerGroupVars-prs53v34lwnb','state changed','OS::Heat::Value',NULL,1556),(2526,'b97ae346-1e9d-4be9-aac3-53daad68e7b6','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-wyf4pqyvckzj','state changed','OS::Heat::Value',NULL,1558),(2527,'9910362c-054d-4e1a-80d0-1738249eda0c','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-6rg543kphx7j','state changed','OS::Heat::Value',NULL,1555),(2528,'4f0c84d8-87b2-4389-8ec2-20d74adad8f0','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','IN_PROGRESS','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-ho5iswwrresy','state changed','OS::Heat::Value',NULL,1559),(2529,'8425f588-10eb-4921-9015-5e4eeb967e3f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:57',NULL,'CREATE','COMPLETE','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-ho5iswwrresy','state changed','OS::Heat::Value',NULL,1559),(2530,'ddfd1ba8-2323-4ec5-879a-7ef420bebb1f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','IN_PROGRESS','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-lbi2u3ik7icq','state changed','OS::Heat::Value',NULL,1557),(2531,'148022ea-9695-4785-8255-d287708b0042','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','IN_PROGRESS','CephStorageGroupVars','overcloud-CephStorageGroupVars-aldubm6udwaz','state changed','OS::Heat::Value',NULL,1560),(2532,'c8ad7dad-f484-44b1-ba99-b778b0e88f81','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','IN_PROGRESS','ComputeGroupVars','overcloud-ComputeGroupVars-3akjlgjuokvy','state changed','OS::Heat::Value',NULL,1561),(2533,'0c14c935-67eb-4d77-9b94-f316059564d9','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','COMPLETE','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-wyf4pqyvckzj','state changed','OS::Heat::Value',NULL,1558),(2534,'85fdef90-4f19-4d04-9c30-4a7184ad79ba','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','COMPLETE','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-lbi2u3ik7icq','state changed','OS::Heat::Value',NULL,1557),(2535,'5cac2279-d556-4b75-bd8e-4d5ebe707aa3','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','COMPLETE','ComputeGroupVars','overcloud-ComputeGroupVars-3akjlgjuokvy','state changed','OS::Heat::Value',NULL,1561),(2536,'8b55462e-7198-422c-ae70-fff3011a54f0','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','COMPLETE','CephStorageGroupVars','overcloud-CephStorageGroupVars-aldubm6udwaz','state changed','OS::Heat::Value',NULL,1560),(2537,'a5140d1e-13ab-4afc-9c24-a44775152abf','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','IN_PROGRESS','ControllerGroupVars','overcloud-ControllerGroupVars-f46mznsmcuks','state changed','OS::Heat::Value',NULL,1563),(2538,'58f0602d-d18c-4536-9a94-de22c90629bd','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','IN_PROGRESS','CellControllerConfigData','overcloud-CellControllerConfigData-f6cijyfyk53q','state changed','OS::Heat::Value',NULL,1565),(2539,'0d2ac2ce-d19b-4dc8-8bbe-5e6aef216a17','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','COMPLETE','ControllerGroupVars','overcloud-ControllerGroupVars-f46mznsmcuks','state changed','OS::Heat::Value',NULL,1563),(2540,'74a62570-6949-4499-9dbe-ae4637cb85f4','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','COMPLETE','CellControllerConfigData','overcloud-CellControllerConfigData-f6cijyfyk53q','state changed','OS::Heat::Value',NULL,1565),(2541,'aba87765-279c-402c-ab34-ac0c01d3b3f3','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','IN_PROGRESS','CellControllerGroupVars','overcloud-CellControllerGroupVars-r3e5sihxda4l','state changed','OS::Heat::Value',NULL,1566),(2542,'fd56f87e-f8ea-4b8a-9fe4-d27449e88160','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:00:58',NULL,'CREATE','COMPLETE','CellControllerGroupVars','overcloud-CellControllerGroupVars-r3e5sihxda4l','state changed','OS::Heat::Value',NULL,1566),(2543,'6732774c-5e98-46b7-bf27-c477bc862a2a','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:00:58',NULL,'UPDATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs','90c90c4b-219a-4516-bc79-f3dae115cb29','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(2544,'6ea199d5-f5be-4fda-81e3-284ba2a60ee2','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:00:58',NULL,'CREATE','IN_PROGRESS','1','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d','state changed','OS::TripleO::Controller',NULL,1567),(2545,'cfed1df4-9797-4367-8ac3-72931c1e039a','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:00:58',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d','d243713e-d905-46a4-9e33-e2334b1bc1ae','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2546,'e5f66021-430e-4a7c-9f32-a8a066cbe9cd','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:00:59',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-DeploymentActions-iuylufhswgox','state changed','OS::Heat::Value',NULL,1568),(2547,'c4b05be3-e3fa-40ad-9fb7-160ebcd8a5c3','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:00:59',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-DeploymentActions-iuylufhswgox','state changed','OS::Heat::Value',NULL,1568),(2548,'89bf5a62-b9f1-4782-9a92-d34f9b8afc1e','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:00:59',NULL,'CREATE','IN_PROGRESS','2','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h','state changed','OS::TripleO::Controller',NULL,1570),(2549,'fbb1bdf5-10e9-4665-9f6c-437438df0721','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:00:59',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2550,'ae1bbbfd-75c7-4076-aa1b-4f1f5d1498c3','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:00',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-DeploymentActions-onvaexdklgfd','state changed','OS::Heat::Value',NULL,1571),(2551,'2f94ca4f-c5d9-4a86-a253-568374d95732','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:00',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-DeploymentActions-onvaexdklgfd','state changed','OS::Heat::Value',NULL,1571),(2552,'926378b6-65fa-48d8-b96f-603f9093fbd5','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:00',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-Controller-bgginci7mlgb','state changed','OS::TripleO::ControllerServer',NULL,1573),(2553,'f59baad8-e682-4901-b8c4-4aa460c0696e','55de6f6b-f4c8-486a-9b39-6585b1b7f1eb','2026-06-10 08:01:00',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-Controller-bgginci7mlgb','55de6f6b-f4c8-486a-9b39-6585b1b7f1eb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2554,'117f3b9b-34ca-4b93-89a7-c5d8285a2cbb','55de6f6b-f4c8-486a-9b39-6585b1b7f1eb','2026-06-10 08:01:00',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-bgginci7mlgb-deployed-server-fejrgwaqnotc','state changed','OS::Heat::DeployedServer',NULL,1574),(2555,'d69d39ca-052b-4a73-8349-bd05ae4f82cc','55de6f6b-f4c8-486a-9b39-6585b1b7f1eb','2026-06-10 08:01:00',NULL,'CREATE','COMPLETE','deployed-server','8106ba62-3135-4291-9ce1-0382fc0b1df8','state changed','OS::Heat::DeployedServer',NULL,1574),(2556,'653b41b0-e579-4f3a-8f6c-7547c5f4eef9','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:01:00',NULL,'CREATE','IN_PROGRESS','0','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b','state changed','OS::TripleO::Controller',NULL,1575),(2557,'391e5865-9b97-4845-9af1-a5d89e6739aa','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:00',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2558,'1af07faa-2ade-4d4f-b703-a460e2333f6e','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:00',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-DeploymentActions-jq5zj36sipuj','state changed','OS::Heat::Value',NULL,1576),(2559,'b6b1aec6-4d73-4c42-8461-c2a02a4a4112','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:00',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-DeploymentActions-jq5zj36sipuj','state changed','OS::Heat::Value',NULL,1576),(2560,'bbbad115-d6e1-4067-97e0-1efe77042b44','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:01',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-Controller-sjecpjc4575f','state changed','OS::TripleO::ControllerServer',NULL,1577),(2561,'45365d9a-8659-4ffd-83a3-3220542d7966','50e1c302-f7f3-46d9-aad6-41e421be579d','2026-06-10 08:01:01',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-Controller-sjecpjc4575f','50e1c302-f7f3-46d9-aad6-41e421be579d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2562,'14a92b71-c796-406a-8f82-edcb82fd4a66','50e1c302-f7f3-46d9-aad6-41e421be579d','2026-06-10 08:01:01',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-sjecpjc4575f-deployed-server-jgnkkpk2jqlg','state changed','OS::Heat::DeployedServer',NULL,1579),(2563,'b025b3ac-317c-4315-be4b-c72777ec91a8','50e1c302-f7f3-46d9-aad6-41e421be579d','2026-06-10 08:01:01',NULL,'CREATE','COMPLETE','deployed-server','d5a4c166-aa53-4499-bcea-9d31876d3e5f','state changed','OS::Heat::DeployedServer',NULL,1579),(2564,'2cc270ec-250b-4489-894a-5bfe2c6576d0','55de6f6b-f4c8-486a-9b39-6585b1b7f1eb','2026-06-10 08:01:01',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-Controller-bgginci7mlgb-ControlPlanePort-pw4yc6q5syxx','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1580),(2565,'59b7c66b-4fb2-44bc-b3b3-46e3f93ab437','0c415c04-52e3-4a01-85d1-8f7e4d3a6ffd','2026-06-10 08:01:01',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-Controller-bgginci7mlgb-ControlPlanePort-pw4yc6q5syxx','0c415c04-52e3-4a01-85d1-8f7e4d3a6ffd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2566,'1a0be6e9-3890-497a-a154-33fde79c1df1','0c415c04-52e3-4a01-85d1-8f7e4d3a6ffd','2026-06-10 08:01:01',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-Controller-bgginci7mlgb-ControlPlanePort-pw4yc6q5syxx','0c415c04-52e3-4a01-85d1-8f7e4d3a6ffd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2567,'9facb0c0-5122-41cd-8afb-c8b7f68bb305','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:01',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-Controller-fdb5wercvsm3','state changed','OS::TripleO::ControllerServer',NULL,1581),(2568,'5e2c6919-6022-4b11-a270-9c6f41c4a802','3447bb75-fe8e-41d3-b7e5-15598b5019f7','2026-06-10 08:01:02',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-Controller-fdb5wercvsm3','3447bb75-fe8e-41d3-b7e5-15598b5019f7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2569,'5a84c05b-6b99-4b95-b678-c8bf9b0e2e76','3447bb75-fe8e-41d3-b7e5-15598b5019f7','2026-06-10 08:01:02',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-Controller-fdb5wercvsm3-ControlPlanePort-26zt5o74fw5c','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1582),(2570,'e79f067d-f83e-41c6-a3c8-668d62c3ffab','50e1c302-f7f3-46d9-aad6-41e421be579d','2026-06-10 08:01:02',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-Controller-sjecpjc4575f-ControlPlanePort-k5ruqozs4dpf','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1583),(2571,'d8fe7312-0076-4844-ab0a-d21fe4bce6f1','55132a8f-4b20-490c-b2ee-b650b46bd7c3','2026-06-10 08:01:02',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-Controller-sjecpjc4575f-ControlPlanePort-k5ruqozs4dpf','55132a8f-4b20-490c-b2ee-b650b46bd7c3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2572,'395dee5f-e387-4ebb-93cc-dc09acf9257d','71cf0fe2-349d-47a9-85f3-151bfbf41243','2026-06-10 08:01:02',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-Controller-fdb5wercvsm3-ControlPlanePort-26zt5o74fw5c','71cf0fe2-349d-47a9-85f3-151bfbf41243','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2573,'82c9ebd4-36b0-4075-a6d2-c4ea88104a76','55132a8f-4b20-490c-b2ee-b650b46bd7c3','2026-06-10 08:01:02',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-Controller-sjecpjc4575f-ControlPlanePort-k5ruqozs4dpf','55132a8f-4b20-490c-b2ee-b650b46bd7c3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2574,'5935521c-1649-4483-a303-1e3fec918e50','71cf0fe2-349d-47a9-85f3-151bfbf41243','2026-06-10 08:01:02',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-Controller-fdb5wercvsm3-ControlPlanePort-26zt5o74fw5c','71cf0fe2-349d-47a9-85f3-151bfbf41243','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2575,'9053d7dc-ed49-43d8-8b7e-528eeca282f6','55de6f6b-f4c8-486a-9b39-6585b1b7f1eb','2026-06-10 08:01:02',NULL,'CREATE','COMPLETE','ControlPlanePort','0c415c04-52e3-4a01-85d1-8f7e4d3a6ffd','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1580),(2576,'fa6f66b4-cec2-4f1c-92a9-dc889ef302ad','55de6f6b-f4c8-486a-9b39-6585b1b7f1eb','2026-06-10 08:01:02',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-Controller-bgginci7mlgb','55de6f6b-f4c8-486a-9b39-6585b1b7f1eb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2577,'f9ddb967-5f3b-49b0-b87d-8f53adedc192','3447bb75-fe8e-41d3-b7e5-15598b5019f7','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-fdb5wercvsm3-deployed-server-ubgtpgrcej2d','state changed','OS::Heat::DeployedServer',NULL,1584),(2578,'9d7adab0-a8a0-4d7e-9af5-e7cfcad05d5d','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','Controller','55de6f6b-f4c8-486a-9b39-6585b1b7f1eb','state changed','OS::TripleO::ControllerServer',NULL,1573),(2579,'377e3772-b4bd-4a68-ab8a-bfc2a8ceaf4d','3447bb75-fe8e-41d3-b7e5-15598b5019f7','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','deployed-server','a2222743-d379-4a04-9f5f-3193eec06992','state changed','OS::Heat::DeployedServer',NULL,1584),(2580,'be3f44f7-daf9-4902-98ac-67fe740fc401','50e1c302-f7f3-46d9-aad6-41e421be579d','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','ControlPlanePort','55132a8f-4b20-490c-b2ee-b650b46bd7c3','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1583),(2581,'f1da5ca4-c06b-4a8c-8b3c-e1c9380b5767','3447bb75-fe8e-41d3-b7e5-15598b5019f7','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','ControlPlanePort','71cf0fe2-349d-47a9-85f3-151bfbf41243','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1582),(2582,'3a633857-d4a8-48d8-9799-e4673de1ace1','50e1c302-f7f3-46d9-aad6-41e421be579d','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-Controller-sjecpjc4575f','50e1c302-f7f3-46d9-aad6-41e421be579d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2583,'cab00c58-cb87-4541-915f-99a2a3e85fac','3447bb75-fe8e-41d3-b7e5-15598b5019f7','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-Controller-fdb5wercvsm3','3447bb75-fe8e-41d3-b7e5-15598b5019f7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2584,'1664ff2d-9200-4063-82c6-1d807fa5f8aa','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StoragePort-2oxupqbjipar','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1586),(2585,'49dffbd1-5e54-4003-a155-ebd7b27496b6','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ExternalPort-ry42jx3sql2c','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1587),(2586,'e5f9afde-817d-4e11-a45a-2188a4db3ace','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-InternalApiPort-s3iezej55rm2','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1589),(2587,'3e978619-f91c-491f-84f3-3ed44dc254e6','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NetHostMap-7vut4zr56lcj','state changed','OS::Heat::Value',NULL,1590),(2588,'2cd6c3f2-e329-4368-8b89-b8a18670c534','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ControllerExtraConfigPre-bx2pd3unlvru','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1588),(2589,'7063e345-6078-456f-91d7-2df9601336e4','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StorageMgmtPort-xus57fyov7i7','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1591),(2590,'092fa5b6-dfe6-49f6-aae8-590dc77bc9ad','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NetHostMap-7vut4zr56lcj','state changed','OS::Heat::Value',NULL,1590),(2591,'530b7ee9-20d9-490c-a390-d80b66d401e6','a29a9c3b-fc3a-496e-83d5-3fbf70ab93c4','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StoragePort-2oxupqbjipar','a29a9c3b-fc3a-496e-83d5-3fbf70ab93c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2592,'96ace52d-8764-4b14-a23e-53ad5a568c6f','940c8177-e1a1-4517-a003-9ac20a96faf1','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ExternalPort-ry42jx3sql2c','940c8177-e1a1-4517-a003-9ac20a96faf1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2593,'cb8846ae-7688-4cbb-941e-d9cd81576ab8','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-TenantPort-2qylwijmsf3y','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1592),(2594,'9ee9a885-94ab-4456-8c3a-ab651bf570d8','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NodeTLSCAData-lnhjbuqdocmh','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2595,'79a764c6-95d2-4141-af8f-4c4db4510a67','3dfe19d9-988c-4665-a8c4-059fcd5ecbd2','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ControllerExtraConfigPre-bx2pd3unlvru','3dfe19d9-988c-4665-a8c4-059fcd5ecbd2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2596,'80c7e158-d00c-4f78-a5e7-84aff1198deb','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-PreNetworkConfig-ldrppxjthzfn','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2597,'14ee0321-3522-4421-bbc6-af779d13626f','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','NodeTLSCAData','184e6765-d686-450e-adbe-a08af9a5fd99','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2598,'244821f3-5f65-49c3-9276-9969be85007b','3dfe19d9-988c-4665-a8c4-059fcd5ecbd2','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ControllerExtraConfigPre-bx2pd3unlvru','3dfe19d9-988c-4665-a8c4-059fcd5ecbd2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2599,'fda753ab-e980-42b8-9700-d64f62ccd067','33cbc1f5-12d1-405e-a769-19dfa1057ddf','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StorageMgmtPort-xus57fyov7i7','33cbc1f5-12d1-405e-a769-19dfa1057ddf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2600,'a71c968d-bbec-4029-aadb-fbe9ca22798a','ba4b6863-56cb-4f9a-8109-a14a4ee1c3e3','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-TenantPort-2qylwijmsf3y','ba4b6863-56cb-4f9a-8109-a14a4ee1c3e3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2601,'c79881b9-20e2-4874-a2b9-4e9494a566df','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','PreNetworkConfig','5bee1a86-e94b-41e0-a299-a2a4c8de6b9e','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2602,'8d201ccb-fba5-49e0-b697-74147de1fee5','5bc5ab90-d285-42ad-ad6d-52009703043c','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-InternalApiPort-s3iezej55rm2','5bc5ab90-d285-42ad-ad6d-52009703043c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2603,'aae70874-a55a-43ac-8f71-6998eaf61164','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ControllerAnsibleHostVars-2rupscfvunya','state changed','OS::Heat::Value',NULL,1595),(2604,'ab51fd76-c04a-4440-ac45-7f01af2474d2','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ControllerAnsibleHostVars-2rupscfvunya','state changed','OS::Heat::Value',NULL,1595),(2605,'a323d3e8-a609-4a36-a436-46070fe15421','940c8177-e1a1-4517-a003-9ac20a96faf1','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ExternalPort-ry42jx3sql2c-ExternalDeployedPort-k4w26aee2n47','state changed','OS::Heat::Value',NULL,1596),(2606,'698629cf-de77-4e4b-94f6-f9242a9fe4f8','a29a9c3b-fc3a-496e-83d5-3fbf70ab93c4','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StoragePort-2oxupqbjipar-StorageDeployedPort-ukzsciieolgs','state changed','OS::Heat::Value',NULL,1597),(2607,'5998923f-0e58-4a23-82e2-004d7250b5fa','940c8177-e1a1-4517-a003-9ac20a96faf1','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ExternalPort-ry42jx3sql2c-ExternalDeployedPort-k4w26aee2n47','state changed','OS::Heat::Value',NULL,1596),(2608,'7ff9965e-89c6-45b5-9c74-c8ccc5c8b762','a29a9c3b-fc3a-496e-83d5-3fbf70ab93c4','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StoragePort-2oxupqbjipar-StorageDeployedPort-ukzsciieolgs','state changed','OS::Heat::Value',NULL,1597),(2609,'350ae85d-4193-40fd-8511-d3543484d5e0','940c8177-e1a1-4517-a003-9ac20a96faf1','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-ExternalPort-ry42jx3sql2c','940c8177-e1a1-4517-a003-9ac20a96faf1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2610,'a757f026-4357-4195-bc41-5bb229d00857','a29a9c3b-fc3a-496e-83d5-3fbf70ab93c4','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StoragePort-2oxupqbjipar','a29a9c3b-fc3a-496e-83d5-3fbf70ab93c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2611,'3fc66576-ef46-438d-afca-8836ecce9b55','5bc5ab90-d285-42ad-ad6d-52009703043c','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-InternalApiPort-s3iezej55rm2-InternalApiDeployedPort-pumrftrhsd7h','state changed','OS::Heat::Value',NULL,1598),(2612,'0170e051-c4f7-4989-82e6-3948cde4c947','33cbc1f5-12d1-405e-a769-19dfa1057ddf','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StorageMgmtPort-xus57fyov7i7-StorageMgmtDeployedPort-uj6a27fiol7j','state changed','OS::Heat::Value',NULL,1599),(2613,'471dec39-478d-43ce-ac4b-e07edd816a70','ba4b6863-56cb-4f9a-8109-a14a4ee1c3e3','2026-06-10 08:01:03',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-TenantPort-2qylwijmsf3y-TenantDeployedPort-sjdnwqixxkmr','state changed','OS::Heat::Value',NULL,1600),(2614,'6298121e-3174-45b6-a8b9-fd3775124b1a','5bc5ab90-d285-42ad-ad6d-52009703043c','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-InternalApiPort-s3iezej55rm2-InternalApiDeployedPort-pumrftrhsd7h','state changed','OS::Heat::Value',NULL,1598),(2615,'0d25f24b-b833-49bc-b1f5-0817ee4875e6','33cbc1f5-12d1-405e-a769-19dfa1057ddf','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StorageMgmtPort-xus57fyov7i7-StorageMgmtDeployedPort-uj6a27fiol7j','state changed','OS::Heat::Value',NULL,1599),(2616,'c4e11cc0-7266-4552-b8d3-b43be9ef0408','ba4b6863-56cb-4f9a-8109-a14a4ee1c3e3','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-TenantPort-2qylwijmsf3y-TenantDeployedPort-sjdnwqixxkmr','state changed','OS::Heat::Value',NULL,1600),(2617,'ac022ec3-f56a-486b-ba69-f467ed4ed654','33cbc1f5-12d1-405e-a769-19dfa1057ddf','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-StorageMgmtPort-xus57fyov7i7','33cbc1f5-12d1-405e-a769-19dfa1057ddf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2618,'571dd12b-6c36-4392-b910-37c6c470f6b2','ba4b6863-56cb-4f9a-8109-a14a4ee1c3e3','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-TenantPort-2qylwijmsf3y','ba4b6863-56cb-4f9a-8109-a14a4ee1c3e3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2619,'bf370116-8b32-4685-8d24-00621e3c9249','5bc5ab90-d285-42ad-ad6d-52009703043c','2026-06-10 08:01:03',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-InternalApiPort-s3iezej55rm2','5bc5ab90-d285-42ad-ad6d-52009703043c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2620,'5fcfdbe0-c413-445d-865e-615ad541be28','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','Controller','3447bb75-fe8e-41d3-b7e5-15598b5019f7','state changed','OS::TripleO::ControllerServer',NULL,1581),(2621,'2fbe126f-c96f-401b-b0d3-7ac230cb77d3','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','Controller','50e1c302-f7f3-46d9-aad6-41e421be579d','state changed','OS::TripleO::ControllerServer',NULL,1577),(2622,'1040e22d-fb32-455d-9b03-9589bc8bc3c5','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NodeTLSCAData-b5wakfd22o6s','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2623,'7858d871-187f-45af-9941-dac1426c4b06','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','NodeTLSCAData','25157915-f145-4482-b18d-47070a71fce8','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2624,'3263e430-e6e7-4b48-b6ec-ea50723b3394','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StorageMgmtPort-bktozfzctyts','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1603),(2625,'d80512e5-6ea2-45f0-8a9b-b6213a6ed49a','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-InternalApiPort-6tsrypdhkojw','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1604),(2626,'61a93d97-5d81-41f9-9ce0-9bf6d5ac8ddd','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NetHostMap-2wkquzzaghvq','state changed','OS::Heat::Value',NULL,1605),(2627,'198ddbfe-6fb3-47a9-b2db-53d27c987fb4','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-TenantPort-46ixfuwjfziu','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1606),(2628,'3027a7f9-30de-407e-8586-4d43263d899b','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NetHostMap-2wkquzzaghvq','state changed','OS::Heat::Value',NULL,1605),(2629,'6fca8f88-8416-4efe-851c-7e7c0989a2d4','528cf6e8-1ac7-46d0-955a-ca4691140498','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StorageMgmtPort-bktozfzctyts','528cf6e8-1ac7-46d0-955a-ca4691140498','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2630,'6a7cd28e-9497-4147-b145-2cff08f82925','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ControllerExtraConfigPre-vbs56ywt5lph','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1607),(2631,'b2d939f5-b9d1-48a4-8d51-c98c76b84c12','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StoragePort-q5y4kxpdab3w','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1608),(2632,'c285c6fe-499a-47bb-ba84-f56714d51613','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-PreNetworkConfig-o375tfe7acj6','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2633,'ee0e7106-4170-4b00-a647-445faf3b5afb','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StorageMgmtPort-gycq74gz4nis','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1610),(2634,'ca1d6e51-f884-4218-832b-a0dadaa4b81a','1072e117-1627-45d5-9944-f6d2ba5e12c0','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-InternalApiPort-6tsrypdhkojw','1072e117-1627-45d5-9944-f6d2ba5e12c0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2635,'7170a434-c209-4366-a3dd-e4943e3501f0','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-PreNetworkConfig-e56jrezpiin7','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2636,'e7046785-2a23-4776-82d7-dabe6580a90a','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StoragePort-yyklmbmdbgvo','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1612),(2637,'8245f98f-3998-4783-aa32-db19646ed0b5','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ControllerAnsibleHostVars-4e24fd6odxou','state changed','OS::Heat::Value',NULL,1611),(2638,'513862fe-4cc7-4528-8ef7-33bbd7f267b3','d9e2d7a9-2c39-46e2-9dc9-7fdec6c0c00e','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-TenantPort-46ixfuwjfziu','d9e2d7a9-2c39-46e2-9dc9-7fdec6c0c00e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2639,'8a00547d-810e-4b31-99b0-978c5dd9f2f7','ccc4083b-a932-4565-abfb-01ffefa6bd58','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StoragePort-q5y4kxpdab3w','ccc4083b-a932-4565-abfb-01ffefa6bd58','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2640,'a95f9750-4fa3-4571-b0fc-0c30c9c48844','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','PreNetworkConfig','9dda2e38-3c45-41b6-9ccc-75e6e20407f9','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2641,'1e997c3b-773f-4c36-a013-f4ab14cf8f5c','3fe74e7f-fc3b-433b-8fdc-9e2ed4b4cc85','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ControllerExtraConfigPre-vbs56ywt5lph','3fe74e7f-fc3b-433b-8fdc-9e2ed4b4cc85','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2642,'d66f7771-5f56-4213-85e7-1e37bae6ec6e','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','PreNetworkConfig','fd0854b0-7e11-4b43-b1b6-d11a689e05fa','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2643,'6337b5a6-640c-43ad-adab-1c0bf984214d','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ControllerAnsibleHostVars-4e24fd6odxou','state changed','OS::Heat::Value',NULL,1611),(2644,'bd8bbeb8-91aa-444c-8a9b-d8f8cd36632f','74079544-1820-440c-82f0-5ea903233730','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StorageMgmtPort-gycq74gz4nis','74079544-1820-440c-82f0-5ea903233730','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2645,'1be44e05-a1ae-4d5c-89bd-d5a9f62aac22','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NetHostMap-26zgtauyz3e6','state changed','OS::Heat::Value',NULL,1613),(2646,'2e7542d5-2b1b-4e76-b67a-1afcd2e8ce90','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NodeTLSCAData-uclb3vnxorc3','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2647,'abc1519d-97d8-48af-bd00-f565a2496a0a','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-TenantPort-zz52ddqfcfil','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1615),(2648,'5678c042-00e7-485a-a964-3be192897a92','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','3dfe19d9-988c-4665-a8c4-059fcd5ecbd2','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1588),(2649,'e3cdff77-b7b0-49c3-80bc-f0699624c950','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ExternalPort-742s7mswjort','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1614),(2650,'79b00016-aebe-46eb-a244-3b5a6fb06cb4','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','StoragePort','a29a9c3b-fc3a-496e-83d5-3fbf70ab93c4','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1586),(2651,'0f7e50d3-e8c6-4909-a2f4-337bead73ecf','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','NodeTLSCAData','21bc4901-0c1f-4c24-bff7-63250aede9ec','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2652,'b5783a59-addd-49f5-8a5f-2952eebffea2','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ControllerExtraConfigPre-kkx47nsh3kf5','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1617),(2653,'05acc5c1-b1fc-40b7-b509-75e87a9118fd','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NetHostMap-26zgtauyz3e6','state changed','OS::Heat::Value',NULL,1613),(2654,'aaf997e0-830b-490a-9228-a2682417b96b','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','InternalApiPort','5bc5ab90-d285-42ad-ad6d-52009703043c','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1589),(2655,'cfca85be-200a-4700-832c-9919de010a21','3fe74e7f-fc3b-433b-8fdc-9e2ed4b4cc85','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ControllerExtraConfigPre-vbs56ywt5lph','3fe74e7f-fc3b-433b-8fdc-9e2ed4b4cc85','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2656,'1dddac80-5c27-4a4a-8ecf-47c5a3088c4c','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','StorageMgmtPort','33cbc1f5-12d1-405e-a769-19dfa1057ddf','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1591),(2657,'91647428-8ae4-4e24-a1fa-092dc446a172','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','ExternalPort','940c8177-e1a1-4517-a003-9ac20a96faf1','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1587),(2658,'57f4af7b-66c6-4ff1-a483-b9bb237aa1fe','528cf6e8-1ac7-46d0-955a-ca4691140498','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StorageMgmtPort-bktozfzctyts-StorageMgmtDeployedPort-uprowbjtrrqj','state changed','OS::Heat::Value',NULL,1620),(2659,'c2dfa7b1-1bc8-463e-a860-6d6447b163cf','cb80d84f-643c-42e8-b287-ad6be6d8f116','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StoragePort-yyklmbmdbgvo','cb80d84f-643c-42e8-b287-ad6be6d8f116','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2660,'7b80f2db-eaad-4f39-8689-cbf297329b75','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','TenantPort','ba4b6863-56cb-4f9a-8109-a14a4ee1c3e3','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1592),(2661,'b5e49411-c9e0-4858-bc7d-75cd67a3a317','ccc4083b-a932-4565-abfb-01ffefa6bd58','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StoragePort-q5y4kxpdab3w-StorageDeployedPort-kyyiupqjecq7','state changed','OS::Heat::Value',NULL,1621),(2662,'89f0535c-d695-439f-9a73-9c52c9926b7d','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NodeExtraConfig-c23tzga6tq65','state changed','OS::TripleO::NodeExtraConfig',NULL,1619),(2663,'3f6b8f48-1e01-4dde-80f3-6de605c4ceb8','1072e117-1627-45d5-9944-f6d2ba5e12c0','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-InternalApiPort-6tsrypdhkojw-InternalApiDeployedPort-eogahhj67snt','state changed','OS::Heat::Value',NULL,1624),(2664,'d782eb00-ea6d-4a96-b2cb-1977e157144a','f862e068-f010-44a0-9672-5c2935674150','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-TenantPort-zz52ddqfcfil','f862e068-f010-44a0-9672-5c2935674150','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2665,'87a85520-3dbd-4de7-9064-2d1e62596a3a','ccc4083b-a932-4565-abfb-01ffefa6bd58','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StoragePort-q5y4kxpdab3w-StorageDeployedPort-kyyiupqjecq7','state changed','OS::Heat::Value',NULL,1621),(2666,'832f6f1d-0b31-47e2-b7d8-7404546b27a2','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ExternalPort-pwmv3mtjicx6','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1628),(2667,'7b564898-f8e8-4585-8e09-7b908638a5d3','efb70594-bac2-4a41-bf41-1a9543f8c540','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ControllerExtraConfigPre-kkx47nsh3kf5','efb70594-bac2-4a41-bf41-1a9543f8c540','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2668,'d22311a2-1d33-4f18-b13b-7c07ae6ee708','1072e117-1627-45d5-9944-f6d2ba5e12c0','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-InternalApiPort-6tsrypdhkojw-InternalApiDeployedPort-eogahhj67snt','state changed','OS::Heat::Value',NULL,1624),(2669,'14a807a5-41f8-43e1-a145-574df550cacc','74079544-1820-440c-82f0-5ea903233730','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StorageMgmtPort-gycq74gz4nis-StorageMgmtDeployedPort-5ddqiadua6zs','state changed','OS::Heat::Value',NULL,1629),(2670,'bb410db8-37d5-4315-9504-b94d2b1c80e9','6c207cd2-d08b-4fb9-9398-5ccf4c26e61d','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ExternalPort-742s7mswjort','6c207cd2-d08b-4fb9-9398-5ccf4c26e61d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2671,'24d9dc7c-824e-4218-a0ee-6352e4d26b6c','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ControllerAnsibleHostVars-fjuuhe44o5op','state changed','OS::Heat::Value',NULL,1631),(2672,'eb9604b5-e8f1-431d-9e01-daa16d3fda2d','ccc4083b-a932-4565-abfb-01ffefa6bd58','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StoragePort-q5y4kxpdab3w','ccc4083b-a932-4565-abfb-01ffefa6bd58','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2673,'d2764fe3-319c-409d-8fca-2a653ac0ea32','efb70594-bac2-4a41-bf41-1a9543f8c540','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ControllerExtraConfigPre-kkx47nsh3kf5','efb70594-bac2-4a41-bf41-1a9543f8c540','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2674,'9a86ea6b-bd62-4a6a-b736-1c2cb3a413da','1072e117-1627-45d5-9944-f6d2ba5e12c0','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-InternalApiPort-6tsrypdhkojw','1072e117-1627-45d5-9944-f6d2ba5e12c0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2675,'26f60b1e-2562-42dc-a7af-57507ae5ceee','74079544-1820-440c-82f0-5ea903233730','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StorageMgmtPort-gycq74gz4nis-StorageMgmtDeployedPort-5ddqiadua6zs','state changed','OS::Heat::Value',NULL,1629),(2676,'be139fd9-1898-4e54-8b71-a8676583d3d3','03746057-2006-430b-b38c-87b676cf0690','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NodeExtraConfig-c23tzga6tq65','03746057-2006-430b-b38c-87b676cf0690','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2677,'2270af71-6673-493b-ba3c-dd24b23e610b','b79026ac-0242-4b36-8a64-6dbc3fc08ff5','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ExternalPort-pwmv3mtjicx6','b79026ac-0242-4b36-8a64-6dbc3fc08ff5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2678,'a5e419d3-f13d-4f59-9fba-9bd054809dbf','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ControllerAnsibleHostVars-fjuuhe44o5op','state changed','OS::Heat::Value',NULL,1631),(2679,'5116af99-f6b8-4fcc-8d04-edf3db74a384','74079544-1820-440c-82f0-5ea903233730','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StorageMgmtPort-gycq74gz4nis','74079544-1820-440c-82f0-5ea903233730','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2680,'2627c5de-cdc2-4acc-9a97-639e32496f8f','03746057-2006-430b-b38c-87b676cf0690','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NodeExtraConfig-c23tzga6tq65','03746057-2006-430b-b38c-87b676cf0690','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2681,'e1add2a2-ab1c-4281-bb6e-85f80f0953a7','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-InternalApiPort-dowdyf6g67lg','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1632),(2682,'c4bce252-eb84-4cc6-93de-be1735115684','d9e2d7a9-2c39-46e2-9dc9-7fdec6c0c00e','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-TenantPort-46ixfuwjfziu-TenantDeployedPort-hn5gx4yjqrew','state changed','OS::Heat::Value',NULL,1636),(2683,'376b003f-223d-4b67-9548-ccd192d6cb08','528cf6e8-1ac7-46d0-955a-ca4691140498','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StorageMgmtPort-bktozfzctyts-StorageMgmtDeployedPort-uprowbjtrrqj','state changed','OS::Heat::Value',NULL,1620),(2684,'a0d2fa6a-8197-463f-af73-6f227e993705','d9e2d7a9-2c39-46e2-9dc9-7fdec6c0c00e','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-TenantPort-46ixfuwjfziu-TenantDeployedPort-hn5gx4yjqrew','state changed','OS::Heat::Value',NULL,1636),(2685,'6229838a-59fd-42ba-8865-71fff93c7cef','6c207cd2-d08b-4fb9-9398-5ccf4c26e61d','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ExternalPort-742s7mswjort-ExternalDeployedPort-iburk457d53y','state changed','OS::Heat::Value',NULL,1637),(2686,'205b97ed-7636-4167-a875-491c5378fe2b','d9e2d7a9-2c39-46e2-9dc9-7fdec6c0c00e','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-TenantPort-46ixfuwjfziu','d9e2d7a9-2c39-46e2-9dc9-7fdec6c0c00e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2687,'720777dc-5fd3-4891-8637-1a01c2a67293','b79026ac-0242-4b36-8a64-6dbc3fc08ff5','2026-06-10 08:01:04',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ExternalPort-pwmv3mtjicx6-ExternalDeployedPort-ccgck3oq2z45','state changed','OS::Heat::Value',NULL,1638),(2688,'f13245a6-787b-4ecd-a4e1-0209faabb787','6c207cd2-d08b-4fb9-9398-5ccf4c26e61d','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ExternalPort-742s7mswjort-ExternalDeployedPort-iburk457d53y','state changed','OS::Heat::Value',NULL,1637),(2689,'86a5eab0-2ed4-49d9-b71b-c251db9631b5','b79026ac-0242-4b36-8a64-6dbc3fc08ff5','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ExternalPort-pwmv3mtjicx6-ExternalDeployedPort-ccgck3oq2z45','state changed','OS::Heat::Value',NULL,1638),(2690,'874c39b1-c7e1-4cc6-80a7-10a67bd45b42','6c207cd2-d08b-4fb9-9398-5ccf4c26e61d','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-ExternalPort-742s7mswjort','6c207cd2-d08b-4fb9-9398-5ccf4c26e61d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2691,'b373b826-30c5-4f1e-8354-c64bf4a4c107','b79026ac-0242-4b36-8a64-6dbc3fc08ff5','2026-06-10 08:01:04',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-ExternalPort-pwmv3mtjicx6','b79026ac-0242-4b36-8a64-6dbc3fc08ff5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2692,'4d4582f6-5c23-4c21-94a0-5da1055ccb62','19d5afd1-4880-4878-b358-d3b404ed53ef','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-InternalApiPort-dowdyf6g67lg','19d5afd1-4880-4878-b358-d3b404ed53ef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2693,'8dc5058f-4d9a-43f7-8bde-ef8fa5e70659','f862e068-f010-44a0-9672-5c2935674150','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-TenantPort-zz52ddqfcfil-TenantDeployedPort-ydu33jwxnfo2','state changed','OS::Heat::Value',NULL,1642),(2694,'091ebdb5-a1f4-4322-bf8f-5989dbf9c348','528cf6e8-1ac7-46d0-955a-ca4691140498','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-StorageMgmtPort-bktozfzctyts','528cf6e8-1ac7-46d0-955a-ca4691140498','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2695,'71be0b15-91a8-4ed2-99ea-cf1ed9b3362e','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NetIpMap-pnpvasswyuwk','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1643),(2696,'0ce9bad5-7640-4244-9ff4-d521e389edbc','f862e068-f010-44a0-9672-5c2935674150','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-TenantPort-zz52ddqfcfil-TenantDeployedPort-ydu33jwxnfo2','state changed','OS::Heat::Value',NULL,1642),(2697,'e61be233-b131-4306-a5a2-4fee9415742d','19d5afd1-4880-4878-b358-d3b404ed53ef','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-InternalApiPort-dowdyf6g67lg-InternalApiDeployedPort-slqcirvsy5vr','state changed','OS::Heat::Value',NULL,1644),(2698,'3a4f6ca2-2f74-4166-a0f2-1796f2f0cd29','f862e068-f010-44a0-9672-5c2935674150','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-TenantPort-zz52ddqfcfil','f862e068-f010-44a0-9672-5c2935674150','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2699,'88c81942-e179-40c3-bec7-94f9b2f53b60','4076c7fb-aa98-491e-9101-a79f4f4014bf','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NetIpMap-pnpvasswyuwk','4076c7fb-aa98-491e-9101-a79f4f4014bf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2700,'5ae78c96-a225-4e66-a460-dc2ee18fede8','19d5afd1-4880-4878-b358-d3b404ed53ef','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-InternalApiPort-dowdyf6g67lg-InternalApiDeployedPort-slqcirvsy5vr','state changed','OS::Heat::Value',NULL,1644),(2701,'d63ba5b7-7efa-4bf6-9624-588ec96ce28d','cb80d84f-643c-42e8-b287-ad6be6d8f116','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StoragePort-yyklmbmdbgvo-StorageDeployedPort-5ixgiztg4sjg','state changed','OS::Heat::Value',NULL,1645),(2702,'ba6d0833-8927-4186-a5b5-389a3e9d9f27','cb80d84f-643c-42e8-b287-ad6be6d8f116','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StoragePort-yyklmbmdbgvo-StorageDeployedPort-5ixgiztg4sjg','state changed','OS::Heat::Value',NULL,1645),(2703,'7eef06f0-bf5b-457e-b43d-fc467ee8b803','19d5afd1-4880-4878-b358-d3b404ed53ef','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-InternalApiPort-dowdyf6g67lg','19d5afd1-4880-4878-b358-d3b404ed53ef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2704,'8fd5ecb7-ab2a-4db5-a05c-332d01fbb810','cb80d84f-643c-42e8-b287-ad6be6d8f116','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-StoragePort-yyklmbmdbgvo','cb80d84f-643c-42e8-b287-ad6be6d8f116','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2705,'94eddfa2-8ed6-42a0-a4cf-e2f679595a19','4076c7fb-aa98-491e-9101-a79f4f4014bf','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NetIpMap-pnpvasswyuwk-NetIpMapValue-35narxn5nggf','state changed','OS::Heat::Value',NULL,1646),(2706,'2b8bd08e-a60d-4b12-92f2-b5ec1dc06929','4076c7fb-aa98-491e-9101-a79f4f4014bf','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NetIpMap-pnpvasswyuwk-NetIpMapValue-35narxn5nggf','state changed','OS::Heat::Value',NULL,1646),(2707,'d01d60ff-d431-4808-ac76-60b3267005da','4076c7fb-aa98-491e-9101-a79f4f4014bf','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d-NetIpMap-pnpvasswyuwk','4076c7fb-aa98-491e-9101-a79f4f4014bf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2708,'ffa3a48e-8934-4c70-87e5-f4cddd569773','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','StorageMgmtPort','528cf6e8-1ac7-46d0-955a-ca4691140498','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1603),(2709,'912154d0-8b86-43b0-aca3-58523b2013e3','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','InternalApiPort','1072e117-1627-45d5-9944-f6d2ba5e12c0','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1604),(2710,'c6715bee-e60c-43d9-8c66-64dbc1d5e1cf','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','StoragePort','ccc4083b-a932-4565-abfb-01ffefa6bd58','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1608),(2711,'c2053edb-64a3-4817-8761-b826d1c37c80','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','TenantPort','d9e2d7a9-2c39-46e2-9dc9-7fdec6c0c00e','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1606),(2712,'442736c8-64e9-4831-b7fc-8bb3424fafa7','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','3fe74e7f-fc3b-433b-8fdc-9e2ed4b4cc85','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1607),(2713,'6357db85-b2cd-427d-9d95-3711327ea361','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','StorageMgmtPort','74079544-1820-440c-82f0-5ea903233730','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1610),(2714,'3bde1615-2a9d-47c0-b1e4-01d1b6353def','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NodeExtraConfig-fhy4dmyz5ks3','state changed','OS::TripleO::NodeExtraConfig',NULL,1656),(2715,'7ce40a91-8e20-425e-8f0e-fc96b7c7f549','2fd59280-e4f7-473c-894b-fd2ac4e0cd83','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NodeExtraConfig-fhy4dmyz5ks3','2fd59280-e4f7-473c-894b-fd2ac4e0cd83','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2716,'dc1daeaa-0a0c-4f47-886e-dfbb9f071599','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','TenantPort','f862e068-f010-44a0-9672-5c2935674150','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1615),(2717,'2e8ecd96-6369-4060-84ef-852072cee0c0','2fd59280-e4f7-473c-894b-fd2ac4e0cd83','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NodeExtraConfig-fhy4dmyz5ks3','2fd59280-e4f7-473c-894b-fd2ac4e0cd83','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2718,'521ae5b3-ba88-4871-8bff-3f5720979ddd','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','efb70594-bac2-4a41-bf41-1a9543f8c540','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1617),(2719,'23e1cd12-229b-4656-9ed3-55e66993f1a4','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','ExternalPort','b79026ac-0242-4b36-8a64-6dbc3fc08ff5','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1628),(2720,'c6c88a65-1d85-468d-9aa5-051905e65894','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','NodeExtraConfig','03746057-2006-430b-b38c-87b676cf0690','state changed','OS::TripleO::NodeExtraConfig',NULL,1619),(2721,'782a9eba-8e74-45d9-81c0-7e14016c9df7','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:05',NULL,'CREATE','COMPLETE','ExternalPort','6c207cd2-d08b-4fb9-9398-5ccf4c26e61d','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1614),(2722,'8eecb799-c152-4f95-9b1a-77c52585d9be','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:05',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NodeExtraConfig-bm3pcgjdkbfa','state changed','OS::TripleO::NodeExtraConfig',NULL,1663),(2723,'5d031539-c946-4f8d-9d87-580cfc749f7f','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','StoragePort','cb80d84f-643c-42e8-b287-ad6be6d8f116','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1612),(2724,'443d8a5d-4461-4907-aa0a-e26a2a52b88b','95a13e8b-bf84-49e8-9fe7-aadb8ecf43dc','2026-06-10 08:01:06',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NodeExtraConfig-bm3pcgjdkbfa','95a13e8b-bf84-49e8-9fe7-aadb8ecf43dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2725,'e87eed97-9aef-4f49-ba6e-b78085c3d05b','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','InternalApiPort','19d5afd1-4880-4878-b358-d3b404ed53ef','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1632),(2726,'f60a0f8c-1fd1-45c9-85bb-3c928bee5d57','95a13e8b-bf84-49e8-9fe7-aadb8ecf43dc','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NodeExtraConfig-bm3pcgjdkbfa','95a13e8b-bf84-49e8-9fe7-aadb8ecf43dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2727,'3a38cebb-6e17-4497-9a63-4b1a3ffc8e2c','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:06',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NetIpMap-77ipynsngkev','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1669),(2728,'e31b94c7-e378-4694-936e-5b54ef64ab91','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','NetIpMap','4076c7fb-aa98-491e-9101-a79f4f4014bf','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1643),(2729,'1964fde1-61e2-48b6-bdf9-88e5a9b164fc','d243713e-d905-46a4-9e33-e2334b1bc1ae','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-1-ivufh6wgm77d','d243713e-d905-46a4-9e33-e2334b1bc1ae','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2730,'769d0bca-5b51-4e2d-9d28-e2054add7927','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:06',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NetIpMap-madnxzaq7ydz','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1672),(2731,'6c8f0384-479d-43ca-9a96-50e560dbdf4a','985a543e-edbd-4f9c-ae13-50ecd3390ca3','2026-06-10 08:01:06',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NetIpMap-77ipynsngkev','985a543e-edbd-4f9c-ae13-50ecd3390ca3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2732,'eb7939a9-1a9a-4ff0-bbd4-cb83c2a3afed','2a9dc413-d21d-4415-b7ad-69625c56c76c','2026-06-10 08:01:06',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NetIpMap-madnxzaq7ydz','2a9dc413-d21d-4415-b7ad-69625c56c76c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2733,'807ab1aa-602b-48b0-9077-39c108dc3a45','985a543e-edbd-4f9c-ae13-50ecd3390ca3','2026-06-10 08:01:06',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NetIpMap-77ipynsngkev-NetIpMapValue-pdcobzreuuzc','state changed','OS::Heat::Value',NULL,1673),(2734,'946c8343-5e59-4f94-94ea-c4f03be7f991','985a543e-edbd-4f9c-ae13-50ecd3390ca3','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NetIpMap-77ipynsngkev-NetIpMapValue-pdcobzreuuzc','state changed','OS::Heat::Value',NULL,1673),(2735,'3962cc09-4f49-43c1-9602-d5546d4238fa','985a543e-edbd-4f9c-ae13-50ecd3390ca3','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b-NetIpMap-77ipynsngkev','985a543e-edbd-4f9c-ae13-50ecd3390ca3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2736,'53bb6f3b-46d4-47a5-b4b9-f8b1c2b860ea','2a9dc413-d21d-4415-b7ad-69625c56c76c','2026-06-10 08:01:06',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NetIpMap-madnxzaq7ydz-NetIpMapValue-qoh3czzsu7k4','state changed','OS::Heat::Value',NULL,1674),(2737,'13760060-b7cf-4c0b-a009-c4bfb68bd6a2','2a9dc413-d21d-4415-b7ad-69625c56c76c','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NetIpMap-madnxzaq7ydz-NetIpMapValue-qoh3czzsu7k4','state changed','OS::Heat::Value',NULL,1674),(2738,'c034035d-07ca-4a20-b866-ef8dc0f40c57','2a9dc413-d21d-4415-b7ad-69625c56c76c','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h-NetIpMap-madnxzaq7ydz','2a9dc413-d21d-4415-b7ad-69625c56c76c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2739,'b48513b9-0c6e-49e0-abf6-84f3af25f230','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','NodeExtraConfig','2fd59280-e4f7-473c-894b-fd2ac4e0cd83','state changed','OS::TripleO::NodeExtraConfig',NULL,1656),(2740,'e2ef1004-65d1-4159-b339-0b2f10e21d1b','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:01:06',NULL,'CREATE','COMPLETE','1','d243713e-d905-46a4-9e33-e2334b1bc1ae','state changed','OS::TripleO::Controller',NULL,1567),(2741,'b1e53633-ec8d-4e9e-9ecd-7c1bb6bde5d3','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:07',NULL,'CREATE','COMPLETE','NodeExtraConfig','95a13e8b-bf84-49e8-9fe7-aadb8ecf43dc','state changed','OS::TripleO::NodeExtraConfig',NULL,1663),(2742,'e6966d9f-c147-4a03-990e-0a1cd8043950','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:07',NULL,'CREATE','COMPLETE','NetIpMap','985a543e-edbd-4f9c-ae13-50ecd3390ca3','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1669),(2743,'618e2884-fd73-44c5-bc60-6da9411a2bf6','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','2026-06-10 08:01:07',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-0-oihx5csydd5b','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2744,'216fc0f6-9d7a-4a14-91db-97ad4765a9fb','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:07',NULL,'CREATE','COMPLETE','NetIpMap','2a9dc413-d21d-4415-b7ad-69625c56c76c','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1672),(2745,'fa7884dc-e157-48dd-83ba-db36e574286e','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','2026-06-10 08:01:07',NULL,'CREATE','COMPLETE','overcloud-Controller-55zuh23vqxrs-2-lsjoymaztp4h','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2746,'e8e5bc85-4dcc-45a7-b06d-680ba155441b','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:01:07',NULL,'CREATE','COMPLETE','0','f6e2f72a-57b1-43e1-8193-cb20f3b133ce','state changed','OS::TripleO::Controller',NULL,1575),(2747,'1482b193-7178-40a9-beef-f1a105fc3d20','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:01:07',NULL,'CREATE','COMPLETE','2','12f25ff6-3f37-462f-8ee6-0179e4f5d6b3','state changed','OS::TripleO::Controller',NULL,1570),(2748,'59c2a81d-9e61-4669-8757-14663378f6b8','90c90c4b-219a-4516-bc79-f3dae115cb29','2026-06-10 08:01:07',NULL,'UPDATE','COMPLETE','overcloud-Controller-55zuh23vqxrs','90c90c4b-219a-4516-bc79-f3dae115cb29','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(2749,'6ccd9f08-0031-46c3-96f6-e09fd9d5e054','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:08',NULL,'CREATE','COMPLETE','Controller','90c90c4b-219a-4516-bc79-f3dae115cb29','state changed','OS::Heat::ResourceGroup',NULL,1539),(2750,'a77bf9ad-61eb-4a36-935b-4b4ce5bd906c','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-aqtuzwxjdm4o','state changed','OS::Heat::Value',NULL,1690),(2751,'9b2394e5-9c74-4d6d-ae6d-a7688d7fe93f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','COMPLETE','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-aqtuzwxjdm4o','state changed','OS::Heat::Value',NULL,1690),(2752,'c42fe2af-ab67-4d94-ac93-bf50d2e981cb','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','BlacklistedHostnames','overcloud-BlacklistedHostnames-ka3fr4ckyohg','state changed','OS::Heat::Value',NULL,1691),(2753,'52569155-ad5c-4fbf-a243-381bd54c709f','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','COMPLETE','BlacklistedHostnames','overcloud-BlacklistedHostnames-ka3fr4ckyohg','state changed','OS::Heat::Value',NULL,1691),(2754,'1bb25a28-9a08-469a-9e29-ee8d567bf8b2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','ServerIdMap','overcloud-ServerIdMap-7uswfuo3cpix','state changed','OS::Heat::Value',NULL,1692),(2755,'66ec5b20-d8a2-4879-b9f7-58c81e5921e2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','COMPLETE','ServerIdMap','overcloud-ServerIdMap-7uswfuo3cpix','state changed','OS::Heat::Value',NULL,1692),(2756,'0556da01-fb0c-42bc-8514-7b8d46e72ecf','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','HostsEntryValue','overcloud-HostsEntryValue-lcm33ftdkojv','state changed','OS::Heat::Value',NULL,1693),(2757,'f6259d0c-97db-4b19-acf8-c1f9eac3dd88','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','COMPLETE','HostsEntryValue','overcloud-HostsEntryValue-lcm33ftdkojv','state changed','OS::Heat::Value',NULL,1693),(2758,'e43b7cbc-01eb-43c1-a829-2413f903ecca','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-ljoe5gqupgum','state changed','OS::Heat::Value',NULL,1695),(2759,'5ea5b015-10e7-444c-ae8d-fa7d665ae854','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','AnsibleHostVars','overcloud-AnsibleHostVars-hvzx7gqramzr','state changed','OS::Heat::Value',NULL,1696),(2760,'1a6b77da-951c-41e7-91f9-b7ba6c3f56da','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','ControllerServers','overcloud-ControllerServers-bbfw36gihluu','state changed','OS::Heat::Value',NULL,1698),(2761,'80079692-76b6-422b-b88b-f43a2e68ae28','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','COMPLETE','AnsibleHostVars','overcloud-AnsibleHostVars-hvzx7gqramzr','state changed','OS::Heat::Value',NULL,1696),(2762,'94d9b38d-2598-401f-bd0c-df7bed7314f0','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','COMPLETE','ControllerServers','overcloud-ControllerServers-bbfw36gihluu','state changed','OS::Heat::Value',NULL,1698),(2763,'23187b00-68e8-4de5-b576-a04bdf355873','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','COMPLETE','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-ljoe5gqupgum','state changed','OS::Heat::Value',NULL,1695),(2764,'85525365-76dc-4afc-9f3f-bd5af747ffe7','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','ControllerIpListMap','overcloud-ControllerIpListMap-k5vaky2hcwdn','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1701),(2765,'ded9072d-3d81-42a8-b9c3-d052a141f258','6a3a3c4d-e20b-4c7f-ac92-0f599e0ab621','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerIpListMap-k5vaky2hcwdn','6a3a3c4d-e20b-4c7f-ac92-0f599e0ab621','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2766,'8ebddb45-a88d-42dd-80c2-657219efd290','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','AllNodesExtraConfig','overcloud-AllNodesExtraConfig-5c4t4aw2ozzw','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2767,'08c8d40d-92cb-4d19-92a8-c46d22d681a2','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:09',NULL,'CREATE','COMPLETE','AllNodesExtraConfig','79d3122e-e34c-458a-9242-10711a32c101','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2768,'1ea7a92e-226d-49d9-8fec-e29ce6c12412','6a3a3c4d-e20b-4c7f-ac92-0f599e0ab621','2026-06-10 08:01:09',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ControllerIpListMap-k5vaky2hcwdn-EnabledServicesValue-5m4v6s2foydk','state changed','OS::Heat::Value',NULL,1702),(2769,'56445aa7-62d7-4369-baf4-3d63ae4c550b','6a3a3c4d-e20b-4c7f-ac92-0f599e0ab621','2026-06-10 08:01:09',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ControllerIpListMap-k5vaky2hcwdn-EnabledServicesValue-5m4v6s2foydk','state changed','OS::Heat::Value',NULL,1702),(2770,'8738a634-c029-4bc2-bb5b-3854e80f3f48','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:10',NULL,'CREATE','IN_PROGRESS','AllNodesDeploySteps','overcloud-AllNodesDeploySteps-4l7lmqfswdeq','state changed','OS::TripleO::PostDeploySteps',NULL,1703),(2771,'9d5160fd-80eb-4f81-aac3-8907aec5c67a','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:10',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-4l7lmqfswdeq','ea6ee5ca-8df3-4973-95d3-f897734e38ab','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2772,'b5d0052b-9767-4eb6-bc0a-b0e4819a1ba4','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:10',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ExternalDeployTasks-y6odyct456et','state changed','OS::Heat::Value',NULL,1704),(2773,'1c927d88-fe99-4e7a-abea-882e79750530','6a3a3c4d-e20b-4c7f-ac92-0f599e0ab621','2026-06-10 08:01:10',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ControllerIpListMap-k5vaky2hcwdn-NetIpMapValue-w5ltz677ftvo','state changed','OS::Heat::Value',NULL,1705),(2774,'bb4ac087-4c39-4ef9-ae60-f7092586f10a','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:10',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ExternalDeployTasks-y6odyct456et','state changed','OS::Heat::Value',NULL,1704),(2775,'d00a6c72-18af-4673-a734-9c5fbd78e3c4','6a3a3c4d-e20b-4c7f-ac92-0f599e0ab621','2026-06-10 08:01:10',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ControllerIpListMap-k5vaky2hcwdn-NetIpMapValue-w5ltz677ftvo','state changed','OS::Heat::Value',NULL,1705),(2776,'8905d06a-def3-49a6-930f-87ea9a3fd712','6a3a3c4d-e20b-4c7f-ac92-0f599e0ab621','2026-06-10 08:01:10',NULL,'CREATE','COMPLETE','overcloud-ControllerIpListMap-k5vaky2hcwdn','6a3a3c4d-e20b-4c7f-ac92-0f599e0ab621','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2777,'1d0ce522-ff63-4f1d-9fd5-66f99d55b057','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:11',NULL,'CREATE','COMPLETE','ControllerIpListMap','6a3a3c4d-e20b-4c7f-ac92-0f599e0ab621','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1701),(2778,'87ee083d-3edb-498d-b9bf-0f8a98920596','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:11',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ExternalPostDeployTasks-gytqinx5uyao','state changed','OS::Heat::Value',NULL,1706),(2779,'43a59903-74ed-4de5-a590-72325367b10f','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:11',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ExternalPostDeployTasks-gytqinx5uyao','state changed','OS::Heat::Value',NULL,1706),(2780,'ca37c972-f538-468f-8332-9a85dac18fab','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:12',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ExternalUpdateTasks-qzxqhna2jueg','state changed','OS::Heat::Value',NULL,1707),(2781,'e40d9c0b-a79a-4d11-98a6-c5dc448b7b63','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:12',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ExternalUpdateTasks-qzxqhna2jueg','state changed','OS::Heat::Value',NULL,1707),(2782,'3bff8974-b24c-4da3-a25d-2fac97c6680b','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:13',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPost','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ComputeExtraConfigPost-cupjd5qpaa5p','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1708),(2783,'78dd480d-7a33-4cc4-8e58-a52491768b1f','816d541a-9fad-417e-93b0-739b2378409b','2026-06-10 08:01:14',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ComputeExtraConfigPost-cupjd5qpaa5p','816d541a-9fad-417e-93b0-739b2378409b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2784,'a7098c5a-8bc7-4c2f-8a07-da699d6ed5dc','816d541a-9fad-417e-93b0-739b2378409b','2026-06-10 08:01:14',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ComputeExtraConfigPost-cupjd5qpaa5p','816d541a-9fad-417e-93b0-739b2378409b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2785,'0b5f56a3-440c-471c-ba16-70242873d7fc','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:14',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPost','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ControllerExtraConfigPost-idrg64bcn2uz','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1709),(2786,'82f3b484-abee-49a5-babd-0508621a746d','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:15',NULL,'CREATE','COMPLETE','ComputeExtraConfigPost','816d541a-9fad-417e-93b0-739b2378409b','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1708),(2787,'c18f6b78-f06d-4a53-8249-e52c00fddf44','af09c424-7567-4dee-9e72-b5f4573c881c','2026-06-10 08:01:15',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ControllerExtraConfigPost-idrg64bcn2uz','af09c424-7567-4dee-9e72-b5f4573c881c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2788,'6d3db10c-a7ef-4445-92e7-81178aa74ee8','af09c424-7567-4dee-9e72-b5f4573c881c','2026-06-10 08:01:15',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ControllerExtraConfigPost-idrg64bcn2uz','af09c424-7567-4dee-9e72-b5f4573c881c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2789,'90682ba8-394c-4eef-bcf8-5ed9a74504a2','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:15',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-PreDeployStepTasks-ridzt7uxmcmd','state changed','OS::Heat::Value',NULL,1711),(2790,'7904d7b6-b941-48ce-a366-457cca432463','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:15',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-PreDeployStepTasks-ridzt7uxmcmd','state changed','OS::Heat::Value',NULL,1711),(2791,'b6517368-4167-4fa9-9087-e5f6ae1ae8c1','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:16',NULL,'CREATE','COMPLETE','ControllerExtraConfigPost','af09c424-7567-4dee-9e72-b5f4573c881c','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1709),(2792,'c7ac4c76-40ea-4e33-a9e3-2b1dfaeec2cd','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:16',NULL,'CREATE','IN_PROGRESS','ComputePostConfig','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ComputePostConfig-z7iuw6naelrw','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(2793,'66d4cb11-bcb1-429b-aa56-b80361e982b0','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:16',NULL,'CREATE','IN_PROGRESS','ControllerPostConfig','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ControllerPostConfig-pfvrj4xdaxtx','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2794,'0d3167c6-9a93-4f1b-8c57-c5af79d70fd4','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:16',NULL,'CREATE','COMPLETE','ComputePostConfig','50e11e75-ceb6-4273-82f6-4a37234187ce','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(2795,'aa5e4a04-82ba-4523-8f0e-856de64b10bd','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:16',NULL,'CREATE','COMPLETE','ControllerPostConfig','ed4c7f01-8d9f-4921-8df3-e91142883598','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2796,'86e9f1b6-5ecb-4501-8ac3-9b085e04a92d','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:16',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ScaleTasks-x43gtoxloq3f','state changed','OS::Heat::Value',NULL,1713),(2797,'f6ff6824-f0f2-4683-b94b-8086e07dad02','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:16',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ScaleTasks-x43gtoxloq3f','state changed','OS::Heat::Value',NULL,1713),(2798,'7f9ba899-fb1c-49b8-b739-a0ea38cc971c','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:17',NULL,'CREATE','IN_PROGRESS','BootstrapServerId','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-BootstrapServerId-4lvfo3albdzj','state changed','OS::Heat::Value',NULL,1714),(2799,'b70e01eb-ac6e-429f-8f41-fe200204b5ca','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:17',NULL,'CREATE','COMPLETE','BootstrapServerId','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-BootstrapServerId-4lvfo3albdzj','state changed','OS::Heat::Value',NULL,1714),(2800,'cd2a308b-6513-433b-b1a4-fa9b56bccaf3','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:18',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ExternalUpgradeTasks-lrwwo6qzmqdf','state changed','OS::Heat::Value',NULL,1715),(2801,'8b403be9-e2da-40d5-a23a-fbff150fe6a3','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:18',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-4l7lmqfswdeq-ExternalUpgradeTasks-lrwwo6qzmqdf','state changed','OS::Heat::Value',NULL,1715),(2802,'3e4fc2a1-5d28-4fc2-a312-93218d444cd1','ea6ee5ca-8df3-4973-95d3-f897734e38ab','2026-06-10 08:01:19',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-4l7lmqfswdeq','ea6ee5ca-8df3-4973-95d3-f897734e38ab','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2803,'caa29ef2-2a27-4b5f-8bdf-3c9173753720','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:19',NULL,'CREATE','COMPLETE','AllNodesDeploySteps','ea6ee5ca-8df3-4973-95d3-f897734e38ab','state changed','OS::TripleO::PostDeploySteps',NULL,1703),(2804,'62f973a8-edd4-4171-8fa2-ba49273c63ce','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','2026-06-10 08:01:19',NULL,'CREATE','COMPLETE','overcloud','a1c0cdaf-962f-4a14-92ad-8dbec212b9f2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL);
/*!40000 ALTER TABLE `event` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `migrate_version`
--

DROP TABLE IF EXISTS `migrate_version`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `migrate_version` (
  `repository_id` varchar(250) NOT NULL,
  `repository_path` text DEFAULT NULL,
  `version` int(11) DEFAULT NULL,
  PRIMARY KEY (`repository_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_swedish_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `migrate_version`
--

LOCK TABLES `migrate_version` WRITE;
/*!40000 ALTER TABLE `migrate_version` DISABLE KEYS */;
INSERT INTO `migrate_version` VALUES ('heat','/usr/lib/python3.9/site-packages/heat/db/sqlalchemy/migrate_repo',86);
/*!40000 ALTER TABLE `migrate_version` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `raw_template`
--

DROP TABLE IF EXISTS `raw_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `raw_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `template` longtext DEFAULT NULL,
  `files` longtext DEFAULT NULL,
  `environment` longtext DEFAULT NULL,
  `files_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `raw_tmpl_files_fkey_ref` (`files_id`),
  CONSTRAINT `raw_tmpl_files_fkey_ref` FOREIGN KEY (`files_id`) REFERENCES `raw_template_files` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=408 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `raw_template`
--

LOCK TABLES `raw_template` WRITE;
/*!40000 ALTER TABLE `raw_template` DISABLE KEYS */;
INSERT INTO `raw_template` VALUES (1,'2026-06-10 07:59:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deploy an OpenStack environment, consisting of several node types (roles), Controller, Compute, BlockStorage, SwiftStorage and CephStorage. The Storage roles enable independent scaling of the storage components, but the minimal deployment is one Controller and one Compute node.\\n\", \"parameters\": {\"CloudNameStorage\": {\"default\": \"overcloud.storage.localdomain\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.localdomain\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageMgmtVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageMgmtVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.localdomain\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"InternalApiVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the InternalApiVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudName\": {\"default\": \"overcloud.localdomain\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"PublicVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the PublicVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"ExternalVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ExternalVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.localdomain\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}, \"ExtraHostFileEntries\": {\"default\": [], \"description\": \"List of extra hosts entries to be appended to /etc/hosts\", \"type\": \"comma_delimited_list\"}, \"UndercloudHostsEntries\": {\"default\": [], \"description\": \"List of undercloud hosts entries to be appended to /etc/hosts. The value is populated with the HEAT_HOSTS entries on the undercloud by tripleoclient when running deploy.\\n\", \"type\": \"comma_delimited_list\"}, \"EndpointMapOverride\": {\"default\": {}, \"description\": \"Can be used to override the calcluated EndpointMap\", \"type\": \"json\"}, \"ExtraConfig\": {\"default\": {}, \"description\": \"Additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"DeployedServerPortMap\": {\"default\": {}, \"type\": \"json\"}, \"NeutronControlPlaneID\": {\"default\": \"ctlplane\", \"type\": \"string\", \"description\": \"Neutron ID or name for ctlplane network.\"}, \"NeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create for accessing external networks.\", \"type\": \"string\"}, \"NeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"Which interface to add to the NeutronPhysicalBridge.\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"DnsSearchDomains\": {\"default\": [], \"description\": \"A list of DNS search domains to be added (in order) to resolv.conf.\", \"type\": \"comma_delimited_list\"}, \"ControlFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ControlVirtualIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"RabbitCookieSalt\": {\"type\": \"string\", \"default\": \"unset\", \"description\": \"Salt for the rabbit cookie, change this to force the randomly generated rabbit cookie to change.\"}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API.\\n\", \"type\": \"json\"}, \"HypervisorNeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create on each hypervisor. This defaults to br-ex the same as the control plane nodes, as we have a uniform configuration of the openvswitch agent. Typically should not need to be changed.\\n\", \"type\": \"string\"}, \"HypervisorNeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"What interface to add to the HypervisorNeutronPhysicalBridge.\", \"type\": \"string\"}, \"NodeCreateBatchSize\": {\"default\": 30, \"description\": \"Maxiumum batch size for creating nodes\", \"type\": \"number\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaLocalMetadataPerCell\": {\"default\": false, \"description\": \"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\n\", \"type\": \"boolean\"}, \"BondInterfaceOvsOptions\": {\"default\": \"\", \"description\": \"The ovs_options or bonding_options string for the bond interface. Set things like lacp=active and/or bond_mode=balance-slb for OVS bonds or like mode=4 for Linux bonds using this option.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^((?!balance.tcp).)*$\", \"description\": \"The balance-tcp bond mode is known to cause packet loss and should not be used in BondInterfaceOvsOptions.\"}]}, \"NetworkConfigWithAnsible\": {\"description\": \"NetworkConfig with ansible flag\", \"type\": \"boolean\", \"default\": true}, \"ControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ControllerNetworkConfigTemplate\": {\"description\": \"Controller NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"controllerExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use CellControllerComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\"}, \"ControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Controller node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"ControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Controller ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Controller ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nControllerServiceChain resource and the Controller resource group.\\nFor example:\\nControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerNetworkConfigTemplate\": {\"description\": \"CellController NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellController node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"CellControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellController ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellController ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerServiceChain resource and the CellController resource group.\\nFor example:\\nCellControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerComputeNetworkConfigTemplate\": {\"description\": \"CellControllerCompute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellControllerCompute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-compute-%index%\"}, \"CellControllerComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellControllerCompute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellControllerCompute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerComputeServiceChain resource and the CellControllerCompute resource group.\\nFor example:\\nCellControllerComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ComputeNetworkConfigTemplate\": {\"description\": \"Compute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NovaComputeExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use ComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\"}, \"ComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Compute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-novacompute-%index%\"}, \"ComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Compute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Compute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NovaComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"DEPRECATED - use ComputeSchedulerHints instead\", \"default\": {}}, \"ComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nComputeServiceChain resource and the Compute resource group.\\nFor example:\\nComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"BlockStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"BlockStorageNetworkConfigTemplate\": {\"description\": \"BlockStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"BlockStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\"}, \"BlockStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"BlockStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"BlockStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"BlockStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for BlockStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-blockstorage-%index%\"}, \"BlockStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from BlockStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"BlockStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for BlockStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"BlockStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"BlockStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"BlockStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"BlockStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"BlockStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nBlockStorageServiceChain resource and the BlockStorage resource group.\\nFor example:\\nBlockStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"BlockStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ObjectStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ObjectStorageNetworkConfigTemplate\": {\"description\": \"ObjectStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ObjectStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\"}, \"ObjectStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ObjectStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ObjectStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for ObjectStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-objectstorage-%index%\"}, \"ObjectStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from ObjectStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ObjectStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for ObjectStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ObjectStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ObjectStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ObjectStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ObjectStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ObjectStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nObjectStorageServiceChain resource and the ObjectStorage resource group.\\nFor example:\\nObjectStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ObjectStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CephStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CephStorageNetworkConfigTemplate\": {\"description\": \"CephStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CephStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\"}, \"CephStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CephStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CephStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CephStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-cephstorage-%index%\"}, \"CephStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CephStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CephStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CephStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CephStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CephStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CephStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CephStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CephStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCephStorageServiceChain resource and the CephStorage resource group.\\nFor example:\\nCephStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CephStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"NetworkerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"NetworkerNetworkConfigTemplate\": {\"description\": \"Networker NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"NetworkerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\"}, \"NetworkerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"NetworkerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"NetworkerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Networker node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-networker-%index%\"}, \"NetworkerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Networker ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"NetworkerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Networker ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"NetworkerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NetworkerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"NetworkerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"NetworkerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"NetworkerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nNetworkerServiceChain resource and the Networker resource group.\\nFor example:\\nNetworkerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"NetworkerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"DeployIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AddVipsToEtcHosts\": {\"default\": true, \"type\": \"boolean\", \"description\": \"Set to true to append per network Vips to /etc/hosts on each node.\\n\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"GlobalConfigExtraMapData\": {\"type\": \"json\", \"default\": {}, \"description\": \"Map of extra global_config_settings data to set on each node.\"}, \"NetConfigDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"Configure os-net-config mappings for specific nodes Your environment file needs to look like:\\n  parameter_defaults:\\n    NetConfigDataLookup:\\n      node1:\\n        nic1: \\\"00:c8:7c:e6:f0:2e\\\"\\n      node2:\\n        nic1: \\\"00:18:7d:99:0c:b6\\\"\\n      node3:\\n        dmiString: \'system-uuid\'\\n        id: \'A8C85861-1B16-4803-8689-AFC62984F8F6\'\\n        nic1: em3\\n      # Dell PowerEdge\\n      nodegroup1:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"PowerEdge R630\\\"\\n        nic1: em3\\n        nic2: em1\\n        nic3: em2\\n      # Cisco UCS B200-M4\\\"\\n      nodegroup2:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"UCSB-B200-M4\\\"\\n        nic1: enp7s0\\n        nic2: enp6s0\\n\\nThis will result in the first node* entry where either a mac matches a local device or a DMI String matches the specified id being written as a mapping file for os-net-config. (/etc/os-net-config/mapping.yaml)\\n\"}, \"DnsServers\": {\"default\": [], \"description\": \"DNS servers to use for the Overcloud (2 max for some implementations). If not set the nameservers configured in the ctlplane subnet\'s dns_nameservers attribute will be used.\\n\", \"type\": \"comma_delimited_list\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"DnsServers\", \"NovaComputeSchedulerHints\", \"NovaComputeExtraConfig\"]}], \"conditions\": {\"add_vips_to_etc_hosts\": {\"equals\": [{\"get_param\": \"AddVipsToEtcHosts\"}, true]}, \"control_fixed_ip_not_set\": {\"equals\": [{\"get_param\": \"ControlFixedIPs\"}, []]}, \"storage_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageVirtualFixedIPs\"}, []]}}, \"storage_mgmt_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, []]}}, \"internal_api_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"InternalApiVirtualFixedIPs\"}, []]}}, \"tenant_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"TenantVirtualFixedIPs\"}, []]}}, \"public_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"PublicVirtualFixedIPs\"}, []]}}, \"set_default_mysql_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"MysqlCellInternal\"]}, \"\"]}]}]}, \"set_default_nova_vnc_proxy_cell_public\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaVNCProxyCellPublic\"]}, \"\"]}]}]}, \"set_default_nova_metadata_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaMetadataCellInternal\"]}, \"\"]}]}]}, \"dnsservers_set\": {\"not\": {\"equals\": [{\"get_param\": \"DnsServers\"}, []]}}}, \"resources\": {\"VipHosts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": [{\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"ctlplane\"]}, \"HOST\": {\"get_param\": \"CloudNameCtlplane\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage\"]}, \"HOST\": {\"get_param\": \"CloudNameStorage\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage_mgmt\"]}, \"HOST\": {\"get_param\": \"CloudNameStorageManagement\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"internal_api\"]}, \"HOST\": {\"get_param\": \"CloudNameInternal\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"external\"]}, \"HOST\": {\"get_param\": \"CloudName\"}}}}]}}, \"NetCidrMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_cidr_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"NetIpVersionMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_ip_version_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"subnets\", 0, \"ip_version\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"ServiceNetMap\": {\"type\": \"OS::TripleO::ServiceNetMap\"}, \"EndpointMap\": {\"type\": \"OS::TripleO::EndpointMap\", \"properties\": {\"CloudEndpoints\": {\"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}, \"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}}, \"NetIpMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}}}, \"EndpointMapData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"EndpointMap\", \"endpoint_map\"]}, {\"get_param\": \"EndpointMapOverride\"}, {\"if\": [\"set_default_mysql_cell_internal\", {\"MysqlCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"MysqlInternal\"]}}, {}]}, {\"if\": [\"set_default_nova_vnc_proxy_cell_public\", {\"NovaVNCProxyCellPublic\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaVNCProxyPublic\"]}}, {}]}, {\"if\": [\"set_default_nova_metadata_cell_internal\", {\"NovaMetadataCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaMetadataInternal\"]}}, {}]}]}}}, \"NodeAdminUserData\": {\"type\": \"OS::TripleO::NodeAdminUserData\"}, \"NodeTimesyncUserData\": {\"type\": \"OS::TripleO::NodeTimesyncUserData\"}, \"NodeUserData\": {\"type\": \"OS::TripleO::NodeUserData\"}, \"ControllerServiceChain\": {\"type\": \"OS::TripleO::ControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"ControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}}}, \"ControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ControllerServiceChain\", \"role_data\"]}}}, \"ControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"ControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}}}}]}}}, \"ControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ControllerServiceNetMap\"}}}}]}}}, \"ControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Controller\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"Controller\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Controller\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}}}, \"ControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Controller\", \"hostname_map\"]}]}}}}, \"ControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ControllerRoleUserData\": {\"type\": \"OS::TripleO::Controller::NodeUserData\"}, \"Controller\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ControllerCount\"}, \"removal_policies\": {\"get_param\": \"ControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Controller\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"ControllerUserData\"}}}}}, \"CellControllerServiceChain\": {\"type\": \"OS::TripleO::CellControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}}}, \"CellControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerServiceChain\", \"role_data\"]}}}, \"CellControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}}}}]}}}, \"CellControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerServiceNetMap\"}}}}]}}}, \"CellControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellController\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellController\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}}}, \"CellControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellController\", \"hostname_map\"]}]}}}}, \"CellControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerRoleUserData\": {\"type\": \"OS::TripleO::CellController::NodeUserData\"}, \"CellController\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellController\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerUserData\"}}}}}, \"CellControllerComputeServiceChain\": {\"type\": \"OS::TripleO::CellControllerComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}}}, \"CellControllerComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerComputeServiceChain\", \"role_data\"]}}}, \"CellControllerComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}}}}]}}}, \"CellControllerComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerComputeServiceNetMap\"}}}}]}}}, \"CellControllerComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellControllerCompute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}}}, \"CellControllerComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellControllerCompute\", \"hostname_map\"]}]}}}}, \"CellControllerComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerComputeRoleUserData\": {\"type\": \"OS::TripleO::CellControllerCompute::NodeUserData\"}, \"CellControllerCompute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerComputeCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellControllerCompute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerComputeUserData\"}}}}}, \"ComputeServiceChain\": {\"type\": \"OS::TripleO::ComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"ComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}}}, \"ComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ComputeServiceChain\", \"role_data\"]}}}, \"ComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NovaComputeExtraConfig\"}, {\"get_param\": \"ComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}}}}]}}}, \"ComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ComputeServiceNetMap\"}}}}]}}}, \"ComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Compute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Compute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}}}, \"ComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Compute\", \"hostname_map\"]}]}}}}, \"ComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ComputeRoleUserData\": {\"type\": \"OS::TripleO::Compute::NodeUserData\"}, \"Compute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ComputeCount\"}, \"removal_policies\": {\"get_param\": \"ComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NovaComputeSchedulerHints\"}, {\"get_param\": \"ComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"ComputeUserData\"}}}}}, \"BlockStorageServiceChain\": {\"type\": \"OS::TripleO::BlockStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"BlockStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}}}, \"BlockStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"BlockStorageServiceChain\", \"role_data\"]}}}, \"BlockStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"BlockStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"BlockStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"BlockStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}}}}]}}}, \"BlockStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"BlockStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"BlockStorageServiceNetMap\"}}}}]}}}, \"BlockStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"BlockStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}}}, \"BlockStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"BlockStorage\", \"hostname_map\"]}]}}}}, \"BlockStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"BlockStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"BlockStorageRoleUserData\": {\"type\": \"OS::TripleO::BlockStorage::NodeUserData\"}, \"BlockStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"BlockStorageCount\"}, \"removal_policies\": {\"get_param\": \"BlockStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"BlockStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::BlockStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"BlockStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"BlockStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"BlockStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"BlockStorageUserData\"}}}}}, \"ObjectStorageServiceChain\": {\"type\": \"OS::TripleO::ObjectStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"ObjectStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}}}, \"ObjectStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ObjectStorageServiceChain\", \"role_data\"]}}}, \"ObjectStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ObjectStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"ObjectStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ObjectStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}}}}]}}}, \"ObjectStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ObjectStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ObjectStorageServiceNetMap\"}}}}]}}}, \"ObjectStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"ObjectStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}}}, \"ObjectStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"ObjectStorage\", \"hostname_map\"]}]}}}}, \"ObjectStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ObjectStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ObjectStorageRoleUserData\": {\"type\": \"OS::TripleO::ObjectStorage::NodeUserData\"}, \"ObjectStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ObjectStorageCount\"}, \"removal_policies\": {\"get_param\": \"ObjectStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ObjectStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::ObjectStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ObjectStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ObjectStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ObjectStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"ObjectStorageUserData\"}}}}}, \"CephStorageServiceChain\": {\"type\": \"OS::TripleO::CephStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"CephStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}}}, \"CephStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CephStorageServiceChain\", \"role_data\"]}}}, \"CephStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CephStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"CephStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CephStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}}}}]}}}, \"CephStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CephStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CephStorageServiceNetMap\"}}}}]}}}, \"CephStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"EnabledServices\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CephStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}}}, \"CephStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CephStorage\", \"hostname_map\"]}]}}}}, \"CephStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CephStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CephStorageRoleUserData\": {\"type\": \"OS::TripleO::CephStorage::NodeUserData\"}, \"CephStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CephStorageCount\"}, \"removal_policies\": {\"get_param\": \"CephStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CephStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CephStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CephStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CephStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CephStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"CephStorageUserData\"}}}}}, \"NetworkerServiceChain\": {\"type\": \"OS::TripleO::NetworkerServices\", \"properties\": {\"Services\": {\"get_param\": \"NetworkerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}}}, \"NetworkerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"NetworkerServiceChain\", \"role_data\"]}}}, \"NetworkerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"NetworkerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NetworkerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"NetworkerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}}]}}}, \"NetworkerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"NetworkerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetworkerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"NetworkerServiceNetMap\"}}}}]}}}, \"NetworkerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Networker\", \"ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Networker\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"NetworkerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Networker\", \"hostname_map\"]}]}}}}, \"NetworkerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NetworkerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"NetworkerRoleUserData\": {\"type\": \"OS::TripleO::Networker::NodeUserData\"}, \"Networker\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"NetworkerCount\"}, \"removal_policies\": {\"get_param\": \"NetworkerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"NetworkerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Networker\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"NetworkerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"NetworkerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NetworkerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}, \"UserData\": {\"get_resource\": \"NetworkerUserData\"}}}}}, \"ControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Controller\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Controller\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellController\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellController\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerCompute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellControllerCompute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Compute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Compute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"BlockStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"BlockStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ObjectStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"ObjectStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CephStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CephStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"NetworkerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Networker\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Networker\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ServerIdMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"server_ids\": {\"Controller\": {\"get_attr\": [\"Controller\", \"nova_server_resource\"]}, \"CellController\": {\"get_attr\": [\"CellController\", \"nova_server_resource\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}, \"Compute\": {\"get_attr\": [\"Compute\", \"nova_server_resource\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorage\", \"nova_server_resource\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorage\", \"nova_server_resource\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorage\", \"nova_server_resource\"]}, \"Networker\": {\"get_attr\": [\"Networker\", \"nova_server_resource\"]}}, \"bootstrap_server_id\": {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}}}}}}, \"DeploymentServerBlacklistDict\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"hostname\": 1}, \"for_each\": {\"hostname\": {\"get_param\": \"DeploymentServerBlacklist\"}}}}}}}, \"HostsEntryValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": {\"list_concat\": [[{\"get_param\": \"UndercloudHostsEntries\"}], [{\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}], {\"get_attr\": [\"Controller\", \"hosts_entry\"]}, {\"get_attr\": [\"CellController\", \"hosts_entry\"]}, {\"get_attr\": [\"CellControllerCompute\", \"hosts_entry\"]}, {\"get_attr\": [\"Compute\", \"hosts_entry\"]}, {\"get_attr\": [\"BlockStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"ObjectStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"CephStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"Networker\", \"hosts_entry\"]}, [{\"get_param\": \"ExtraHostFileEntries\"}]]}}}}, \"CloudNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"cloud_name_storage\": {\"get_param\": \"CloudNameStorage\"}, \"cloud_name_storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"cloud_name_internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"cloud_name_external\": {\"get_param\": \"CloudName\"}, \"cloud_name_ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}, \"GlobalConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}]}}}, \"Networks\": {\"type\": \"OS::TripleO::Network\", \"depends_on\": \"ServiceNetMap\", \"properties\": {\"CtlplaneNetworkCidrs\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}]}, \"ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}]}, \"edge_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}]}, \"edge_ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}]}}}}, \"ControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}}}}, \"ControllerNetworkConfig\": {\"type\": \"OS::TripleO::Controller::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"CellControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\"], \"service_net_map\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}}}}, \"CellControllerNetworkConfig\": {\"type\": \"OS::TripleO::CellController::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"CellControllerComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}}}}, \"CellControllerComputeNetworkConfig\": {\"type\": \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"ComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"compute\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}}}}, \"ComputeNetworkConfig\": {\"type\": \"OS::TripleO::Compute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"BlockStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"BlockStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"BlockStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}}}}, \"BlockStorageNetworkConfig\": {\"type\": \"OS::TripleO::BlockStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"ObjectStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ObjectStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ObjectStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}}}}, \"ObjectStorageNetworkConfig\": {\"type\": \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"CephStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CephStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CephStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"ceph\", \"storage\"], \"service_net_map\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}}}}, \"CephStorageNetworkConfig\": {\"type\": \"OS::TripleO::CephStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}}}, \"NetworkerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"NetworkerLocalMtu\"}, \"role_networks\": [\"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"NetworkerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}}}}, \"NetworkerNetworkConfig\": {\"type\": \"OS::TripleO::Networker::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ControlVirtualIP\": {\"depends_on\": \"ServiceNetMap\", \"type\": \"OS::TripleO::Network::Ports::ControlPlaneVipPort\", \"properties\": {\"name\": \"control_virtual_ip\", \"dns_name\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameCtlplane\"}, 0]}, \"network\": {\"get_param\": \"NeutronControlPlaneID\"}, \"fixed_ips\": {\"if\": [\"control_fixed_ip_not_set\", [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}}], {\"get_param\": \"ControlFixedIPs\"}]}, \"replacement_policy\": \"AUTO\", \"tags\": [\"tripleo_vip_net=ctlplane\", {\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"OS::stack_name\"}}}}]}}, \"StorageVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorage\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_virtual_fixed_ip_set\", {\"get_param\": \"StorageVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"Storage\"]}}]]}, \"IsVirtualIP\": true}}, \"StorageMgmtVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageMgmtVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorageManagement\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_mgmt_virtual_fixed_ip_set\", {\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"StorageMgmt\"]}}]]}, \"IsVirtualIP\": true}}, \"InternalApiVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::InternalApiVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"internal_api_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameInternal\"}, 0]}, \"FixedIPs\": {\"if\": [\"internal_api_virtual_fixed_ip_set\", {\"get_param\": \"InternalApiVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"InternalApi\"]}}]]}, \"IsVirtualIP\": true}}, \"PublicVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::ExternalVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"external_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudName\"}, 0]}, \"FixedIPs\": {\"if\": [\"public_virtual_fixed_ip_set\", {\"get_param\": \"PublicVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"External\"]}}]]}, \"IsVirtualIP\": true}}, \"VipMap\": {\"type\": \"OS::TripleO::Network::Ports::NetVipMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"StorageIp\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address\"]}, \"StorageIpUri\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address_uri\"]}, \"ExternalIp\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address\"]}, \"ExternalIpUri\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address_uri\"]}}, \"depends_on\": \"ServiceNetMap\"}, \"AllNodesExtraConfig\": {\"type\": \"OS::TripleO::AllNodesExtraConfig\", \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}}}, \"BlacklistedIpAddresses\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellController\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Compute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Networker\", \"blacklist_ip_address\"]}]}}}, \"AnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"Controller\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"ansible_host_vars_map\"]}]}}, \"CellController\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellController\", \"ansible_host_vars_map\"]}]}}, \"CellControllerCompute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellControllerCompute\", \"ansible_host_vars_map\"]}]}}, \"Compute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Compute\", \"ansible_host_vars_map\"]}]}}, \"BlockStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"BlockStorage\", \"ansible_host_vars_map\"]}]}}, \"ObjectStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"ObjectStorage\", \"ansible_host_vars_map\"]}]}}, \"CephStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CephStorage\", \"ansible_host_vars_map\"]}]}}, \"Networker\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Networker\", \"ansible_host_vars_map\"]}]}}}}}, \"BlacklistedHostnames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellController\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Compute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Networker\", \"blacklist_hostname\"]}]}}}, \"AllNodesDeploySteps\": {\"type\": \"OS::TripleO::PostDeploySteps\", \"depends_on\": [\"AllNodesExtraConfig\"], \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"role_data\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}, \"ServiceNetMapLower\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, \"PingTestGatewayIPsMap\": {\"Controller\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"CellController\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"Compute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"CephStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}]}}, \"Networker\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}}, \"PingTestIpsMap\": {\"Controller\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"external_ip_address\"]}}}]]}, \"CellController\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}}}]]}, \"CellControllerCompute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}}}]]}, \"Compute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}}}]]}, \"BlockStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}}}]]}, \"ObjectStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}}}]]}, \"CephStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}}}]]}, \"Networker\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}}}]]}}, \"HostsEntry\": {\"get_attr\": [\"HostsEntryValue\", \"value\"]}, \"EnabledServices\": {\"list_concat\": [{\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}]}, \"ControlVirtualIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"EnabledNetworks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"NetVipMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"CloudNames\": {\"get_attr\": [\"CloudNames\", \"value\"]}, \"UndercloudHostsEntries\": {\"get_param\": \"UndercloudHostsEntries\"}, \"ExtraHostsEntries\": {\"get_param\": \"ExtraHostFileEntries\"}, \"VipHostsEntries\": {\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}, \"KeystoneResourcesConfigs\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"keystone_resources\"]}]}, \"NetCidrMap\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}}}}, \"outputs\": {\"ManagedEndpoints\": {\"description\": \"Asserts that the keystone endpoints have been provisioned.\", \"value\": true}, \"KeystoneURL\": {\"description\": \"URL for the Overcloud Keystone service\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\", \"KeystonePublic\", \"uri_no_suffix\"]}}, \"KeystoneAdminVip\": {\"description\": \"Keystone Admin VIP endpoint\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\", \"KeystoneAdminApiNetwork\"]}]}}, \"EndpointMap\": {\"description\": \"Mapping of the resources with the needed info for their endpoints.\\nThis includes the protocol used, the IP, port and also a full\\nrepresentation of the URI.\\n\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}}, \"HostsEntry\": {\"description\": \"The content that should be appended to your /etc/hosts if you want to get\\nhostname-based access to the deployed nodes (useful for testing without\\nsetting up a DNS).\\n\", \"value\": {\"list_concat_unique\": [{\"get_attr\": [\"HostsEntryValue\", \"value\"]}, {\"get_attr\": [\"VipHosts\", \"value\"]}]}}, \"EnabledServices\": {\"description\": \"The services enabled on each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}, \"RoleData\": {\"description\": \"The configuration data associated with each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}}, \"RoleConfig\": {\"description\": \"The configuration workflows associated with each role\", \"value\": {\"get_attr\": [\"AllNodesDeploySteps\", \"RoleConfig\"]}}, \"RoleNetIpMap\": {\"description\": \"Mapping of each network to a list of IPs for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerIpListMap\", \"net_ip_map\"]}, \"CellController\": {\"get_attr\": [\"CellControllerIpListMap\", \"net_ip_map\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeIpListMap\", \"net_ip_map\"]}, \"Compute\": {\"get_attr\": [\"ComputeIpListMap\", \"net_ip_map\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageIpListMap\", \"net_ip_map\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageIpListMap\", \"net_ip_map\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageIpListMap\", \"net_ip_map\"]}, \"Networker\": {\"get_attr\": [\"NetworkerIpListMap\", \"net_ip_map\"]}}}, \"RoleGroupVars\": {\"description\": \"Mapping of roles to ansible group_vars to be applied config in those roles\", \"value\": {\"Controller\": {\"map_merge\": [{\"get_attr\": [\"ControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"ControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ControllerExtraGroupVars\"}]}, \"CellController\": {\"map_merge\": [{\"get_attr\": [\"CellControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerExtraGroupVars\"}]}, \"CellControllerCompute\": {\"map_merge\": [{\"get_attr\": [\"CellControllerComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerComputeExtraGroupVars\"}]}, \"Compute\": {\"map_merge\": [{\"get_attr\": [\"ComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"ComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ComputeExtraGroupVars\"}]}, \"BlockStorage\": {\"map_merge\": [{\"get_attr\": [\"BlockStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"BlockStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"BlockStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"BlockStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"BlockStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"BlockStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"BlockStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"BlockStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"BlockStorageExtraGroupVars\"}]}, \"ObjectStorage\": {\"map_merge\": [{\"get_attr\": [\"ObjectStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"ObjectStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ObjectStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ObjectStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ObjectStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ObjectStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ObjectStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ObjectStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ObjectStorageExtraGroupVars\"}]}, \"CephStorage\": {\"map_merge\": [{\"get_attr\": [\"CephStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"CephStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CephStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CephStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CephStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CephStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CephStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CephStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CephStorageExtraGroupVars\"}]}, \"Networker\": {\"map_merge\": [{\"get_attr\": [\"NetworkerGroupVars\", \"value\"]}, {\"get_attr\": [\"NetworkerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"NetworkerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"NetworkerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"NetworkerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"NetworkerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"NetworkerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"NetworkerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"NetworkerExtraGroupVars\"}]}}}, \"RoleNetHostnameMap\": {\"description\": \"Mapping of each network to a list of hostnames for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"RoleTags\": {\"description\": \"Tags for each role, as defined in roles_data.yaml\", \"value\": {\"Controller\": [\"primary\", \"controller\", \"external_bridge\"], \"CellController\": [\"primary\", \"controller\"], \"CellControllerCompute\": [\"primary\", \"controller\", \"external_bridge\"], \"Compute\": [\"compute\", \"external_bridge\"], \"BlockStorage\": [\"storage\"], \"ObjectStorage\": [\"storage\"], \"CephStorage\": [\"ceph\", \"storage\"], \"Networker\": [\"external_bridge\"]}}, \"VipMap\": {\"description\": \"Mapping of each network to VIP addresses. Also includes the Redis and OVN DBs VIPs.\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}}, \"ServerIdData\": {\"description\": \"Mapping of each role to a list of nova server IDs and the bootstrap ID\", \"value\": {\"get_attr\": [\"ServerIdMap\", \"value\"]}}, \"BlacklistedHostnames\": {\"description\": \"List of blacklisted hostnames\", \"value\": {\"get_attr\": [\"BlacklistedHostnames\", \"value\"]}}, \"BlacklistedIpAddresses\": {\"description\": \"List of blacklisted ctlplane IP addresses\", \"value\": {\"get_attr\": [\"BlacklistedIpAddresses\", \"value\"]}}, \"GlobalConfig\": {\"description\": \"The global_config (hieradata).\", \"value\": {\"get_attr\": [\"GlobalConfig\", \"value\"]}}, \"RoleNetworkConfigMap\": {\"description\": \"Mapping of roles to network config\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkConfig\", \"config\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkConfig\", \"config\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkConfig\", \"config\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkConfig\", \"config\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkConfig\", \"config\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkConfig\", \"config\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkConfig\", \"config\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkConfig\", \"config\"]}}}, \"AnsibleHostVarsMap\": {\"description\": \"Map of Ansible Host variables per role\", \"value\": {\"get_attr\": [\"AnsibleHostVars\", \"value\"]}}, \"TripleoHeatTemplatesJinja2RenderingDataSources\": {\"description\": \"The role_data and the network_data used when rendering the THT Jinja2 templates\", \"value\": {\"roles_data\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"networks_data\": [{\"name\": \"Storage\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage\", \"dns_domain\": \"storage.ooo.test.\", \"service_net_map_replace\": \"storage\", \"subnets\": {\"storage_subnet\": {\"vlan\": 21, \"ip_subnet\": \"172.18.0.0/24\", \"allocation_pools\": [{\"start\": \"172.18.0.120\", \"end\": \"172.18.0.250\"}]}}, \"idx\": 0}, {\"name\": \"StorageMgmt\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage_mgmt\", \"dns_domain\": \"storagemgmt.ooo.test.\", \"service_net_map_replace\": \"storage_mgmt\", \"subnets\": {\"storage_mgmt_subnet\": {\"vlan\": 23, \"ip_subnet\": \"172.20.0.0/24\", \"allocation_pools\": [{\"start\": \"172.20.0.120\", \"end\": \"172.20.0.250\"}]}}, \"idx\": 1}, {\"name\": \"InternalApi\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"internal_api\", \"dns_domain\": \"internal-api.ooo.test.\", \"service_net_map_replace\": \"internal_api\", \"subnets\": {\"internal_api_subnet\": {\"vlan\": 20, \"ip_subnet\": \"172.17.0.0/24\", \"allocation_pools\": [{\"start\": \"172.17.0.120\", \"end\": \"172.17.0.250\"}]}}, \"idx\": 2}, {\"name\": \"Tenant\", \"mtu\": 1500, \"vip\": false, \"name_lower\": \"tenant\", \"dns_domain\": \"tenant.ooo.test.\", \"service_net_map_replace\": \"tenant\", \"subnets\": {\"tenant_subnet\": {\"vlan\": 22, \"ip_subnet\": \"172.19.0.0/24\", \"allocation_pools\": [{\"start\": \"172.19.0.120\", \"end\": \"172.19.0.250\"}]}}, \"idx\": 3}, {\"name\": \"External\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"external\", \"dns_domain\": \"external.ooo.test.\", \"service_net_map_replace\": \"external\", \"subnets\": {\"external_subnet\": {\"vlan\": 44, \"ip_subnet\": \"172.21.0.0/24\", \"allocation_pools\": [{\"start\": \"172.21.0.120\", \"end\": \"172.21.0.250\"}]}}, \"idx\": 4}]}}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"value\": {\"get_param\": \"AdminPassword\"}}, \"KeystoneRegion\": {\"description\": \"Keystone region for endpoint\", \"value\": {\"get_param\": \"KeystoneRegion\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(2,'2026-06-10 07:59:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(3,'2026-06-10 07:59:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mapping of service_name_network -> network name\\n\", \"parameters\": {\"ServiceNetMap\": {\"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults. Note that the key in this map must match the service_name in the service template, e.g if the service_name is heat_api the key must be either heat_api_network, or optionally HeatApiNetwork (which will be internally converted to transform captalization to underscores).\", \"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"VipSubnetMap\": {\"description\": \"Map of (network_name or service_name) -> subnet_name that defines which subnet to host the VIP. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\", \"default\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMapDeprecatedMapping\": {\"default\": {\"RabbitMqNetwork\": \"RabbitmqNetwork\", \"CephPublicNetwork\": \"CephMonNetwork\", \"SwiftMgmtNetwork\": \"SwiftStorageNetwork\"}, \"description\": \"Mapping older deprecated service names, intended for internal use only, this will be removed in future.\", \"type\": \"json\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"ServiceNetMapDeprecatedMapping\"]}], \"resources\": {\"ServiceNetMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"map_replace\": [{\"get_param\": \"ServiceNetMap\"}, {\"values\": {\"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}, \"keys\": {\"get_param\": \"ServiceNetMapDeprecatedMapping\"}}]}, {\"NovaVncProxyNetwork\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}]}}}}, \"outputs\": {\"service_net_map\": {\"value\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}, \"service_net_map_lower\": {\"value\": {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}}}}, \"vip_subnet_map\": {\"value\": {\"map_replace\": [{\"get_param\": \"VipSubnetMap\"}, {\"values\": {\"ctlplane-subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(4,'2026-06-10 07:59:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Control Plane network.\\n\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ControlPlaneVipData\": {\"description\": \"Control Plane Virtual IP data\\n\", \"default\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"type\": \"json\"}}, \"outputs\": {\"name\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"name\"]}}, \"fixed_ips\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"fixed_ips\"]}}, \"network\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"network\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"subnets\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"control_virtual_ip\", \"dns_name\": \"overcloud\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_vip_net=ctlplane,tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(5,'2026-06-10 07:59:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(6,'2026-06-10 07:59:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Create networks to split out Overcloud traffic\", \"parameters\": {\"DeployedNetworkEnvironment\": {\"type\": \"json\", \"description\": \"Deployed network environment\", \"default\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}}, \"CtlplaneNetworkCidrs\": {\"type\": \"json\", \"description\": \"Cidrs for the ctlplane network.\"}, \"CtlplaneNetworkAttributes\": {\"type\": \"json\", \"default\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"description\": \"A map containing attributes of the undercloud ctlplane network and subnets. NOTE: The value for this parameter is automatically populated in the plan environment by tripleoclient.\\n\"}}, \"resources\": {\"NetworkExtraConfig\": {\"type\": \"OS::TripleO::Network::ExtraConfig\"}, \"NetworkAttributesMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkAttributes\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_attributes_map\"]}]}}}, \"NetworkCidrMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkCidrs\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_cidr_map\"]}]}}}, \"NetworkIpVersionMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"yaql\": {\"expression\": \"$.data.items().first().last().ip_version\", \"data\": {\"get_param\": [\"CtlplaneNetworkAttributes\", \"subnets\"]}}}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_ip_version_map\"]}]}}}}, \"outputs\": {\"net_cidr_map\": {\"value\": {\"get_attr\": [\"NetworkCidrMap\", \"value\"]}}, \"net_ip_version_map\": {\"value\": {\"get_attr\": [\"NetworkIpVersionMap\", \"value\"]}}, \"net_attributes_map\": {\"value\": {\"get_attr\": [\"NetworkAttributesMap\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"CtlplaneNetworkCidrs\": \"[\\\"192.168.122.0/24\\\"]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(7,'2026-06-10 07:59:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(8,'2026-06-10 07:59:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (9,'2026-06-10 07:59:11',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"node_admin_username\": {\"type\": \"string\", \"default\": \"heat-admin\"}, \"node_admin_extra_ssh_keys\": {\"type\": \"comma_delimited_list\", \"default\": []}}, \"description\": \"Uses cloud-init to create an additional user with a known name, in addition to the distro-default user created by the cloud-init default.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"user_config\"}}]}}, \"user_config\": {\"type\": \"OS::Heat::CloudConfig\", \"properties\": {\"cloud_config\": {\"user\": {\"get_param\": \"node_admin_username\"}, \"ssh_authorized_keys\": {\"get_param\": \"node_admin_extra_ssh_keys\"}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(10,'2026-06-10 07:59:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(11,'2026-06-10 07:59:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the External network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"External network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"external_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"external_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(12,'2026-06-10 07:59:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"internal_api_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(13,'2026-06-10 07:59:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(14,'2026-06-10 07:59:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(15,'2026-06-10 07:59:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(16,'2026-06-10 07:59:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(17,'2026-06-10 07:59:14',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIp\": {\"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"StorageIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageIpSubnet\": {\"description\": \"IP address/subnet on the storage network\", \"default\": \"\", \"type\": \"string\"}, \"StorageIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpSubnet\": {\"description\": \"IP address/subnet on the storage_mgmt network\", \"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIp\": {\"default\": \"\", \"type\": \"string\"}, \"InternalApiIpSubnet\": {\"description\": \"IP address/subnet on the internal_api network\", \"default\": \"\", \"type\": \"string\"}, \"InternalApiIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIp\": {\"default\": \"\", \"type\": \"string\"}, \"TenantIpSubnet\": {\"description\": \"IP address/subnet on the tenant network\", \"default\": \"\", \"type\": \"string\"}, \"TenantIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIp\": {\"default\": \"\", \"type\": \"string\"}, \"ExternalIpSubnet\": {\"description\": \"IP address/subnet on the external network\", \"default\": \"\", \"type\": \"string\"}, \"ExternalIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"resources\": {\"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"ctlplane\": {\"get_param\": \"ControlPlaneIp\"}, \"ctlplane_subnet\": {\"list_join\": [\"\", [{\"get_param\": \"ControlPlaneIp\"}, \"/\", {\"get_param\": \"ControlPlaneSubnetCidr\"}]]}, \"ctlplane_uri\": {\"str_replace\": {\"template\": {\"make_url\": {\"host\": {\"get_param\": \"ControlPlaneIp\"}}}, \"params\": {\"//\": \"\"}}}, \"storage\": {\"get_param\": \"StorageIp\"}, \"storage_subnet\": {\"get_param\": \"StorageIpSubnet\"}, \"storage_uri\": {\"get_param\": \"StorageIpUri\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIp\"}, \"storage_mgmt_subnet\": {\"get_param\": \"StorageMgmtIpSubnet\"}, \"storage_mgmt_uri\": {\"get_param\": \"StorageMgmtIpUri\"}, \"internal_api\": {\"get_param\": \"InternalApiIp\"}, \"internal_api_subnet\": {\"get_param\": \"InternalApiIpSubnet\"}, \"internal_api_uri\": {\"get_param\": \"InternalApiIpUri\"}, \"tenant\": {\"get_param\": \"TenantIp\"}, \"tenant_subnet\": {\"get_param\": \"TenantIpSubnet\"}, \"tenant_uri\": {\"get_param\": \"TenantIpUri\"}, \"external\": {\"get_param\": \"ExternalIp\"}, \"external_subnet\": {\"get_param\": \"ExternalIpSubnet\"}, \"external_uri\": {\"get_param\": \"ExternalIpUri\"}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"storage_mgmt_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"storage_mgmt_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"internal_api_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"internal_api_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"tenant_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"tenant_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"external\": {\"get_param\": \"ExternalNetName\"}, \"external_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}, \"external_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIp\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"StorageIp\": \"172.18.0.250\", \"StorageIpUri\": \"172.18.0.250\", \"StorageMgmtIp\": \"172.20.0.248\", \"StorageMgmtIpUri\": \"172.20.0.248\", \"InternalApiIp\": \"172.17.0.242\", \"InternalApiIpUri\": \"172.17.0.242\", \"ExternalIp\": \"172.21.0.164\", \"ExternalIpUri\": \"172.21.0.164\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(18,'2026-06-10 07:59:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(19,'2026-06-10 07:59:16',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"NtpService\": {\"default\": \"chrony\", \"description\": \"NTP Service to use for the timesync bootstrap.\", \"type\": \"string\"}}, \"description\": \"Uses cloud-init to bootstrap timesync configuration to ensure it is done as soon as possible. We do additional and more complex configurations as part of the deployment itself.\\n\", \"conditions\": {\"use_chrony\": {\"equals\": [{\"get_param\": \"NtpService\"}, \"chrony\"]}}, \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"timesync_chrony\"}}, {\"config\": {\"get_resource\": \"timesync_sync\"}}]}}, \"timesync_chrony\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nif [ \\\"$service\\\" != \\\"chrony\\\" ]; then\\n  exit 0\\nfi\\nset -x\\nSERVERS=\\\"$ntp_servers\\\"\\nPOOLS=\\\"$ntp_pools\\\"\\nsystemctl is-active --quiet chronyd || systemctl start chronyd\\nfor server in $SERVERS; do\\n  chronyc add server \\\"${server}\\\" iburst\\ndone\\nfor pool in $POOLS; do\\n  chronyc add server \\\"${pool}\\\" iburst\\ndone\\nchronyc sources\\n\", \"params\": {\"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}, \"$ntp_pools\": {\"list_join\": [\" \", {\"get_param\": \"NtpPool\"}]}, \"$service\": {\"get_param\": \"NtpService\"}}}}}}, \"timesync_sync\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nset -x\\nif [ \\\"$service\\\" = \\\"chrony\\\" ]; then\\n    if command -v chronyc >/dev/null; then\\n        chronyc makestep\\n        chronyc waitsync 30\\n    else\\n        echo \\\"No chronyc available, skipping sync\\\"\\n    fi\\nelif [ \\\"$service\\\" = \\\"ntp\\\" ]; then\\n    if command -v ntpdate >/dev/null; then\\n        ntpdate -u $ntp_servers\\n    else\\n        echo \\\"No ntpdate available, skipping sync\\\"\\n    fi\\nfi\\nhwclock --systohc --utc\\n\", \"params\": {\"$service\": {\"get_param\": \"NtpService\"}, \"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}}}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (20,'2026-06-10 07:59:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"A map of OpenStack endpoints. Since the endpoints are URLs, we need to have brackets around IPv6 IP addresses. The inputs to these parameters come from net_ip_uri_map, which will include these brackets in IPv6 addresses.\", \"parameters\": {\"NetIpMap\": {\"type\": \"json\", \"default\": {}, \"description\": \"The Net IP map\"}, \"ServiceNetMap\": {\"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"The Service Net map\"}, \"EndpointMap\": {\"type\": \"json\", \"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}, \"CloudEndpoints\": {\"type\": \"json\", \"default\": {}, \"description\": \"A map containing the DNS names for the different endpoints (external, internal_api, etc.)\"}}, \"outputs\": {\"endpoint_map\": {\"value\": {\"AodhAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}}, \"AodhInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}}, \"AodhPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}}, \"BarbicanAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}}, \"BarbicanInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}}, \"BarbicanPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}}, \"CephDashboardInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}}, \"CephGrafanaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}}, \"CephRgwAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}}}}, \"CephRgwInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}}}}, \"CephRgwPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}}}}, \"CinderAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV2Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV2Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV2Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"DesignateAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}}}}, \"DesignateInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}}}}, \"DesignatePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}}}}, \"DockerRegistryInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}}, \"GaneshaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}}, \"GlanceAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}}, \"GlanceInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, \"GlancePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}}, \"GnocchiAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}}, \"GnocchiInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}}, \"GnocchiPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}}, \"HeatAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}}}}, \"HeatInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}}}}, \"HeatPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}}}}, \"HeatCfnAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}}}}, \"HeatCfnInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}}}}, \"HeatCfnPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}}, \"HorizonPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"path\": \"/dashboard\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}}}}, \"IronicAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}}}}, \"IronicInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}}}}, \"IronicPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}}}}, \"IronicInspectorAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}}, \"IronicInspectorInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}}, \"IronicInspectorPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}}, \"KeystoneAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystonePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"KeystoneV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystoneV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"ManilaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"ManilaV1Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaV1Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaV1Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"MetricsQdrPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}}, \"MysqlInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}}, \"NeutronAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}}, \"NeutronInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}}, \"NeutronPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}}, \"NovaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}}}}, \"NovaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}}}}, \"NovaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}}}}, \"NovaMetadataInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}}, \"NovaVNCProxyAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}}, \"NovaVNCProxyInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}}, \"NovaVNCProxyPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}}, \"NovajoinAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}}}}, \"NovajoinInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}}}}, \"NovajoinPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}}}}, \"OctaviaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}}, \"OctaviaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}}, \"OctaviaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}}, \"PlacementAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}}}}, \"PlacementInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}}}}, \"PlacementPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}}}}, \"SwiftAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}, \"SwiftS3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftS3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftS3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NetIpMap\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"CloudEndpoints\": {\"ctlplane\": \"overcloud.ctlplane.ooo.test\", \"storage\": \"overcloud.storage.ooo.test\", \"storage_mgmt\": \"overcloud.storagemgmt.ooo.test\", \"internal_api\": \"overcloud.internalapi.ooo.test\", \"external\": \"overcloud.ooo.test\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(21,'2026-06-10 07:59:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(22,'2026-06-10 07:59:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CephStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(23,'2026-06-10 07:59:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::NetworkerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(24,'2026-06-10 07:59:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::CeilometerAgentCentral,OS::TripleO::Services::CeilometerAgentNotification,OS::TripleO::Services::CinderApi,OS::TripleO::Services::CinderBackup,OS::TripleO::Services::CinderScheduler,OS::TripleO::Services::CinderVolume,OS::TripleO::Services::Clustercheck,OS::TripleO::Services::Collectd,OS::TripleO::Services::ContainerImagePrepare,OS::TripleO::Services::GlanceApi,OS::TripleO::Services::GlanceApiInternal,OS::TripleO::Services::HAproxy,OS::TripleO::Services::HeatApi,OS::TripleO::Services::HeatApiCloudwatch,OS::TripleO::Services::HeatApiCfn,OS::TripleO::Services::HeatEngine,OS::TripleO::Services::Horizon,OS::TripleO::Services::IpaClient,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::Keystone,OS::TripleO::Services::ManilaApi,OS::TripleO::Services::ManilaBackendCephFs,OS::TripleO::Services::ManilaScheduler,OS::TripleO::Services::ManilaShare,OS::TripleO::Services::Memcached,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQL,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NeutronApi,OS::TripleO::Services::NeutronCorePlugin,OS::TripleO::Services::NovaApi,OS::TripleO::Services::NovaConductor,OS::TripleO::Services::NovaMetadata,OS::TripleO::Services::NovaScheduler,OS::TripleO::Services::NovaVncProxy,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::OVNDBs,OS::TripleO::Services::OVNController,OS::TripleO::Services::Pacemaker,OS::TripleO::Services::PlacementApi,OS::TripleO::Services::OsloMessagingRpc,OS::TripleO::Services::OsloMessagingNotify,OS::TripleO::Services::Podman,OS::TripleO::Services::Redis,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::SwiftProxy,OS::TripleO::Services::SwiftRingBuilder,OS::TripleO::Services::SwiftStorage,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(25,'2026-06-10 07:59:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::BlockStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (26,'2026-06-10 07:59:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::Collectd,OS::TripleO::Services::ComputeCeilometerAgent,OS::TripleO::Services::CeilometerAgentIpmi,OS::TripleO::Services::IpaClient,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NovaCompute,OS::TripleO::Services::NovaLibvirt,OS::TripleO::Services::NovaLibvirtGuests,OS::TripleO::Services::NovaMigrationTarget,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::Podman,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned,OS::TripleO::Services::OVNController,OS::TripleO::Services::OVNMetadataAgent\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(27,'2026-06-10 07:59:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(28,'2026-06-10 07:59:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ObjectStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(29,'2026-06-10 07:59:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(30,'2026-06-10 07:59:19',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_names\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(31,'2026-06-10 07:59:19',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_names\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(32,'2026-06-10 07:59:20',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_names\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(33,'2026-06-10 07:59:20',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_names\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(34,'2026-06-10 07:59:20',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_names\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (35,'2026-06-10 07:59:20',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::ComputeCeilometerAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CeilometerAgentIpmi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::IpaClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::NovaCompute\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::NovaLibvirt\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::NovaLibvirtGuests\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::NovaMigrationTarget\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::OVNMetadataAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"21\"]}}, \"outputs\": {\"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}]}, \"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (36,'2026-06-10 07:59:20',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::CeilometerAgentCentral\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::CeilometerAgentNotification\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CinderApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::CinderBackup\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::CinderScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::CinderVolume\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::Clustercheck\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::ContainerImagePrepare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::GlanceApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::GlanceApiInternal\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::HAproxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::HeatApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::HeatApiCloudwatch\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::HeatApiCfn\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::HeatEngine\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Horizon\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::IpaClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::Keystone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::ManilaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::ManilaBackendCephFs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::ManilaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"21\"]}, \"26\": {\"type\": \"OS::TripleO::Services::ManilaShare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"22\"]}, \"27\": {\"type\": \"OS::TripleO::Services::Memcached\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"23\"]}, \"28\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"24\"]}, \"29\": {\"type\": \"OS::TripleO::Services::MySQL\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"25\"]}, \"30\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"26\"]}, \"31\": {\"type\": \"OS::TripleO::Services::NeutronApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"27\"]}, \"32\": {\"type\": \"OS::TripleO::Services::NeutronCorePlugin\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"28\"]}, \"33\": {\"type\": \"OS::TripleO::Services::NovaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"29\"]}, \"34\": {\"type\": \"OS::TripleO::Services::NovaConductor\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"30\"]}, \"35\": {\"type\": \"OS::TripleO::Services::NovaMetadata\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"31\"]}, \"36\": {\"type\": \"OS::TripleO::Services::NovaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"32\"]}, \"37\": {\"type\": \"OS::TripleO::Services::NovaVncProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"33\"]}, \"38\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"34\"]}, \"39\": {\"type\": \"OS::TripleO::Services::OVNDBs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"35\"]}, \"40\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"36\"]}, \"41\": {\"type\": \"OS::TripleO::Services::Pacemaker\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"37\"]}, \"42\": {\"type\": \"OS::TripleO::Services::PlacementApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"38\"]}, \"43\": {\"type\": \"OS::TripleO::Services::OsloMessagingRpc\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"39\"]}, \"44\": {\"type\": \"OS::TripleO::Services::OsloMessagingNotify\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"40\"]}, \"45\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"41\"]}, \"46\": {\"type\": \"OS::TripleO::Services::Redis\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"42\"]}, \"47\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"43\"]}, \"48\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"44\"]}, \"49\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"45\"]}, \"50\": {\"type\": \"OS::TripleO::Services::SwiftProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"46\"]}, \"51\": {\"type\": \"OS::TripleO::Services::SwiftRingBuilder\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"47\"]}, \"52\": {\"type\": \"OS::TripleO::Services::SwiftStorage\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"48\"]}, \"53\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"49\"]}, \"54\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"50\"]}, \"55\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"51\"]}, \"56\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"52\"]}, \"57\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"53\"]}}, \"outputs\": {\"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_names\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"step_config\"]}]}, \"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_name\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}, {\"get_attr\": [\"26\", \"role_data\"]}, {\"get_attr\": [\"27\", \"role_data\"]}, {\"get_attr\": [\"28\", \"role_data\"]}, {\"get_attr\": [\"29\", \"role_data\"]}, {\"get_attr\": [\"30\", \"role_data\"]}, {\"get_attr\": [\"31\", \"role_data\"]}, {\"get_attr\": [\"32\", \"role_data\"]}, {\"get_attr\": [\"33\", \"role_data\"]}, {\"get_attr\": [\"34\", \"role_data\"]}, {\"get_attr\": [\"35\", \"role_data\"]}, {\"get_attr\": [\"36\", \"role_data\"]}, {\"get_attr\": [\"37\", \"role_data\"]}, {\"get_attr\": [\"38\", \"role_data\"]}, {\"get_attr\": [\"39\", \"role_data\"]}, {\"get_attr\": [\"40\", \"role_data\"]}, {\"get_attr\": [\"41\", \"role_data\"]}, {\"get_attr\": [\"42\", \"role_data\"]}, {\"get_attr\": [\"43\", \"role_data\"]}, {\"get_attr\": [\"44\", \"role_data\"]}, {\"get_attr\": [\"45\", \"role_data\"]}, {\"get_attr\": [\"46\", \"role_data\"]}, {\"get_attr\": [\"47\", \"role_data\"]}, {\"get_attr\": [\"48\", \"role_data\"]}, {\"get_attr\": [\"49\", \"role_data\"]}, {\"get_attr\": [\"50\", \"role_data\"]}, {\"get_attr\": [\"51\", \"role_data\"]}, {\"get_attr\": [\"52\", \"role_data\"]}, {\"get_attr\": [\"53\", \"role_data\"]}, {\"get_attr\": [\"54\", \"role_data\"]}, {\"get_attr\": [\"55\", \"role_data\"]}, {\"get_attr\": [\"56\", \"role_data\"]}, {\"get_attr\": [\"57\", \"role_data\"]}]}, \"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"26\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"27\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"28\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"29\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"30\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"31\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"32\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"33\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"34\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"35\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"36\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"37\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"38\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"39\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"40\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"41\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"42\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"43\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"44\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"45\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"46\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"47\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"48\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"49\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"50\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"51\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"52\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"53\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"54\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"55\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"56\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"57\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"26\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"27\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"28\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"29\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"30\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"31\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"32\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"33\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"34\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"35\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"36\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"37\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"38\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"39\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"40\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"41\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"42\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"43\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"44\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"45\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"46\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"47\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"48\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"49\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"50\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"51\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"52\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"53\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"54\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"55\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"56\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"57\", \"role_data\", \"config_settings\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"docker_config\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (37,'2026-06-10 07:59:20',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_names\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, service_name\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(38,'2026-06-10 07:59:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CellController server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(39,'2026-06-10 07:59:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a Networker server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"internal_api\", \"tenant\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(40,'2026-06-10 07:59:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CephStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(41,'2026-06-10 07:59:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a ObjectStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(42,'2026-06-10 07:59:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(43,'2026-06-10 07:59:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a BlockStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(44,'2026-06-10 07:59:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CellControllerCompute server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(45,'2026-06-10 07:59:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(46,'2026-06-10 07:59:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (47,'2026-06-10 07:59:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Ipmi service\\n\", \"parameters\": {\"ContainerCeilometerIpmiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentIpmiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.ipmi\", \"file\": \"/var/log/containers/ceilometer/ipmi.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"13qiQT0Nynohgkp6fAkpbtLxa\"}, \"MonitoringSubscriptionCeilometerIpmi\": {\"default\": \"overcloud-ceilometer-agent-ipmi\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CeilometerAgentCentralBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerIpmiImage\": \"ContainerCeilometerIpmiImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerIpmiImage\": {\"get_param\": \"ContainerCeilometerIpmiImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Ipmi role.\", \"value\": {\"service_name\": \"ceilometer_agent_ipmi\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerIpmi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"ipmi_namespace\": true}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_ipmi\": [{\"get_param\": \"CeilometerAgentIpmiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_ipmi\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(48,'2026-06-10 07:59:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"EN0BRljM39cmljy9d0IOJQNAu\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"S7StMMDKvgk7UEFIb9ggBAhnr\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"Gw7UKk275edaf1BK4QNxasIq\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(49,'2026-06-10 07:59:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(50,'2026-06-10 07:59:26',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"blacklist_hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"external_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(51,'2026-06-10 07:59:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(52,'2026-06-10 07:59:26',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"blacklist_hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"external_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(53,'2026-06-10 07:59:26',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"blacklist_hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(54,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Compute service\\n\", \"parameters\": {\"ContainerCeilometerComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerCompute\": {\"default\": \"overcloud-ceilometer-agent-compute\", \"type\": \"string\"}, \"InstanceDiscoveryMethod\": {\"default\": \"libvirt_metadata\", \"description\": \"Method used to discover instances running on compute node\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"naive\", \"libvirt_metadata\", \"workload_partitioning\"]}]}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"13qiQT0Nynohgkp6fAkpbtLxa\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerComputeImage\": \"ContainerCeilometerComputeImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerComputeImage\": {\"get_param\": \"ContainerCeilometerComputeImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Compute role.\", \"value\": {\"service_name\": \"ceilometer_agent_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::polling::instance_discovery_method\": {\"get_param\": \"InstanceDiscoveryMethod\"}}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"compute_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"ceilometer_agent_compute\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerComputeImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_libvirt.target\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(55,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (56,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"blacklist_hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(57,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Add services and subhosts to IPA server\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"PythonInterpreter\": {\"type\": \"string\", \"description\": \"The python interpreter to use for python and ansible actions\", \"default\": \"$(command -v python3 || command -v python)\"}, \"IdMDomain\": {\"default\": \"ooo.test\", \"description\": \"IDM domain to register IDM client. Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"string\"}, \"IdMServer\": {\"default\": \"ipa.ooo.test\", \"description\": \"FQDN for the FreeIPA server.  If you set this value, IdMDomain also has to be provided.  Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"comma_delimited_list\"}, \"IdMNovaKeytab\": {\"default\": \"FILE:/etc/novajoin/krb5.keytab\", \"description\": \"keytab for the nova/[host fqdn] user on the FreeIPA server.\", \"type\": \"string\"}, \"IdMNovaCredentialCache\": {\"default\": \"/etc/novajoin/krb5.cache\", \"description\": \"credential cache for nova/[host fqdn] user\", \"type\": \"string\"}, \"MakeHomeDir\": {\"type\": \"boolean\", \"description\": \"Configure PAM to create a users home directory if it does not exist.\", \"default\": false}, \"IdMNoNtpSetup\": {\"default\": false, \"description\": \"Set to true to add --no-ntp to the IDM client install call. This will cause IDM client install not to set up NTP.\", \"type\": \"boolean\"}, \"IdMEnrollBaseServer\": {\"default\": true, \"description\": \"Set to true to enroll the base server (computes, controllers)\", \"type\": \"boolean\"}, \"IdMInstallClientPackages\": {\"default\": false, \"description\": \"Set to True to have ansible-freeipa install ipa client packages on the overcloud node.\", \"type\": \"boolean\"}, \"IdMModifyDNS\": {\"default\": true, \"description\": \"Set to false to disable DNS records manipulation in the FreeIPA server.\", \"type\": \"boolean\"}, \"IdMZoneSplitIPv4\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}, \"IdMZoneSplitIPv6\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}}, \"conditions\": {\"idm_server_provided\": {\"not\": {\"equals\": [{\"get_param\": \"IdMServer\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ipaservice service\", \"value\": {\"service_name\": \"ipaservice\", \"upgrade_tasks\": [], \"step_config\": \"\", \"ipa_registration_tasks\": [{\"name\": \"Get undercloud FQDN\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"set_fact\": {\"undercloud_fqdn\": \"{{ ansible_facts[\'fqdn\'] }}\"}}, {\"include_role\": {\"name\": \"tripleo_ipa_registration\", \"apply\": {\"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ undercloud_fqdn }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}}, \"vars\": {\"tripleo_ipa_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}, \"tripleo_ipa_delegate_server\": \"{{ inventory_hostname }}\", \"tripleo_ipa_base_server_fqdn\": \"{{ fqdn_canonical }}\", \"tripleo_ipa_server_metadata\": \"{{ service_metadata_settings | to_json }}\"}, \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}, {\"name\": \"Enroll the node as an ipa client\", \"vars\": {\"ipaclient_install_packages\": {\"get_param\": \"IdMInstallClientPackages\"}, \"idm_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}}, \"block\": [{\"name\": \"check if default.conf exists\", \"stat\": {\"path\": \"/etc/ipa/default.conf\"}, \"register\": \"ipa_conf_exists\"}, {\"name\": \"install openssl-perl\", \"become\": true, \"package\": {\"name\": \"openssl-perl\", \"state\": \"present\"}, \"when\": [\"ipaclient_install_packages|bool\"]}, {\"name\": \"register as an ipa client\", \"include_role\": {\"name\": \"ipaclient\", \"apply\": {\"become\": true}}, \"vars\": {\"map_merge\": [{\"state\": \"present\", \"ipaclient_otp\": \"{{ ipa_host_otp }}\", \"ipaclient_mkhomedir\": {\"get_param\": \"MakeHomeDir\"}, \"ipaclient_no_ntp\": {\"get_param\": \"IdMNoNtpSetup\"}, \"ipaclient_force\": true, \"ipaclient_hostname\": \"{{ fqdn_canonical }}\", \"ansible_fqdn\": \"{{ ipaclient_hostname }}\", \"ipaclients\": [\"ipaclient_hostname\"], \"ansible_distribution\": \"{{ ansible_facts[\'distribution\'] }}\", \"ansible_distribution_major_version\": \"{{ ansible_facts[\'distribution_major_version\'] }}\", \"ansible_distribution_release\": \"{{ ansible_facts[\'distribution_release\'] }}\", \"ansible_distribution_version\": \"{{ ansible_facts[\'distribution_version\'] }}\", \"ansible_os_family\": \"{{ ansible_facts[\'os_family\'] }}\"}, {\"if\": [\"idm_server_provided\", {\"ipaclient_servers\": {\"get_param\": \"IdMServer\"}, \"ipaclient_domain\": {\"get_param\": \"IdMDomain\"}}]}]}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"restart certmonger service\", \"become\": true, \"systemd\": {\"state\": \"restarted\", \"daemon_reload\": true, \"name\": \"certmonger.service\"}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"set discovered ipa realm\", \"set_fact\": {\"idm_realm\": {\"str_replace\": {\"template\": \"{{ lookup(\'ini\', \'realm default=DEFAULT section=global file=/etc/ipa/default.conf\')}}\", \"params\": {\"DEFAULT\": {\"yaql\": {\"expression\": \"$.data.toUpper()\", \"data\": {\"get_param\": \"IdMDomain\"}}}}}}}}], \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}], \"external_deploy_tasks\": [{\"name\": \"add the DNS entries into IPA in step 1\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"tripleo_ipa_dns\"}, \"vars\": {\"tripleo_ipa_ptr_zone_split_ipv4\": {\"get_param\": \"IdMZoneSplitIPv4\"}, \"tripleo_ipa_ptr_zone_split_ipv6\": {\"get_param\": \"IdMZoneSplitIPv6\"}}, \"when\": {\"get_param\": \"IdMModifyDNS\"}}], \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ ansible_facts[\'fqdn\'] }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}], \"scale_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"down\", \"block\": [{\"name\": \"unregister node from ipa server\", \"import_role\": {\"name\": \"tripleo_ipa_cleanup\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"vars\": {\"tripleo_ipa_keytab\": {\"get_param\": \"IdMNovaKeytab\"}, \"tripleo_ipa_hosts_to_delete\": [\"{{ fqdn_canonical }}\"]}}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"check if ipa server has required permissions\", \"import_role\": {\"name\": \"tls_everywhere\", \"tasks_from\": \"ipa-server-check\"}, \"tags\": [\"opendev-validation\", \"opendev-validation-tls-everywhere\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(58,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"blacklist_hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"hostname\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(59,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"blacklist_hostname\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(60,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Iscsid service\\n\", \"parameters\": {\"ContainerIscsidImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"ContainerIscsidConfigImage\": {\"description\": \"The container image to use for the iscsid config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LVMFilterEnabled\": {\"default\": false, \"description\": \"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"LVMFilterAllowlist\": {\"default\": [], \"description\": \"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LVMFilterDenylist\": {\"default\": [\".*\"], \"description\": \"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"IscsidCHAPAlgorithms\": {\"default\": \"SHA3-256,SHA256,SHA1,MD5\", \"description\": \"A comma separated list of algorithms to be used for the CHAP algorithm.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo_tripleo_lvmfilter_enabled\": \"LVMFilterEnabled\", \"tripleo_tripleo_lvmfilter_devices_allowlist\": \"LVMFilterAllowlist\", \"tripleo_tripleo_lvmfilter_devices_denylist\": \"LVMFilterDenylist\", \"ContainerIscsidImage\": \"ContainerIscsidImage\", \"ContainerIscsidConfigImage\": \"ContainerIscsidConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"LVMFilterEnabled\": {\"get_param\": \"LVMFilterEnabled\"}, \"LVMFilterAllowlist\": {\"get_param\": \"LVMFilterAllowlist\"}, \"LVMFilterDenylist\": {\"get_param\": \"LVMFilterDenylist\"}, \"ContainerIscsidImage\": {\"get_param\": \"ContainerIscsidImage\"}, \"ContainerIscsidConfigImage\": {\"get_param\": \"ContainerIscsidConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Iscsid role.\", \"value\": {\"service_name\": \"iscsid\", \"config_settings\": {\"tripleo::profile::base::iscsid::chap_algs\": {\"get_param\": \"IscsidCHAPAlgorithms\"}}, \"service_config_settings\": {}, \"deploy_steps_tasks\": [{\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}], \"ansible_group_vars\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidConfigImage\"]}, \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"iscsid\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}], \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(61,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(62,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Notification service\\n\", \"parameters\": {\"ContainerCeilometerNotificationImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentNotificationLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.notification\", \"file\": \"/var/log/containers/ceilometer/agent-notification.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerNotification\": {\"default\": \"overcloud-ceilometer-agent-notification\", \"type\": \"string\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"CeilometerQdrPublishEvents\": {\"default\": false, \"description\": \"Whether to send events to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrPublishMetrics\": {\"default\": false, \"description\": \"Whether to send telemetry data to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrEventsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"event\"}, \"description\": \"Configuration for notifier publisher for events.\", \"type\": \"json\"}, \"CeilometerQdrMetricsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"metering\"}, \"description\": \"Configuration for notifier publisher for metrics.\", \"type\": \"json\"}, \"ManageEventPipeline\": {\"default\": true, \"description\": \"Whether to manage event_pipeline.yaml.\", \"type\": \"boolean\"}, \"EventPipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in event_pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManageEventPipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}, \"ManagePipeline\": {\"default\": false, \"description\": \"Whether to manage pipeline.yaml.\", \"type\": \"boolean\"}, \"PipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManagePipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerNotificationImage\": \"ContainerCeilometerNotificationImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerNotificationImage\": {\"get_param\": \"ContainerCeilometerNotificationImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"conditions\": {\"ceilometer_qdr_publish\": {\"or\": [{\"get_param\": \"CeilometerQdrPublishEvents\"}, {\"get_param\": \"CeilometerQdrPublishMetrics\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Notification role.\", \"value\": {\"service_name\": \"ceilometer_agent_notification\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerNotification\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::notification::manage_event_pipeline\": {\"get_param\": \"ManageEventPipeline\"}, \"ceilometer::agent::notification::manage_pipeline\": {\"get_param\": \"ManagePipeline\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_enabled\": {\"get_param\": \"CeilometerQdrPublishMetrics\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_events_enabled\": {\"get_param\": \"CeilometerQdrPublishEvents\"}, \"tripleo::profile::base::ceilometer::agent::notification::pipeline_publishers\": {\"get_param\": \"PipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::event_pipeline_publishers\": {\"get_param\": \"EventPipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_params\": {\"get_param\": \"CeilometerQdrMetricsConfig\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_event_params\": {\"get_param\": \"CeilometerQdrEventsConfig\"}}, {\"if\": [\"ceilometer_qdr_publish\", {\"tripleo::profile::base::ceilometer::agent::notification::notifier_host_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_host_port\": {\"get_param\": \"MetricsQdrPort\"}}]}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_notification\": [{\"get_param\": \"CeilometerAgentNotificationLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::notification\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_notification.json\": {\"command\": \"/usr/bin/ceilometer-agent-notification --logfile /var/log/ceilometer/agent-notification.log\", \"config_files\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]]}}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_notification\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_notification.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent notification container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_notification\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_notification\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(63,'2026-06-10 07:59:27',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(64,'2026-06-10 07:59:28',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (65,'2026-06-10 07:59:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBackupBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"CinderBackupBackend\": {\"get_param\": \"CinderBackupBackend\"}, \"CinderBackupRbdPoolName\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"CephClientUserName\": {\"get_param\": \"CephClientUserName\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::cinder::backup_bundle::cinder_backup_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::backup_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::backup::manage_service\": false, \"cinder::backup::enabled\": false}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"puppet_config\", \"step_config\"]}, \"include tripleo::profile::pacemaker::cinder::backup_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Backup tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Backup HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-backup temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-backup\", \"tripleo_ha_image_update_new_image\": \"{{cinder_backup_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_backup_image}}\"}, \"when\": [\"(pcmk_cinder_backup_image != \\\"\\\")\", \"(pcmk_cinder_backup_image != cinder_backup_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-backup container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_backup_image == cinder_backup_image_latest\", \"fail_msg\": \"cinder-backup image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder-backup container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"cinder_backup fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder backup bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA cinder_backup container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"Prepare switch of cinder_backup image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_backup image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-backup | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_backup_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_backup image facts\", \"set_fact\": {\"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_backup_image_current\": \"{{cinder_backup_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_backup image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image_current}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}, {\"name\": \"Create cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_backup_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_backup_bootstrap_node={{cinder_backup_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_backup retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_backup_bootstrap_node\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Update the cinder_backup bundle to use the new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-backup container image={{cinder_backup_image_latest}}\"}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_backup retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}, {\"name\": \"Retag the pacemaker image for cinder_backup\", \"when\": [\"step|int == 3\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step3\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(66,'2026-06-10 07:59:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"EN0BRljM39cmljy9d0IOJQNAu\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"S7StMMDKvgk7UEFIb9ggBAhnr\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"Gw7UKk275edaf1BK4QNxasIq\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(67,'2026-06-10 07:59:28',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(68,'2026-06-10 07:59:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"13qiQT0Nynohgkp6fAkpbtLxa\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"S7StMMDKvgk7UEFIb9ggBAhnr\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(69,'2026-06-10 07:59:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(70,'2026-06-10 07:59:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(71,'2026-06-10 07:59:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(72,'2026-06-10 07:59:29',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (73,'2026-06-10 07:59:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(74,'2026-06-10 07:59:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(75,'2026-06-10 07:59:29',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(76,'2026-06-10 07:59:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"EN0BRljM39cmljy9d0IOJQNAu\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"S7StMMDKvgk7UEFIb9ggBAhnr\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"Gw7UKk275edaf1BK4QNxasIq\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(77,'2026-06-10 07:59:29',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(78,'2026-06-10 07:59:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(79,'2026-06-10 07:59:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"13qiQT0Nynohgkp6fAkpbtLxa\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"S7StMMDKvgk7UEFIb9ggBAhnr\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(80,'2026-06-10 07:59:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"EN0BRljM39cmljy9d0IOJQNAu\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"S7StMMDKvgk7UEFIb9ggBAhnr\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"Gw7UKk275edaf1BK4QNxasIq\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (81,'2026-06-10 07:59:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"EN0BRljM39cmljy9d0IOJQNAu\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"S7StMMDKvgk7UEFIb9ggBAhnr\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"Gw7UKk275edaf1BK4QNxasIq\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(82,'2026-06-10 07:59:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(83,'2026-06-10 07:59:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(84,'2026-06-10 07:59:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder API service\\n\", \"parameters\": {\"ContainerCinderApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.api\", \"file\": \"/var/log/containers/cinder/cinder-api.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"CinderDefaultVolumeType\": {\"default\": \"tripleo\", \"description\": \"The name of Cinder\'s default volume type.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \".*\\\\S.*\", \"description\": \"The default volume type name cannot be empty.\\n\"}]}, \"CinderEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Cinder database.\\n\", \"type\": \"boolean\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V7WgDxaLxT5M80e5C9n2UCcFO\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionCinderApi\": {\"default\": \"overcloud-cinder-api\", \"type\": \"string\"}, \"CinderWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for cinder::wsgi::apache\", \"default\": 1}, \"CinderApiPolicies\": {\"description\": \"A hash of policies to configure for Cinder API.\\ne.g. { cinder-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"CinderApiWsgiTimeout\": {\"default\": 60, \"description\": \"The number of seconds until a Cinder API WSGI connection times out.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderApiImage\": \"ContainerCinderApiImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderApiImage\": {\"get_param\": \"ContainerCinderApiImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder API role.\", \"value\": {\"service_name\": \"cinder_api\", \"firewall_rules\": {\"119 cinder\": {\"dport\": [8776]}}, \"firewall_frontend_rules\": {\"100 cinder_haproxy_frontend\": {\"dport\": [8776]}}, \"firewall_ssl_frontend_rules\": {\"100 cinder_haproxy_frontend_ssl\": {\"dport\": [13776]}}, \"keystone_resources\": {\"cinder\": {\"users\": {\"cinder\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}}, \"cinderv3\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"CinderV3Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"CinderV3Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"CinderV3Admin\", \"uri\"]}}, \"users\": {\"cinderv3\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"volumev3\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"keystone_resources_managed\": false}, {\"cinder::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::authtoken::project_name\": \"service\", \"cinder::keystone::authtoken::user_domain_name\": \"Default\", \"cinder::keystone::authtoken::project_domain_name\": \"Default\", \"cinder::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::keystone::authtoken::interface\": \"internal\", \"cinder::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"cinder::policy::policies\": {\"get_param\": \"CinderApiPolicies\"}, \"cinder::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"cinder::api::default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}, \"cinder::api::enable_proxy_headers_parsing\": true, \"tripleo::profile::base::cinder::cinder_enable_db_purge\": {\"get_param\": \"CinderEnableDBPurge\"}, \"cinder::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"cinder::api::service_name\": \"httpd\", \"cinder::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::vhost_custom_fragment\": {\"str_replace\": {\"template\": \"Timeout TIMEOUT\", \"params\": {\"TIMEOUT\": {\"get_param\": \"CinderApiWsgiTimeout\"}}}}, \"cinder::wsgi::apache::workers\": {\"get_param\": \"CinderWorkers\"}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_api\": [{\"get_param\": \"CinderApiLoggingSource\"}]}, \"mysql\": {\"cinder::db::mysql::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::db::mysql::user\": \"cinder\", \"cinder::db::mysql::host\": \"%\", \"cinder::db::mysql::dbname\": \"cinder\"}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line,cinder_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec cinder_api su cinder -s /bin/bash -c \'cinder-manage db sync --bump-versions\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"cinder_api_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_3\": {\"cinder_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"cinder_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"cinder_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron cinder\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/cinder-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}, {\"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_api\", \"cinder_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}], \"external_deploy_tasks\": [{\"name\": \"Clean up legacy Cinder keystone catalog entries\", \"become\": true, \"openstack.cloud.catalog_service\": {\"cloud\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}, \"name\": \"{{ item.service_name }}\", \"service_type\": \"{{ item.service_type }}\", \"state\": \"absent\"}, \"loop\": [{\"service_name\": \"cinderv2\", \"service_type\": \"volumev2\"}, {\"service_name\": \"cinderv3\", \"service_type\": \"volume\"}], \"loop_control\": {\"index_var\": \"cinder_api_service\"}, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"]}, {\"name\": \"Manage Cinder\'s default volume type\", \"become\": true, \"vars\": {\"default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}}, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"when\": [\"step|int == 5\", \"not ansible_check_mode|bool\"], \"shell\": \"if ! openstack volume type show \\\"{{ default_volume_type }}\\\"; then\\n    openstack volume type create --public \\\"{{ default_volume_type }}\\\"\\nfi\\neval $(openstack volume type show __DEFAULT__ -f shell -c id -c description)\\nif [ -n \\\"$id\\\" ]; then\\n    if ! openstack volume type delete $id ; then\\n        tripleo_descr=\\\"For internal use, \'{{ default_volume_type }}\' is the default volume type\\\"\\n        if [ \\\"$description\\\" != \\\"$tripleo_descr\\\" ]; then\\n            openstack volume type set $id --description \\\"$tripleo_descr\\\"\\n        fi\\n    fi\\nfi\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"changed_when\": false}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(85,'2026-06-10 07:59:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Migration Target service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DockerNovaMigrationSshdPort\": {\"default\": 2022, \"description\": \"Port that dockerized nova migration target sshd service binds to.\", \"type\": \"number\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"SshdBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Migration Target service.\", \"value\": {\"service_name\": \"nova_migration_target\", \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept libvirt subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept api subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"SshdBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\": [{\"get_param\": [\"MigrationSshKey\", \"public_key\"]}], \"tripleo::profile::base::nova::migration::target::ssh_localaddrs\": [\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\", \"%{hiera(\'live_migration_ssh_inbound_addr\')}\"], \"live_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"cold_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"tripleo::profile::base::sshd::port\": [22]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"SshdBase\", \"role_data\", \"step_config\"]}, \"include tripleo::profile::base::nova::migration::target\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova-migration-target.json\": {\"command\": {\"str_replace\": {\"template\": \"dumb-init --single-child -- /usr/sbin/sshd -D -p SSHDPORT\", \"params\": {\"SSHDPORT\": {\"get_param\": \"DockerNovaMigrationSshdPort\"}}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/host-ssh/ssh_host_*_key\", \"dest\": \"/etc/ssh/\", \"owner\": \"root\", \"perm\": \"0600\"}]}}, \"host_prep_tasks\": [{\"name\": \"Create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"loop\": [{\"path\": \"/run/libvirt\", \"setype\": \"virt_var_run_t\"}]}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}], \"docker_config\": {\"step_4\": {\"nova_migration_target\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/etc/ssh:/host-ssh:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"validate nova-migration-target container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_migration_target\"}, \"register\": \"nova_migration_target_infos\", \"failed_when\": [\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], \"update_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}], \"upgrade_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(86,'2026-06-10 07:59:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(87,'2026-06-10 07:59:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(88,'2026-06-10 07:59:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (89,'2026-06-10 07:59:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Compute service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"DockerNovaComputeUlimit\": {\"default\": [\"nofile=131072\", \"memlock=67108864\"], \"description\": \"ulimit for Nova Compute Container\", \"type\": \"comma_delimited_list\"}, \"NovaComputeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.compute\", \"file\": \"/var/log/containers/nova/nova-compute.log\"}}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"NovaComputeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaComputeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"NovaComputeStartupDelay\": {\"default\": 0, \"description\": \"Delays the startup of nova-compute service after compute node is booted. This is to give a chance to ceph to get back healthy before booting instances after and overcloud reboot.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 0, \"max\": 600}}], \"tags\": [\"role_specific\"]}, \"EnableInstanceHA\": {\"default\": false, \"description\": \"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\", \"type\": \"boolean\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"NovaMkisofsCmd\": {\"default\": \"mkisofs\", \"description\": \"Name or path of the tool used for ISO image creation.\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsEnabled\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Nova\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsOptions\": {\"default\": \"context=system_u:object_r:nfs_t:s0\", \"description\": \"NFS mount options for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsVersion\": {\"default\": \"4.2\", \"description\": \"NFS version used for nova storage (when NovaNfsEnabled is true). Since NFSv3 does not support full locking a NFSv4 version need to be used.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^4.?[0-9]?\"}], \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeForceRawImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to convert non-raw cached base images to raw format.\\nSet to \\\"False\\\" if you have a system with slow I/O or low available space,\\ntrading the higher CPU requirements of compression for that of minimized input\\nbandwidth.\\nNotes::\\n- The Compute service removes any compression from the base image during\\n  compression, to avoid CPU bottlenecks. Converted images cannot have backing\\n  files, which might be a security issue.\\n- The raw image format uses more space than other image formats, for example,\\n  qcow2.\\n  Raw base images are always used with libvirt_images_type=lvm.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeUseCowImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to use CoW (Copy on Write) images in cqow2 format for libvirt\\ninstance disks. With CoW, depending on the backing store and host caching,\\nthere might be better concurrency achieved by having each instance operate\\non its own copy.\\nSet to \\\"False\\\" to use the raw format. Raw format uses more space for common\\nparts of the disk image.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtPreAllocateImages\": {\"default\": \"none\", \"description\": \"Specifies the preallocation mode for libvirt instance disks.\\nSet to one of the following valid values::\\n- none - No storage is provisioned at instance start.\\n- space - Storage is fully allocated at instance start using fallocate,\\n          which can help with both space guarantees and I/O performance.\\n\\nEven when not using CoW instance disks, the copy each instance gets is sparse\\nand so the instance might fail unexpectedly at run time with ENOSPC. By\\nrunning fallocate(1) on the instance disk images, the Compute service\\nimmediately and efficiently allocates the space for them in the file system,\\nif supported. Run time performance should also be improved because the file\\nsystem does not have to dynamically allocate blocks at run time, which reduces\\nCPU overhead and file fragmentation.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"space\"]}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheManagerInterval\": {\"default\": 2400, \"description\": \"Specifies the number of seconds to wait between runs of the image cache\\nmanager, which impacts base image caching on Compute nodes. This period\\nis used in the auto removal of unused cached images configured with\\nremove_unused_base_images and remove_unused_original_minimum_age_seconds.\\n\\nSet to \\\"0\\\" to run at the default interval of 60 seconds (not recommended)\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": -1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to automatically remove unused base images from the cache\\nat intervals configured by using image_cache_manager_interval. Images\\nare defined as unused if they have not been accessed during the time\\nspecified by using remove_unused_original_minimum_age_seconds.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"default\": 3600, \"description\": \"Specifies the minimum age that an unused resized base image must be to\\nbe removed from the cache, in seconds. Unused unresized base images\\nyounger than this will not be removed.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCachePrecacheConcurrency\": {\"default\": 1, \"description\": \"Maximum number of Compute nodes to trigger image precaching in parallel.\\nWhen an image precache request is made, Compute nodes are contacted {by\\nwho/which service} to initiate the download.\\n\\nHigher numbers will cause more computes to work in parallel and may result\\nin reduced time to complete the operation, but may also DDoS the image\\nservice. Lower numbers will result in more sequential operation, lower\\nimage service load, but likely longer runtime to completion.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaPCIPassthrough\": {\"description\": \"List of PCI Passthrough whitelist parameters. Example - NovaPCIPassthrough:\\n  - vendor_id: \\\"8086\\\"\\n    product_id: \\\"154c\\\"\\n    address: \\\"0000:05:00.0\\\"\\n    physical_network: \\\"datacentre\\\"\\nFor different formats, refer to the nova.conf documentation for pci_passthrough_whitelist configuration\\n\", \"type\": \"json\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeCpuSharedSet\": {\"description\": \"The behavior of this option depends on the deprecated `NovaVcpuPinSet` option:\\n\\n* `NovaVcpuPinSet` is not set: `NovaComputeCpuSharedSet` is set to a\\n  comma-separated list or range of physical host CPU numbers used to:\\n\\n  - provide vCPU inventory\\n  - determine the host CPUs that unpinned instances can be scheduled to\\n  - determine the host CPUS that instance emulator threads should be\\n    offloaded to for instances configured with the share emulator thread\\n    policy, `hw:emulator_threads_policy=share`\\n\\n* `NovaVcpuPinSet` is set: `NovaComputeCpuSharedSet` is set to a list or\\n  range of host CPU cores used to determine the host CPUs that instance\\n  emulator threads should be offloaded to for instances configured with\\n  the share emulator thread policy (`hw:emulator_threads_policy=share`).\\n  In this case, `NovaVcpuPinSet` is used to provide vCPU inventory and to\\n  determine the host CPUs that both pinned and unpinned instances can be\\n  scheduled to.\\n\\nEx. NovaComputeCpuSharedSet: [4-12,^8,15] will reserve cores from 4-12\\nand 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaComputeCpuDedicatedSet\": {\"description\": \"A list or range of host CPU cores to which processes for pinned instance CPUs (PCPUs) can be scheduled. Ex. NovaComputeCpuDedicatedSet: [4-12,^8,15] will reserve cores from 4-12 and 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaReservedHostMemory\": {\"description\": \"Reserved RAM for host processes.\\n\", \"type\": \"number\", \"default\": 512, \"constraints\": [{\"range\": {\"min\": 512}}], \"tags\": [\"role_specific\"]}, \"NovaReservedHugePages\": {\"description\": \"A list of valid key=value which reflect NUMA node ID, page size (Default unit is KiB) and number of pages to be reserved. Example - NovaReservedHugePages: [\\\"node:0,size:2048,count:64\\\",\\\"node:1,size:1GB,count:1\\\"] will reserve on NUMA node 0 64 pages of 2MiB and on NUMA node 1 1 page of 1GiB\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"OvsDpdkSocketMemory\": {\"default\": \"\", \"description\": \"Sets the amount of hugepage memory to assign per NUMA node. It is recommended to use the socket closest to the PCIe slot used for the desired DPDK NIC.  The format should be in \\\"<socket 0 mem>, <socket 1 mem>, <socket n mem>\\\", where the value is specified in MB.  For example: \\\"1024,0\\\".\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"MonitoringSubscriptionNovaCompute\": {\"default\": \"overcloud-nova-compute\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"VerifyGlanceSignatures\": {\"default\": false, \"description\": \"Whether to verify image signatures.\", \"type\": \"boolean\"}, \"NovaAutoDisabling\": {\"default\": \"10\", \"description\": \"Max number of consecutive build failures before the nova-compute will disable itself.\", \"type\": \"string\"}, \"NeutronPhysnetNUMANodesMapping\": {\"description\": \"Map of physnet name as key and NUMA nodes as value.\\nEx. NeutronPhysnetNUMANodesMapping: {\'foo\': [0, 1], \'bar\': [1]} where `foo` and `bar` are\\nphysnet names and corresponding values are list of associated numa_nodes.\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NeutronTunnelNUMANodes\": {\"description\": \"Used to configure NUMA affinity for all tunneled networks.\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtRxQueueSize\": {\"description\": \"virtio-net RX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtTxQueueSize\": {\"description\": \"virtio-net TX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtFileBackedMemory\": {\"description\": \"Available capacity in MiB for file-backed memory. When configured, the ``NovaRAMAllocationRatio`` and ``NovaReservedHostMemory`` parameters must be set to 0.\\n\", \"default\": 0, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtVolumeUseMultipath\": {\"default\": false, \"description\": \"Whether to enable or not the multipath connection of the volumes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaHWMachineType\": {\"description\": \"To specify a default machine type per host architecture.\\n\", \"default\": \"x86_64=pc-q35-rhel9.0.0\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaComputeEnableKsm\": {\"default\": false, \"description\": \"Whether to enable KSM on compute nodes or not. Especially in NFV use case one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"U723oHmIgjQCMvwRlNhiXicOo\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V7WgDxaLxT5M80e5C9n2UCcFO\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NovaLibvirtNumPciePorts\": {\"description\": \"Set `num_pcie_ports` to specify the number of PCIe ports an instance will get. Libvirt allows a custom number of PCIe ports (pcie-root-port controllers) a target instance will get. Some will be used by default, rest will be available for hotplug use.\\n\", \"default\": 16, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"description\": \"A number of seconds to memory usage statistics period, zero or negative value mean to disable memory usage statistics.\\n\", \"default\": 10, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationWaitForVIFPlug\": {\"description\": \"Whether to wait for `network-vif-plugged` events before starting guest transfer.\", \"default\": true, \"type\": \"boolean\"}, \"NovaLiveMigrationPermitPostCopy\": {\"description\": \"If \\\"True\\\" activates the instance on the destination node before migration is complete, and to set an upper bound on the memory that needs to be transferred. Post copy gets enabled per default if the compute roles is not a realtime role or disabled by this parameter.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationPermitAutoConverge\": {\"description\": \"Defaults to \\\"True\\\" to slow down the instance CPU until the memory copy process is faster than the instance\'s memory writes when the migration performance is slow and might not complete. Auto converge will only be used if this flag is set to True and post copy is not permitted or post copy is unavailable due to the version of libvirt and QEMU.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"NovaCPUAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual CPU to physical CPU allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaRAMAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual RAM to physical RAM allocation ratio.\", \"default\": 1.0, \"tags\": [\"role_specific\"]}, \"NovaDiskAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual disk to physical disk allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaEnableVTPM\": {\"type\": \"boolean\", \"description\": \"Whether to enable support for enumlated Trusted Platform Module (TPM) devices.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaMaxDiskDevicesToAttach\": {\"type\": \"number\", \"description\": \"Maximum number of disk devices allowed to attach to a single server. Note that the number of disks supported by an server depends on the bus used. For example, the ide disk bus is limited to 4 attached devices. The configured maximum is enforced during server create, rebuild, evacuate, unshelve, live migrate, and attach volume. Operators changing this parameter on a compute service that is hosting servers should be aware that it could cause rebuilds to fail, if the maximum is decreased lower than the number of devices already attached to servers. Operators should also be aware that during a cold migration, the configured maximum is only enforced in-place and the destination is not checked before the move. -1 means unlimited\\n\", \"default\": -1, \"tags\": [\"role_specific\"]}, \"NovaPMEMMappings\": {\"type\": \"string\", \"description\": \"PMEM namespace mappings as backend for vPMEM feature. This parameter sets Nova\'s `pmem_namespaces` configuration options. PMEM namespaces needs to be create manually or with conjunction with `NovaPMEMNamespaces` parameter. Requires format: $LABEL:$NSNAME[|$NSNAME][,$LABEL:$NSNAME[|$NSNAME]].\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaPMEMNamespaces\": {\"type\": \"string\", \"description\": \"Creates PMEM namespaces on the host server using `ndctl` tool through Ansible. Requires format: $SIZE:$NSNAME[,$SIZE:$NSNAME...]. $SIZE supports the suffixes \\\"k\\\" or \\\"K\\\" for KiB, \\\"m\\\" or \\\"M\\\" for MiB, \\\"g\\\" or \\\"G\\\" for GiB and \\\"t\\\" or \\\"T\\\" for TiB. NOTE: This requires properly configured NVDIMM regions and enough space for requested namespaces.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaImageCacheTTL\": {\"type\": \"number\", \"description\": \"Time in seconds that nova compute should continue caching an image once it is no longer used by any instances on the host\\n\", \"default\": 86400, \"tags\": [\"role_specific\"]}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"type\": \"json\", \"description\": \"Map of vgpu type(s) the instances can get as key and list of corresponding device addresses as value. Ex. NovaVGPUTypesDeviceAddressesMapping: {\'nvidia-35\': [\'0000:84:00.0\', \'0000:85:00.0\'],\\n                                  \'nvidia-36\': [\'0000:86:00.0\']}\\nwhere `nvidia-35` and `nvidia-36` are vgpu types and corresponding values are list of associated device addresses.\\n\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NovaComputeDisableIrqBalance\": {\"default\": false, \"description\": \"Whether to disable irqbalance on compute nodes or not. Especially in Realtime Compute role one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUMode\": {\"type\": \"string\", \"description\": \"The libvirt CPU mode to configure. Defaults to \'host-model\' if virt_type is set to kvm, otherwise defaults to \'none\'\\n\", \"default\": \"host-model\", \"constraints\": [{\"allowed_values\": [\"custom\", \"host-model\", \"none\", \"host-passthrough\"]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModels\": {\"type\": \"comma_delimited_list\", \"description\": \"The named libvirt CPU model (see names listed in /usr/share/libvirt/cpu_map.xml). Only has effect if cpu_mode=\\\"custom\\\" and virt_type=\\\"kvm|qemu\\\"\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModelExtraFlags\": {\"type\": \"string\", \"description\": \"This allows specifying granular CPU feature flags when specifying CPU models. Only has effect if cpu_mode is not set to \'none\'.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaDisableImageDownloadToRbd\": {\"type\": \"boolean\", \"description\": \"Refuse to boot an instance if it would require downloading from glance and uploading to ceph instead of a COW clone.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaDisableComputeServiceCheckForFfu\": {\"type\": \"boolean\", \"description\": \"Facilitate a Fast-Forward upgrade where new control services are being started before compute nodes have been able to update their service record.\\n\", \"default\": false}, \"NovaStatedirOwnershipSkip\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths relative to nova_statedir to ignore when recursively setting the ownership and selinux context.\\n\", \"default\": [\"triliovault-mounts\"]}, \"NovaImageTypeExcludeList\": {\"type\": \"comma_delimited_list\", \"description\": \"List of image formats that should not be advertised as supported by the compute service.\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtMaxQueues\": {\"type\": \"number\", \"description\": \"Add parameter to configure the libvirt max_queues. The maximum number of virtio queue pairs that can be enabled when creating a multiqueue guest. The number of virtio queues allocated will be the lesser of the CPUs requested by the guest and the max value defined. Default 0 corresponds to not set\\n\", \"default\": 0, \"tags\": [\"role_specific\"]}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"NovaGlanceEnableRbdDownload\": {\"type\": \"boolean\", \"description\": \"Enable download of Glance images directly via RBD.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdDownloadMultistoreID\": {\"type\": \"string\", \"description\": \"The hash key, which is the backend ID, of the GlanceMultistoreConfig to be used for the role where NovaGlanceEnableRbdDownload is enabled and defaults should be overridden. If CephClientUserName or GlanceRbdPoolName are not set in the GlanceMultistoreConfig, the global values of those parameters will be used.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"NovaGlanceRbdCopyPollInterval\": {\"type\": \"number\", \"description\": \"The interval in seconds with which to poll Glance after asking for it to copy an image to the local rbd store.\\n\", \"default\": 15, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdCopyTimeout\": {\"type\": \"number\", \"description\": \"The overall maximum time we will wait for Glance to complete an image copy to our local rbd store.\\n\", \"default\": 600, \"tags\": [\"role_specific\"]}, \"CustomProviderInventories\": {\"description\": \"Array of hashes describing the custom providers for the compute role.\\nFormat:\\nname/uuid - Resource providers to target can be identified by either\\nUUID or name. In addition, the value $COMPUTE_NODE can be used in\\nthe UUID field to identify all nodes managed by the service.\\nExactly one of uuid or name is mandatory. If neither uuid or name\\nis provided, the special uuid $COMPUTE_NODE gets set in the template.\\n\\ninventories - (Optional) Hash of custom provider inventories. \'total\' is\\na mandatory property. Any other optional properties not populated will\\nbe given a default value by placement. If overriding a pre-existing\\nprovider values will not be preserved from the existing inventory.\\n\\ntraits - (Optional) Array of additional traits.\\nExample:\\nComputeParameters:\\n  CustomProviderInventories:\\n    - uuid: $COMPUTE_NODE\\n      inventories:\\n        CUSTOM_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n          reserved: 0\\n          min_unit: 1\\n          max_unit: 10\\n          step_size: 1\\n          allocation_ratio: 1.0\\n        CUSTOM_ANOTHER_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n      traits:\\n        - CUSTOM_P_STATE_ENABLED\\n        - CUSTOM_C_STATE_ENABLED\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaVcpuPinSet\": {\"description\": \"A list or range of host CPU cores to which processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is set, or to which both emulator threads and processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is unset. Ex. NovaVcpuPinSet: [\'4-12\',\'^8\'] will reserve cores from 4-12 excluding 8\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenstack mailing list.\\n\", \"parameters\": [\"NovaVcpuPinSet\"]}], \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"compute_startup_delay\": {\"and\": [{\"not\": {\"get_param\": \"EnableInstanceHA\"}}, {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaComputeStartupDelay\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, \"\"]}]}]}}]}, \"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"enable_live_migration_tunnelled\": {\"and\": [{\"or\": [{\"and\": [{\"get_param\": \"NovaNfsEnabled\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, true]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}]}, {\"not\": \"use_tls_for_live_migration\"}]}, \"libvirt_file_backed_memory_enabled\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtFileBackedMemory\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, \"\"]}]}]}}, \"reserved_huge_pages_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaReservedHugePages\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaReservedHugePages\"}, []]}]}}, \"is_realtime\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"TunedProfileName\"]}, \"realtime-virtual-host\"]}, \"ovs_dpdk_socket_memory_not_set\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"OvsDpdkSocketMemory\"}, \"\"]}]}, \"nova_libvirt_max_queues_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtMaxQueues\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, 0]}]}]}}, \"glance_enable_rbd_download_set\": {\"or\": [{\"and\": [{\"get_param\": \"NovaGlanceEnableRbdDownload\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, true]}]}, \"nova_glance_rbd_download_multistore_id_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceRbdDownloadMultistoreID\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"\"]}]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"NovaComputeCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"NovaServiceName\": \"compute\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::vcpu_pin_set\": \"NovaVcpuPinSet\", \"nova::compute::cpu_shared_set\": \"NovaComputeCpuSharedSet\", \"nova::compute::cpu_dedicated_set\": \"NovaComputeCpuDedicatedSet\", \"nova::compute::reserved_host_memory\": \"NovaReservedHostMemory\", \"nova::compute::reserved_huge_pages\": \"NovaReservedHugePages\", \"nova::compute::neutron_physnets_numa_nodes_mapping\": \"NeutronPhysnetNUMANodesMapping\", \"nova::compute::neutron_tunnel_numa_nodes\": \"NeutronTunnelNUMANodes\", \"nova::compute::resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt::rx_queue_size\": \"NovaLibvirtRxQueueSize\", \"nova::compute::libvirt::tx_queue_size\": \"NovaLibvirtTxQueueSize\", \"nova::compute::libvirt::file_backed_memory\": \"NovaLibvirtFileBackedMemory\", \"nova::compute::libvirt::volume_use_multipath\": \"NovaLibvirtVolumeUseMultipath\", \"nova::compute::libvirt::hw_machine_type\": \"NovaHWMachineType\", \"nova::compute::mkisofs_cmd\": \"NovaMkisofsCmd\", \"compute_enable_ksm\": \"NovaComputeEnableKsm\", \"nova::compute::rbd::libvirt_images_rbd_pool\": \"NovaRbdPoolName\", \"tripleo::profile::base::nova::compute::nova_nfs_enabled\": \"NovaNfsEnabled\", \"nfs_backend_enable\": \"NovaNfsEnabled\", \"nfs_share\": \"NovaNfsShare\", \"nfs_options\": \"NovaNfsOptions\", \"nfs_vers\": \"NovaNfsVersion\", \"nova::compute::libvirt::num_pcie_ports\": \"NovaLibvirtNumPciePorts\", \"nova::compute::libvirt::mem_stats_period_seconds\": \"NovaLibvirtMemStatsPeriodSeconds\", \"nova::compute::rbd::ephemeral_storage\": \"NovaEnableRbdBackend\", \"resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::cpu_allocation_ratio\": \"NovaCPUAllocationRatio\", \"nova::ram_allocation_ratio\": \"NovaRAMAllocationRatio\", \"nova::disk_allocation_ratio\": \"NovaDiskAllocationRatio\", \"nova::compute::max_disk_devices_to_attach\": \"NovaMaxDiskDevicesToAttach\", \"nova::compute::libvirt::pmem_namespaces\": \"NovaPMEMMappings\", \"nova_pmem_namespaces\": \"NovaPMEMNamespaces\", \"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\": \"NovaImageCacheTTL\", \"nova::compute::libvirt::swtpm_enabled\": \"NovaEnableVTPM\", \"nova::compute::vgpu::vgpu_types_device_addresses_mapping\": \"NovaVGPUTypesDeviceAddressesMapping\", \"compute_disable_irqbalance\": \"NovaComputeDisableIrqBalance\", \"nova::compute::libvirt::cpu_mode\": \"NovaLibvirtCPUMode\", \"nova::compute::libvirt::cpu_models\": \"NovaLibvirtCPUModels\", \"nova::compute::libvirt::cpu_model_extra_flags\": \"NovaLibvirtCPUModelExtraFlags\", \"nova_compute_opt_volumes\": \"NovaComputeOptVolumes\", \"nova_compute_startup_delay\": \"NovaComputeStartupDelay\", \"nova_compute_opt_env_vars\": \"NovaComputeOptEnvVars\", \"nova::workarounds::never_download_image_if_on_rbd\": \"NovaDisableImageDownloadToRbd\", \"nova::compute::image_type_exclude_list\": \"NovaImageTypeExcludeList\", \"nova_permit_post_copy\": \"NovaLiveMigrationPermitPostCopy\", \"nova_permit_auto_converge\": \"NovaLiveMigrationPermitAutoConverge\", \"nova_libvirt_max_queues\": \"NovaLibvirtMaxQueues\", \"nova_glance_enable_rbd_download\": \"NovaGlanceEnableRbdDownload\", \"nova_glance_rbd_download_multistore_id\": \"NovaGlanceRbdDownloadMultistoreID\", \"nova::compute::force_raw_images\": \"NovaComputeForceRawImages\", \"nova::compute::use_cow_images\": \"NovaComputeUseCowImages\", \"nova::compute::libvirt::preallocate_images\": \"NovaComputeLibvirtPreAllocateImages\", \"nova::compute::image_cache::manager_interval\": \"NovaComputeImageCacheManagerInterval\", \"nova::compute::image_cache::remove_unused_base_images\": \"NovaComputeImageCacheRemoveUnusedBaseImages\", \"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\", \"nova::compute::image_cache::precache_concurrency\": \"NovaComputeImageCachePrecacheConcurrency\", \"nova::compute::provider::custom_inventories\": \"CustomProviderInventories\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\": \"NovaGlanceRbdCopyPollInterval\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\": \"NovaGlanceRbdCopyTimeout\", \"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaVcpuPinSet\": {\"get_param\": \"NovaVcpuPinSet\"}, \"NovaComputeCpuSharedSet\": {\"get_param\": \"NovaComputeCpuSharedSet\"}, \"NovaComputeCpuDedicatedSet\": {\"get_param\": \"NovaComputeCpuDedicatedSet\"}, \"NovaReservedHostMemory\": {\"get_param\": \"NovaReservedHostMemory\"}, \"NovaReservedHugePages\": {\"if\": [\"reserved_huge_pages_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"if\": [\"ovs_dpdk_socket_memory_not_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"repeat\": {\"for_each\": {\"<%node%>\": {\"yaql\": {\"expression\": \"range(0,len($.data.dpdk_p)).join(\\\",\\\").split(\\\",\\\")\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}}}}, \"<%size%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\")) -> [$hz]*len($.data.dpdk_p)\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}, \"<%count%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>int(switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\"))) -> $.data.dpdk_p.select(int($)*1024/$hz).join(\\\",\\\").split(\',\')\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}}, \"template\": \"node:<%node%>,size:<%size%>,count:<%count%>\", \"permutations\": false}}]}]}, \"NeutronPhysnetNUMANodesMapping\": {\"get_param\": \"NeutronPhysnetNUMANodesMapping\"}, \"NeutronTunnelNUMANodes\": {\"get_param\": \"NeutronTunnelNUMANodes\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaLibvirtRxQueueSize\": {\"get_param\": \"NovaLibvirtRxQueueSize\"}, \"NovaLibvirtTxQueueSize\": {\"get_param\": \"NovaLibvirtTxQueueSize\"}, \"NovaLibvirtFileBackedMemory\": {\"get_param\": \"NovaLibvirtFileBackedMemory\"}, \"NovaLibvirtVolumeUseMultipath\": {\"get_param\": \"NovaLibvirtVolumeUseMultipath\"}, \"NovaHWMachineType\": {\"get_param\": \"NovaHWMachineType\"}, \"NovaComputeEnableKsm\": {\"get_param\": \"NovaComputeEnableKsm\"}, \"NovaRbdPoolName\": {\"get_param\": \"NovaRbdPoolName\"}, \"NovaMkisofsCmd\": {\"get_param\": \"NovaMkisofsCmd\"}, \"NovaNfsEnabled\": {\"get_param\": \"NovaNfsEnabled\"}, \"NovaNfsShare\": {\"get_param\": \"NovaNfsShare\"}, \"NovaNfsOptions\": {\"get_param\": \"NovaNfsOptions\"}, \"NovaNfsVersion\": {\"get_param\": \"NovaNfsVersion\"}, \"NovaLibvirtNumPciePorts\": {\"get_param\": \"NovaLibvirtNumPciePorts\"}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"get_param\": \"NovaLibvirtMemStatsPeriodSeconds\"}, \"NovaEnableRbdBackend\": {\"get_param\": \"NovaEnableRbdBackend\"}, \"NovaCPUAllocationRatio\": {\"get_param\": \"NovaCPUAllocationRatio\"}, \"NovaRAMAllocationRatio\": {\"get_param\": \"NovaRAMAllocationRatio\"}, \"NovaDiskAllocationRatio\": {\"get_param\": \"NovaDiskAllocationRatio\"}, \"NovaEnableVTPM\": {\"get_param\": \"NovaEnableVTPM\"}, \"NovaMaxDiskDevicesToAttach\": {\"get_param\": \"NovaMaxDiskDevicesToAttach\"}, \"NovaPMEMMappings\": {\"get_param\": \"NovaPMEMMappings\"}, \"NovaPMEMNamespaces\": {\"get_param\": \"NovaPMEMNamespaces\"}, \"NovaImageCacheTTL\": {\"get_param\": \"NovaImageCacheTTL\"}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"get_param\": \"NovaVGPUTypesDeviceAddressesMapping\"}, \"NovaComputeDisableIrqBalance\": {\"get_param\": \"NovaComputeDisableIrqBalance\"}, \"NovaLibvirtCPUMode\": {\"get_param\": \"NovaLibvirtCPUMode\"}, \"NovaLibvirtCPUModels\": {\"get_param\": \"NovaLibvirtCPUModels\"}, \"NovaLibvirtCPUModelExtraFlags\": {\"get_param\": \"NovaLibvirtCPUModelExtraFlags\"}, \"NovaComputeOptVolumes\": {\"get_param\": \"NovaComputeOptVolumes\"}, \"NovaComputeStartupDelay\": {\"get_param\": \"NovaComputeStartupDelay\"}, \"NovaComputeOptEnvVars\": {\"get_param\": \"NovaComputeOptEnvVars\"}, \"NovaDisableImageDownloadToRbd\": {\"get_param\": \"NovaDisableImageDownloadToRbd\"}, \"NovaImageTypeExcludeList\": {\"get_param\": \"NovaImageTypeExcludeList\"}, \"NovaLiveMigrationPermitPostCopy\": {\"get_param\": \"NovaLiveMigrationPermitPostCopy\"}, \"NovaLiveMigrationPermitAutoConverge\": {\"get_param\": \"NovaLiveMigrationPermitAutoConverge\"}, \"NovaLibvirtMaxQueues\": {\"get_param\": \"NovaLibvirtMaxQueues\"}, \"NovaGlanceEnableRbdDownload\": {\"get_param\": \"NovaGlanceEnableRbdDownload\"}, \"NovaGlanceRbdDownloadMultistoreID\": {\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"NovaComputeForceRawImages\": {\"get_param\": \"NovaComputeForceRawImages\"}, \"NovaComputeUseCowImages\": {\"get_param\": \"NovaComputeUseCowImages\"}, \"NovaComputeLibvirtPreAllocateImages\": {\"get_param\": \"NovaComputeLibvirtPreAllocateImages\"}, \"NovaComputeImageCacheManagerInterval\": {\"get_param\": \"NovaComputeImageCacheManagerInterval\"}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedBaseImages\"}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\"}, \"NovaComputeImageCachePrecacheConcurrency\": {\"get_param\": \"NovaComputeImageCachePrecacheConcurrency\"}, \"CustomProviderInventories\": {\"get_param\": \"CustomProviderInventories\"}, \"NovaGlanceRbdCopyPollInterval\": {\"get_param\": \"NovaGlanceRbdCopyPollInterval\"}, \"NovaGlanceRbdCopyTimeout\": {\"get_param\": \"NovaGlanceRbdCopyTimeout\"}, \"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"nova_compute_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for nova_compute\", \"value\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}, \"role_data\": {\"description\": \"Role data for the Nova Compute service.\", \"value\": {\"service_name\": \"nova_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"nova::compute::pci::passthrough\": {\"str_replace\": {\"template\": \"JSON_PARAM\", \"params\": {\"map_replace\": [{\"map_replace\": [{\"JSON_PARAM\": \"NovaPCIPassthrough\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaPCIPassthrough\": {\"get_param\": \"NovaPCIPassthrough\"}}}]}}}, \"nova::compute::libvirt::migration_support\": false, \"tripleo::profile::base::nova::migration::client::nova_compute_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::rbd::libvirt_images_rbd_glance_store_name\": {\"get_param\": \"GlanceBackendID\"}, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"tripleo::profile::base::nova::compute::cinder_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::cinder::username\": \"cinder\", \"nova::cinder::auth_type\": \"v3password\", \"nova::cinder::project_name\": \"service\", \"nova::cinder::password\": {\"get_param\": \"CinderPassword\"}, \"nova::cinder::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::cinder::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"nova::compute::instance_usage_audit\": true, \"nova::compute::instance_usage_audit_period\": \"hour\", \"nova::compute::consecutive_build_service_disable_threshold\": {\"get_param\": \"NovaAutoDisabling\"}, \"nova::compute::live_migration_wait_for_vif_plug\": {\"get_param\": \"NovaLiveMigrationWaitForVIFPlug\"}, \"nova::migration::libvirt::live_migration_permit_post_copy\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_post_copy\"]}]}, \"nova::migration::libvirt::live_migration_permit_auto_converge\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_auto_converge\"]}]}, \"nova::migration::libvirt::live_migration_tunnelled\": false, \"nova::compute::vncserver_proxyclient_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"protocol\"]}, \"nova::vncproxy::common::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"port\"]}, \"nova::compute::verify_glance_signatures\": {\"get_param\": [\"VerifyGlanceSignatures\"]}, \"nova::ram_allocation_ratio\": {\"if\": [\"libvirt_file_backed_memory_enabled\", \"1.0\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::ram_allocation_ratio\"]}]}, \"nova::compute::libvirt::max_queues\": {\"if\": [\"nova_libvirt_max_queues_set\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_max_queues\"]}]}, \"nova::workarounds::disable_compute_service_check_for_ffu\": {\"get_param\": \"NovaDisableComputeServiceCheckForFfu\"}}, {\"if\": [\"glance_enable_rbd_download_set\", {\"nova::glance::enable_rbd_download\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_enable_rbd_download\"]}, \"nova::glance::rbd_user\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_ceph_client_user_name) -> $.data.multistore.get($k).get(\\\"CephClientUserName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_ceph_client_user_name\": {\"get_param\": \"CephClientUserName\"}}}}, {\"get_param\": \"CephClientUserName\"}]}, \"nova::glance::rbd_pool\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_glance_rbd_pool_name) -> $.data.multistore.get($k).get(\\\"GlanceRbdPoolName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_glance_rbd_pool_name\": {\"get_param\": \"GlanceRbdPoolName\"}}}}, {\"get_param\": \"GlanceRbdPoolName\"}]}, \"nova::glance::rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key) -> list(coalesce($.data.multistore, {}).get($k)).flatten().select($.get(\\\"CephClusterName\\\"))\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}, {\"get_param\": \"CephClusterName\"}]}, \".conf\"]]}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_nova_compute\": [{\"get_param\": \"NovaComputeLoggingSource\"}]}, \"collectd\": {\"tripleo.collectd.plugins.nova_compute\": [\"virt\"], \"collectd::plugin::virt::connection\": \"qemu:///system\"}}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"nova_config\", \"step_config\": \"# TODO(emilien): figure how to deal with libvirt profile.\\n# We\'ll probably treat it like we do with Neutron plugins.\\n# Until then, just include it in the default nova-compute role.\\ninclude tripleo::profile::base::nova::compute::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_compute.json\": {\"command\": {\"list_join\": [\" \", [{\"if\": [\"compute_startup_delay\", {\"str_replace\": {\"template\": \"/var/lib/nova/delay-nova-compute --delay DELAY --nova-binary\", \"params\": {\"DELAY\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}}]}, \"/usr/bin/nova-compute\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}, {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\": {\"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"get_attr\": [\"NovaComputeCommon\", \"container_config_scripts\"]}]}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"nova_statedir_owner\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"none\", \"user\": \"root\", \"security_opt\": [\"label=disable\"], \"privileged\": false, \"detach\": false, \"volumes\": [\"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"], \"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\", \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}, \"NOVA_STATEDIR_OWNERSHIP_SKIP\": {\"list_join\": [\":\", {\"get_param\": \"NovaStatedirOwnershipSkip\"}]}}}}, \"step_5\": {\"map_merge\": [{\"nova_compute\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"ulimit\": {\"get_param\": \"DockerNovaComputeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"nova\", \"restart\": \"always\", \"depends_on\": {\"list_concat\": [[\"tripleo_nova_libvirt.target\"], {\"if\": [{\"get_param\": \"NovaNfsEnabled\"}, [\"var-lib-nova-instances.mount\"]]}]}, \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_volumes\"]}, [\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/run/nova:/run/nova:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/sys/class/net:/sys/class/net\", \"/sys/bus/pci:/sys/bus/pci\", \"/boot:/boot:ro\", \"/var/lib/nova:/var/lib/nova:shared\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_env_vars\"]}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, {\"LIBGUESTFS_BACKEND\": \"direct\"}]}}}, {\"if\": [{\"not\": {\"get_param\": \"NovaAdditionalCell\"}}, {\"nova_wait_for_compute_service\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/var/lib/container-config-scripts:/container-config-scripts\"]]}, \"user\": \"nova\", \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}}}}]}]}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check for /var/lib/nova/instances directory exitance\", \"stat\": {\"path\": \"/var/lib/nova/instances\"}, \"register\": \"check_nova_instances_result\"}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/_nova_secontext\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/nova/instances\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/tmpfiles.d\"}]}, {\"name\": \"ensure /run/nova is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-nova.conf\", \"content\": \"d /run/nova 0777 root root - -\\n\"}}, {\"name\": \"create tempfiles\", \"command\": \"systemd-tmpfiles --create\"}], [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}], [{\"name\": \"delay installation of systemd-container\", \"when\": \"check_nova_instances_result.stat.exists\", \"block\": [{\"name\": \"check systemd-container package installed or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\", \"failed_when\": false}, {\"name\": \"get latest package from downloaded package versions\", \"shell\": \"ls -1t /var/tmp/systemd-container* | head -1\", \"register\": \"latest_systemd_container_package\", \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"], \"failed_when\": false}, {\"name\": \"Install systemd-container package on boot\", \"copy\": {\"dest\": \"/etc/systemd/system/install-systemd-container.service\", \"content\": \"[Unit]\\nDescription=Install systemd container package on system boot\\nBefore=tripleo_nova_virtqemud.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\nExecStartPost=rm -f /var/tmp/systemd-container*\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": [\"latest_systemd_container_package is defined\", \"(\'stdout\' in latest_systemd_container_package)\", \"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"enable install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"state\": \"stopped\", \"enabled\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"check if install-systemd-container service exists\", \"stat\": {\"path\": \"/etc/systemd/system/install-systemd-container.service\"}, \"register\": \"install_systemd_container_result\"}, {\"name\": \"disable and mask install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"not is_systemd_container_package.changed\", \"install_systemd_container_result.stat.exists\"]}]}, {\"name\": \"is Nova Resume Guests State On Host Boot enabled\", \"set_fact\": {\"resume_guests_state_on_host_boot_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"resume_guests_state_on_host_boot\"]}}}, {\"name\": \"install libvirt-guests systemd unit file (docker)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'docker\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs\", \"copy\": {\"dest\": \"/etc/systemd/system/libvirt-guests.service\", \"content\": \"[Unit]\\nDescription=Suspend/Resume Running libvirt Guests\\nAfter=network.target\\nAfter=time-sync.target\\nAfter=virt-guest-shutdown.target\\nAfter=docker.service\\nAfter=tripleo-container-shutdown.service\\nAfter=rhel-push-plugin.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\n# Hack just call traditional service until we factor\\n# out the code\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\nExecStop=/bin/{{container_cli}} stop nova_compute\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"libvirt-guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"libvirt-guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"install tripleo_nova_libvirt_guests systemd unit file (podman)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'podman\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\"}, {\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\"}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"tripleo_nova_libvirt_guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Do we prepend nova startup with a delay\", \"set_fact\": {\"nova_compute_delay\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}, {\"name\": \"install nova-compute delay wrapper script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/scripts/delay-nova-compute\"}, \"dest\": \"/var/lib/nova/delay-nova-compute\", \"mode\": 493}, \"when\": \"nova_compute_delay|int > 0\"}, {\"name\": \"Is irqbalance enabled\", \"set_fact\": {\"compute_irqbalance_disabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_disable_irqbalance\"]}}}, {\"name\": \"disable irqbalance service on compute\", \"when\": \"compute_irqbalance_disabled|bool\", \"service\": {\"name\": \"irqbalance.service\", \"state\": \"stopped\", \"enabled\": false}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"deploy_steps_tasks\": [{\"name\": \"install systemd-container for a greenfield\", \"when\": [\"step|int == 1\", \"not check_nova_instances_result.stat.exists\"], \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}}, {\"name\": \"validate nova-compute container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_compute\"}, \"register\": \"nova_compute_infos\", \"failed_when\": [\"nova_compute_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 6\"]}, {\"name\": \"manage PMEM namespaces for vPMEM\", \"include_role\": {\"name\": \"tripleo_nvdimm\"}, \"vars\": {\"tripleo_nvdimm_pmem_namespaces\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_pmem_namespaces\"]}}, \"when\": [\"step|int == 1\", \"tripleo_nvdimm_pmem_namespaces != \'\'\"]}, {\"name\": \"manage OS version 9 specific sysctls\", \"when\": [\"step|int == 1\", \"ansible_facts[\'os_family\'] == \'RedHat\'\", \"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"], \"block\": [{\"name\": \"Enable post-copy by setting unprivileged_userfaultfd\", \"sysctl\": {\"name\": \"vm.unprivileged_userfaultfd\", \"value\": 1, \"sysctl_set\": true, \"sysctl_file\": \"/etc/sysctl.d/99-tripleo-postcopy.conf\", \"state\": \"present\", \"reload\": true}}]}, {\"name\": \"enable/disable ksm\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"is KSM enabled\", \"set_fact\": {\"compute_ksm_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_enable_ksm\"]}}}, {\"name\": \"disable KSM on compute\", \"when\": \"not compute_ksm_enabled|bool\", \"block\": [{\"name\": \"Check for ksm\", \"shell\": \"systemctl is-active ksm.service || systemctl is-enabled ksm.service\", \"become\": true, \"failed_when\": false, \"register\": \"ksm_service_check\"}, {\"name\": \"disable KSM services\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"], \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\"], \"register\": \"ksmdisabled\"}, {\"name\": \"delete PageKSM after disable ksm on compute\", \"command\": \"echo 2 >/sys/kernel/mm/ksm/run\", \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\", \"ksmdisabled is changed\"]}]}, {\"name\": \"enable KSM on compute\", \"when\": \"compute_ksm_enabled|bool\", \"block\": [{\"name\": \"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\", \"package\": {\"name\": \"qemu-kvm-common\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"]}, {\"name\": \"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\", \"package\": {\"name\": \"ksmtuned\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"]}, {\"name\": \"enable ksmtunded\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"started\", \"enabled\": true}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"]}]}]}], \"external_post_deploy_tasks\": {\"get_attr\": [\"NovaComputeCommon\", \"nova_compute_common_deploy_steps_tasks\"]}, \"upgrade_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}, {\"name\": \"nova_compute pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"absent\", \"fstype\": \"nfs4\"}, \"when\": \"nfs_backend_enable|bool\"}]}, {\"name\": \"nova_compute post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}], \"update_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}], \"post_update_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"post_upgrade_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get nova-compute service ID\", \"command\": \"openstack compute service list --service nova-compute --column ID --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"is additional Cell?\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"Set fact for nova_compute services\", \"set_fact\": {\"nova_compute_service\": \"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Check search output\", \"fail\": {\"msg\": \"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\"}, \"when\": [\"(nova_compute_service | length) > 1\"]}, {\"name\": \"Disable nova services\", \"when\": [\"(nova_compute_service | length) == 1\"], \"block\": [{\"name\": \"Disable nova-compute service\", \"command\": \"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"when\": [\"not is_additional_cell|bool\"]}, {\"name\": \"Stop nova-compute container\", \"service\": {\"name\": \"tripleo_nova_compute\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_nova_compute\", \"failed_when\": \"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\"}, {\"name\": \"Delete nova-compute service\", \"command\": \"openstack compute service delete {{ nova_compute_service[0].ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(90,'2026-06-10 07:59:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupWorkers\": {\"type\": \"number\", \"default\": 1, \"description\": \"The number of cinder-backup processes to launch.\"}, \"CinderBackupMaxOperations\": {\"type\": \"number\", \"default\": 15, \"description\": \"The maximum number of concurrent cinder backup/restore operations (0 means unlimited).\"}, \"CinderBackupCompressionAlgorithm\": {\"default\": \"zlib\", \"description\": \"The compression algorithm used by Cinder Backup backends that are based on Cinder\'s \\\"chunked\\\" backup driver. This includes the swift, nfs, gcs and s3 backends. The ceph backend does not support the feature.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"zlib\", \"bzip2\", \"zstd\"]}]}, \"CinderBackupRbdClusterName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The Ceph cluster where backups are to be stored. If no value is specified then the CephClusterName value is used.\"}, \"CinderBackupRbdClientUserName\": {\"default\": \"\", \"type\": \"string\", \"description\": \"The Ceph client name used by the backup service. If no value is specified then the CephClientUserName value is used.\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CinderBackupNfsShare\": {\"default\": \"\", \"description\": \"NFS share to be mounted\", \"type\": \"string\"}, \"CinderBackupNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options passed to the NFS client. See NFS man page for details.\", \"type\": \"string\"}, \"CinderBackupGcsCredentials\": {\"default\": {}, \"description\": \"The GCS service account credentials, in JSON format.\", \"type\": \"json\"}, \"CinderBackupGcsProjectId\": {\"default\": \"\", \"description\": \"The GCS project ID.\", \"type\": \"string\"}, \"CinderBackupGcsBucket\": {\"default\": \"volumebackups\", \"description\": \"The GCS bucket where backups are to be stored.\", \"type\": \"string\"}, \"CinderBackupGcsBucketLocation\": {\"default\": \"\", \"description\": \"If set, it specifies the location where the GCS bucket should be created.\", \"type\": \"string\"}, \"CinderBackupS3EndpointUrl\": {\"default\": \"\", \"description\": \"The URL where the S3 server is listening.\", \"type\": \"string\"}, \"CinderBackupS3AccessKey\": {\"default\": \"\", \"description\": \"The S3 query token access key.\", \"type\": \"string\"}, \"CinderBackupS3SecretKey\": {\"default\": \"\", \"description\": \"The S3 query token secret key.\", \"type\": \"string\"}, \"CinderBackupS3Bucket\": {\"default\": \"volumebackups\", \"description\": \"The S3 bucket where backups are to be stored.\", \"type\": \"string\"}, \"MonitoringSubscriptionCinderBackup\": {\"default\": \"overcloud-cinder-backup\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderBackup\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::backup::backup_workers\": {\"get_param\": \"CinderBackupWorkers\"}, \"cinder::backup::backup_max_operations\": {\"get_param\": \"CinderBackupMaxOperations\"}}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, {\"cinder::backup::ceph::backup_ceph_user\": {\"str_replace\": {\"template\": \"USERNAME\", \"params\": {\"USERNAME\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClientUserName\"}, \"\"]}, {\"get_param\": \"CephClientUserName\"}, {\"get_param\": \"CinderBackupRbdClientUserName\"}]}}}}, \"cinder::backup::ceph::backup_ceph_pool\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"cinder::backup::ceph::backup_ceph_conf\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.conf\", \"params\": {\"CLUSTER\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClusterName\"}, \"\"]}, {\"get_param\": \"CephClusterName\"}, {\"get_param\": \"CinderBackupRbdClusterName\"}]}}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"swift\"]}, {\"cinder::backup::swift::backup_swift_container\": \"volumebackups\", \"cinder::backup::swift::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}, \"cinder::backup::swift::swift_catalog_info\": \"object-store:swift:internalURL\"}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"nfs\"]}, {\"cinder::backup::nfs::backup_share\": {\"get_param\": \"CinderBackupNfsShare\"}, \"cinder::backup::nfs::backup_mount_options\": {\"get_param\": \"CinderBackupNfsMountOptions\"}, \"cinder::backup::nfs::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"gcs\"]}, {\"tripleo::profile::base::cinder::backup::gcs::credentials\": {\"get_param\": \"CinderBackupGcsCredentials\"}, \"cinder::backup::google::backup_gcs_project_id\": {\"get_param\": \"CinderBackupGcsProjectId\"}, \"cinder::backup::google::backup_gcs_bucket\": {\"get_param\": \"CinderBackupGcsBucket\"}, \"cinder::backup::google::backup_gcs_bucket_location\": {\"get_param\": \"CinderBackupGcsBucketLocation\"}, \"cinder::config::cinder_config\": {\"DEFAULT/backup_compression_algorithm\": {\"value\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"s3\"]}, {\"cinder::backup::s3::backup_s3_endpoint_url\": {\"get_param\": \"CinderBackupS3EndpointUrl\"}, \"cinder::backup::s3::backup_s3_store_access_key\": {\"get_param\": \"CinderBackupS3AccessKey\"}, \"cinder::backup::s3::backup_s3_store_secret_key\": {\"get_param\": \"CinderBackupS3SecretKey\"}, \"cinder::backup::s3::backup_s3_store_bucket\": {\"get_param\": \"CinderBackupS3Bucket\"}, \"cinder::backup::s3::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_backup\": [{\"get_param\": \"DockerCinderBackupLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"str_replace\": {\"template\": \"include tripleo::profile::base::cinder::backup::DRIVER\", \"params\": {\"DRIVER\": {\"get_param\": \"CinderBackupBackend\"}}}}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_backup\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"deploy_steps_tasks\": [{\"name\": \"Clean up when switching cinder-backup from pcmk to active-active\", \"when\": [\"step|int == 1\"], \"become\": true, \"block\": [{\"name\": \"Check if cinder-backup is running under pacemaker\", \"command\": \"pcs status\", \"register\": \"cinder_backup_pcs_status\", \"check_mode\": false, \"failed_when\": false, \"changed_when\": false}, {\"when\": [\"\\\"cinder-backup\\\" in cinder_backup_pcs_status.stdout\"], \"block\": [{\"name\": \"Remove the openstack-cinder-backup pcs resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"delete\"}, \"run_once\": true}, {\"name\": \"Identify the cinder-backup pcmklatest container image\", \"shell\": \"{{container_cli}} images | awk \'$1 ~ \\\"cinder-backup\\\" && $2 == \\\"pcmklatest\\\" {print $1\\\":\\\"$2}\'\", \"register\": \"cinder_backup_pcmklatest_image\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Remove the cinder-backup pcmklatest container image\", \"command\": \"{{container_cli}} rmi {{cinder_backup_pcmklatest_image.stdout}}\", \"when\": [\"cinder_backup_pcmklatest_image.stdout|length > 0\"]}]}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder backup container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_backup\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_backup\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"CephClientUserName\": \"openstack\", \"CinderBackupBackend\": \"swift\", \"CinderBackupRbdPoolName\": \"backups\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(91,'2026-06-10 07:59:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(92,'2026-06-10 07:59:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::pacemaker::cinder::volume_bundle::cinder_volume_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::volume_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::volume::manage_service\": false, \"cinder::volume::enabled\": false, \"cinder::backend_host\": \"hostgroup\"}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\"], [\"include tripleo::profile::pacemaker::cinder::volume_bundle\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Volume tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Volume HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-volume temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-volume\", \"tripleo_ha_image_update_new_image\": \"{{cinder_volume_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_volume_image}}\"}, \"when\": [\"(pcmk_cinder_volume_image != \\\"\\\")\", \"(pcmk_cinder_volume_image != cinder_volume_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-volume container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_volume_image == cinder_volume_image_latest\", \"fail_msg\": \"cinder-volume image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"cinder_volume fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder volume bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"Prepare switch of cinder_volume image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_volume image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-volume | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_volume_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_volume image facts\", \"set_fact\": {\"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_volume_image_current\": \"{{cinder_volume_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_volume image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image_current}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}, {\"name\": \"Create cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_volume_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_volume_bootstrap_node={{cinder_volume_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_volume retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_volume_bootstrap_node\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"pcs resource bundle update cinder_volume for new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-volume container image={{cinder_volume_image_latest}}\"}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_volume retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}, {\"name\": \"Retag pacemaker cinder_volume\", \"when\": [\"step|int == 3\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"absent\"}}]}], {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}]}, \"post_upgrade_tasks\": [{\"name\": \"Start cinder_volume service (pacemaker)\", \"become\": true, \"when\": \"step|int == 1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(93,'2026-06-10 07:59:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Load kernel modules with kmod and configure kernel options with sysctl.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelPidMax\": {\"default\": 1048576, \"description\": \"Configures sysctl kernel.pid_max key\", \"type\": \"number\"}, \"KernelDisableIPv6\": {\"default\": 0, \"description\": \"Configures sysctl net.ipv6.{default/all}.disable_ipv6 keys\", \"type\": \"number\"}, \"KernelIpForward\": {\"default\": 1, \"description\": \"Configures net.ipv4.ip_forward key\", \"type\": \"number\"}, \"KernelIpv6ConfAllForwarding\": {\"default\": 0, \"description\": \"Configures the net.ipv6.conf.all.forwarding key\", \"type\": \"number\"}, \"KernelIpv4ConfAllRpFilter\": {\"default\": 1, \"description\": \"Configures the net.ipv4.conf.all.rp_filter key\", \"type\": \"number\"}, \"KernelIpNonLocalBind\": {\"default\": 1, \"description\": \"Configures net.ipv{4,6}.ip_nonlocal_bind key\", \"type\": \"number\"}, \"NeighbourGcThreshold1\": {\"default\": 1024, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh1 value. This is the minimum number of entries to keep in the ARP cache. The garbage collector will not run if there are fewer than this number of entries in the cache.\", \"type\": \"number\"}, \"NeighbourGcThreshold2\": {\"default\": 2048, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh2 value. This is the soft maximum number of entries to keep in the ARP cache. The garbage collector will  allow the number of entries to exceed this for 5 seconds before collection will be performed.\", \"type\": \"number\"}, \"NeighbourGcThreshold3\": {\"default\": 4096, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh3 value. This is the hard maximum number of entries to keep in the ARP cache. The garbage collector will always run if there are more than this number of entries in the cache.\", \"type\": \"number\"}, \"InotifyInstancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}, \"BridgeNfCallArpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-arptables key\", \"type\": \"number\"}, \"BridgeNfCallIpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-iptables key\", \"type\": \"number\"}, \"BridgeNfCallIp6Tables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-ip6tables key\", \"type\": \"number\"}, \"ExtraKernelModules\": {\"default\": {}, \"description\": \"Hash of extra Kernel modules to load.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraKernelPackages\": {\"default\": {}, \"description\": \"List of extra kernel related packages to install.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraSysctlSettings\": {\"default\": {}, \"description\": \"Hash of extra sysctl settings to apply.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"FsAioMaxNumber\": {\"default\": 0, \"description\": \"The kernel allocates aio memory on demand, and this number limits the number of parallel aio requests; the only drawback of a larger limit is that a malicious guest could issue parallel requests to cause the kernel to set aside memory.  Set this number at least as large as\\n  128 * (number of virtual disks on the host)\\nLibvirt uses a default of 1M requests to allow 8k disks, with at most 64M of kernel memory if all disks hit an aio request at the same time.\\n\", \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"InotifyIntancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"InotifyIntancesMax\"]}], \"conditions\": {\"ipv6_disabled\": {\"equals\": [{\"get_param\": \"KernelDisableIPv6\"}, 1]}, \"is_inotify_intances_max_default\": {\"equals\": [{\"get_param\": \"InotifyIntancesMax\"}, 1024]}, \"fs_aio_max_number_set\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, 0]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, \"\"]}}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_kernel_modules\": \"ExtraKernelModules\", \"extra_kernel_packages\": \"ExtraKernelPackages\", \"extra_sysctl_settings\": \"ExtraSysctlSettings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraKernelModules\": {\"get_param\": \"ExtraKernelModules\"}, \"ExtraKernelPackages\": {\"get_param\": \"ExtraKernelPackages\"}, \"ExtraSysctlSettings\": {\"get_param\": \"ExtraSysctlSettings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Kernel modules\", \"value\": {\"service_name\": \"kernel\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_kernel\"}}], \"ansible_group_vars\": {\"hieradata_localhost_address\": {\"if\": [\"ipv6_disabled\", \"127.0.0.1\", \"localhost\"]}, \"tripleo_kernel_extra_modules\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_modules\"]}, \"tripleo_kernel_extra_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_packages\"]}, \"tripleo_kernel_sysctl_extra_settings\": {\"map_merge\": [{\"net.ipv6.conf.default.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": {\"get_param\": \"KernelIpForward\"}}, \"net.ipv4.conf.all.rp_filter\": {\"value\": {\"get_param\": \"KernelIpv4ConfAllRpFilter\"}}, \"net.ipv6.conf.all.forwarding\": {\"value\": {\"get_param\": \"KernelIpv6ConfAllForwarding\"}}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"kernel.pid_max\": {\"value\": {\"get_param\": \"KernelPidMax\"}}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": {\"get_param\": \"NeighbourGcThreshold1\"}}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": {\"get_param\": \"NeighbourGcThreshold2\"}}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": {\"get_param\": \"NeighbourGcThreshold3\"}}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": {\"get_param\": \"BridgeNfCallArpTables\"}}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": {\"get_param\": \"BridgeNfCallIpTables\"}}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": {\"get_param\": \"BridgeNfCallIp6Tables\"}}, \"fs.inotify.max_user_instances\": {\"value\": {\"if\": [\"is_inotify_intances_max_default\", {\"get_param\": \"InotifyInstancesMax\"}, {\"get_param\": \"InotifyIntancesMax\"}]}}}, {\"if\": [\"fs_aio_max_number_set\", {\"fs.aio-max-nr\": {\"value\": {\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}}}]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_sysctl_settings\"]}]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(94,'2026-06-10 07:59:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(95,'2026-06-10 07:59:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"yes\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}}, \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"config_settings\": {\"tripleo::profile::base::sshd::bannertext\": {\"get_param\": \"BannerText\"}, \"tripleo::profile::base::sshd::motd\": {\"get_param\": \"MessageOfTheDay\"}, \"tripleo::profile::base::sshd::options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo::profile::base::sshd::password_authentication\": {\"get_param\": \"PasswordAuthentication\"}}, \"step_config\": \"include tripleo::profile::base::sshd\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (96,'2026-06-10 07:59:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(97,'2026-06-10 07:59:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(98,'2026-06-10 07:59:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for nova-compute containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"nova_statedir_ownership.py\": {\"mode\": \"0700\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_statedir_ownership.py\"}}, \"nova_wait_for_compute_service.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_wait_for_compute_service.py\"}}}}, \"nova_compute_common_deploy_steps_tasks\": {\"description\": \"Common host prep tasks for nova-compute services (compute + ironic)\", \"value\": [{\"block\": [{\"name\": \"is additonal Cell?\", \"set_fact\": {\"nova_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"check if discover hosts is required\", \"when\": [\"not nova_additional_cell|bool\", \"nova_cellv2_discovery_done is not defined\"], \"block\": [{\"name\": \"discover via nova_manager?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_manager\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_manager\"}, \"when\": [\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\"]}, {\"name\": \"discover via nova_api?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_api\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_api\"}, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\", \"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\"]}, {\"name\": \"Warn if no discovery host available\", \"fail\": {\"msg\": \"No hosts available to run nova cell_v2 host discovery.\"}, \"ignore_errors\": true, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\"]}, {\"name\": \"Discovering nova hosts\", \"command\": \"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\", \"become\": true, \"changed_when\": false, \"delegate_to\": \"{{ nova_cellv2_discovery_delegate_host }}\", \"when\": [\"nova_cellv2_discovery_delegate_host is defined\"]}, {\"set_fact\": {\"nova_cellv2_discovery_done\": true}}]}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(99,'2026-06-10 07:59:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(100,'2026-06-10 07:59:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(101,'2026-06-10 07:59:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Qpid dispatch router service for metrics and monitoring purposes\\n\", \"parameters\": {\"ContainerMetricsQdrImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ContainerMetricsQdrConfigImage\": {\"description\": \"The container image to use for the qdrouterd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionQdr\": {\"default\": \"overcloud-qdr\", \"type\": \"string\"}, \"MetricsQdrLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MetricsQdrConnectors\": {\"default\": [], \"description\": \"Connectors configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrSSLProfiles\": {\"default\": [{\"name\": \"sslProfile\"}], \"description\": \"SSL Profiles for the connectors (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAddresses\": {\"default\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"description\": \"Addresses configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAutoLinks\": {\"default\": [], \"description\": \"AutoLinks for the Configured Addresses\", \"type\": \"json\"}, \"MetricsQdrUseSSL\": {\"default\": false, \"description\": \"Set to true if it is required to use SSL or TLS on the connection for the local listener. !WARNING! Currently breaks connections from collectd and ceilometer.\", \"type\": \"boolean\"}, \"MetricsQdrUseEncryption\": {\"default\": false, \"description\": \"Set to true if it is required to encrypt connection to the peer for listener. Not currently implemented, use EnableInternalTLS instead. This option can be ignored.\", \"type\": \"boolean\"}, \"MetricsQdrSaslMechanisms\": {\"default\": \"ANONYMOUS\", \"description\": \"List of accepted SASL auth mechanisms for listener in format of comma separated list.\", \"type\": \"string\"}, \"MetricsQdrSslCertDb\": {\"default\": \"/etc/ipa/ca.crt\", \"description\": \"Path to SSL certificate db for listener.\", \"type\": \"string\"}, \"MetricsQdrSslCertFile\": {\"default\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"description\": \"Path to SSL certificate file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslKeyFile\": {\"default\": \"/etc/pki/tls/private/metrics_qdr.key\", \"description\": \"Path to SSL private key file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPwFile\": {\"default\": \"\", \"description\": \"Path to SSL password file for certificate key for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPassword\": {\"default\": \"\", \"description\": \"SSL password to be supplied for listener.\", \"type\": \"string\"}, \"MetricsQdrTrustedCerts\": {\"default\": \"\", \"description\": \"Path to file containing trusted certificates for listener.\", \"type\": \"string\"}, \"MetricsQdrAuthenticateClient\": {\"default\": false, \"description\": \"Authenticate the client using SSL/TLS\", \"type\": \"boolean\"}, \"MetricsQdrExternalEndpoint\": {\"default\": false, \"description\": \"Whether QDR should listen on external network interface. To enable listening on external network one must deploy QDRs in mesh mode.\", \"type\": \"boolean\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableSTF\": {\"default\": false, \"description\": \"Set to true to enable configuration for STF client.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"QdrCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"listener_ssl_enabled\": {\"equals\": [{\"get_param\": \"MetricsQdrUseSSL\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"QdrCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMetricsQdrImage\": \"ContainerMetricsQdrImage\", \"ContainerMetricsQdrConfigImage\": \"ContainerMetricsQdrConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMetricsQdrImage\": {\"get_param\": \"ContainerMetricsQdrImage\"}, \"ContainerMetricsQdrConfigImage\": {\"get_param\": \"ContainerMetricsQdrConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the metrics Qdr role.\", \"value\": {\"service_name\": \"metrics_qdr\", \"firewall_rules\": {\"map_merge\": [{\"109 metrics qdr\": {\"dport\": [{\"get_param\": \"MetricsQdrPort\"}]}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"109 accept internal metrics qdr ctlplane subnet <%net_cidr%>\": {\"dport\": [5667, 5668]}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionQdr\"}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_metrics_qdr\": [{\"get_param\": \"MetricsQdrLoggingSource\"}]}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::qdr::listener_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::haproxy::metrics_qdr\": {\"get_param\": \"MetricsQdrExternalEndpoint\"}, \"tripleo::profile::base::metrics::qdr::listener_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::qdr::username\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::qdr::password\": {\"get_param\": \"MetricsQdrPassword\"}, \"tripleo::profile::base::metrics::qdr::connectors\": {\"get_param\": \"MetricsQdrConnectors\"}, \"tripleo::profile::base::metrics::qdr::addresses\": {\"get_param\": \"MetricsQdrAddresses\"}, \"tripleo::profile::base::metrics::qdr::autolink_addresses\": {\"get_param\": \"MetricsQdrAutoLinks\"}, \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": {\"if\": [\"listener_ssl_enabled\", true, false]}, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": {\"get_param\": \"MetricsQdrUseEncryption\"}, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": {\"get_param\": \"MetricsQdrSaslMechanisms\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": {\"get_param\": \"MetricsQdrSslCertDb\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": {\"get_param\": \"MetricsQdrSslCertFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": {\"get_param\": \"MetricsQdrSslKeyFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": {\"get_param\": \"MetricsQdrSslPwFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": {\"get_param\": \"MetricsQdrSslPassword\"}, \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": {\"get_param\": \"MetricsQdrTrustedCerts\"}, \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": {\"get_param\": \"MetricsQdrAuthenticateClient\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"list_concat\": [{\"get_param\": \"MetricsQdrSSLProfiles\"}, [{\"name\": \"tlsProfile\", \"certFile\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"keyFile\": \"/etc/pki/tls/private/metrics_qdr.key\", \"caCertFile\": {\"get_param\": \"InternalTLSCAFile\"}}]]}}, {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"get_param\": \"MetricsQdrSSLProfiles\"}}]}, {\"if\": [\"enable_stf\", {\"tripleo::profile::base::metrics::qdr::interior_mesh_nodes\": \"\", \"tripleo::profile::base::metrics::qdr::router_mode\": \"edge\"}, null]}]}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"metrics_qdr\", \"network\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}, \"type\": \"node\"}], null]}, \"puppet_config\": {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\", \"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"principal\": {\"str_replace\": {\"template\": \"metrics_qdr/{{fqdn_NETWORK}}@{{idm_realm}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"QdrCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(102,'2026-06-10 07:59:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(103,'2026-06-10 07:59:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(104,'2026-06-10 07:59:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (105,'2026-06-10 07:59:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Modular Libvirt Service\\n\", \"parameters\": {\"ContainerNovaLibvirtImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtUlimit\": {\"default\": [\"nofile=131072\", \"nproc=126960\"], \"description\": \"ulimit for Nova Libvirt Container\", \"type\": \"comma_delimited_list\"}, \"ContainerNovaLibvirtPidsLimit\": {\"default\": 65536, \"description\": \"Tune nova_libvirt container PID limit (set to 0 for unlimited) (defaults to 65536)\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"UseCustomGnuTlsQemuCryptoPolicy\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If set to true, will use CustomGnuTlsQemuCryptoPolicy in crypto policy.\"}, \"CustomGnuTlsQemuCryptoPolicy\": {\"default\": \"QEMU=NONE:+ECDHE-RSA:+ECDHE-ECDSA:+RSA:+DHE-RSA:+GROUP-X25519:+GROUP-X448:+GROUP-SECP256R1:+GROUP-SECP384R1:+GROUP-SECP521R1:+GROUP-FFDHE2048:+GROUP-FFDHE3072:+GROUP-FFDHE4096:+GROUP-FFDHE6144:+GROUP-FFDHE8192:+CHACHA20-POLY1305:+AEAD:+SHA1:+SHA512:+SIGN-ECDSA-SHA256:+SIGN-ECDSA-SECP256R1-SHA256:+SIGN-ECDSA-SHA384:+SIGN-ECDSA-SECP384R1-SHA384:+SIGN-ECDSA-SHA512:+SIGN-ECDSA-SECP521R1-SHA512:+SIGN-EdDSA-Ed25519:+SIGN-EdDSA-Ed448:+SIGN-RSA-PSS-SHA256:+SIGN-RSA-PSS-SHA384:+SIGN-RSA-PSS-SHA512:+SIGN-RSA-PSS-RSAE-SHA256:+SIGN-RSA-PSS-RSAE-SHA384:+SIGN-RSA-PSS-RSAE-SHA512:+SIGN-RSA-SHA256:+SIGN-RSA-SHA384:+SIGN-RSA-SHA512:+VERS-TLS1.3:+VERS-TLS1.2:+VERS-DTLS1.2\", \"description\": \"Custom GnuTls Crypto Policy for QEMU\", \"type\": \"string\"}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"UseTLSTransportForVnc\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\"}, \"UseTLSTransportForNbd\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt NBD and configure the relevant keys for libvirt.\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"LibvirtCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuServerCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuClientCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for TLS in libvirt. This file will be symlinked to the default CA path in libvirt, which is /etc/pki/CA/cacert.pem. Note that due to limitations GNU TLS, which is the TLS backend for libvirt, the file must be less than 65K (so we can\'t use the system\'s CA bundle). This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"QemuCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for qemu. This file will be symlinked to the default CA path, which is /etc/pki/qemu/ca-cert.pem. This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"VhostuserSocketGroup\": {\"default\": \"qemu\", \"description\": \"The vhost-user socket directory group name. Defaults to \'qemu\'. When vhostuser mode is \'dpdkvhostuserclient\' (which is the default mode), the vhost socket is created by qemu.\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtType\": {\"type\": \"string\", \"default\": \"qemu\"}, \"LibvirtEnabledPerfEvents\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"This is a performance event list which could be used as monitor. For example - ``enabled_perf_events = cmt, mbml, mbmt`` The supported events list can be found in https://libvirt.org/html/libvirt-libvirt-domain.html , which you may need to search key words ``VIR_PERF_PARAM_*``\"}, \"MonitoringSubscriptionNovaLibvirt\": {\"default\": \"overcloud-nova-libvirt\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"LibvirtTLSPassword\": {\"description\": \"The password for the libvirt service when TLS is enabled\", \"type\": \"string\", \"hidden\": true, \"default\": \"GhFjIdW1ysmls0LZQMCGaOen4\"}, \"QemuDefaultTLSVerify\": {\"description\": \"Whether to enable or disable TLS client certificate verification. Enabling this option will reject any client who does not have a certificate signed by the CA in /etc/pki/qemu/ca-cert.pem\\n\", \"default\": true, \"type\": \"boolean\"}, \"LibvirtLogFilters\": {\"description\": \"Defines a filter in libvirt daemon to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\"}, \"LibvirtVirtlogdLogFilters\": {\"description\": \"Defines a filter in virtlogd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:logging 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtsecretdLogFilters\": {\"description\": \"Defines a filter in virtsecretd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtnodedevdLogFilters\": {\"description\": \"Defines a filter in virtnodedevd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtstoragedLogFilters\": {\"description\": \"Defines a filter in virtstoraged to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtqemudLogFilters\": {\"description\": \"Defines a filter in virtqemud to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtproxydLogFilters\": {\"description\": \"Defines a filter in virtproxyd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtTLSPriority\": {\"description\": \"Override the compile time default TLS priority string.\\n\", \"type\": \"string\", \"default\": \"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\"}, \"NovaLibvirtOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaEnableVirtlogdContainerWrapper\": {\"description\": \"Generate a virtlogd wrapper script so that virtlogd launches in a separate container and won\'t get restarted e.g. on minor updates.\", \"type\": \"boolean\", \"default\": true}, \"VirtlogdWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}}, \"conditions\": {\"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"libvirt_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCACert\"}, \"\"]}}, \"need_libvirt_secret\": {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaEnableRbdBackend\"}, true]}]}, {\"get_param\": \"CinderEnableRbdBackend\"}]}, \"use_tls_for_vnc\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForVnc\"}]}, \"libvirt_vnc_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtVncCACert\"}, \"\"]}}, \"use_tls_for_nbd\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForNbd\"}]}, \"qemu_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuCACert\"}, \"\"]}}, \"key_size_libvirt_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_client_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuClientCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_server_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuServerCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"vhostuser_socket_group\": \"VhostuserSocketGroup\", \"nova_libvirt_opt_volumes\": \"NovaLibvirtOptVolumes\", \"ContainerNovaLibvirtImage\": \"ContainerNovaLibvirtImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"VhostuserSocketGroup\": {\"get_param\": \"VhostuserSocketGroup\"}, \"NovaLibvirtOptVolumes\": {\"get_param\": \"NovaLibvirtOptVolumes\"}, \"ContainerNovaLibvirtImage\": {\"get_param\": \"ContainerNovaLibvirtImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}, \"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NovaLibvirtLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaLibvirt\"}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLibvirtCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Libvirt service.\", \"value\": {\"service_name\": \"nova_libvirt\", \"firewall_rules\": {\"200 nova_libvirt\": {\"dport\": [16514, \"61152-61215\", \"5900-6923\"]}}, \"ansible_group_vars\": {\"tripleo_nova_libvirt_virsh_container\": \"nova_virtproxyd\"}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaLibvirt\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"config_settings\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\": {\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\": \"/var/lib/container-config-scripts/virtlogd_wrapper\", \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"tripleo::profile::base::nova::virtlogd_wrapper::debug\": {\"if\": [{\"get_param\": \"VirtlogdWrapperDebug\"}, true, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}]}, \"nova::compute::libvirt::migration_support\": false, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::nova::migration::client::libvirt_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::libvirt::services::libvirt_virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::enabled_perf_events\": {\"get_param\": \"LibvirtEnabledPerfEvents\"}, \"nova::compute::libvirt::qemu::configure_qemu\": true, \"nova::compute::libvirt::qemu::max_files\": 32768, \"nova::compute::libvirt::qemu::max_processes\": 131072, \"nova::migration::qemu::configure_qemu\": true, \"nova::migration::qemu::migration_port_min\": 61152, \"nova::migration::qemu::migration_port_max\": 61215, \"nova::compute::libvirt::vncserver_listen\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::libvirt::log_filters\": {\"get_param\": \"LibvirtLogFilters\"}, \"nova::compute::libvirt::virtlogd::log_filters\": {\"get_param\": \"LibvirtVirtlogdLogFilters\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::compute::libvirt::virtsecretd::log_filters\": {\"get_param\": \"LibvirtVirtsecretdLogFilters\"}, \"nova::compute::libvirt::virtnodedevd::log_filters\": {\"get_param\": \"LibvirtVirtnodedevdLogFilters\"}, \"nova::compute::libvirt::virtstoraged::log_filters\": {\"get_param\": \"LibvirtVirtstoragedLogFilters\"}, \"nova::compute::libvirt::virtqemud::log_filters\": {\"get_param\": \"LibvirtVirtqemudLogFilters\"}, \"nova::compute::libvirt::virtproxyd::log_filters\": {\"get_param\": \"LibvirtVirtproxydLogFilters\"}, \"tripleo::profile::base::nova::libvirt::modular_libvirt\": true, \"nova::compute::libvirt::services::modular_libvirt\": true, \"nova::compute::libvirt::modular_libvirt\": true, \"nova::migration::libvirt::modular_libvirt\": true}, {\"if\": [\"use_tls_for_live_migration\", {\"tripleo::profile::base::nova::migration::client::libvirt_tls\": true, \"tripleo::profile::base::nova::libvirt::tls_password\": {\"get_param\": [\"LibvirtTLSPassword\"]}, \"nova::compute::libvirt::qemu::default_tls_verify\": {\"get_param\": \"QemuDefaultTLSVerify\"}, \"nova::compute::libvirt::tls_priority\": {\"get_param\": \"LibvirtTLSPriority\"}, \"nova::migration::libvirt::listen_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, {\"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}]}, {\"if\": [\"use_tls_for_vnc\", {\"nova::compute::libvirt::qemu::vnc_tls\": true, \"nova::compute::libvirt::qemu::vnc_tls_verify\": true}]}, {\"if\": [\"use_tls_for_nbd\", {\"nova::compute::libvirt::qemu::nbd_tls\": true, \"nova::migration::libvirt::live_migration_with_native_tls\": true}]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_virtlogd.json\": {\"command\": {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"/usr/local/bin/virtlogd_wrapper\", \"/usr/sbin/virtlogd --config /etc/libvirt/virtlogd.conf\"]}, \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtsecretd.json\": {\"command\": \"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtnodedevd.json\": {\"command\": \"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtstoraged.json\": {\"command\": \"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtqemud.json\": {\"command\": \"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtproxyd.json\": {\"command\": \"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}}, \"container_config_scripts\": {\"nova_libvirt_init_secret.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_libvirt_init_secret.sh\"}}}, \"docker_config\": {\"step_2\": {\"nova_virtqemud_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"net\": \"none\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"user\": \"root\", \"volumes\": [\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R tss:tss /var/log/swtpm\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"create_virtlogd_wrapper\": {\"start_order\": 1, \"detach\": false, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::nova::virtlogd_wrapper\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_3\": {\"map_merge\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, {\"nova_virtlogd_wrapper\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {\"nova_virtlogd\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}, {\"nova_virtsecretd\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtnodedevd\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtstoraged\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtqemud\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\", {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, \"/etc/crypto-policies:/etc/crypto-policies:ro\"]}]]}}}, {\"nova_virtproxyd\": {\"start_order\": 5, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}]}, \"step_4\": {\"if\": [\"need_libvirt_secret\", {\"nova_libvirt_init_secret\": {\"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"security_opt\": [\"label=disable\"], \"privileged\": false, \"user\": \"root\", \"cgroupns\": \"host\", \"net\": \"host\", \"environment\": {\"LIBVIRT_DEFAULT_URI\": \"qemu:///system\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/nova_libvirt/etc/nova:/etc/nova\", \"/etc/libvirt:/etc/libvirt\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/lib/container-config-scripts/nova_libvirt_init_secret.sh:/nova_libvirt_init_secret.sh:ro\", {\"str_replace\": {\"template\": \"HOST_CEPH:/etc/ceph:ro\", \"params\": {\"HOST_CEPH\": {\"get_param\": \"CephConfigPath\"}}}}]]}, \"command\": {\"list_join\": [\" \", [{\"str_replace\": {\"template\": \"/nova_libvirt_init_secret.sh CLUSTER:USER\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}], {\"repeat\": {\"template\": \"<%ceph_info%>\", \"for_each\": {\"<%ceph_info%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\":\\\" + $.get(\\\"CephClientUserName\\\", $u))\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Ensure recovery of containerized virtqemud\", \"when\": \"step|int == 4\", \"become\": true, \"block\": [{\"name\": \"Create virtqemud recovery script\", \"copy\": {\"dest\": \"/usr/libexec/recover_tripleo_nova_virtqemud.sh\", \"mode\": \"0755\", \"content\": \"#!/bin/bash\\npgrep -f /sbin/virtqemud\\n[ $? -eq 0 ] && exit 0\\nkill -9 $(cat /run/nova_virtqemud.pid)\\n\"}}, {\"name\": \"Create virtqemud recovery trigger service\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud\\nAfter=tripleo_nova_virtqemud.service\\nRequisite=tripleo_nova_virtqemud.service\\n[Service]\\nType=oneshot\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Create virtqemud recovery trigger timer\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\nPartOf=tripleo_nova_virtqemud.service\\n[Timer]\\nOnCalendar=*:5/10\\nOnActiveSec=120\\nOnUnitActiveSec=60\\nRandomizedDelaySec=1m\\n[Install]\\nWantedBy=timers.target\\n\"}}, {\"name\": \"Enable virtqemud recovery trigger service\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.service\", \"enabled\": true, \"daemon_reload\": true}}, {\"name\": \"Enable virtqemud recovery trigger timer\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.timer\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"register\": \"virtqemud_recover_timer_result\"}, {\"name\": \"Really enable virtqemud recovery trigger timer\", \"shell\": {\"cmd\": \"systemctl enable --now tripleo_nova_virtqemud_recover.timer\"}, \"when\": \"virtqemud_recover_timer_result.status.UnitFileState != \\\"enabled\\\"\"}]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/libvirt\", \"/etc/pki/libvirt/private\", \"/etc/pki/qemu\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"libvirt-server-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to libvirt dirs\\ncp CACERT /etc/pki/CA/cacert.pem\\nchown root:root /etc/pki/CA/cacert.pem\\nchmod 644 /etc/pki/CA/cacert.pem\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"params\": {\"CACERT\": {\"if\": [\"libvirt_specific_ca_set\", {\"get_param\": \"LibvirtCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"libvirt-client-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to libvirt dirs\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-server-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to qemu dir\\ncp CACERT /etc/pki/qemu/ca-cert.pem\\nchown root:root /etc/pki/qemu/ca-cert.pem\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\nchgrp qemu /etc/pki/qemu/server-*\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\nchmod 0640 /etc/pki/qemu/server-key.pem\\n\", \"params\": {\"CACERT\": {\"if\": [\"qemu_specific_ca_set\", {\"get_param\": \"QemuCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_qemu_server_override_set\", {\"get_param\": \"QemuServerCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-client-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to qemu dir\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\nchgrp qemu /etc/pki/qemu/client-*\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\nchmod 0640 /etc/pki/qemu/client-key.pem\\n\", \"key_size\": {\"if\": [\"key_size_qemu_client_override_set\", {\"get_param\": \"QemuClientCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]]}, [{\"name\": \"Set up systemd target for libvirt services\", \"when\": \"step|int == 4\", \"block\": [{\"name\": \"Create systemd file\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt.target\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"[Unit]\\nWants=tripleo_nova_virtsecretd.service\\nWants=tripleo_nova_virtnodedevd.service\\nWants=tripleo_nova_virtstoraged.service\\nWants=tripleo_nova_virtproxyd.service\\nWants=tripleo_nova_virtqemud.service\\nAfter=tripleo_nova_virtsecretd.service\\nAfter=tripleo_nova_virtnodedevd.service\\nAfter=tripleo_nova_virtstoraged.service\\nAfter=tripleo_nova_virtproxyd.service\\nAfter=tripleo_nova_virtqemud.service\\n\"}, \"become\": true, \"register\": \"libvirt_target_result\"}, {\"name\": \"Reload systemd\", \"systemd\": {\"name\": \"tripleo_nova_libvirt.target\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"become\": true, \"when\": \"libvirt_target_result.changed\"}]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\", \"mode\": \"{{ item.mode | default(omit) }}\"}, \"with_items\": [{\"path\": \"/etc/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/secrets\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/qemu\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/cache/libvirt\"}, {\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/run/libvirt\"}, {\"path\": \"/var/log/containers/libvirt/swtpm\", \"setype\": \"container_file_t\", \"mode\": \"0770\"}]}, {\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}, {\"name\": \"create directory for vhost-user sockets with qemu ownership\", \"file\": {\"path\": \"/var/lib/vhost_sockets\", \"state\": \"directory\", \"owner\": \"qemu\", \"group\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"vhostuser_socket_group\"]}, \"setype\": \"virt_cache_t\", \"seuser\": \"system_u\"}}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"with_items\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": \"libvirt_installed.rc == 0\"}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}, {\"name\": \"Enable os_enable_vtpm SELinux boolean for vTPM\", \"seboolean\": {\"name\": \"os_enable_vtpm\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, [{\"name\": \"set gnutls_qemu_config_crypto_policy fact\", \"set_fact\": {\"gnutls_qemu_config_crypto_policy\": {\"get_param\": \"CustomGnuTlsQemuCryptoPolicy\"}}}, {\"name\": \"create gnutls-qemu.config\", \"copy\": {\"dest\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"{{ gnutls_qemu_config_crypto_policy }}\\n\"}, \"register\": \"update_gnutls_config\"}], [{\"name\": \"remove gnutls-qemu.config\", \"file\": {\"path\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"state\": \"absent\"}, \"register\": \"update_gnutls_config\"}]]}, {\"name\": \"update crypto policies\", \"command\": \"update-crypto-policies\", \"when\": \"update_gnutls_config.changed\"}]]}, \"metadata_settings\": {\"list_concat\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"libvirt\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"qemu\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"libvirt-vnc\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}]]}]}, \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Fail if we are on RHEL8 as this is monolithic libvirt deployment\", \"when\": [\"step|int == 0\", \"\'system_upgrade\' not in ansible_run_tags\", \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"], \"fail\": {\"msg\": \"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\"}}, {\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Get container virtlogd image\", \"when\": \"step|int == 1\", \"tags\": \"always\", \"set_fact\": {\"virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}}}, {\"name\": \"Force pull image novalibvirt\", \"when\": [\"step|int == 1\"], \"containers.podman.podman_image\": {\"name\": \"{{ virtlogd_image }}\", \"force\": true}}, {\"name\": \"Diff OS release in container image and baremetal\", \"when\": \"step|int == 1\", \"shell\": \"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"failed_when\": false, \"register\": \"libvirt_ubi_diff\"}, {\"name\": \"Fail if UBI of the container does not match RHEL of running host\", \"when\": [\"\'system_upgrade\' not in ansible_run_tags\", \"step|int == 1\", \"libvirt_ubi_diff.rc == 1\"], \"fail\": {\"msg\": \"The host operating system versus container UBI does not match.\\n{{ libvirt_ubi_diff.stdout }}\\nMost likely container passed to NovaLibvirt was EL8 one.\\nYou have to pass the correct container for container-image-prepare.\\nIf you would continue all running workloads would get destroyed.\\n\"}}], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [{\"name\": \"Switch virtlogd image before system upgrade\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade\"], \"block\": [{\"name\": \"Get running image version\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"old_virtlogd_image\"}, {\"name\": \"Switch running image to new image in wrapper script\", \"shell\": \"set -o pipefail\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\n\", \"when\": [\"old_virtlogd_image.stdout != virtlogd_image\", \"old_virtlogd_image.stdout != \'\'\"]}]}]]}]}, \"update_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtCommon\", \"update_tasks\"]}, [{\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(106,'2026-06-10 07:59:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(107,'2026-06-10 07:59:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(108,'2026-06-10 07:59:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(109,'2026-06-10 07:59:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Scheduler service\\n\", \"parameters\": {\"ContainerCinderSchedulerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderSchedulerLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.scheduler\", \"file\": \"/var/log/containers/cinder/cinder-scheduler.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCinderScheduler\": {\"default\": \"overcloud-cinder-scheduler\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderSchedulerImage\": \"ContainerCinderSchedulerImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderSchedulerImage\": {\"get_param\": \"ContainerCinderSchedulerImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Scheduler role.\", \"value\": {\"service_name\": \"cinder_scheduler\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderScheduler\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::scheduler::scheduler_driver\": \"cinder.scheduler.filter_scheduler.FilterScheduler\"}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_scheduler\": [{\"get_param\": \"CinderSchedulerLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::scheduler\"], [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_scheduler.json\": {\"command\": \"/usr/bin/cinder-scheduler --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}}, \"docker_config\": {\"step_2\": {\"cinder_scheduler_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_scheduler\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_common_volumes\"]}, [\"/var/lib/kolla/config_files/cinder_scheduler.json:/var/lib/kolla/config_files/config.json:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder scheduler container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_scheduler\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(110,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"SNMP client configured with Puppet, to facilitate Ceilometer Hardware monitoring in the undercloud. This service is required to enable hardware monitoring.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"Gw7UKk275edaf1BK4QNxasIq\"}, \"SnmpdBindHost\": {\"description\": \"An array of bind host addresses on which SNMP daemon will listen.\", \"type\": \"comma_delimited_list\", \"default\": [\"udp:161\", \"udp6:[::1]:161\"]}, \"SnmpdOptions\": {\"description\": \"A string containing the commandline options passed to snmpd\", \"type\": \"string\", \"default\": \"-LS0-5d\"}, \"SnmpdIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the snmpd network. If empty (default), SnmpdNetwork will be taken.\", \"type\": \"string\"}}, \"conditions\": {\"snmpd_network_unset\": {\"equals\": [{\"get_param\": \"SnmpdIpSubnet\"}, \"\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the SNMP services\", \"value\": {\"service_name\": \"snmp\", \"firewall_rules\": {\"if\": [\"snmpd_network_unset\", {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"SnmpdNetwork\"]}]}}, \"template\": {\"124 snmp <%net_cidr%>\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"<%net_cidr%>\"}}}}}, {\"124 snmp\": {\"dport\": 161, \"proto\": \"udp\", \"source\": {\"get_param\": \"SnmpdIpSubnet\"}}}]}, \"config_settings\": {\"tripleo::profile::base::snmp::snmpd_user\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"tripleo::profile::base::snmp::snmpd_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"snmp::agentaddress\": {\"get_param\": \"SnmpdBindHost\"}, \"snmp::snmpd_options\": {\"get_param\": \"SnmpdOptions\"}}, \"step_config\": \"include tripleo::profile::base::snmp\\n\", \"upgrade_tasks\": [{\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(111,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V7WgDxaLxT5M80e5C9n2UCcFO\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"5QAuCI6DgbWqEzUK0gVmITEDx\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(112,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (113,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"5QAuCI6DgbWqEzUK0gVmITEDx\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"BN25Oqhi9kgi2kJiX6IVi01JG\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": true, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(114,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(115,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Firewall settings\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ExtraFirewallRules\": {\"default\": {}, \"description\": \"Mapping of firewall rules.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_firewall_rules\": \"ExtraFirewallRules\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraFirewallRules\": {\"get_param\": \"ExtraFirewallRules\"}}}]}}}}, \"conditions\": {\"no_ctlplane\": {\"equals\": [{\"get_params\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}, null]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO firewall settings\", \"value\": {\"service_name\": \"tripleo_firewall\", \"config_settings\": {\"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false}, \"ansible_group_vars\": {\"tripleo_nftables_debug\": {\"get_param\": \"Debug\"}}, \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"003 accept ssh from ctlplane subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": 22}}}}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_firewall_rules\"]}]}, \"host_prep_tasks\": [{\"if\": [\"no_ctlplane\", {\"name\": \"Failure - ctlplane subnet is unset\", \"fail\": {\"msg\": \"No CIDRs found in the ctlplane network tags.\\nPlease refer to the documentation in order to\\nset the correct network tags in DeployedServerPortMap.\\n\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}]}], \"host_firewall_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}], \"update_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}], \"upgrade_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(116,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(117,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"5QAuCI6DgbWqEzUK0gVmITEDx\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"BN25Oqhi9kgi2kJiX6IVi01JG\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": true, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(118,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(119,'2026-06-10 07:59:34',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(120,'2026-06-10 07:59:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (121,'2026-06-10 07:59:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(122,'2026-06-10 07:59:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"DockerCinderVolumeUlimit\": {\"default\": [\"nofile=131072\"], \"description\": \"ulimit for Cinder Volume Container\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CinderISCSIAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the Iscsi Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderISCSIHelper\": {\"default\": \"lioadm\", \"description\": \"The iSCSI helper to use with cinder.\", \"type\": \"string\"}, \"CinderISCSIProtocol\": {\"default\": \"iscsi\", \"description\": \"Whether to use TCP (\'iscsi\') or iSER RDMA (\'iser\') for iSCSI\", \"type\": \"string\"}, \"CinderNfsAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NFS Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options for NFS mounts used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNfsServers\": {\"default\": \"\", \"description\": \"NFS servers used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderNfsSnapshotSupport\": {\"default\": false, \"description\": \"Whether to enable support for snapshots in the NFS driver. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"boolean\"}, \"CinderNasSecureFileOperations\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file operations are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNasSecureFilePermissions\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file permissions are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderRbdBackendName\": {\"type\": \"comma_delimited_list\", \"default\": \"tripleo_ceph\", \"description\": \"A list of Cinder RBD backend names.\"}, \"CinderRbdAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the RBD Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderRbdFlattenVolumeFromSnapshot\": {\"default\": false, \"description\": \"Whether RBD volumes created from a snapshot should be flattened in order to remove a dependency on the snapshot.\\n\", \"type\": \"boolean\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\"}, \"MonitoringSubscriptionCinderVolume\": {\"default\": \"overcloud-cinder-volume\", \"type\": \"string\"}, \"CinderEtcdLocalConnect\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When running Cinder A/A, whether to connect to Etcd via the local IP for the Etcd network. If set to true, the ip on the local node will be used. If set to false, the VIP on the Etcd network will be used instead. Defaults to false.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"120 iscsi initiator\": {\"dport\": 3260}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderVolume\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"CinderCommon\", \"cinder_volume_config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::base::cinder::volume::cinder_enable_iscsi_backend\": {\"get_param\": \"CinderEnableIscsiBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_rbd_backend\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_volume_cluster\": {\"get_param\": \"CinderVolumeCluster\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_mount_options\": {\"get_param\": \"CinderNfsMountOptions\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_servers\": {\"get_param\": \"CinderNfsServers\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_snapshot_support\": {\"get_param\": \"CinderNfsSnapshotSupport\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_operations\": {\"get_param\": \"CinderNasSecureFileOperations\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_permissions\": {\"get_param\": \"CinderNasSecureFilePermissions\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_helper\": {\"get_param\": \"CinderISCSIHelper\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_protocol\": {\"get_param\": \"CinderISCSIProtocol\"}, \"tripleo::profile::base::cinder::volume::rbd::backend_name\": {\"get_param\": \"CinderRbdBackendName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_pool_name\": {\"get_param\": \"CinderRbdPoolName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_user_name\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_flatten_volume_from_snapshot\": {\"get_param\": \"CinderRbdFlattenVolumeFromSnapshot\"}, \"tripleo::profile::base::cinder::volume::rbd::multi_config\": {\"get_param\": \"CinderRbdMultiConfig\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderISCSIAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::iscsi::backend_availability_zone\": {\"get_param\": \"CinderISCSIAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNfsAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nfs::backend_availability_zone\": {\"get_param\": \"CinderNfsAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderRbdAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::rbd::backend_availability_zone\": {\"get_param\": \"CinderRbdAvailabilityZone\"}}]}, {\"if\": [{\"get_param\": \"CinderEtcdLocalConnect\"}, {\"tripleo::profile::base::cinder::volume::etcd_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"EtcdNetwork\"]}}}}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_volume\": [{\"get_param\": \"CinderVolumeLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\", \"include tripleo::profile::base::cinder::volume\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_volume\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"ulimit\": {\"get_param\": \"DockerCinderVolumeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"upgrade_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder volume container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_volume\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_volume\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(123,'2026-06-10 07:59:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(124,'2026-06-10 07:59:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(125,'2026-06-10 07:59:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova libvirt service\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"LibvirtDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Set to True to enable debugging libvirt services.\"}, \"LibvirtLogLevel\": {\"default\": 3, \"description\": \"Defines log level in libvirt to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtlogdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtlogd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtsecretdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtsecretd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtnodedevdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtnodedevd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtqemudLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtqemud to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtproxydLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtproxyd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtstoragedLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtstoraged to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": {\"nova::compute::libvirt::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/libvirtd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtLogLevel\"}]}}}}, \"nova::compute::libvirt::virtlogd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtlogd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtlogdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtsecretd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtsecretd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtsecretdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtnodedevd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtnodedevd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtnodedevdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtqemud::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtqemud.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtqemudLogLevel\"}]}}}}, \"nova::compute::libvirt::virtproxyd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtproxyd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtproxydLogLevel\"}]}}}}, \"nova::compute::libvirt::virtstoraged::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtstoraged.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtstoragedLogLevel\"}]}}}}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to file in the host.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/libvirt\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(126,'2026-06-10 07:59:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(127,'2026-06-10 07:59:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized OVN Metadata agent\\n\", \"parameters\": {\"ContainerOvnMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\"}, \"ContainerNeutronConfigImage\": {\"description\": \"The container image to use for the neutron config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"OvnMetadataAgentLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.neutron.agent.ovn-metadata\", \"file\": \"/var/log/containers/neutron/networking-ovn-metadata-agent.log\"}}, \"OVNEnableHaproxyDockerWrapper\": {\"description\": \"Generate a wrapper script so that haproxy is launched in a separate container.\", \"type\": \"boolean\", \"default\": true}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"OVNWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NeutronMetadataProxySharedSecret\": {\"description\": \"Shared secret to prevent spoofing\", \"type\": \"string\", \"hidden\": true, \"default\": \"0L1TuMmYu9cXN2twLue5RLHjS\"}, \"NeutronMetadataWorkers\": {\"default\": 1, \"description\": \"Sets the number of worker processes for the neutron OVN metadata agent.\\nThe default value results in the configuration being left unset and a\\nsystem-dependent default will be chosen (usually the number of\\nprocessors). Please note that this can result in a large number of\\nprocesses and memory consumption on systems with a large core count. On\\nsuch systems it is recommended that a non-default value be selected that\\nmatches the load requirements.\\n\", \"type\": \"string\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\"}, \"OVNNorthboundServerPort\": {\"description\": \"Port of the OVN Northbound DB server\", \"type\": \"number\", \"default\": 6641}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the OVN Southbound DB server\", \"type\": \"number\", \"default\": 6642}, \"OVNDbConnectionTimeout\": {\"description\": \"Timeout in seconds for the OVSDB connection transaction\", \"type\": \"number\", \"default\": 180}, \"OVNOvsdbProbeInterval\": {\"description\": \"Probe interval in ms for the OVSDB session\", \"type\": \"number\", \"default\": 60000}, \"MonitoringSubscriptionOvnMetadata\": {\"default\": \"overcloud-ovn-metadata\", \"type\": \"string\"}, \"OvnMetadataAgentDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging for OVN Metadata agent.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"DockerAdditionalSockets\": {\"default\": [\"/var/lib/openstack/docker.sock\"], \"description\": \"Additional domain sockets for the docker daemon to bind to (useful for mounting into containers that launch other containers)\", \"type\": \"comma_delimited_list\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"OvnMetadataCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OvnHardwareOffloadedQos\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable the QoS support for hardware offloaded ports\"}, \"OVNMetadataImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNMetadataUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}}, \"conditions\": {\"haproxy_wrapper_enabled\": {\"equals\": [{\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"neutron_metadata_workers_unset\": {\"equals\": [{\"get_param\": \"NeutronMetadataWorkers\"}, \"\"]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"OvnMetadataCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NeutronBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NeutronLogging\": {\"type\": \"OS::TripleO::Services::Logging::NeutronCommon\", \"properties\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerOvnMetadataImage\": \"ContainerOvnMetadataImage\", \"ContainerNeutronConfigImage\": \"ContainerNeutronConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerOvnMetadataImage\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"ContainerNeutronConfigImage\": {\"get_param\": \"ContainerNeutronConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for OVNMetadata agent\", \"value\": {\"service_name\": \"ovn_metadata\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionOvnMetadata\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NeutronLogging\", \"config_settings\"]}, {\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\": \"/var/lib/neutron/ovn_metadata_haproxy_wrapper\", \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo::profile::base::neutron::container_cli\": {\"get_param\": \"ContainerCli\"}, \"neutron::agents::ovn_metadata::shared_secret\": {\"get_param\": \"NeutronMetadataProxySharedSecret\"}, \"neutron::agents::ovn_metadata::auth_password\": {\"get_param\": \"NeutronPassword\"}, \"neutron::agents::ovn_metadata::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"neutron::agents::ovn_metadata::auth_tenant\": \"service\", \"neutron::agents::ovn_metadata::metadata_host\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataCellInternal\", \"host_nobrackets\"]}, \"neutron::agents::ovn_metadata::ovsdb_connection_timeout\": {\"get_param\": \"OVNDbConnectionTimeout\"}, \"neutron::agents::ovn_metadata::ovsdb_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}, \"neutron::agents::ovn_metadata::hwol_qos_enabled\": {\"get_param\": \"OvnHardwareOffloadedQos\"}, \"ovn::northbound::port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"neutron::agents::ovn_metadata::debug\": {\"if\": [{\"get_param\": \"OvnMetadataAgentDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::agents::ovn_metadata::metadata_protocol\": {\"if\": [\"internal_tls_enabled\", \"https\", \"http\"]}}, {\"if\": [\"neutron_metadata_workers_unset\", {}, {\"neutron::agents::ovn_metadata::metadata_workers\": {\"get_param\": \"NeutronMetadataWorkers\"}}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::protocol\": \"ssl\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\"}, {}]}]}, \"puppet_config\": {\"puppet_tags\": \"neutron_config,ovn_metadata_agent_config\", \"config_volume\": \"neutron\", \"step_config\": \"include tripleo::profile::base::neutron::ovn_metadata\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_metadata_agent.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini\", {\"get_attr\": [\"NeutronLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/var/lib/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/ovn_metadata.key\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_2\": {\"create_haproxy_wrapper\": {\"start_order\": 1, \"detach\": false, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\"]]}}}, \"step_4\": {\"setup_ovs_manager\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"exec\", \"include tripleo::profile::base::neutron::ovn_metadata\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_metadata_agent\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"cgroupns\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NeutronLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\", \"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\", \"/run/netns:/run/netns:shared\", \"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\"], {\"if\": [\"docker_enabled\", [\"/var/lib/openstack:/var/lib/openstack\"], null]}, {\"if\": [\"haproxy_wrapper_enabled\", [\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\"], null]}, {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\", \"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"metadata_settings\"]}, {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_metadata\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_metadata\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_metadata/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_metadata_agent\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"OvnMetadataCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NeutronLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create /run/netns with temp namespace\", \"command\": \"ip netns add ns_temp\", \"register\": \"ipnetns_add_result\", \"failed_when\": false}, {\"name\": \"remove temp namespace\", \"command\": \"ip netns delete ns_temp\", \"failed_when\": false, \"when\": [\"ipnetns_add_result.rc is defined\", \"ipnetns_add_result.rc == 0\"]}, {\"name\": \"create /var/lib/neutron\", \"file\": {\"path\": \"/var/lib/neutron\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"set conditions\", \"set_fact\": {\"haproxy_wrapper_enabled\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"debug_enabled\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"docker_additional_sockets\": {\"get_param\": \"DockerAdditionalSockets\"}}}, {\"name\": \"create kill_scripts directory within /var/lib/neutron\", \"file\": {\"state\": \"directory\", \"path\": \"/var/lib/neutron/kill_scripts\"}}, {\"name\": \"create haproxy kill script\", \"when\": \"haproxy_wrapper_enabled|bool\", \"copy\": {\"dest\": \"/var/lib/neutron/kill_scripts/haproxy-kill\", \"mode\": 493, \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/kill-script\"}}}]]}, \"upgrade_tasks\": [], \"external_update_tasks\": [{\"name\": \"Check if python3-openvswitch3.1 workaround is needed\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": \"step|int == 1\", \"shell\": \"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\n\", \"register\": \"metadata_python_ovs_3_1\", \"failed_when\": false, \"loop\": \"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}, {\"name\": \"Update ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"become\": true, \"loop\": \"{{ hosts_to_update_metadata }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_metadata_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_metadata_agent image pull successful.\", \"when\": [\"\'results\' in ovn_metadata_image_update\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_metadata_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"tags\": [\"ovn_metadata_parallel\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0}]}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"never\", \"ovn_metadata_serial\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"loop_control\": {\"pause\": 1}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(128,'2026-06-10 07:59:35',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V7WgDxaLxT5M80e5C9n2UCcFO\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"5QAuCI6DgbWqEzUK0gVmITEDx\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(129,'2026-06-10 07:59:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (130,'2026-06-10 07:59:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"NovaServiceName\": \"compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(131,'2026-06-10 07:59:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(132,'2026-06-10 07:59:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure libvirt-guests\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsShutdownTimeout\": {\"default\": 300, \"description\": \"Number of seconds we\'re willing to wait for a guest to shut down. If this is 0, then there is no time out (use with caution, as guests might not respond to a shutdown request). The default value is 300 seconds (5 minutes).\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt_guests::shutdown_timeout\": \"NovaResumeGuestsShutdownTimeout\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaResumeGuestsShutdownTimeout\": {\"get_param\": \"NovaResumeGuestsShutdownTimeout\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for libvirt-guests\", \"value\": {\"service_name\": \"nova_libvirt_guests\", \"config_settings\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::compute::libvirt_guests\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(133,'2026-06-10 07:59:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(134,'2026-06-10 07:59:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(135,'2026-06-10 07:59:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(136,'2026-06-10 07:59:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(137,'2026-06-10 07:59:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(138,'2026-06-10 07:59:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V7WgDxaLxT5M80e5C9n2UCcFO\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"5QAuCI6DgbWqEzUK0gVmITEDx\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (139,'2026-06-10 07:59:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.  This mapping overrides those in ServiceNetMapDefaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}}, \"conditions\": {\"memory_backing_dir_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"QemuMemoryBackingDir\"}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"QemuMemoryBackingDir\"]}, \"\"]}]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::libvirt::qemu::memory_backing_dir\": \"QemuMemoryBackingDir\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"QemuMemoryBackingDir\": {\"get_param\": \"QemuMemoryBackingDir\"}}}]}}}}, \"outputs\": {\"kolla_config_files\": {\"description\": \"Common kolla config_files.\", \"value\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}]]}}, \"kolla_permissions\": {\"description\": \"Common kolla permissions.\", \"value\": {\"list_concat\": [[{\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"config_settings\": {\"description\": \"Extra hieradata for all modular virt daemons.\", \"value\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}}, \"volumes\": {\"description\": \"Common volumes for all modular virt daemons.\", \"value\": {\"list_concat\": [[\"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\", \"/etc/pki/libvirt:/etc/pki/libvirt:ro\", \"/etc/pki/qemu:/etc/pki/qemu:ro\"]]}, {\"if\": [\"memory_backing_dir_set\", [{\"str_replace\": {\"template\": \"MEMORY_BACKING_DIR:MEMORY_BACKING_DIR\", \"params\": {\"MEMORY_BACKING_DIR\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::compute::libvirt::qemu::memory_backing_dir\"]}}}}]]}]}}, \"update_tasks\": {\"description\": \"Common update tasks for modular virt daemons\", \"value\": [{\"name\": \"check systemd-container package present or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\"}, {\"name\": \"download systemd-container package if not present\", \"yum\": {\"name\": \"systemd-container\", \"state\": \"present\", \"download_only\": true, \"download_dir\": \"/var/tmp/\"}, \"when\": \"is_systemd_container_package.changed\"}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(140,'2026-06-10 07:59:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(141,'2026-06-10 07:59:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"V7WgDxaLxT5M80e5C9n2UCcFO\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"5QAuCI6DgbWqEzUK0gVmITEDx\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(142,'2026-06-10 07:59:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(143,'2026-06-10 07:59:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized rsyslogd service for purposes of centralized log collection of OpenStack services\' logs.\\n\", \"parameters\": {\"ContainerRsyslogImage\": {\"description\": \"The container image to use for container\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"ContainerRsyslogConfigImage\": {\"description\": \"The container image to use for the rsyslog config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RsyslogReopenOnTruncate\": {\"default\": true, \"description\": \"Rsyslog imfile reopenOnTruncate parameter\", \"type\": \"boolean\"}, \"RsyslogElasticsearchSetting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-elasticsearch plugin\", \"type\": \"json\"}, \"RsyslogElasticsearchTlsCACert\": {\"default\": \"\", \"description\": \"Contains content of the CA cert for the CA that issued Elasticsearch server cert.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientCert\": {\"default\": \"\", \"description\": \"Contains content of the client cert for doing client cert auth against Elasticsearch.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientKey\": {\"default\": \"\", \"description\": \"Contains content of the private key corresponding to the cert RsyslogElasticsearchTlsClientCert.\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RsyslogAmqp1Setting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-omamqp1 plugin\", \"type\": \"json\"}, \"RsyslogAmqp1Local\": {\"default\": true, \"description\": \"Set to false to disable prefilling host connection value to local QDR in RsyslogAmqp1Setting.\", \"type\": \"boolean\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"RsyslogMaxMessageSize\": {\"default\": \"32k\", \"description\": \"Maximum supported message size (both for sending and receiving) for rsyslogd.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRsyslogImage\": \"ContainerRsyslogImage\", \"ContainerRsyslogConfigImage\": \"ContainerRsyslogConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRsyslogImage\": {\"get_param\": \"ContainerRsyslogImage\"}, \"ContainerRsyslogConfigImage\": {\"get_param\": \"ContainerRsyslogConfigImage\"}}}]}}}}, \"conditions\": {\"use_tls\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}, \"\"]}]}}, \"use_elasticsearch\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {}]}}, \"use_amqp1\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {}]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the rsyslog role.\", \"value\": {\"service_name\": \"rsyslog\", \"config_settings\": {\"map_merge\": [{\"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": {\"get_param\": \"RsyslogMaxMessageSize\"}}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": {\"get_param\": \"CloudName\"}, \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": {\"get_param\": \"KeystoneRegion\"}, \"format\": \"jsonf\"}}]}}}, {\"if\": [\"use_elasticsearch\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch\": {\"map_merge\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {\"template\": \"rsyslog-record\", \"searchIndex\": \"rsyslog-node-index\", \"dynSearchIndex\": \"on\", \"errorfile\": \"/var/log/rsyslog/omelasticsearch.log\"}]}}, {}]}, {\"if\": [\"use_amqp1\", {\"tripleo::profile::base::logging::rsyslog::amqp1\": {\"map_merge\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {\"template\": \"rsyslog-record\"}, {\"if\": [{\"get_param\": \"RsyslogAmqp1Local\"}, {\"host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}:$PORT\", \"params\": {\"$PORT\": {\"get_param\": \"MetricsQdrPort\"}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}}]}]}}, {}]}, {\"if\": [{\"get_param\": \"RsyslogReopenOnTruncate\"}, {\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\"}, {}]}, {\"if\": [\"use_tls\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_ca_cert\": {\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_cert\": {\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_key\": {\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}}]}]}, \"puppet_config\": {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_3\": {\"rsyslog\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(144,'2026-06-10 07:59:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Neutron service\\n\", \"parameters\": {\"NeutronServiceName\": {\"description\": \"service name\", \"type\": \"string\"}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": {\"str_replace\": {\"template\": \"--log-file=/var/log/neutron/SERVICE.log\", \"params\": {\"SERVICE\": {\"get_param\": \"NeutronServiceName\"}}}}}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/neutron:/var/log/neutron:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/neutron\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(145,'2026-06-10 07:59:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(146,'2026-06-10 07:59:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL HA clustercheck service deployment using puppet This service is used by HAProxy in a HA scenario to report whether the local galera node is synced\\n\", \"parameters\": {\"ContainerClustercheckImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerClustercheckConfigImage\": {\"description\": \"The container image to use for the clustercheck config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ClustercheckListener\": {\"default\": \"socat\", \"description\": \"How to expose the clustercheck service over TCP\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"socat\", \"xinetd\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlPuppetBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerClustercheckImage\": \"ContainerClustercheckImage\", \"ContainerClustercheckConfigImage\": \"ContainerClustercheckConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerClustercheckImage\": {\"get_param\": \"ContainerClustercheckImage\"}, \"ContainerClustercheckConfigImage\": {\"get_param\": \"ContainerClustercheckConfigImage\"}}}]}}}}, \"conditions\": {\"socat_listener\": {\"equals\": [{\"get_param\": \"ClustercheckListener\"}, \"socat\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service clustercheck using composable services.\", \"value\": {\"service_name\": \"clustercheck\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlPuppetBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::clustercheck::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$FQDN$NETWORK\')}\", \"params\": {\"$FQDN\": {\"if\": [\"socat_listener\", \"\", \"fqdn_\"]}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}}]}, \"puppet_config\": {\"config_volume\": \"clustercheck\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::pacemaker::clustercheck\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/clustercheck.json\": {\"command\": {\"if\": [\"socat_listener\", \"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\" \\\"$TRIPLEO_SOCAT_BIND\\\" system:\\\"grep -qPe \\\\\\\"^\\\\\\\\r\\\\$\\\\\\\" && /usr/bin/clustercheck\\\"\", \"/usr/sbin/xinetd -dontfork\"]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"clustercheck\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckImage\"]}, \"restart\": \"always\", \"net\": \"host\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\", \"/var/lib/mysql:/var/lib/mysql\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": null, \"upgrade_tasks\": null, \"update_tasks\": null, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop clustercheck container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"clustercheck\"], \"tripleo_delegate_to\": \"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(147,'2026-06-10 07:59:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (148,'2026-06-10 07:59:38',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(149,'2026-06-10 07:59:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron base service. Shared for all Neutron agents.\\n\", \"parameters\": {\"DatabaseSyncTimeout\": {\"default\": 900, \"description\": \"DB Sync Timeout default\", \"type\": \"number\"}, \"NeutronDhcpAgentsPerNetwork\": {\"type\": \"number\", \"default\": 0, \"description\": \"The number of neutron dhcp agents to schedule per network\"}, \"DhcpAgentNotification\": {\"default\": false, \"description\": \"Whether or not to enable DHCP agent notifications.\", \"type\": \"boolean\"}, \"NeutronDnsDomain\": {\"type\": \"string\", \"default\": \"ooo.test\", \"description\": \"Domain to use for building the hostnames.\"}, \"NeutronCorePlugin\": {\"default\": \"ml2\", \"description\": \"The core plugin for Neutron. The value should be the entrypoint to be loaded\\nfrom neutron.core_plugins namespace.\\n\", \"type\": \"string\"}, \"NeutronServicePlugins\": {\"default\": \"qos,ovn-router,trunk,segments,port_forwarding,log\", \"description\": \"Comma-separated list of service plugin entrypoints to be loaded from the\\nneutron.service_plugins namespace.\\n\", \"type\": \"comma_delimited_list\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NeutronDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Neutron services.\", \"type\": \"boolean\"}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"NeutronGlobalPhysnetMtu\": {\"type\": \"number\", \"default\": 1350, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(If this is not changed TenantNetPhysnetMtu will be used.)\\n\"}, \"TenantNetPhysnetMtu\": {\"type\": \"number\", \"default\": 1500, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(The mtu setting of the Tenant network in network_data.yaml\\ncontrol\'s this parameter.)\\n\"}, \"NeutronDBSyncExtraParams\": {\"default\": \"\", \"description\": \"String of extra command line parameters to append to the neutron-db-manage\\nupgrade head command.\\n\", \"type\": \"string\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"NeutronGlobalReportInterval\": {\"default\": 300, \"description\": \"Seconds between nodes reporting state to server; should be less than NeutronAgentDownTime, best if it is half or less than NeutronAgentDownTime.\\n\", \"type\": \"number\"}}, \"conditions\": {\"dhcp_agents_zero\": {\"equals\": [{\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}, 0]}, \"global_physnet_mtu_unset\": {\"equals\": [{\"get_param\": \"NeutronGlobalPhysnetMtu\"}, 0]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron base service.\", \"value\": {\"service_name\": \"neutron_base\", \"config_settings\": {\"map_merge\": [{\"neutron::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"neutron::core_plugin\": {\"get_param\": \"NeutronCorePlugin\"}, \"neutron::service_plugins\": {\"get_param\": \"NeutronServicePlugins\"}, \"neutron::report_interval\": {\"get_param\": \"NeutronGlobalReportInterval\"}, \"neutron::logging::debug\": {\"if\": [{\"get_param\": \"NeutronDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"neutron::allow_overlapping_ips\": true, \"neutron::dhcp_agent_notification\": {\"get_param\": \"DhcpAgentNotification\"}, \"neutron::dns_domain\": {\"get_param\": \"NeutronDnsDomain\"}, \"neutron::rabbit_heartbeat_timeout_threshold\": 60, \"neutron::host\": \"%{hiera(\'fqdn_canonical\')}\", \"neutron::db::database_db_max_retries\": -1, \"neutron::db::database_max_retries\": -1, \"neutron::db::sync::db_sync_timeout\": {\"get_param\": \"DatabaseSyncTimeout\"}, \"neutron::global_physnet_mtu\": {\"if\": [\"global_physnet_mtu_unset\", {\"get_param\": \"TenantNetPhysnetMtu\"}, {\"get_param\": \"NeutronGlobalPhysnetMtu\"}]}, \"neutron::db::sync::extra_params\": {\"get_param\": \"NeutronDBSyncExtraParams\"}, \"neutron::vlan_transparent\": {\"get_param\": \"EnableVLANTransparency\"}, \"neutron::rabbit_heartbeat_in_pthread\": false}, {\"if\": [\"dhcp_agents_zero\", {}, {\"tripleo::profile::base::neutron::dhcp_agents_per_network\": {\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(150,'2026-06-10 07:59:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized logrotate with crond for containerized service logs rotation\\n\", \"parameters\": {\"ContainerCrondImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"ContainerCrondConfigImage\": {\"description\": \"The container image to use for the crond config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LogrotateMaxsize\": {\"description\": \"Configures the maxsize param for containerized logrotate.\", \"type\": \"string\", \"default\": \"10M\"}, \"LogrotateRotationInterval\": {\"description\": \"Configures rotation interval for containerized logrotate.\", \"type\": \"string\", \"default\": \"daily\", \"constraints\": [{\"allowed_values\": [\"hourly\", \"daily\", \"weekly\", \"monthly\"]}]}, \"LogrotateRotate\": {\"description\": \"Configures the rotate param for containerized logrotate.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotatePurgeAfterDays\": {\"description\": \"Enforces life time (days) of rotated and compressed files.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotateDateExt\": {\"description\": \"Enable/disable dateext parameter.\", \"type\": \"boolean\", \"default\": false}, \"LogrotateDateFormat\": {\"description\": \"Configures dateformat strings for containerized logrotate. This is valid when LogrotateDateExt is true. The allowed specifiers are only %Y %m %d %H %M %S %V and %s.\", \"type\": \"string\", \"default\": \"-%Y%m%d\", \"constraints\": [{\"allowed_pattern\": \"-(%[YmdHMSVs])+$\"}]}, \"LogrotateDateYesterday\": {\"description\": \"Configures dateyesterday paramter for containerized logrotate. This is valid when LogrotateDateExt is true.\", \"type\": \"boolean\", \"default\": false}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCrondImage\": \"ContainerCrondImage\", \"ContainerCrondConfigImage\": \"ContainerCrondConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCrondImage\": {\"get_param\": \"ContainerCrondImage\"}, \"ContainerCrondConfigImage\": {\"get_param\": \"ContainerCrondConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the crond role.\", \"value\": {\"service_name\": \"logrotate_crond\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::logging::logrotate::maxsize\": {\"get_param\": \"LogrotateMaxsize\"}, \"tripleo::profile::base::logging::logrotate::rotation\": {\"get_param\": \"LogrotateRotationInterval\"}, \"tripleo::profile::base::logging::logrotate::rotate\": {\"get_param\": \"LogrotateRotate\"}, \"tripleo::profile::base::logging::logrotate::purge_after_days\": {\"get_param\": \"LogrotatePurgeAfterDays\"}, \"tripleo::profile::base::logging::logrotate::dateext\": {\"get_param\": \"LogrotateDateExt\"}}, {\"if\": [{\"get_param\": \"LogrotateDateExt\"}, {\"tripleo::profile::base::logging::logrotate::dateformat\": {\"get_param\": \"LogrotateDateFormat\"}, \"tripleo::profile::base::logging::logrotate::dateyesterday\": {\"get_param\": \"LogrotateDateYesterday\"}}]}]}, \"host_prep_tasks\": [{\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"deploy_steps_tasks\": [{\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": {\"get_param\": \"LogrotatePurgeAfterDays\"}}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}], \"update_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"upgrade_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"puppet_config\": {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"logrotate_crond\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondImage\"]}, \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(151,'2026-06-10 07:59:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(152,'2026-06-10 07:59:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(153,'2026-06-10 07:59:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(154,'2026-06-10 07:59:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Composable Timezone service\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Timezone role using composable services.\", \"value\": {\"service_name\": \"timezone\", \"host_prep_tasks\": [{\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": {\"get_param\": \"TimeZone\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (155,'2026-06-10 07:59:40',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment with pacemaker bundle\\n\", \"parameters\": {\"ContainerMysqlImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerMysqlConfigImage\": {\"description\": \"The container image to use for the mysql config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"L35jp4QTgu\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\"}, \"MysqlUpgradePersist\": {\"type\": \"boolean\", \"default\": false}, \"MysqlUpgradeTransfer\": {\"type\": \"boolean\", \"default\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"MysqlGaleraSSTMethod\": {\"type\": \"string\", \"default\": \"rsync\", \"description\": \"Method used by galera to perform State Snapshot Transfers\", \"constraints\": [{\"allowed_values\": [\"rsync\", \"mariabackup\"]}]}, \"MysqlMariabackupUser\": {\"type\": \"string\", \"default\": \"mariabackup\", \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\"}, \"MysqlMariabackupPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\", \"default\": \"j1B32DBXFtXhrmqmIBzhbZcyq\"}, \"MysqlGaleraSSLCipher\": {\"type\": \"string\", \"default\": \"AES128-SHA256\", \"description\": \"Symmetric cipher to use.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMysqlImage\": \"ContainerMysqlImage\", \"ContainerMysqlConfigImage\": \"ContainerMysqlConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMysqlImage\": {\"get_param\": \"ContainerMysqlImage\"}, \"ContainerMysqlConfigImage\": {\"get_param\": \"ContainerMysqlConfigImage\"}}}]}}}}, \"conditions\": {\"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service MySQL using composable services.\", \"value\": {\"service_name\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::ca_file\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": {\"get_param\": \"MysqlGaleraSSTMethod\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": {\"get_param\": \"MysqlMariabackupUser\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": {\"get_param\": \"MysqlMariabackupPassword\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": {\"get_param\": \"MysqlGaleraSSLCipher\"}}]}, \"puppet_config\": {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\", \"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\", \"echo -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\", \"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\", \"kolla_set_configs\", \"sudo -u mysql -E kolla_extend_start\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\", \"mysqld_safe --skip-networking --wsrep-on=OFF &\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\"], {\"if\": [{\"equals\": [{\"get_param\": \"MysqlGaleraSSTMethod\"}, \"mariabackup\"]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\"\"]]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\", \"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": {\"get_param\": \"MysqlMariabackupUser\"}, \"DB_MARIABACKUP_PASSWORD\": {\"get_param\": \"MysqlMariabackupPassword\"}}}}, \"step_2\": {\"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], {\"if\": [{\"get_param\": \"ConfigDebug\"}, [\"--debug\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"]]}]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}], \"post_update_tasks\": [{\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}], [{\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}], {\"get_attr\": [\"MysqlBase\", \"mysql_drop_unused_users\"]}, [{\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], [\"/var/log/containers/mysql:/var/log/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": {\"list_join\": [\"\\n\", [\"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\", {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}, \"mysqladmin shutdown\"]]}}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}]]}, \"external_upgrade_tasks\": [{\"vars\": {\"mysql_upgrade_transfer\": {\"get_param\": \"MysqlUpgradeTransfer\"}}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(156,'2026-06-10 07:59:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Prepare container images\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImagePrepare\": {\"default\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images.\", \"type\": \"json\"}, \"ContainerImagePrepareLogFile\": {\"default\": \"/var/log/tripleo-container-image-prepare.log\", \"type\": \"string\", \"description\": \"Used to store outputs of \\\"openstack tripleo container image prepare\\\".\"}, \"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NeutronMechanismDrivers\": {\"default\": \"ovn\", \"description\": \"The mechanism drivers for the Neutron tenant network.\\n\", \"type\": \"comma_delimited_list\"}, \"DockerRegistryMirror\": {\"description\": \"Optional. Mirror to use for registry docker.io\", \"default\": \"\", \"type\": \"string\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ContainerImagePrepareDebug\": {\"default\": false, \"description\": \"Whether or not we want to activate --debug in tripleo container image prepare.\", \"type\": \"boolean\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"AdditionalArchitectures\": {\"default\": [], \"description\": \"List of additional architectures to enable.\", \"type\": \"comma_delimited_list\"}, \"ControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 3}, \"CellControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CellControllerComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 3}, \"BlockStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for container image prepare\", \"value\": {\"service_name\": \"container_image_prepare\", \"external_deploy_tasks\": [{\"name\": \"Run tripleo-container-image-prepare role\", \"import_role\": {\"name\": \"tripleo_container_image_prepare\"}, \"vars\": {\"tripleo_container_image_prepare_log_file\": {\"get_param\": \"ContainerImagePrepareLogFile\"}, \"tripleo_container_image_prepare_debug\": {\"if\": [{\"get_param\": \"ContainerImagePrepareDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo_container_image_prepare_roles\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"tripleo_container_image_prepare_content\": {\"parameter_defaults\": {\"ContainerImagePrepare\": {\"get_param\": \"ContainerImagePrepare\"}, \"DockerInsecureRegistryAddress\": {\"get_param\": \"DockerInsecureRegistryAddress\"}, \"NeutronMechanismDrivers\": {\"get_param\": \"NeutronMechanismDrivers\"}, \"DockerRegistryMirror\": {\"get_param\": \"DockerRegistryMirror\"}, \"ContainerImageRegistryCredentials\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"AdditionalArchitectures\": {\"get_param\": \"AdditionalArchitectures\"}, \"ControllerContainerImagePrepare\": {\"get_param\": \"ControllerContainerImagePrepare\"}, \"ControllerServices\": {\"get_param\": \"ControllerServices\"}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerContainerImagePrepare\": {\"get_param\": \"CellControllerContainerImagePrepare\"}, \"CellControllerServices\": {\"get_param\": \"CellControllerServices\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeContainerImagePrepare\": {\"get_param\": \"CellControllerComputeContainerImagePrepare\"}, \"CellControllerComputeServices\": {\"get_param\": \"CellControllerComputeServices\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeContainerImagePrepare\": {\"get_param\": \"ComputeContainerImagePrepare\"}, \"ComputeServices\": {\"get_param\": \"ComputeServices\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageContainerImagePrepare\": {\"get_param\": \"BlockStorageContainerImagePrepare\"}, \"BlockStorageServices\": {\"get_param\": \"BlockStorageServices\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageContainerImagePrepare\": {\"get_param\": \"ObjectStorageContainerImagePrepare\"}, \"ObjectStorageServices\": {\"get_param\": \"ObjectStorageServices\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageContainerImagePrepare\": {\"get_param\": \"CephStorageContainerImagePrepare\"}, \"CephStorageServices\": {\"get_param\": \"CephStorageServices\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerContainerImagePrepare\": {\"get_param\": \"NetworkerContainerImagePrepare\"}, \"NetworkerServices\": {\"get_param\": \"NetworkerServices\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}}}}, \"when\": [\"(step | int) == 1\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(157,'2026-06-10 07:59:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(158,'2026-06-10 07:59:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Chrony time service deployment using ansible, this YAML file creates the interface between the HOT template and the ansible role that actually installs and configure chronyd.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"ChronyGlobalServerOptions\": {\"default\": \"\", \"description\": \"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"ChronyGlobalPoolOptions\": {\"default\": \"\", \"description\": \"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"NtpIburstEnable\": {\"default\": true, \"description\": \"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\", \"type\": \"boolean\"}, \"MaxPoll\": {\"description\": \"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 10, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"MinPoll\": {\"description\": \"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 6, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"ChronyAclRules\": {\"default\": [\"deny all\"], \"description\": \"Access Control List of NTP clients.  By default no clients are permitted.\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"chrony_global_server_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalServerOptions\"}, \"\"]}, \"chrony_global_pool_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalPoolOptions\"}, \"\"]}, \"ntp_iburst\": {\"equals\": [{\"get_param\": \"NtpIburstEnable\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role chrony using composable timesync services.\", \"value\": {\"service_name\": \"chrony\", \"firewall_rules\": {\"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}}, \"host_prep_tasks\": [{\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}], \"ansible_group_vars\": {\"chrony_role_action\": \"all\", \"chrony_ntp_servers\": {\"get_param\": \"NtpServer\"}, \"chrony_ntp_pools\": {\"get_param\": \"NtpPool\"}, \"chrony_global_server_settings\": {\"if\": [\"chrony_global_server_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalServerOptions\"}]}, \"chrony_global_pool_settings\": {\"if\": [\"chrony_global_pool_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalPoolOptions\"}]}, \"chrony_manage_package\": {\"get_param\": \"EnablePackageInstall\"}, \"chrony_acl_rules\": {\"get_param\": \"ChronyAclRules\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(159,'2026-06-10 07:59:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ovn Controller agent.\\n\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ContainerOvnControllerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"ContainerOvnControllerConfigImage\": {\"description\": \"The container image to use for the ovn_controller config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the Southbound DB Server\", \"type\": \"number\", \"default\": 6642}, \"NeutronBridgeMappings\": {\"description\": \"The OVS logical->physical bridge mappings to use. See the Neutron documentation for details. Defaults to mapping br-ex - the external bridge on hosts - to a physical name \'datacentre\' which can be used to create provider networks (and we use this for the default floating network) - if changing this either use different post-install network scripts or be sure to keep \'datacentre\' as a mapping network name.\\n\", \"type\": \"comma_delimited_list\", \"default\": \"datacentre:br-ex\", \"tags\": [\"role_specific\"]}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"OVNEncapType\": {\"description\": \"Type of encapsulation used in OVN. It can be \\\"geneve\\\" or \\\"vxlan\\\".\\n\", \"type\": \"string\", \"default\": \"geneve\", \"constraints\": [{\"allowed_values\": [\"geneve\", \"vxlan\"]}]}, \"OVNIntegrationBridge\": {\"description\": \"Name of the OVS bridge to use as integration bridge by OVN Controller.\\n\", \"type\": \"string\", \"default\": \"br-int\"}, \"OVNMetadataEnabled\": {\"description\": \"Whether Metadata Service has to be enabled\", \"type\": \"boolean\", \"default\": true}, \"OVNAvailabilityZone\": {\"description\": \"The az options to configure in ovs db. eg. [\'az-0\', \'az-1\', \'az-2\']\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"OVNCMSOptions\": {\"description\": \"The CMS options to configure in ovs db\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNEncapTos\": {\"description\": \"The value to be applied to OVN tunnel interface\'s option:tos as specified in the Open_vSwitch database Interface table. This feature is supported from OVN v21.12.0.\\n\", \"type\": \"string\", \"default\": \"0\", \"tags\": [\"role_specific\"]}, \"OvsHwOffload\": {\"default\": false, \"description\": \"Enable OVS Hardware Offload. This feature supported from OVS 2.8.0\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"OVNRemoteProbeInterval\": {\"description\": \"Probe interval in ms\", \"type\": \"number\", \"default\": 60000}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"OVNOpenflowProbeInterval\": {\"description\": \"The inactivity probe interval of the OpenFlow connection to the OpenvSwitch integration bridge, in seconds.\\n\", \"type\": \"number\", \"default\": 60}, \"OVNOfctrlWaitBeforeClear\": {\"description\": \"Sets the time ovn-controller will wait on startup before clearing all openflow rules and installing the new ones, in ms.\\n\", \"type\": \"number\", \"default\": 8000}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ContainerOvnCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OVNContainerCpusetCpus\": {\"description\": \"Limit the specific CPUs or cores a container can use. It can be specified as a single core (ex. 0), as a comma-separated list (ex. 0,1), as a range (ex. 0-3) or a combination if previous methods (ex 0-3,7,11-15).  The selected cores should be isolated from guests and hypervisor in order to obtain best possible performance.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNStaticBridgeMacMappings\": {\"type\": \"json\", \"default\": {}, \"description\": \"Static OVN Bridge MAC address mappings. Unique OVN bridge mac addresses\\nis dynamically allocated by creating neutron ports. When neutron isn\'t\\navailable, for instance in the standalone deployment, use this parameter\\nto provide static OVN bridge mac addresses. For example:\\n   controller-0:\\n     datacenter: 00:00:5E:00:53:00\\n     provider: 00:00:5E:00:53:01\\n   compute-0:\\n     datacenter: 00:00:5E:00:54:00\\n     provider: 00:00:5E:00:54:01\\n\", \"tags\": [\"role_specific\"]}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}, \"OVNControllerImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerGarpMaxTimeout\": {\"description\": \"When used, this configuration value specifies the maximum timeout (in seconds) between two consecutive GARP packets sent by ovn-controller.\\n\", \"type\": \"number\", \"default\": 0}}, \"conditions\": {\"force_config_drive\": {\"equals\": [{\"get_param\": \"OVNMetadataEnabled\"}, false]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}, \"enable_vlan_transparency\": {\"equals\": [{\"get_param\": \"EnableVLANTransparency\"}, true]}, \"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"ovn_cpu_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"OVNContainerCpusetCpus\"}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNContainerCpusetCpus\"]}, \"\"]}}]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}}, \"az_ovn_unset\": {\"and\": [{\"equals\": [{\"get_param\": \"OVNAvailabilityZone\"}, []]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn::controller::ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn::controller::ovn_cms_options\": {\"if\": [\"az_ovn_unset\", \"OVNCMSOptions\", \"OVNCMSOptionsMerged\"]}, \"ovn::controller::ovn_encap_tos\": \"OVNEncapTos\", \"vswitch::ovs::enable_hw_offload\": \"OvsHwOffload\", \"container_cpuset_cpus\": \"OVNContainerCpusetCpus\", \"ContainerOvnControllerImage\": \"ContainerOvnControllerImage\", \"ContainerOvnControllerConfigImage\": \"ContainerOvnControllerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}, \"OVNCMSOptionsMerged\": {\"list_join\": [\"\", [{\"str_replace\": {\"template\": \"$OVNCMSOptions\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}, \"\"]}}, {\"$OVNCMSOptions\": {\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}}, {\"$OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}}]}}}, {\"str_replace\": {\"template\": \",availability-zones=$OVNAvailabilityZone\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}}, {\"$OVNAvailabilityZone\": {\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}}, {\"$OVNAvailabilityZone\": {\"list_join\": [\",\", {\"get_param\": \"OVNAvailabilityZone\"}]}}]}}}]]}, \"OVNEncapTos\": {\"get_param\": \"OVNEncapTos\"}, \"OvsHwOffload\": {\"get_param\": \"OvsHwOffload\"}, \"OVNContainerCpusetCpus\": {\"get_param\": \"OVNContainerCpusetCpus\"}, \"ContainerOvnControllerImage\": {\"get_param\": \"ContainerOvnControllerImage\"}, \"ContainerOvnControllerConfigImage\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}}]}}}, \"OVNBridgeMappingsValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn_static_bridge_mac_mappings\": \"OVNStaticBridgeMacMappings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNStaticBridgeMacMappings\": {\"get_param\": \"OVNStaticBridgeMacMappings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ovn Controller agent.\", \"value\": {\"service_name\": \"ovn_controller\", \"firewall_rules\": {\"118 neutron vxlan networks\": {\"proto\": \"udp\", \"dport\": 4789, \"state\": []}, \"119 neutron geneve networks\": {\"proto\": \"udp\", \"dport\": 6081, \"state\": []}, \"120 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"OUTPUT\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}, \"121 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"PREROUTING\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"ovn::controller::ovn_encap_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronTenantNetwork\"]}}}}, \"ovn::controller::ovn_encap_type\": {\"get_param\": \"OVNEncapType\"}, \"ovn::controller::ovn_bridge\": {\"get_param\": \"OVNIntegrationBridge\"}, \"ovn::controller::hostname\": \"%{hiera(\'fqdn_canonical\')}\", \"ovn::controller::ovn_remote_probe_interval\": {\"get_param\": \"OVNRemoteProbeInterval\"}, \"ovn::controller::ovn_openflow_probe_interval\": {\"get_param\": \"OVNOpenflowProbeInterval\"}, \"ovn::controller::ovn_ofctrl_wait_before_clear\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}, \"ovn::controller::garp_max_timeout_sec\": {\"get_param\": \"OVNControllerGarpMaxTimeout\"}, \"ovn::controller::ovn_monitor_all\": true}, {\"if\": [\"force_config_drive\", {\"nova::compute::force_config_drive\": true}, {}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::agents::ovn::protocol\": \"ssl\"}, {}]}, {\"if\": [\"enable_vlan_transparency\", {\"vswitch::ovs::vlan_limit\": 0}, {}]}]}, \"service_config_settings\": {}, \"puppet_config\": {\"puppet_tags\": \"vs_config,exec\", \"config_volume\": \"ovn_controller\", \"step_config\": \"include tripleo::profile::base::neutron::agents::ovn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/etc/sysconfig/modules:/etc/sysconfig/modules\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_controller.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock\", {\"if\": [\"internal_tls_enabled\", {\"list_join\": [\" \", [\"-p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C\", {\"get_param\": \"InternalTLSCAFile\"}]]}, \"\"]}]]}, \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_controller\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}, \"docker_config\": {\"step_4\": {\"configure_cms_options\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\"$CMS_OPTS\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\"], \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_controller\": {\"map_merge\": [{\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"depends_on\": [\"openvswitch.service\"]}, {\"if\": [\"ovn_cpu_set\", {\"cpuset_cpus\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"container_cpuset_cpus\"]}}]}, {\"healthcheck\": {\"test\": {\"list_join\": [\" \", [\"/openstack/healthcheck\", {\"yaql\": {\"expression\": \"str($.data.port)\", \"data\": {\"port\": {\"get_param\": \"OVNSouthboundServerPort\"}}}}]]}}, \"volumes\": {\"list_concat\": [[\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}, \"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\", \"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_controller\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_controller/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_controller\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"ContainerOvnCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/openvswitch\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/openvswitch/ovn\", \"setype\": \"container_file_t\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Copy in cleanup script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup\"}, \"dest\": \"/usr/libexec/neutron-cleanup\", \"force\": true, \"mode\": \"0755\"}}, {\"name\": \"Copy in cleanup service\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup.service\"}, \"dest\": \"/usr/lib/systemd/system/neutron-cleanup.service\", \"force\": true}}, {\"name\": \"Enabling the cleanup service\", \"service\": {\"name\": \"neutron-cleanup\", \"enabled\": true}, \"when\": \"not (ansible_check_mode|bool)\"}], \"external_deploy_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"ovn_controller_external_deploy_init\", \"block\": [{\"name\": {\"str_replace\": {\"template\": \"create ovn mac address for $ROLE_NAME role nodes\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"tripleo_ovn_mac_addresses\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": {\"get_param\": \"RootStackName\"}, \"role_name\": {\"get_param\": \"RoleName\"}, \"server_resource_names\": {\"str_replace\": {\"template\": \"{{ groups[\\\"$ROLE_NAME\\\"] }}\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"ovn_bridge_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_bridge_mappings\"]}, \"ovn_static_bridge_mac_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_static_bridge_mac_mappings\"]}}}]}], \"external_update_tasks\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 1\", \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_controller image pull successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_image_update\"], \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"OVN Container image used\", \"debug\": {\"msg\": \"ovn container will be using {{ image }}\"}, \"vars\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovs_vsctl\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Was the update of OVN OVS related parameter successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovs_vsctl\"], \"become\": true, \"tags\": [\"ovn\"], \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovs_vsctl.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"set_fact\": {\"any_ovn_host\": \"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\"}, \"tags\": \"ovn\", \"when\": \"step|int == 1\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"delegate_to\": \"{{ any_ovn_host }}\", \"when\": \"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\", \"tags\": [\"ovn\"], \"become\": true}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\", \"query\": \"results[?item == \'{{item}}\'].stdout\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\", \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_update\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile | json_query(query) | first }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Was the ovn_controller successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_update\"], \"tags\": \"ovn\", \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 1\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}], \"upgrade_tasks\": [{\"name\": \"Fetch running ovn_controller image\", \"shell\": \"set -e\\npodman inspect --format \\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\" ovn_controller\\n\", \"register\": \"running_ovn_image\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\", \"ovn_image\"]}, {\"name\": \"Run ovn_controller upgrade\", \"tags\": [\"ovn\", \"ovn_image\"], \"vars\": {\"ovn_controller_image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": [\"step|int == 4\", \"running_ovn_image.stdout != ovn_controller_image\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 4\", \"tags\": [\"ovn\", \"ovn_image\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"]}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile.stdout }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 4\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get neutron agents ID\", \"command\": \"openstack network agent list --column ID --column Host --column Binary --format yaml\", \"register\": \"neutron_agents_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Filter only current host\", \"set_fact\": {\"neutron_agents\": \"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Deleting OVN agents\", \"block\": [{\"name\": \"Stop OVN containers\", \"loop\": [\"tripleo_ovn_controller\", \"tripleo_ovn_metadata_agent\"], \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_containers\", \"failed_when\": \"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\"}, {\"name\": \"Delete neutron agents\", \"loop\": \"{{ neutron_agents }}\", \"loop_control\": {\"loop_var\": \"agent\", \"label\": \"{{ agent.Host }}/{{ agent.Binary }}\"}, \"command\": \"openstack network agent delete {{ agent.ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(160,'2026-06-10 07:59:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"yes\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"SshServerOptionsOverrides\"]}], \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}, \"ssh_banner_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"BannerText\"}, \"\"]}}, \"ssh_motd_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"MessageOfTheDay\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo_sshd_password_authentication\": {\"get_param\": \"PasswordAuthentication\"}, \"tripleo_sshd_banner_enabled\": {\"if\": [\"ssh_banner_text_set\", true, false]}, \"tripleo_sshd_banner_text\": {\"get_param\": \"BannerText\"}, \"tripleo_sshd_motd_enabled\": {\"if\": [\"ssh_motd_text_set\", true, false]}, \"tripleo_sshd_message_of_the_day\": {\"get_param\": \"MessageOfTheDay\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(161,'2026-06-10 07:59:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment using puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MysqlMaxConnections\": {\"description\": \"Configures MySQL max_connections config setting\", \"type\": \"number\", \"default\": 4096}, \"MysqlIncreaseFileLimit\": {\"description\": \"Flag to increase MySQL open-files-limit to 16384\", \"type\": \"boolean\", \"default\": true}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"L35jp4QTgu\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\"}, \"EnableGalera\": {\"default\": true, \"description\": \"Whether to use Galera instead of regular MariaDB.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableMysqlAuthEd25519\": {\"type\": \"boolean\", \"description\": \"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\", \"default\": false}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"MysqlInnodbBufferPoolSize\": {\"type\": \"string\", \"description\": \"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\", \"default\": \"128M\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MysqlCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, \"innodb_buffer_pool_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlInnodbBufferPoolSize\"}, \"\"]}}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlCertificateKeySize\"}, \"\"]}}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"mysql_upgrade_db.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}}}}, \"mysql_drop_unused_users\": {\"description\": \"Ansible block to clean up unusued Openstack DB users\", \"value\": [{\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}]}, \"role_data\": {\"description\": \"Service MySQL using composable services.\", \"value\": {\"service_name\": \"mysql\", \"config_settings\": {\"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"mysql_max_connections\": {\"get_param\": \"MysqlMaxConnections\"}, \"mysql::server::root_password\": {\"get_param\": \"MysqlRootPassword\"}, \"mysql_clustercheck_password\": {\"get_param\": \"MysqlClustercheckPassword\"}, \"enable_galera\": {\"get_param\": \"EnableGalera\"}, \"mysql_auth_ed25519\": {\"get_param\": \"EnableMysqlAuthEd25519\"}, \"mysql_bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": {\"get_param\": \"MysqlIncreaseFileLimit\"}, \"tripleo::profile::base::database::mysql::certificate_specs\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"service_certificate\": \"/etc/pki/tls/certs/mysql.crt\", \"service_key\": \"/etc/pki/tls/private/mysql.key\"}]}, \"innodb_buffer_pool_size\": {\"if\": [\"innodb_buffer_pool_set\", {\"get_param\": \"MysqlInnodbBufferPoolSize\"}]}}, \"step_config\": \"include tripleo::profile::base::database::mysql\\n\", \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MysqlCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (162,'2026-06-10 07:59:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"ApomcwoXm9jjJOvUNPSNDY3vi\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(163,'2026-06-10 07:59:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"parameters\": {\"ContainerHeatApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"ContainerHeatApiConfigImage\": {\"description\": \"The container image to use for the heat_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api\", \"file\": \"/var/log/containers/heat/heat_api.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"HeatApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatApiOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"osNd9JfhsrCO9svVkwwbZnQ0E\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApi\": {\"default\": \"overcloud-heat-api\", \"type\": \"string\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiImage\": \"ContainerHeatApiImage\", \"ContainerHeatApiConfigImage\": \"ContainerHeatApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiImage\": {\"get_param\": \"ContainerHeatApiImage\"}, \"ContainerHeatApiConfigImage\": {\"get_param\": \"ContainerHeatApiConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API role.\", \"value\": {\"service_name\": \"heat_api\", \"firewall_rules\": {\"125 heat_api\": {\"dport\": [8004]}}, \"firewall_frontend_rules\": {\"100 heat_api_haproxy_frontend\": {\"dport\": [8004]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_haproxy_frontend_ssl\": {\"dport\": [13004]}}, \"keystone_resources\": {\"heat\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"uri\"]}}, \"users\": {\"heat\": {\"password\": {\"get_param\": \"HeatPassword\"}}, \"heat_stack_domain_admin\": {\"password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"roles\": [\"admin\"], \"domain\": \"heat_stack\"}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"orchestration\", \"roles\": [\"heat_stack_user\"], \"domains\": [\"heat_stack\"]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiLogging\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::wsgi::apache_api::vhost_custom_fragment\": \"Timeout 600\", \"heat::api::service_name\": \"httpd\", \"heat::wsgi::apache_api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api\": [{\"get_param\": \"HeatApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api\", \"puppet_tags\": \"heat_config,file,concat,file_line,heat_api_paste_ini\", \"step_config\": \"include tripleo::profile::base::heat::api\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, {\"get_param\": \"HeatApiOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatApiOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"heat_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron heat\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api\", \"heat_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(164,'2026-06-10 07:59:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure tuned\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"TunedCustomProfile\": {\"default\": \"\", \"description\": \"The definition of a new tuned profile in INI format which will be named after the TunedProfileName and applied to the host. E.g. if TunedProfileName is \'my_profile\', it creates the file \'/etc/tuned/my_profile/tuned.conf\' on host whose content is the value of TunedCustomProfile, e.g. \\\"[main]\\\\n include=throughput-performance\\\\n[sysctl]\\\\nvm.dirty_ratio=10\\\"\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"description\": \"Tuned Profile to apply to the host\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"tuned_custom_profile\": \"TunedCustomProfile\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"TunedCustomProfile\": {\"get_param\": \"TunedCustomProfile\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for tuned\", \"value\": {\"service_name\": \"tuned\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tuned\"}}], \"ansible_group_vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_custom_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_custom_profile\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(165,'2026-06-10 07:59:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(166,'2026-06-10 07:59:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Package installation settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"UpgradeLeappEnabled\": {\"description\": \"Use Leapp for operating system upgrade\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDebug\": {\"description\": \"Print debugging output when running Leapp\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDevelSkip\": {\"description\": \"Skip Leapp checks by setting env variables when running Leapp in\\ndevelopment/testing. For example, LEAPP_DEVEL_SKIP_RHSM=1.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappCommandOptions\": {\"description\": \"In case or using UpgradeLeappDevelSkip with LEAPP_NO_RHSM=1 user\\ncan specify --enablerepo <repo1> --enablerepo <repo2> options for\\nleapp to use these repositories for the upgrade process.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappRebootTimeout\": {\"description\": \"Timeout (seconds) for the OS upgrade phase via Leapp\", \"type\": \"number\", \"default\": 3600}, \"UpgradeLeappPostRebootDelay\": {\"description\": \"Maximum (seconds) to wait for machine to reboot and respond to a test\\ncommand.\\n\", \"type\": \"number\", \"default\": 120}, \"UpgradeLeappToRemove\": {\"default\": [], \"description\": \"List of packages to remove during Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappToInstall\": {\"default\": [], \"description\": \"List of packages to install after Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappUnloadKernelDrivers\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of modules to unload from the system due to being incompatible\\nwith the next RHEL version. If not being unloaded Leapp will\\ninhibit the upgrade.\\n\"}, \"LeappActorsToRemove\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of actors to remove from the leapp process to prevent them\\nfrom inhibiting the upgrade.\\n\"}, \"LeappRepoInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the Leapp process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds to get Leapp working.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NICsPrefixesToUdev\": {\"default\": [], \"description\": \"List of NIC prefixes to hardcode into udev in order to prevent\\nrenaming.\\n\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappPreRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds before rebooting into Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappPostRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds after rebooting from Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"SkipPackageUpdate\": {\"default\": false, \"description\": \"Set to true to skip the update all packages\", \"type\": \"boolean\"}, \"SkipRhelEnforcement\": {\"default\": false, \"description\": \"Whether to avoid or not RHEL/OSP policies enforcement on Red Hat. Mainly for CI purpose.  It shouldn\'t matter on other distributions where it\'s disabled in the role. Set to true to skip the enforcement.\", \"type\": \"boolean\"}, \"DnfStreams\": {\"default\": [], \"description\": \"List of streams to be configured before updating packages. Each list element contains a dictionary with the following values defined module[mandatory], stream[mandatory], distribution_version[mandatory] and profile[optional]. If the profile is not specified \'common\' will be used instead.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"BaseTripleoPackages\": {\"default\": [], \"description\": \"List of packages to install.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"dnf_module_list\": \"DnfStreams\", \"upgrade_leapp_devel_skip\": \"UpgradeLeappDevelSkip\", \"upgrade_leapp_command_options\": \"UpgradeLeappCommandOptions\", \"upgrade_leapp_to_remove\": \"UpgradeLeappToRemove\", \"upgrade_leapp_to_install\": \"UpgradeLeappToInstall\", \"leapp_repo_init_command\": \"LeappRepoInitCommand\", \"leapp_init_command\": \"LeappInitCommand\", \"nics_prefixes_to_keep\": \"NICsPrefixesToUdev\", \"upgrade_leapp_modules_to_unload\": \"LeappUnloadKernelDrivers\", \"upgrade_leapp_actors_to_remove\": \"LeappActorsToRemove\", \"upgrade_init_command\": \"UpgradeInitCommand\", \"base_tripleo_packages\": \"BaseTripleoPackages\", \"leapp_pre_reboot_command\": \"LeappPreRebootCommand\", \"leapp_post_reboot_command\": \"LeappPostRebootCommand\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"DnfStreams\": {\"get_param\": \"DnfStreams\"}, \"UpgradeLeappDevelSkip\": {\"get_param\": \"UpgradeLeappDevelSkip\"}, \"UpgradeLeappCommandOptions\": {\"get_param\": \"UpgradeLeappCommandOptions\"}, \"UpgradeLeappToRemove\": {\"get_param\": \"UpgradeLeappToRemove\"}, \"UpgradeLeappToInstall\": {\"get_param\": \"UpgradeLeappToInstall\"}, \"LeappUnloadKernelDrivers\": {\"get_param\": \"LeappUnloadKernelDrivers\"}, \"LeappPreRebootCommand\": {\"get_param\": \"LeappPreRebootCommand\"}, \"LeappPostRebootCommand\": {\"get_param\": \"LeappPostRebootCommand\"}, \"LeappActorsToRemove\": {\"get_param\": \"LeappActorsToRemove\"}, \"UpgradeInitCommand\": {\"get_param\": \"UpgradeInitCommand\"}, \"LeappRepoInitCommand\": {\"get_param\": \"LeappRepoInitCommand\"}, \"LeappInitCommand\": {\"get_param\": \"LeappInitCommand\"}, \"NICsPrefixesToUdev\": {\"get_param\": \"NICsPrefixesToUdev\"}, \"BaseTripleoPackages\": {\"get_param\": \"BaseTripleoPackages\"}}}]}}}, \"Podman\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"conditions\": {\"podman_requires_login\": {\"equals\": [{\"get_param\": \"ContainerImageRegistryLogin\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO package settings\", \"value\": {\"service_name\": \"tripleo_packages\", \"config_settings\": {\"tripleo::packages::enable_install\": {\"get_param\": \"EnablePackageInstall\"}}, \"step_config\": \"include ::tripleo::packages\\n\", \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": {\"get_param\": \"UpgradeLeappDebug\"}, \"upgrade_leapp_devel_skip\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_devel_skip\"]}, \"upgrade_leapp_command_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_command_options\"]}, \"upgrade_leapp_reboot_timeout\": {\"get_param\": \"UpgradeLeappRebootTimeout\"}, \"upgrade_leapp_post_reboot_delay\": {\"get_param\": \"UpgradeLeappPostRebootDelay\"}}, \"vars\": {\"_upgradeLeappEnabled\": {\"get_param\": \"UpgradeLeappEnabled\"}}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_repo_init_command\"]}]]}}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_init_command\"]}]]}}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_remove\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_install\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_modules_to_unload\"]}}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_actors_to_remove\"]}}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nics_prefixes_to_keep\"]}}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_pre_reboot_command\"]}]]}}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_post_reboot_command\"]}]]}}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", \"if [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_init_command\"]}]]}}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_param\": \"UpgradeInitCommonCommand\"}]]}}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"base_tripleo_packages\"]}}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}], {\"if\": [\"podman_requires_login\", {\"get_attr\": [\"Podman\", \"role_data\", \"workaround_upgrade_tasks\"]}, []]}]}, \"external_upgrade_tasks\": [{\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"update_tasks\": [{\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": {\"get_param\": \"SkipRhelEnforcement\"}}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(167,'2026-06-10 07:59:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service for pacemaker\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"monitoring_subscription\"]}, \"ansible_group_vars\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"ansible_group_vars\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::mysql_clustercheck\": true, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, {\"haproxy_docker\": true, \"tripleo::profile::pacemaker::haproxy_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping_init_bundle\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_certs_directory\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_keys_directory\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::haproxy_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"class tripleo::firewall(){}; define tripleo::firewall::rule( $port = undef, $dport = undef, $sport = undef, $proto = undef, $action = undef, $state = undef, $source = undef, $iniface = undef, $chain = undef, $destination = undef, $extras = undef){}\", \"[\'pcmk_bundle\', \'pcmk_resource\', \'pcmk_property\', \'pcmk_constraint\', \'pcmk_resource_default\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::pacemaker::haproxy_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"yaql\": {\"expression\": \"$.data.select($+\\\":\\\"+$+\\\":ro\\\")\", \"data\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}}}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"register\": \"puppet_host_outputs\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"if hiera(\'enable_load_balancer\', true) { class {\'::tripleo::haproxy\': use_internal_certificates => false, manage_firewall => hiera(\'tripleo::firewall::manage_firewall\', true), }}\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}]]}, \"metadata_settings\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container managed by Pacemaker\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"HAproxy tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"HAproxy HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}, []]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"haproxy temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"haproxy-bundle\", \"tripleo_ha_image_update_new_image\": \"{{haproxy_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_haproxy_image}}\"}, \"when\": [\"(pcmk_haproxy_image != \\\"\\\")\", \"(pcmk_haproxy_image != haproxy_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of haproxy container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_haproxy_image == haproxy_image_latest\", \"fail_msg\": \"haproxy image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Set HAProxy upgrade facts\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_haproxy_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}]}, {\"name\": \"Mount TLS cert if needed\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node\"], \"block\": [{\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Disable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": \"haproxy_cert_mounted.rc == 6 and haproxy_public_tls_enabled|bool\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}]}, {\"name\": \"Haproxy fetch and retag container image for pacemaker\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 2\"], \"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Wait for 10s to settle connections on new VIPs\", \"wait_for\": {\"timeout\": 10}, \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"]}, {\"name\": \"Block local INPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"# server controller-0.storage.redhat.local 172.17.3.93:8080 check fall 5 inter 2000 rise 2\\n# server controller-0.internalapi.redhat.local fd00:fd00:fd00:2000::176:9292 check fall 5 inter 2000 rise 2\\nset -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\necho \\\"insert rule $PROTOCOL filter INPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time\\\"\\ndone | xargs -i nft {} $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\"\\n\"}, {\"name\": \"Generate block for other nodes OUTPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\n echo \\\"nft insert rule $PROTOCOL \\\\$TABLE OUTPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\\\\\" \\\"\\ndone\\n\", \"register\": \"haproxy_iptables_block\"}, {\"name\": \"Block OUTPUT SYN packets to this node on other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"delegate_to\": \"{{ item }}\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | head -n 1 \\\\\\nawk \'{print $3}\' | while read BACKEND; do\\n    IP=${BACKEND%:*}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\ndone\\nTABLE=$(nft list tables | grep -q \\\"$PROTOCOL raw\\\" && echo raw || echo filter )\\necho \\\"{{ haproxy_iptables_block.stdout}}\\\" | while read i; do bash -c \\\"$i\\\"; done\\n\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\"}], \"post_update_tasks\": [{\"name\": \"HAProxy bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}, {\"name\": \"Cleanup local SYN DROP rules\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"shell\": \"nft -a list chain filter INPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule filter INPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}, {\"name\": \"Cleanup SYN DROP rules from other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"delegate_to\": \"{{ item }}\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\", \"shell\": \"nft -a list chain raw OUTPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule raw OUTPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Prepare switch of haproxy image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get haproxy image id currently used by pacemaker\", \"shell\": \"pcs resource config haproxy-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"haproxy_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for haproxy\", \"set_fact\": {\"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"haproxy_image_current\": \"{{haproxy_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current haproxy image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image_current}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\", \"pull_image\": false}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}, {\"name\": \"Create haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"touch\"}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set upgrade haproxy facts\", \"set_fact\": {\"is_haproxy_bootstrap_node\": \"{{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}}, {\"name\": \"Check for haproxy retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\"}, \"register\": \"haproxy_retag_state_file\"}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node|bool\", \"haproxy_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the haproxy cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Expose HAProxy stats socket on the host and mount TLS cert if needed\", \"block\": [{\"name\": \"Check haproxy stats socket configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-var-lib\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_stats_exposed\"}, {\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Add a bind mount for stats socket in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-var-lib source-dir=/var/lib/haproxy target-dir=/var/lib/haproxy options=rw\", \"when\": \"haproxy_stats_exposed.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": [\"haproxy_cert_mounted.rc == 6\", \"haproxy_public_tls_enabled|bool\"]}]}, {\"name\": \"Update the haproxy bundle to use the new container image name\", \"command\": \"pcs resource bundle update haproxy-bundle container image={{haproxy_image_latest}}\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"absent\"}}]}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"step|int == 3\"], \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Ensure config works for the new config\", \"shell\": \"set -o pipefail\\nawk -i inplace -v INPLACE_SUFFIX=.bak \'/  rsprep/ {print \\\"  http-response replace-header Location \\\" $3\\\" \\\"$5; next;}; {print} \' /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(168,'2026-06-10 07:59:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (169,'2026-06-10 07:59:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"CertmongerCA\": {\"type\": \"string\", \"default\": \"\", \"description\": \"CA to use for certmonger\"}, \"HAProxyCertificateDNSNames\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Override the default HAProxy Certificate DNS Names\"}, \"HAProxyCertificatePrincipal\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the default HAProxy Certificate Principal\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}, \"principal_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificatePrincipal\"}, \"\"]}}, \"dnsnames_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateDNSNames\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_public_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::service_certificate\": {\"get_param\": \"DeployedSSLCertificatePath\"}}, \"certificates_specs\": {\"haproxy-external\": {\"service_pem\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}, \"metadata_settings\": [{\"service\": \"haproxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"type\": \"vip\"}], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"certmonger_ca\": {\"get_param\": \"CertmongerCA\"}}, \"block\": [{\"name\": \"make sure certmonger is installed\", \"package\": {\"name\": \"certmonger\", \"state\": \"present\"}}, {\"name\": \"make sure certmonger service is started\", \"systemd\": {\"state\": \"started\", \"enabled\": true, \"masked\": false, \"name\": \"certmonger.service\"}}, {\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"name\": \"Extract and trust certmonger\'s local CA\", \"shell\": \"set -e\\nca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\nopenssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\nchmod 0644 ${ca_pem}\\nupdate-ca-trust extract\\ntest -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n\", \"retries\": 5, \"delay\": 1, \"register\": \"local_ca_extract_result\", \"until\": \"local_ca_extract_result.rc == 0\", \"when\": \"certmonger_ca != \'IPA\' and (ipa_realm is not defined)\"}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"haproxy-external-cert\", \"dns\": {\"if\": [\"dnsnames_override_set\", {\"get_param\": \"HAProxyCertificateDNSNames\"}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"ip\": {\"if\": [\"dnsnames_override_set\", {\"str_replace\": {\"template\": \"{{DNSNAMES|ipaddr}}\", \"params\": {\"DNSNAMES\": {\"get_param\": \"HAProxyCertificateDNSNames\"}}}}, {\"str_replace\": {\"template\": \"{{[cloud_names.cloud_name_NETWORK]|ipaddr}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"principal\": {\"if\": [\"principal_override_set\", {\"get_param\": \"HAProxyCertificatePrincipal\"}, {\"str_replace\": {\"template\": \"haproxy/{{cloud_names.cloud_name_NETWORK}}@{{idm_realm|default(\'UNDERCLOUD\')}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-external-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-external-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\n\\nca_type=CATYPE\\nif [ \\\"$ca_type\\\" = \\\"self-sign\\\" ]; then\\n  # refresh the ca cert just in case the ca cert has been renewed\\n  ca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\n  openssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\n  chmod 0644 ${ca_pem}\\n  update-ca-trust extract\\n  test -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n  openssl x509 -in ${ca_pem} -out /tmp/cm-local-ca.pem\\n  ca_path=\\\"/tmp/cm-local-ca.pem\\\"\\nelse\\n  ca_path=\\\"/etc/ipa/ca.crt\\\"\\nfi\\n\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\nservice_pem=\\\"PEMPATH\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CATYPE\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\", \"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"PEMPATH\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(170,'2026-06-10 07:59:43',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(171,'2026-06-10 07:59:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(172,'2026-06-10 07:59:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(173,'2026-06-10 07:59:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(174,'2026-06-10 07:59:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyStatsPassword\": {\"description\": \"Password for HAProxy stats endpoint\", \"hidden\": true, \"type\": \"string\", \"default\": \"kidfQULq1xgBfPvuhAsTlRfxc\"}, \"HAProxyStatsUser\": {\"description\": \"User for HAProxy stats endpoint\", \"default\": \"admin\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"13qiQT0Nynohgkp6fAkpbtLxa\"}, \"MonitoringSubscriptionHaproxy\": {\"default\": \"overcloud-haproxy\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"EnableLoadBalancer\": {\"default\": true, \"description\": \"Whether to deploy a LoadBalancer, set to false when an external load balancer is used.\", \"type\": \"boolean\"}, \"HAProxyStatsEnabled\": {\"default\": true, \"description\": \"Whether or not to enable the HAProxy stats interface.\", \"type\": \"boolean\"}, \"InternalTLSCRLPEMFile\": {\"default\": \"/etc/pki/CA/crl/overcloud-crl.pem\", \"type\": \"string\", \"description\": \"Specifies the default CRL PEM file to use for revocation if TLS is used for services in the internal network.\"}, \"InternalTLSCRLPEMDir\": {\"default\": \"/etc/pki/CA/crl/\", \"type\": \"string\", \"description\": \"The directory of the CRL PEM file to be mounted.\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyLogging\": {\"type\": \"OS::TripleO::Services::Logging::HAProxy\"}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"107 haproxy stats\": {\"dport\": 1993}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHaproxy\"}, \"ansible_group_vars\": {\"tripleo_firewall_frontend_enabled\": true, \"tripleo_firewall_ssl_frontend_enabled\": {\"if\": [\"public_tls_enabled\", true]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}, \"tripleo::haproxy::haproxy_stats_user\": {\"get_param\": \"HAProxyStatsUser\"}, \"tripleo::haproxy::haproxy_stats_password\": {\"get_param\": \"HAProxyStatsPassword\"}, \"tripleo::haproxy::haproxy_stats_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HaproxyNetwork\"]}}}}, \"tripleo::haproxy::redis_password\": {\"get_param\": \"RedisPassword\"}, \"tripleo::haproxy::crl_file\": null, \"tripleo::haproxy::haproxy_stats\": {\"get_param\": \"HAProxyStatsEnabled\"}, \"enable_load_balancer\": {\"get_param\": \"EnableLoadBalancer\"}, \"tripleo::profile::base::haproxy::certificates_specs\": {\"map_merge\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"certificates_specs\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"certificates_specs\"]}]}, \"tripleo::haproxy::service_certificate\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"DeployedSSLCertificatePath\"}]}, \"tripleo::haproxy::ca_bundle\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}, {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": \"class {\'tripleo::profile::base::haproxy\': manage_firewall => false}\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"get_param\": \"DeployedSSLCertificatePath\"}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro,shared\"]]}, {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro,shared\"]]}]]}]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true, \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"docker_config\", \"step_1\"]}, {\"haproxy\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HAProxyLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/haproxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/haproxy:/var/lib/kolla/config_files/src:ro\", \"/var/lib/haproxy:/var/lib/haproxy:rw,z\"], {\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"list_join\": [\"\", [\"/var/lib/kolla/config_files/src-tls\", {\"get_param\": \"DeployedSSLCertificatePath\"}]]}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro\"]]}]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"when\": \"step|int == 1\", \"register\": \"puppet_host_outputs\", \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"include tripleo::profile::base::haproxy\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"upgrade_tasks\": [{\"name\": \"ensure we have haproxy log dir with the correct setype\", \"file\": {\"path\": \"/var/log/containers/haproxy\", \"state\": \"directory\", \"setype\": \"var_log_t\", \"recurse\": true}, \"when\": \"step|int == 1\"}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop haproxy container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"haproxy\"], \"tripleo_delegate_to\": \"{{ groups[\'haproxy\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/haproxy\", \"setype\": \"var_log_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/haproxy\", \"setype\": \"container_file_t\"}]}]]}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"metadata_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"metadata_settings\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(175,'2026-06-10 07:59:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/heat:/var/log/heat:z\", \"/var/log/containers/httpd/heat-api:/var/log/httpd:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/heat\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/heat-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(176,'2026-06-10 07:59:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"CertmongerCA\": {\"type\": \"string\", \"default\": \"\", \"description\": \"CA to use for certmonger\"}, \"HAProxyCertificateDNSNames\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Override the default HAProxy Certificate DNS Names\"}, \"HAProxyCertificatePrincipal\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the default HAProxy Certificate Principal\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}, \"principal_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificatePrincipal\"}, \"\"]}}, \"dnsnames_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateDNSNames\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_public_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::service_certificate\": {\"get_param\": \"DeployedSSLCertificatePath\"}}, \"certificates_specs\": {\"haproxy-external\": {\"service_pem\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}, \"metadata_settings\": [{\"service\": \"haproxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"type\": \"vip\"}], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"certmonger_ca\": {\"get_param\": \"CertmongerCA\"}}, \"block\": [{\"name\": \"make sure certmonger is installed\", \"package\": {\"name\": \"certmonger\", \"state\": \"present\"}}, {\"name\": \"make sure certmonger service is started\", \"systemd\": {\"state\": \"started\", \"enabled\": true, \"masked\": false, \"name\": \"certmonger.service\"}}, {\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"name\": \"Extract and trust certmonger\'s local CA\", \"shell\": \"set -e\\nca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\nopenssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\nchmod 0644 ${ca_pem}\\nupdate-ca-trust extract\\ntest -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n\", \"retries\": 5, \"delay\": 1, \"register\": \"local_ca_extract_result\", \"until\": \"local_ca_extract_result.rc == 0\", \"when\": \"certmonger_ca != \'IPA\' and (ipa_realm is not defined)\"}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"haproxy-external-cert\", \"dns\": {\"if\": [\"dnsnames_override_set\", {\"get_param\": \"HAProxyCertificateDNSNames\"}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"ip\": {\"if\": [\"dnsnames_override_set\", {\"str_replace\": {\"template\": \"{{DNSNAMES|ipaddr}}\", \"params\": {\"DNSNAMES\": {\"get_param\": \"HAProxyCertificateDNSNames\"}}}}, {\"str_replace\": {\"template\": \"{{[cloud_names.cloud_name_NETWORK]|ipaddr}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"principal\": {\"if\": [\"principal_override_set\", {\"get_param\": \"HAProxyCertificatePrincipal\"}, {\"str_replace\": {\"template\": \"haproxy/{{cloud_names.cloud_name_NETWORK}}@{{idm_realm|default(\'UNDERCLOUD\')}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-external-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-external-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\n\\nca_type=CATYPE\\nif [ \\\"$ca_type\\\" = \\\"self-sign\\\" ]; then\\n  # refresh the ca cert just in case the ca cert has been renewed\\n  ca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\n  openssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\n  chmod 0644 ${ca_pem}\\n  update-ca-trust extract\\n  test -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n  openssl x509 -in ${ca_pem} -out /tmp/cm-local-ca.pem\\n  ca_path=\\\"/tmp/cm-local-ca.pem\\\"\\nelse\\n  ca_path=\\\"/etc/ipa/ca.crt\\\"\\nfi\\n\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\nservice_pem=\\\"PEMPATH\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CATYPE\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\", \"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"PEMPATH\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (177,'2026-06-10 07:59:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance internal service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"GlanceApiInternalLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api_internal.log\"}}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiInternalConfigImage\": {\"description\": \"The container image to use for the glance_api_internal config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"GlanceApi\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiInternalConfigImage\": \"ContainerGlanceApiInternalConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiInternalConfigImage\": {\"get_param\": \"ContainerGlanceApiInternalConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the internal Glance API.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\"]}, {\"service_name\": \"glance_api_internal\", \"firewall_rules\": {\"112 glance_api_internal\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 glance_api_internal_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"keystone_resources\": {}, \"config_settings\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_glance_api_internal\": [{\"get_param\": \"GlanceApiInternalLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"glance_api_internal\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [{\"str_replace\": {\"template\": \"class { \'tripleo::profile::base::glance::api\':\\n  bind_port => PORT,\\n  tls_proxy_port => PORT,\\n  log_file => \'/var/log/glance/api_internal.log\',\\n  show_image_direct_url => true,\\n  show_multiple_locations => true,\\n}\\n\", \"params\": {\"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiInternalConfigImage\"]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"glance_api_internal\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\", \"volumes\"]}}}}}]}, \"glance_api_internal_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\", \"volumes\"]}}}}}]}]}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api internal container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api_internal\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api_internal\'] | default([]) }}\"}}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(178,'2026-06-10 07:59:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(179,'2026-06-10 07:59:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"HAProxyNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellController\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"Compute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"internal_api\"]}}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"CephStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}, \"Networker\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"internal_api\"]}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy internal TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_internal_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::use_internal_certificates\": true}, \"certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"haproxy-NETWORK\": {\"service_pem\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/overcloud-haproxy-NETWORK.pem\"]]}}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}, \"metadata_settings\": {\"repeat\": {\"template\": [{\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"vip\"}, {\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"haproxy-NETWORK-cert\", \"dns\": [\"{{fqdn_NETWORK}}\", \"{{cloud_names.cloud_name_NETWORK}}\"], \"principal\": \"haproxy/{{fqdn_NETWORK}}@{{idm_realm}}\", \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-NETWORK-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-NETWORK-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\n\\nca_path=\\\"/etc/ipa/ca.crt\\\"\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\nservice_pem=\\\"CERTSDIR/overcloud-haproxy-NETWORK.pem\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(180,'2026-06-10 07:59:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"osNd9JfhsrCO9svVkwwbZnQ0E\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(181,'2026-06-10 07:59:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(182,'2026-06-10 07:59:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(183,'2026-06-10 07:59:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(184,'2026-06-10 07:59:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAProxy API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_1\": {}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": null}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (185,'2026-06-10 07:59:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"ApomcwoXm9jjJOvUNPSNDY3vi\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(186,'2026-06-10 07:59:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(187,'2026-06-10 07:59:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(188,'2026-06-10 07:59:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(189,'2026-06-10 07:59:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"HAProxyNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellController\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"Compute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"internal_api\"]}}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"CephStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}, \"Networker\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"internal_api\"]}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy internal TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_internal_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::use_internal_certificates\": true}, \"certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"haproxy-NETWORK\": {\"service_pem\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/overcloud-haproxy-NETWORK.pem\"]]}}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}, \"metadata_settings\": {\"repeat\": {\"template\": [{\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"vip\"}, {\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"haproxy-NETWORK-cert\", \"dns\": [\"{{fqdn_NETWORK}}\", \"{{cloud_names.cloud_name_NETWORK}}\"], \"principal\": \"haproxy/{{fqdn_NETWORK}}@{{idm_realm}}\", \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-NETWORK-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-NETWORK-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\n\\nca_path=\\\"/etc/ipa/ca.crt\\\"\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\nservice_pem=\\\"CERTSDIR/overcloud-haproxy-NETWORK.pem\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(190,'2026-06-10 07:59:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(191,'2026-06-10 07:59:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(192,'2026-06-10 07:59:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (193,'2026-06-10 07:59:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Horizon service\\n\", \"parameters\": {\"ContainerHorizonImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"ContainerHorizonConfigImage\": {\"description\": \"The container image to use for the horizon config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HorizonDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Horizon service.\", \"type\": \"boolean\"}, \"HorizonAllowedHosts\": {\"default\": \"*\", \"description\": \"A list of IP/Hostname for the server Horizon is running on. Used for header checks.\", \"type\": \"comma_delimited_list\"}, \"HorizonPasswordValidator\": {\"description\": \"Regex for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonPasswordValidatorHelp\": {\"description\": \"Help text for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonSecret\": {\"description\": \"Secret key for Django\", \"type\": \"string\", \"hidden\": true, \"default\": \"M1cr1IduHd\"}, \"HorizonSecureCookies\": {\"description\": \"Set CSRF_COOKIE_SECURE / SESSION_COOKIE_SECURE in Horizon\", \"type\": \"boolean\", \"default\": false}, \"HorizonSessionTimeout\": {\"description\": \"Set session timeout for horizon in seconds\", \"type\": \"number\", \"default\": 1800}, \"MemcachedIPv6\": {\"default\": false, \"description\": \"Enable IPv6 features in Memcached.\", \"type\": \"boolean\"}, \"MonitoringSubscriptionHorizon\": {\"default\": \"overcloud-horizon\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HorizonVhostExtraParams\": {\"default\": {\"add_listen\": true, \"priority\": 10, \"access_log_format\": \"%a %l %u %t \\\\\\\"%r\\\\\\\" %>s %b \\\\\\\"%%{}{Referer}i\\\\\\\" \\\\\\\"%%{}{User-Agent}i\\\\\\\"\", \"options\": [\"FollowSymLinks\", \"MultiViews\"]}, \"description\": \"Extra parameters for Horizon vhost configuration\", \"type\": \"json\"}, \"HorizonCustomizationModule\": {\"default\": \"\", \"description\": \"Horizon has a global overrides mechanism available to perform customizations\", \"type\": \"string\"}, \"HorizonHelpURL\": {\"default\": \"http://docs.openstack.org\", \"description\": \"On top of dashboard there is a Help button. This button could be used to re-direct user to vendor documentation or dedicated help portal.\", \"type\": \"string\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}, \"WebSSOEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable support for Web Single Sign-On\"}, \"WebSSOInitialChoice\": {\"default\": \"OIDC\", \"type\": \"string\", \"description\": \"The initial authentication choice to select by default\"}, \"WebSSOChoicesHideKeystone\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Hide Keystone crednetials login when WebSSO is enabled.\"}, \"WebSSOChoices\": {\"default\": [[\"OIDC\", \"OpenID Connect\"]], \"type\": \"json\", \"description\": \"Specifies the list of SSO authentication choices to present. Each item is a list of an SSO choice identifier and a display message.\"}, \"WebSSOIDPMapping\": {\"default\": {\"OIDC\": [\"myidp\", \"openid\"]}, \"type\": \"json\", \"description\": \"Specifies a mapping from SSO authentication choice to identity provider and protocol.  The identity provider and protocol names must match the resources defined in keystone.\"}, \"HorizonDomainChoices\": {\"default\": [], \"type\": \"json\", \"description\": \"Specifies available domains to choose from. We expect an array of hashes, and the hashes should have two items each (name, display) containing Keystone domain name and a human-readable description of the domain respectively.\"}, \"HorizonLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.horizon\", \"file\": \"/var/log/containers/horizon/horizon.log\"}}, \"HorizonHstsHeaderValue\": {\"default\": [], \"description\": \"Enables HTTP Strict-Transport-Security header in response.\", \"type\": \"comma_delimited_list\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MemcachedIPv6\"]}], \"conditions\": {\"horizon_domain_choices_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonDomainChoices\"}, []]}}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}]}, 6]}, \"horizon_logger_debug\": {\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"HorizonDebug\"}]}, \"horizon_hsts_header_value_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonHstsHeaderValue\"}, []]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHorizonImage\": \"ContainerHorizonImage\", \"ContainerHorizonConfigImage\": \"ContainerHorizonConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHorizonImage\": {\"get_param\": \"ContainerHorizonImage\"}, \"ContainerHorizonConfigImage\": {\"get_param\": \"ContainerHorizonConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Horizon API role.\", \"value\": {\"service_name\": \"horizon\", \"firewall_rules\": {\"126 horizon\": {\"dport\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, 443, 80]}]}}, \"firewall_frontend_rules\": {\"100 horizon_haproxy_frontend\": {\"dport\": [80]}}, \"firewall_ssl_frontend_rules\": {\"100 horizon_haproxy_frontend_ssl\": {\"dport\": [443]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHorizon\"}, \"config_settings\": {\"map_merge\": [{\"horizon::allowed_hosts\": {\"get_param\": \"HorizonAllowedHosts\"}, \"horizon::enable_secure_proxy_ssl_header\": true, \"horizon::secure_proxy_addr_header\": \"HTTP_X_FORWARDED_FOR\", \"horizon::disable_password_reveal\": true, \"horizon::enforce_password_check\": true, \"horizon::disallow_iframe_embed\": true, \"horizon::cache_backend\": \"django.core.cache.backends.memcached.MemcachedCache\", \"horizon::django_session_engine\": \"django.contrib.sessions.backends.cache\", \"horizon::vhost_extra_params\": {\"get_param\": \"HorizonVhostExtraParams\"}, \"horizon::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Public\", \"uri\"]}, \"horizon::password_validator\": {\"get_param\": [\"HorizonPasswordValidator\"]}, \"horizon::password_validator_help\": {\"get_param\": [\"HorizonPasswordValidatorHelp\"]}, \"horizon::secret_key\": {\"get_param\": \"HorizonSecret\"}, \"horizon::secure_cookies\": {\"get_param\": [\"HorizonSecureCookies\"]}, \"horizon::session_timeout\": {\"get_param\": \"HorizonSessionTimeout\"}, \"memcached_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"horizon::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::listen_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"horizon::customization_module\": {\"get_param\": \"HorizonCustomizationModule\"}, \"horizon::timezone\": {\"get_param\": \"TimeZone\"}, \"horizon::file_upload_temp_dir\": \"/var/tmp\", \"horizon::help_url\": {\"get_param\": \"HorizonHelpURL\"}, \"horizon::enable_user_pass\": \"UNSET\"}, {\"if\": [{\"get_param\": \"WebSSOEnable\"}, {\"horizon::websso_enabled\": {\"get_param\": \"WebSSOEnable\"}, \"horizon::websso_initial_choice\": {\"get_param\": \"WebSSOInitialChoice\"}, \"horizon::websso_choices\": {\"get_param\": \"WebSSOChoices\"}, \"horizon::websso_idp_mapping\": {\"get_param\": \"WebSSOIDPMapping\"}, \"horizon::websso_choices_hide_keystone\": {\"get_param\": \"WebSSOChoicesHideKeystone\"}}]}, {\"if\": [{\"get_param\": \"HorizonDebug\"}, {\"horizon::django_debug\": true}, {\"horizon::django_debug\": {\"get_param\": \"Debug\"}}]}, {\"if\": [\"horizon_logger_debug\", {\"horizon::log_level\": \"DEBUG\"}]}, {\"if\": [\"horizon_domain_choices_set\", {\"horizon::keystone_domain_choices\": {\"get_param\": \"HorizonDomainChoices\"}}]}]}, \"ansible_group_vars\": {\"keystone_enable_member\": true}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_horizon\": {\"yaql\": {\"expression\": \"$.data.sources.flatten()\", \"data\": {\"sources\": [{\"get_param\": \"HorizonLoggingSource\"}]}}}}, \"haproxy\": {\"if\": [\"horizon_hsts_header_value_set\", {\"tripleo::profile::base::horizon::hsts_header_value\": {\"get_param\": \"HorizonHstsHeaderValue\"}}]}}, \"puppet_config\": {\"config_volume\": \"horizon\", \"puppet_tags\": \"horizon_config\", \"step_config\": \"include tripleo::profile::base::horizon\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/horizon.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/horizon/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/etc/openstack-dashboard/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/\", \"owner\": \"apache:apache\", \"recurse\": false}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/local_settings.d/\", \"owner\": \"apache:apache\", \"recurse\": false}]}}, \"docker_config\": {\"step_2\": {\"horizon_fix_perms\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"touch /var/log/horizon/horizon.log ; chown -R apache:apache /var/log/horizon && chmod -R a+rx /etc/openstack-dashboard\"], \"volumes\": [\"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/lib/config-data/puppet-generated/horizon/etc/openstack-dashboard:/etc/openstack-dashboard\"]}}, \"step_3\": {\"horizon\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/horizon.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/horizon:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/tmp/horizon:/var/tmp:z\", \"/var/www:/var/www:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"ENABLE_DESIGNATE\": \"yes\", \"ENABLE_HEAT\": \"yes\", \"ENABLE_IRONIC\": \"yes\", \"ENABLE_MANILA\": \"yes\", \"ENABLE_OCTAVIA\": \"yes\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/www\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/tmp/horizon\", \"setype\": \"container_file_t\", \"mode\": \"01777\"}]}, {\"name\": \"ensure /var/tmp/horizon exists on boot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/var-tmp-horizon.conf\", \"content\": \"d /var/tmp/horizon 01777 root root - -\\n\"}}], \"upgrade_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"update_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop horizon container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"horizon\"], \"tripleo_delegate_to\": \"{{ groups[\'horizon\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(194,'2026-06-10 07:59:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(195,'2026-06-10 07:59:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a Compute server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[{\\\"service_name\\\": \\\"boot_params_service\\\", \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Configure tuned before reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}, \\\"vars\\\": {\\\"tuned_profile\\\": \\\"throughput-performance\\\", \\\"tuned_isolated_cores\\\": \\\"\\\"}}, {\\\"name\\\": \\\"Configure kernel args and reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"kernelargs.yml\\\"}, \\\"vars\\\": {\\\"tripleo_kernel_args\\\": \\\"\\\", \\\"tripleo_kernel_hugepages\\\": {}, \\\"tripleo_kernel_hugepages_remove\\\": false, \\\"tripleo_kernel_defer_reboot\\\": false, \\\"tripleo_kernel_reboot_timeout\\\": 900}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"upgrade prepare for leapp to align kernel arg shortcommings in leapp\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"fix grub entries to have name start with GRUB_\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\\\", \\\"replace\\\": \\\"GRUB_\\\\\\\\1\\\\\\\\2\\\"}}, {\\\"name\\\": \\\"fix grub entries in append statement\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\\\", \\\"replace\\\": \\\"\\\\\\\\1{GRUB_\\\\\\\\2}\\\\\\\\3\\\"}}]}]}, {\\\"service_name\\\": \\\"ca_certs\\\", \\\"config_settings\\\": {\\\"tripleo::trusted_cas::ca_map\\\": {}}, \\\"step_config\\\": \\\"include tripleo::trusted_cas\\\"}, {\\\"service_name\\\": \\\"collectd\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::metrics::collectd::enable_file_logging\\\": true, \\\"collectd::plugin::logfile::log_file\\\": \\\"/var/log/collectd/collectd.log\\\", \\\"collectd::manage_repo\\\": false, \\\"collectd::purge\\\": true, \\\"collectd::recurse\\\": true, \\\"collectd::purge_config\\\": true, \\\"collectd::minimum_version\\\": \\\"5.7\\\", \\\"collectd::interval\\\": 120, \\\"collectd::plugin::unixsock::socketgroup\\\": \\\"root\\\", \\\"collectd::plugin::unixsock::socketfile\\\": \\\"/run/collectd-socket\\\", \\\"collectd::plugin::unixsock::deletesocket\\\": true, \\\"collectd::plugin::cpu::reportbycpu\\\": true, \\\"collectd::plugin::cpu::reportbystate\\\": true, \\\"collectd::plugin::cpu::reportnumcpu\\\": false, \\\"collectd::plugin::cpu::valuespercentage\\\": true, \\\"collectd::plugin::df::ignoreselected\\\": true, \\\"collectd::plugin::df::reportbydevice\\\": true, \\\"collectd::plugin::df::fstypes\\\": [\\\"xfs\\\"], \\\"collectd::plugin::load::reportrelative\\\": true, \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\", \\\"collectd::plugin::virt::extra_stats\\\": \\\"pcpu cpu_util vcpu memory disk disk_err disk_allocation disk_capacity disk_physical domain_state job_stats_background perf\\\", \\\"collectd::plugin::virt::hostname_format\\\": \\\"hostname\\\", \\\"tripleo.collectd.plugins.collectd\\\": [\\\"cpu\\\", \\\"df\\\", \\\"disk\\\", \\\"hugepages\\\", \\\"interface\\\", \\\"load\\\", \\\"memory\\\", \\\"unixsock\\\", \\\"uptime\\\"], \\\"tripleo::profile::base::metrics::collectd::amqp_transport_name\\\": \\\"metrics\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_address\\\": \\\"collectd\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_instances\\\": {}, \\\"tripleo::profile::base::metrics::collectd::amqp_retry_delay\\\": 1, \\\"tripleo::profile::base::metrics::collectd::amqp_host\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_port\\\": 5666, \\\"tripleo::profile::base::metrics::collectd::amqp_user\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_password\\\": \\\"guest\\\"}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_collectd\\\": [{\\\"tag\\\": \\\"collectd\\\", \\\"file\\\": \\\"/var/log/containers/collectd/collectd.log\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"collectd\\\", \\\"puppet_tags\\\": \\\"collectd_client_config,exec\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::collectd\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/collectd.json\\\": {\\\"command\\\": \\\"/usr/sbin/collectd -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/collectd.d\\\", \\\"dest\\\": \\\"/etc/\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/collectd\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/config-scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"collectd_check_health.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2022 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n\\\\nimport json\\\\nimport os\\\\nimport re\\\\nimport shutil\\\\nimport subprocess\\\\nimport sys\\\\n\\\\nfrom pkg_resources import packaging\\\\n\\\\n\\\\nSOCKET = \\\\\\\"unix:/run/podman/podman.sock\\\\\\\"\\\\nPS_FORMAT = (\'{\\\\\\\"service\\\\\\\": \\\\\\\"{{.Names}}\\\\\\\", \\\\\\\"container\\\\\\\": \\\\\\\"{{.ID}}\\\\\\\", \'\\\\n             \'\\\\\\\"status\\\\\\\": \\\\\\\"{{.State}}\\\\\\\", \\\\\\\"healthy\\\\\\\": \\\\\\\"{{.Status}}\\\\\\\"},\')\\\\nBASE_FORMAT = \\\\\\\"{service: .Name, container: .Id, status: .State.Running, \\\\\\\"\\\\nRUNNING_REX = re.compile(r\\\\\\\"Up .*(?P<health>\\\\\\\\(u?n?healthy\\\\\\\\))\\\\\\\")\\\\nSKIP_LIST = [\'.*_bootstrap\', \'container-puppet-.*\', \'.*_db_sync\',\\\\n             \'.*_cron\', \'create_.*_wrapper\', \'.*_wait_bundle\',\\\\n             \'configure_.*\', \'.*_fix_perms\', \'.*_init_logs?\',\\\\n             \'.*_init_perm\', \'(nova|placement)_wait_for_.*\', \'nova_.*ensure_\',\\\\n             \'(swift_)?setup_.*\', \'mysql_data_ownership\', \'swift_copy_rings\',\\\\n             \'nova_statedir_owner\']\\\\n\\\\n\\\\nclass ExecuteError(Exception):\\\\n    def __init__(self, rc, msg):\\\\n        self.rc = rc\\\\n        self.msg = msg\\\\n        super().__init__()\\\\n\\\\n\\\\ndef execute(cmd, workdir: str = None,\\\\n            prev_proc: subprocess.Popen = None) -> subprocess.Popen:\\\\n    # Note(mmagr): When this script is executed by collectd-sensubility started\\\\n    #              via collectd the script has non-root permission but inherits\\\\n    #              environment from collectd with root permission. We need\\\\n    #              to avoid sensubility access /root when using podman-remote.\\\\n    #              See https://bugzilla.redhat.com/show_bug.cgi?id=2091076 for\\\\n    #              more info.\\\\n    proc_env = os.environ.copy()\\\\n    proc_env[\\\\\\\"HOME\\\\\\\"] = \\\\\\\"/tmp\\\\\\\"\\\\n    if type(cmd[0]) is list:  # multiple piped commands\\\\n        last = prev_proc\\\\n        for c in cmd:\\\\n            last = execute(c, workdir, last)\\\\n        return last\\\\n    else:  # single command\\\\n        inpipe = prev_proc.stdout if prev_proc is not None else None\\\\n        proc = subprocess.Popen(cmd, cwd=workdir, env=proc_env, stdin=inpipe,\\\\n                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)\\\\n        if prev_proc is not None:\\\\n            prev_proc.stdout.close()\\\\n            prev_proc.stderr.close()\\\\n        return proc\\\\n\\\\n\\\\ndef get_health_from_status(status):\\\\n    healthy = status in (\'healthy\', \'running\')\\\\n    return int(healthy)\\\\n\\\\n\\\\ndef fetch_state_from_inspect(cont, fmt):\\\\n    proc = execute([\\\\n        [shutil.which(\'podman-remote\'),\\\\n           \'--url\', SOCKET, \'inspect\', cont[\\\\\\\"container\\\\\\\"]],\\\\n        [shutil.which(\'jq\'), \'.[] | %s\' % fmt]\\\\n    ])\\\\n    o, e = proc.communicate()\\\\n    if proc.returncode != 0:\\\\n        msg = \\\\\\\"Failed to fetch status of %s: %s\\\\\\\" % (cont, e.decode())\\\\n        raise ExecuteError(proc.returncode, msg)\\\\n\\\\n    item = json.loads(o.decode())\\\\n    item[\'status\'] = \'running\' if item[\'status\'] else \'stopped\'\\\\n    if len(item[\'healthy\']) > 0 and item[\'status\'] != \'stopped\':\\\\n        item[\'status\'] = item[\'healthy\']\\\\n\\\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\\\n    return item\\\\n\\\\n\\\\ndef fetch_state(item):\\\\n    if \'up \' in item[\'status\'].lower():\\\\n        item[\'status\'] = \'running\'\\\\n    if item[\'status\'] != \'running\':\\\\n        item[\'status\'] = \'stopped\'\\\\n\\\\n    match = RUNNING_REX.match(item[\'healthy\'])\\\\n    if match:\\\\n        health = match.group(\'health\')\\\\n    else:\\\\n        health = \'\'\\\\n    if health:\\\\n        item[\'status\'] = health.strip(\\\\\\\"()\\\\\\\")\\\\n\\\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\\\n    return item\\\\n\\\\n\\\\ndef fetch_container_health(ps_result, inspect_fmt):\\\\n\\\\n    def container_filter(item):\\\\n        for rx in [re.compile(i) for i in SKIP_LIST]:\\\\n            if rx.match(item[\\\\\\\"service\\\\\\\"]):\\\\n                return False\\\\n        return True\\\\n    try:\\\\n        containers = filter(container_filter, json.loads(ps_result))\\\\n    except json.decoder.JSONDecodeError:\\\\n        return 1, \\\\\\\"%s\\\\\\\\nFailed to parse above output.\\\\\\\" % ps_result\\\\n\\\\n    out = []\\\\n    for cont in containers:\\\\n        try:\\\\n            out.append(fetch_state(cont))\\\\n        except Exception:\\\\n            # fallback to slow inspect way in case of any error\\\\n            try:\\\\n                out.append(fetch_state_from_inspect(cont, inspect_fmt))\\\\n            except ExecuteError as ex:\\\\n                return ex.rc, ex.msg\\\\n    return 0, out\\\\n\\\\n\\\\nif __name__ == \\\\\\\"__main__\\\\\\\":\\\\n    proc = execute([shutil.which(\'podman-remote\'),\\\\n                    \'--url\', SOCKET, \'version\',\\\\n                    \'--format\', r\'{{.Server.Version}}\'])\\\\n    o, e = proc.communicate()\\\\n    try:\\\\n        if packaging.version.parse(o.decode().strip()) >= packaging.version.parse(\\\\\\\"4.0.0\\\\\\\"):\\\\n            inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Health.Status}\\\\\\\"\\\\n        else:\\\\n            inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Healthcheck.Status}\\\\\\\"\\\\n    except Exception:\\\\n        # keep podman-4.0.0+ format in case of version decoding error\\\\n        inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Health.Status}\\\\\\\"\\\\n\\\\n    proc = execute([shutil.which(\'podman-remote\'), \'--url\', SOCKET,\\\\n                    \'ps\', \'--all\', \'--format\', PS_FORMAT])\\\\n    o, e = proc.communicate()\\\\n    if proc.returncode != 0:\\\\n        print(\\\\\\\"Failed to list containers:\\\\\\\\n%s\\\\\\\\n%s\\\\\\\" % (o.decode(), e.decode()))\\\\n        sys.exit(1)\\\\n\\\\n    rc, status = fetch_container_health(\\\\\\\"[%s]\\\\\\\" % o.decode().strip(\\\\\\\"\\\\\\\\n,\\\\\\\"), inspect_fmt)\\\\n    if rc != 0:\\\\n        print(\\\\\\\"Failed to inspect containers:\\\\\\\\n%s\\\\\\\" % status)\\\\n        sys.exit(rc)\\\\n    print(json.dumps(status))\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"collectd\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"memory\\\": \\\"512m\\\", \\\"cap_add\\\": [\\\"IPC_LOCK\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\\\", \\\"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/collectd:/var/log/collectd:rw,z\\\", \\\"/var/lib/container-config-scripts:/config-scripts:ro\\\", \\\"/var/lib/container-user-scripts:/scripts:z\\\", \\\"/run:/run:rw\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/collectd\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/container-user-scripts/\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}]}, {\\\"name\\\": \\\"import provision_mcelog\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_provision_mcelog\\\"}, \\\"when\\\": false}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"set enable_sensubility fact\\\", \\\"set_fact\\\": {\\\"enable_sensubility\\\": false}}, {\\\"name\\\": \\\"create podman socket for sensubility purposes\\\", \\\"block\\\": [{\\\"name\\\": \\\"create podman socket and appropriate systemd service\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_service\\\"}, \\\"vars\\\": {\\\"tripleo_podman_socket_path\\\": \\\"/var/lib/tripleo-podman/collectd/podman.sock\\\"}}, {\\\"name\\\": \\\"create systemd service for ensuring socket file ACL contains collectd\\\", \\\"become\\\": true, \\\"ansible.builtin.copy\\\": {\\\"content\\\": \\\"[Unit]\\\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\\\nRequires=tripleo_collectd.service\\\\nAfter=tripleo_podman.service\\\\nAfter=tripleo_collectd.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\", \\\"dest\\\": \\\"/etc/systemd/system/tripleo_podman_collectd_acl.service\\\", \\\"mode\\\": 420}}, {\\\"name\\\": \\\"enable podman.sock ACL service\\\", \\\"ansible.builtin.service\\\": {\\\"name\\\": \\\"tripleo_podman_collectd_acl.service\\\", \\\"enabled\\\": true}}, {\\\"name\\\": \\\"create directory for downloads of users\' scripts\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/container-user-scripts\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"download exec scripts\\\", \\\"ansible.builtin.get_url\\\": {\\\"url\\\": \\\"{{ item.source }}\\\", \\\"checksum\\\": \\\"{{ item.checksum }}\\\", \\\"dest\\\": \\\"/var/lib/container-user-scripts/{{ item.name }}\\\", \\\"mode\\\": \\\"0755\\\"}, \\\"with_items\\\": []}], \\\"when\\\": [\\\"enable_sensubility|bool\\\", \\\"step|int == 1\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}, {\\\"name\\\": \\\"Force pull image collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 3\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"UBI8 to UBI9 switch of collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update collectd to UBI9\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_3\\\", \\\"config_patterns\\\": \\\"collectd.json\\\", \\\"config_id\\\": [\\\"tripleo_step3\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\"collectd\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\"}}}}]}]}, {\\\"service_name\\\": \\\"ceilometer_agent_compute\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ceilometer-agent-compute\\\", \\\"config_settings\\\": {\\\"ceilometer::logging::debug\\\": true, \\\"ceilometer::agent::polling::manage_polling\\\": false, \\\"ceilometer::agent::service_credentials::password\\\": \\\"S7StMMDKvgk7UEFIb9ggBAhnr\\\", \\\"ceilometer::agent::service_credentials::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"ceilometer::agent::service_credentials::region_name\\\": \\\"regionOne\\\", \\\"ceilometer::agent::service_credentials::project_name\\\": \\\"service\\\", \\\"ceilometer::agent::service_credentials::user_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::auth_project_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::interface\\\": \\\"internalURL\\\", \\\"ceilometer::notification_driver\\\": [\\\"noop\\\"], \\\"ceilometer::amqp_rpc_address_prefix\\\": \\\"\\\", \\\"ceilometer::amqp_notify_address_prefix\\\": \\\"\\\", \\\"ceilometer::telemetry_secret\\\": \\\"EN0BRljM39cmljy9d0IOJQNAu\\\", \\\"ceilometer::snmpd_readonly_username\\\": \\\"ro_snmp_user\\\", \\\"ceilometer::snmpd_readonly_user_password\\\": \\\"Gw7UKk275edaf1BK4QNxasIq\\\", \\\"ceilometer::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ceilometer::rabbit_heartbeat_in_pthread\\\": false, \\\"ceilometer::cache::enabled\\\": true, \\\"ceilometer::cache::tls_enabled\\\": true, \\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"ceilometer::cache::enable_socket_keepalive\\\": true, \\\"ceilometer::agent::polling::instance_discovery_method\\\": \\\"libvirt_metadata\\\", \\\"ceilometer_redis_password\\\": \\\"13qiQT0Nynohgkp6fAkpbtLxa\\\", \\\"compute_namespace\\\": true, \\\"ceilometer::agent::polling::tenant_name_discovery\\\": false}, \\\"service_config_settings\\\": {\\\"keystone\\\": {\\\"tripleo::profile::base::keystone::ceilometer_notification_topics\\\": [\\\"notifications\\\"]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"ceilometer_agent_compute\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_libvirt.target\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]}, {\\\"service_name\\\": \\\"ceilometer_agent_ipmi\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ceilometer-agent-ipmi\\\", \\\"config_settings\\\": {\\\"ceilometer::logging::debug\\\": true, \\\"ceilometer::agent::polling::manage_polling\\\": false, \\\"ceilometer::agent::service_credentials::password\\\": \\\"S7StMMDKvgk7UEFIb9ggBAhnr\\\", \\\"ceilometer::agent::service_credentials::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"ceilometer::agent::service_credentials::region_name\\\": \\\"regionOne\\\", \\\"ceilometer::agent::service_credentials::project_name\\\": \\\"service\\\", \\\"ceilometer::agent::service_credentials::user_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::auth_project_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::interface\\\": \\\"internalURL\\\", \\\"ceilometer::notification_driver\\\": [\\\"noop\\\"], \\\"ceilometer::amqp_rpc_address_prefix\\\": \\\"\\\", \\\"ceilometer::amqp_notify_address_prefix\\\": \\\"\\\", \\\"ceilometer::telemetry_secret\\\": \\\"EN0BRljM39cmljy9d0IOJQNAu\\\", \\\"ceilometer::snmpd_readonly_username\\\": \\\"ro_snmp_user\\\", \\\"ceilometer::snmpd_readonly_user_password\\\": \\\"Gw7UKk275edaf1BK4QNxasIq\\\", \\\"ceilometer::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ceilometer::rabbit_heartbeat_in_pthread\\\": false, \\\"ceilometer::cache::enabled\\\": true, \\\"ceilometer::cache::tls_enabled\\\": true, \\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"ceilometer::cache::enable_socket_keepalive\\\": true, \\\"ceilometer_redis_password\\\": \\\"13qiQT0Nynohgkp6fAkpbtLxa\\\", \\\"ipmi_namespace\\\": true}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_ceilometer_agent_ipmi\\\": [{\\\"tag\\\": \\\"openstack.ceilometer.agent.ipmi\\\", \\\"file\\\": \\\"/var/log/containers/ceilometer/ipmi.log\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"ceilometer_init_log\\\": {\\\"start_order\\\": 0, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R ceilometer:ceilometer /var/log/ceilometer\\\"], \\\"volumes\\\": [\\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]}}, \\\"step_4\\\": {\\\"ceilometer_agent_ipmi\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}, {\\\"service_name\\\": \\\"ipaservice\\\", \\\"upgrade_tasks\\\": [], \\\"step_config\\\": \\\"\\\", \\\"ipa_registration_tasks\\\": [{\\\"name\\\": \\\"Get undercloud FQDN\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"set_fact\\\": {\\\"undercloud_fqdn\\\": \\\"{{ ansible_facts[\'fqdn\'] }}\\\"}}, {\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ipa_registration\\\", \\\"apply\\\": {\\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"environment\\\": {\\\"IPA_USER\\\": \\\"nova/{{ undercloud_fqdn }}\\\", \\\"KRB5_CLIENT_KTNAME\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"KRB5CCNAME\\\": \\\"/etc/novajoin/krb5.cache\\\", \\\"IPA_HOST\\\": \\\"ipa.ooo.test\\\"}}}, \\\"vars\\\": {\\\"tripleo_ipa_enroll_base_server\\\": true, \\\"tripleo_ipa_delegate_server\\\": \\\"{{ inventory_hostname }}\\\", \\\"tripleo_ipa_base_server_fqdn\\\": \\\"{{ fqdn_canonical }}\\\", \\\"tripleo_ipa_server_metadata\\\": \\\"{{ service_metadata_settings | to_json }}\\\"}, \\\"when\\\": \\\"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\\\"}, {\\\"name\\\": \\\"Enroll the node as an ipa client\\\", \\\"vars\\\": {\\\"ipaclient_install_packages\\\": false, \\\"idm_enroll_base_server\\\": true}, \\\"block\\\": [{\\\"name\\\": \\\"check if default.conf exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/ipa/default.conf\\\"}, \\\"register\\\": \\\"ipa_conf_exists\\\"}, {\\\"name\\\": \\\"install openssl-perl\\\", \\\"become\\\": true, \\\"package\\\": {\\\"name\\\": \\\"openssl-perl\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ipaclient_install_packages|bool\\\"]}, {\\\"name\\\": \\\"register as an ipa client\\\", \\\"include_role\\\": {\\\"name\\\": \\\"ipaclient\\\", \\\"apply\\\": {\\\"become\\\": true}}, \\\"vars\\\": {\\\"state\\\": \\\"present\\\", \\\"ipaclient_otp\\\": \\\"{{ ipa_host_otp }}\\\", \\\"ipaclient_mkhomedir\\\": false, \\\"ipaclient_no_ntp\\\": false, \\\"ipaclient_force\\\": true, \\\"ipaclient_hostname\\\": \\\"{{ fqdn_canonical }}\\\", \\\"ansible_fqdn\\\": \\\"{{ ipaclient_hostname }}\\\", \\\"ipaclients\\\": [\\\"ipaclient_hostname\\\"], \\\"ansible_distribution\\\": \\\"{{ ansible_facts[\'distribution\'] }}\\\", \\\"ansible_distribution_major_version\\\": \\\"{{ ansible_facts[\'distribution_major_version\'] }}\\\", \\\"ansible_distribution_release\\\": \\\"{{ ansible_facts[\'distribution_release\'] }}\\\", \\\"ansible_distribution_version\\\": \\\"{{ ansible_facts[\'distribution_version\'] }}\\\", \\\"ansible_os_family\\\": \\\"{{ ansible_facts[\'os_family\'] }}\\\", \\\"ipaclient_servers\\\": [\\\"ipa.ooo.test\\\"], \\\"ipaclient_domain\\\": \\\"ooo.test\\\"}, \\\"when\\\": [\\\"idm_enroll_base_server|bool\\\", \\\"not ipa_conf_exists.stat.exists\\\"]}, {\\\"name\\\": \\\"restart certmonger service\\\", \\\"become\\\": true, \\\"systemd\\\": {\\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true, \\\"name\\\": \\\"certmonger.service\\\"}, \\\"when\\\": [\\\"idm_enroll_base_server|bool\\\", \\\"not ipa_conf_exists.stat.exists\\\"]}, {\\\"name\\\": \\\"set discovered ipa realm\\\", \\\"set_fact\\\": {\\\"idm_realm\\\": \\\"{{ lookup(\'ini\', \'realm default=OOO.TEST section=global file=/etc/ipa/default.conf\')}}\\\"}}], \\\"when\\\": \\\"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\\\"}], \\\"external_deploy_tasks\\\": [{\\\"name\\\": \\\"add the DNS entries into IPA in step 1\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ipa_dns\\\"}, \\\"vars\\\": {\\\"tripleo_ipa_ptr_zone_split_ipv4\\\": \\\"1\\\", \\\"tripleo_ipa_ptr_zone_split_ipv6\\\": \\\"1\\\"}, \\\"when\\\": true}], \\\"environment\\\": {\\\"IPA_USER\\\": \\\"nova/{{ ansible_facts[\'fqdn\'] }}\\\", \\\"KRB5_CLIENT_KTNAME\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"KRB5CCNAME\\\": \\\"/etc/novajoin/krb5.cache\\\", \\\"IPA_HOST\\\": \\\"ipa.ooo.test\\\"}}], \\\"scale_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"down\\\", \\\"block\\\": [{\\\"name\\\": \\\"unregister node from ipa server\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ipa_cleanup\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"vars\\\": {\\\"tripleo_ipa_keytab\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"tripleo_ipa_hosts_to_delete\\\": [\\\"{{ fqdn_canonical }}\\\"]}}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"check if ipa server has required permissions\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tls_everywhere\\\", \\\"tasks_from\\\": \\\"ipa-server-check\\\"}, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-tls-everywhere\\\"]}]}]}, {\\\"service_name\\\": \\\"iscsid\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::iscsid::chap_algs\\\": \\\"SHA3-256,SHA256,SHA1,MD5\\\"}, \\\"service_config_settings\\\": {}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Run lvmfilter role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_lvmfilter\\\"}, \\\"when\\\": [\\\"step|int == 1\\\"]}], \\\"ansible_group_vars\\\": {\\\"tripleo_tripleo_lvmfilter_enabled\\\": false, \\\"tripleo_tripleo_lvmfilter_devices_allowlist\\\": [], \\\"tripleo_tripleo_lvmfilter_devices_denylist\\\": [\\\".*\\\"], \\\"ContainerIscsidImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"ContainerIscsidConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"iscsid\\\", \\\"puppet_tags\\\": \\\"iscsid_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::iscsid\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"volumes\\\": [\\\"/etc/iscsi:/tmp/iscsi.host:z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/iscsid.json\\\": {\\\"command\\\": \\\"/usr/sbin/iscsid -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"iscsid\\\": {\\\"start_order\\\": 2, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys:/sys\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/etc/target:/etc/target:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext entry for iscsi\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"{{ item.path }}(/.*)?\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"stat /lib/systemd/system/iscsid.socket\\\", \\\"stat\\\": \\\"path=/lib/systemd/system/iscsid.socket\\\", \\\"register\\\": \\\"stat_iscsid_socket\\\"}, {\\\"name\\\": \\\"Stop and disable iscsid.socket service\\\", \\\"service\\\": \\\"name=iscsid.socket state=stopped enabled=no\\\", \\\"when\\\": \\\"stat_iscsid_socket.stat.exists\\\"}, {\\\"name\\\": \\\"Check if iscsi.service is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet iscsi.service\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"iscsi_service_enabled_result\\\"}, {\\\"name\\\": \\\"Stop iscsi.service\\\", \\\"service\\\": \\\"name=iscsi.service state=stopped enabled=no\\\", \\\"when\\\": [\\\"iscsi_service_enabled_result is changed\\\", \\\"iscsi_service_enabled_result.rc == 0\\\"]}], \\\"upgrade_tasks\\\": []}, {\\\"service_name\\\": \\\"kernel\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\"}}], \\\"ansible_group_vars\\\": {\\\"hieradata_localhost_address\\\": \\\"localhost\\\", \\\"tripleo_kernel_extra_modules\\\": {}, \\\"tripleo_kernel_extra_packages\\\": {}, \\\"tripleo_kernel_sysctl_extra_settings\\\": {\\\"net.ipv6.conf.default.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_local_reserved_ports\\\": {\\\"value\\\": \\\"35357,49000-49001\\\"}, \\\"net.ipv6.conf.all.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv6.conf.lo.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_forward\\\": {\\\"value\\\": 1}, \\\"net.ipv4.conf.all.rp_filter\\\": {\\\"value\\\": 1}, \\\"net.ipv6.conf.all.forwarding\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_nonlocal_bind\\\": {\\\"value\\\": 1}, \\\"net.ipv6.ip_nonlocal_bind\\\": {\\\"value\\\": 1}, \\\"kernel.pid_max\\\": {\\\"value\\\": 1048576}, \\\"net.ipv4.neigh.default.gc_thresh1\\\": {\\\"value\\\": 1024}, \\\"net.ipv4.neigh.default.gc_thresh2\\\": {\\\"value\\\": 2048}, \\\"net.ipv4.neigh.default.gc_thresh3\\\": {\\\"value\\\": 4096}, \\\"net.bridge.bridge-nf-call-arptables\\\": {\\\"value\\\": 1}, \\\"net.bridge.bridge-nf-call-iptables\\\": {\\\"value\\\": 1}, \\\"net.bridge.bridge-nf-call-ip6tables\\\": {\\\"value\\\": 1}, \\\"fs.inotify.max_user_instances\\\": {\\\"value\\\": 1024}, \\\"fs.aio-max-nr\\\": {\\\"value\\\": 1048576}}}}, {\\\"service_name\\\": \\\"metrics_qdr\\\", \\\"firewall_rules\\\": {\\\"109 metrics qdr\\\": {\\\"dport\\\": [5666]}, \\\"109 accept internal metrics qdr ctlplane subnet 192.168.122.0/24\\\": {\\\"dport\\\": [5667, 5668]}}, \\\"monitoring_subscription\\\": \\\"overcloud-qdr\\\", \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_metrics_qdr\\\": [{\\\"tag\\\": \\\"openstack.nova.consoleauth\\\", \\\"file\\\": \\\"/var/log/containers/metrics_qdr/metrics_qdr.log\\\", \\\"startmsg.regex\\\": \\\"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\\\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\\\\\\\\\([a-z]+\\\\\\\\\\\\\\\\) \\\"}]}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::metrics::qdr::listener_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::haproxy::metrics_qdr\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_port\\\": 5666, \\\"tripleo::profile::base::metrics::qdr::username\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::qdr::password\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::qdr::connectors\\\": [], \\\"tripleo::profile::base::metrics::qdr::addresses\\\": [{\\\"prefix\\\": \\\"collectd\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/metering.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/event.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}], \\\"tripleo::profile::base::metrics::qdr::autolink_addresses\\\": [], \\\"tripleo::profile::base::metrics::qdr::listener_require_ssl\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_require_encrypt\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_sasl_mech\\\": \\\"ANONYMOUS\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\\\": \\\"\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_password\\\": \\\"\\\", \\\"tripleo::profile::base::metrics::qdr::listener_trusted_certs\\\": \\\"\\\", \\\"qdr::log_enable\\\": \\\"info+\\\", \\\"qdr::log_output\\\": \\\"/var/log/qdrouterd/metrics_qdr.log\\\", \\\"qdr::listener_auth_peer\\\": false, \\\"tripleo::profile::base::metrics::qdr::ssl_profiles\\\": [{\\\"name\\\": \\\"sslProfile\\\"}, {\\\"name\\\": \\\"tlsProfile\\\", \\\"certFile\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"keyFile\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"caCertFile\\\": \\\"/etc/ipa/ca.crt\\\"}]}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"metrics_qdr\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"metrics_qdr\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::qdr\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/metrics_qdr.json\\\": {\\\"command\\\": \\\"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/qdrouterd\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"metrics_qdr_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\\\"]}, \\\"metrics_qdr\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"qdrouterd\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\\\", \\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\", \\\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\\\", \\\"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"metrics_qdr\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"metrics_qdr/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep metrics_qdr)\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/metrics_qdr.key\\\\n# Copy the new cert from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n# Copy the new key from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a container restart to read the new certificate\\\\n{{container_cli}} restart \\\\\\\"$container_name\\\\\\\"\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}]}, {\\\"service_name\\\": \\\"mysql_client\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::database::mysql::client::enable_ssl\\\": true, \\\"tripleo::profile::base::database::mysql::client::ssl_ca\\\": \\\"/etc/ipa/ca.crt\\\"}, \\\"step_config\\\": \\\"include tripleo::profile::base::database::mysql::client\\\"}, {\\\"service_name\\\": \\\"nova_compute\\\", \\\"monitoring_subscription\\\": \\\"overcloud-nova-compute\\\", \\\"config_settings\\\": {\\\"nova::my_ip\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::rabbit_use_ssl\\\": \\\"True\\\", \\\"nova::keystone::service_user::send_service_user_token\\\": true, \\\"nova::keystone::service_user::project_name\\\": \\\"service\\\", \\\"nova::keystone::service_user::password\\\": \\\"5QAuCI6DgbWqEzUK0gVmITEDx\\\", \\\"nova::keystone::service_user::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::keystone::service_user::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::project_name\\\": \\\"service\\\", \\\"nova::placement::password\\\": \\\"BN25Oqhi9kgi2kJiX6IVi01JG\\\", \\\"nova::placement::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::placement::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::valid_interfaces\\\": \\\"internal\\\", \\\"nova::os_region_name\\\": \\\"regionOne\\\", \\\"nova::logging::debug\\\": true, \\\"nova::purge_config\\\": false, \\\"nova::network::neutron::project_name\\\": \\\"service\\\", \\\"nova::network::neutron::username\\\": \\\"neutron\\\", \\\"nova::network::neutron::region_name\\\": \\\"regionOne\\\", \\\"nova::dhcp_domain\\\": \\\"\\\", \\\"nova::network::neutron::password\\\": \\\"V6qvOdr4xOrW2qdKJR3d8Svn0\\\", \\\"nova::network::neutron::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::network::neutron::valid_interfaces\\\": \\\"internal\\\", \\\"nova::glance::valid_interfaces\\\": \\\"internal\\\", \\\"nova::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"nova::cinder_catalog_info\\\": \\\"volumev3:cinderv3:internalURL\\\", \\\"nova::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"nova::notify_on_state_change\\\": \\\"vm_and_task_state\\\", \\\"nova::notification_driver\\\": [\\\"noop\\\"], \\\"nova::notification_format\\\": \\\"unversioned\\\", \\\"nova::network::neutron::auth_type\\\": \\\"v3password\\\", \\\"nova::db::database_db_max_retries\\\": -1, \\\"nova::db::database_max_retries\\\": -1, \\\"nova::network::neutron::ovs_bridge\\\": \\\"br-int\\\", \\\"nova::compute::sync_power_state_interval\\\": 600, \\\"nova_is_additional_cell\\\": false, \\\"nova::cross_az_attach\\\": true, \\\"nova::cache::enabled\\\": true, \\\"nova::cache::tls_enabled\\\": true, \\\"nova::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"nova::rabbit_heartbeat_in_pthread\\\": false, \\\"nova::ovsdb_connection\\\": \\\"\\\", \\\"nova::compute::vcpu_pin_set\\\": [], \\\"nova::compute::cpu_shared_set\\\": [], \\\"nova::compute::cpu_dedicated_set\\\": [], \\\"nova::compute::reserved_host_memory\\\": 512, \\\"nova::compute::reserved_huge_pages\\\": [], \\\"nova::compute::neutron_physnets_numa_nodes_mapping\\\": {}, \\\"nova::compute::neutron_tunnel_numa_nodes\\\": [], \\\"nova::compute::resume_guests_state_on_host_boot\\\": false, \\\"nova::compute::libvirt::rx_queue_size\\\": 512, \\\"nova::compute::libvirt::tx_queue_size\\\": 512, \\\"nova::compute::libvirt::file_backed_memory\\\": 0, \\\"nova::compute::libvirt::volume_use_multipath\\\": false, \\\"nova::compute::libvirt::hw_machine_type\\\": \\\"x86_64=pc-q35-rhel9.0.0\\\", \\\"nova::compute::mkisofs_cmd\\\": \\\"mkisofs\\\", \\\"compute_enable_ksm\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_pool\\\": \\\"vms\\\", \\\"tripleo::profile::base::nova::compute::nova_nfs_enabled\\\": false, \\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\", \\\"nova::compute::libvirt::num_pcie_ports\\\": 16, \\\"nova::compute::libvirt::mem_stats_period_seconds\\\": 10, \\\"nova::compute::rbd::ephemeral_storage\\\": false, \\\"resume_guests_state_on_host_boot\\\": false, \\\"nova::cpu_allocation_ratio\\\": 0.0, \\\"nova::ram_allocation_ratio\\\": 1.0, \\\"nova::disk_allocation_ratio\\\": 0.0, \\\"nova::compute::max_disk_devices_to_attach\\\": -1, \\\"nova::compute::libvirt::pmem_namespaces\\\": \\\"\\\", \\\"nova_pmem_namespaces\\\": \\\"\\\", \\\"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\\\": 86400, \\\"nova::compute::libvirt::swtpm_enabled\\\": false, \\\"nova::compute::vgpu::vgpu_types_device_addresses_mapping\\\": {}, \\\"compute_disable_irqbalance\\\": false, \\\"nova::compute::libvirt::cpu_mode\\\": \\\"host-model\\\", \\\"nova::compute::libvirt::cpu_models\\\": [], \\\"nova::compute::libvirt::cpu_model_extra_flags\\\": \\\"\\\", \\\"nova_compute_opt_volumes\\\": [], \\\"nova_compute_startup_delay\\\": 0, \\\"nova_compute_opt_env_vars\\\": {}, \\\"nova::workarounds::never_download_image_if_on_rbd\\\": false, \\\"nova::compute::image_type_exclude_list\\\": [], \\\"nova_permit_post_copy\\\": true, \\\"nova_permit_auto_converge\\\": true, \\\"nova_libvirt_max_queues\\\": 0, \\\"nova_glance_enable_rbd_download\\\": false, \\\"nova_glance_rbd_download_multistore_id\\\": \\\"\\\", \\\"nova::compute::force_raw_images\\\": true, \\\"nova::compute::use_cow_images\\\": true, \\\"nova::compute::libvirt::preallocate_images\\\": \\\"none\\\", \\\"nova::compute::image_cache::manager_interval\\\": 2400, \\\"nova::compute::image_cache::remove_unused_base_images\\\": true, \\\"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\\\": 3600, \\\"nova::compute::image_cache::precache_concurrency\\\": 1, \\\"nova::compute::provider::custom_inventories\\\": {}, \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\\\": 15, \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\\\": 600, \\\"ContainerNovaComputeImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"nova::compute::pci::passthrough\\\": \\\"\\\", \\\"nova::compute::libvirt::migration_support\\\": false, \\\"tripleo::profile::base::nova::migration::client::nova_compute_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": 2022, \\\"nova::compute::rbd::libvirt_images_rbd_glance_store_name\\\": \\\"default_backend\\\", \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": \\\"/etc/ceph/ceph.conf\\\", \\\"nova::compute::rbd::libvirt_rbd_user\\\": \\\"openstack\\\", \\\"nova::compute::rbd::rbd_keyring\\\": \\\"client.openstack\\\", \\\"tripleo::profile::base::nova::compute::cinder_nfs_backend\\\": false, \\\"rbd_persistent_storage\\\": false, \\\"rbd_disk_cachemodes\\\": [\\\"network=writeback\\\"], \\\"nova::cinder::username\\\": \\\"cinder\\\", \\\"nova::cinder::auth_type\\\": \\\"v3password\\\", \\\"nova::cinder::project_name\\\": \\\"service\\\", \\\"nova::cinder::password\\\": \\\"V7WgDxaLxT5M80e5C9n2UCcFO\\\", \\\"nova::cinder::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::cinder::region_name\\\": \\\"regionOne\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": \\\"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": \\\"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\\\", \\\"nova::compute::instance_usage_audit\\\": true, \\\"nova::compute::instance_usage_audit_period\\\": \\\"hour\\\", \\\"nova::compute::consecutive_build_service_disable_threshold\\\": \\\"10\\\", \\\"nova::compute::live_migration_wait_for_vif_plug\\\": true, \\\"nova::migration::libvirt::live_migration_permit_post_copy\\\": true, \\\"nova::migration::libvirt::live_migration_permit_auto_converge\\\": true, \\\"nova::migration::libvirt::live_migration_tunnelled\\\": false, \\\"nova::compute::vncserver_proxyclient_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::compute::vncproxy_host\\\": \\\"overcloud.ooo.test\\\", \\\"nova::vncproxy::common::vncproxy_protocol\\\": \\\"https\\\", \\\"nova::vncproxy::common::vncproxy_host\\\": \\\"overcloud.ooo.test\\\", \\\"nova::vncproxy::common::vncproxy_port\\\": \\\"13080\\\", \\\"nova::compute::verify_glance_signatures\\\": false, \\\"nova::workarounds::disable_compute_service_check_for_ffu\\\": false}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_compute\\\": [{\\\"tag\\\": \\\"openstack.nova.compute\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-compute.log\\\"}]}, \\\"collectd\\\": {\\\"tripleo.collectd.plugins.nova_compute\\\": [\\\"virt\\\"], \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\"}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"nova_config\\\", \\\"step_config\\\": \\\"# TODO(emilien): figure how to deal with libvirt profile.\\\\n# We\'ll probably treat it like we do with Neutron plugins.\\\\n# Until then, just include it in the default nova-compute role.\\\\ninclude tripleo::profile::base::nova::compute::libvirt\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_compute.json\\\": {\\\"command\\\": \\\"/usr/bin/nova-compute \\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/*\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\\\": {\\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"nova_statedir_ownership.py\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\nimport logging\\\\nimport os\\\\nimport pwd\\\\nimport selinux\\\\nimport stat\\\\nimport sys\\\\n\\\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\\\n\\\\nif debug.lower() == \'true\':\\\\n    loglevel = logging.DEBUG\\\\nelse:\\\\n    loglevel = logging.INFO\\\\n\\\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\\\nLOG = logging.getLogger(\'nova_statedir\')\\\\n\\\\n\\\\nclass PathManager(object):\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"Helper class to manipulate ownership of a given path\\\\\\\"\\\\\\\"\\\\\\\"\\\\n    def __init__(self, path):\\\\n        self.path = path\\\\n        self.uid = None\\\\n        self.gid = None\\\\n        self.is_dir = None\\\\n        self.secontext = None\\\\n        self._update()\\\\n\\\\n    def _update(self):\\\\n        try:\\\\n            statinfo = os.stat(self.path)\\\\n            self.is_dir = stat.S_ISDIR(statinfo.st_mode)\\\\n            self.uid = statinfo.st_uid\\\\n            self.gid = statinfo.st_gid\\\\n            self.secontext = selinux.lgetfilecon(self.path)[1]\\\\n        except Exception:\\\\n            LOG.exception(\'Could not update metadata for %s\', self.path)\\\\n            raise\\\\n\\\\n    def __str__(self):\\\\n        return \\\\\\\"uid: {} gid: {} path: {}{}\\\\\\\".format(\\\\n            self.uid,\\\\n            self.gid,\\\\n            self.path,\\\\n            \'/\' if self.is_dir else \'\'\\\\n        )\\\\n\\\\n    def has_owner(self, uid, gid):\\\\n        return self.uid == uid and self.gid == gid\\\\n\\\\n    def has_either(self, uid, gid):\\\\n        return self.uid == uid or self.gid == gid\\\\n\\\\n    def chown(self, uid, gid):\\\\n        target_uid = -1\\\\n        target_gid = -1\\\\n        if self.uid != uid:\\\\n            target_uid = uid\\\\n        if self.gid != gid:\\\\n            target_gid = gid\\\\n        if (target_uid, target_gid) != (-1, -1):\\\\n            LOG.info(\'Changing ownership of %s from %d:%d to %d:%d\',\\\\n                     self.path,\\\\n                     self.uid,\\\\n                     self.gid,\\\\n                     self.uid if target_uid == -1 else target_uid,\\\\n                     self.gid if target_gid == -1 else target_gid)\\\\n            try:\\\\n                os.chown(self.path, target_uid, target_gid)\\\\n                self._update()\\\\n            except Exception:\\\\n                LOG.exception(\'Could not change ownership of %s: \',\\\\n                              self.path)\\\\n                raise\\\\n        else:\\\\n            LOG.info(\'Ownership of %s already %d:%d\',\\\\n                     self.path,\\\\n                     uid,\\\\n                     gid)\\\\n\\\\n    def chcon(self, context):\\\\n        # If dir returns whether to recusively set context\\\\n        try:\\\\n            try:\\\\n                selinux.lsetfilecon(self.path, context)\\\\n                LOG.info(\'Setting selinux context of %s to %s\',\\\\n                     self.path, context)\\\\n                return True\\\\n            except OSError as e:\\\\n                if self.is_dir and e.errno == 95:\\\\n                    # Operation not supported, assume NFS mount and skip\\\\n                    LOG.info(\'Setting selinux context not supported for %s\',\\\\n                             self.path)\\\\n                    return False\\\\n                else:\\\\n                    raise\\\\n        except Exception:\\\\n            LOG.exception(\'Could not set selinux context of %s to %s:\',\\\\n                          self.path, context)\\\\n            raise\\\\n\\\\n\\\\nclass NovaStatedirOwnershipManager(object):\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"Class to manipulate the ownership of the nova statedir (/var/lib/nova).\\\\n\\\\n       The nova uid/gid differ on the host and container images. An upgrade\\\\n       that switches from host systemd services to docker requires a change in\\\\n       ownership. Previously this was a naive recursive chown, however this\\\\n       causes issues if nova instance are shared via an NFS mount: any open\\\\n       filehandles in qemu/libvirt fail with an I/O error (LP1778465).\\\\n\\\\n       Instead the upgrade/FFU ansible tasks now lay down a marker file when\\\\n       stopping and disabling the host systemd services. We use this file to\\\\n       determine the host nova uid/gid. We then walk the tree and update any\\\\n       files that have the host uid/gid to the docker nova uid/gid. As files\\\\n       owned by root/qemu etc... are ignored this avoids the issues with open\\\\n       filehandles. The marker is removed once the tree has been walked.\\\\n\\\\n       For subsequent runs, or for a new deployment, we simply ensure that the\\\\n       docker nova user/group owns all directories. This is required as the\\\\n       directories are created with root ownership in host_prep_tasks (the\\\\n       docker nova uid/gid is not known in this context).\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"\\\\n    def __init__(self, statedir, upgrade_marker=\'upgrade_marker\',\\\\n                 nova_user=\'nova\', secontext_marker=\'../_nova_secontext\',\\\\n                 exclude_paths=None):\\\\n        self.statedir = statedir\\\\n        self.nova_user = nova_user\\\\n\\\\n        self.upgrade_marker_path = os.path.join(statedir, upgrade_marker)\\\\n        self.secontext_marker_path = os.path.normpath(os.path.join(statedir, secontext_marker))\\\\n        self.upgrade = os.path.exists(self.upgrade_marker_path)\\\\n\\\\n        self.exclude_paths = [self.upgrade_marker_path]\\\\n        if exclude_paths is not None:\\\\n            for p in exclude_paths:\\\\n                if not p.startswith(os.path.sep):\\\\n                    p = os.path.join(self.statedir, p)\\\\n                self.exclude_paths.append(p)\\\\n\\\\n        self.target_uid, self.target_gid = self._get_nova_ids()\\\\n        self.previous_uid, self.previous_gid = self._get_previous_nova_ids()\\\\n        self.id_change = (self.target_uid, self.target_gid) != \\\\\\\\\\\\n            (self.previous_uid, self.previous_gid)\\\\n        self.target_secontext = self._get_secontext()\\\\n\\\\n    def _get_nova_ids(self):\\\\n        nova_uid, nova_gid = pwd.getpwnam(self.nova_user)[2:4]\\\\n        return nova_uid, nova_gid\\\\n\\\\n    def _get_previous_nova_ids(self):\\\\n        if self.upgrade:\\\\n            statinfo = os.stat(self.upgrade_marker_path)\\\\n            return statinfo.st_uid, statinfo.st_gid\\\\n        else:\\\\n            return self._get_nova_ids()\\\\n\\\\n    def _get_secontext(self):\\\\n        if os.path.exists(self.secontext_marker_path):\\\\n            return selinux.lgetfilecon(self.secontext_marker_path)[1]\\\\n        else:\\\\n            return None\\\\n\\\\n    def _walk(self, top, chcon=True):\\\\n        for f in os.listdir(top):\\\\n            pathname = os.path.join(top, f)\\\\n\\\\n            if pathname in self.exclude_paths:\\\\n                continue\\\\n\\\\n            try:\\\\n                pathinfo = PathManager(pathname)\\\\n                LOG.info(\\\\\\\"Checking %s\\\\\\\", pathinfo)\\\\n                if pathinfo.is_dir:\\\\n                    # Always chown the directories\\\\n                    pathinfo.chown(self.target_uid, self.target_gid)\\\\n                    chcon_r = chcon\\\\n                    if chcon:\\\\n                        chcon_r = pathinfo.chcon(self.target_secontext)\\\\n                    self._walk(pathname, chcon_r)\\\\n                elif self.id_change:\\\\n                    # Only chown files if it\'s an upgrade and the file is owned by\\\\n                    # the host nova uid/gid\\\\n                    pathinfo.chown(\\\\n                        self.target_uid if pathinfo.uid == self.previous_uid\\\\n                        else pathinfo.uid,\\\\n                        self.target_gid if pathinfo.gid == self.previous_gid\\\\n                        else pathinfo.gid\\\\n                    )\\\\n                    if chcon:\\\\n                        pathinfo.chcon(self.target_secontext)\\\\n            except Exception:\\\\n                # Likely to have been caused by external systems\\\\n                # interacting with this directory tree,\\\\n                # especially on NFS e.g snapshot dirs.\\\\n                # Just ignore it and continue on to the next entry\\\\n                continue\\\\n\\\\n    def run(self):\\\\n        LOG.info(\'Applying nova statedir ownership\')\\\\n        LOG.info(\'Target ownership for %s: %d:%d\',\\\\n                 self.statedir,\\\\n                 self.target_uid,\\\\n                 self.target_gid)\\\\n\\\\n        pathinfo = PathManager(self.statedir)\\\\n        LOG.info(\\\\\\\"Checking %s\\\\\\\", pathinfo)\\\\n        pathinfo.chown(self.target_uid, self.target_gid)\\\\n        chcon = self.target_secontext is not None\\\\n\\\\n        if chcon:\\\\n            pathinfo.chcon(self.target_secontext)\\\\n\\\\n        self._walk(self.statedir, chcon)\\\\n\\\\n        if self.upgrade:\\\\n            LOG.info(\'Removing upgrade_marker %s\',\\\\n                     self.upgrade_marker_path)\\\\n            os.unlink(self.upgrade_marker_path)\\\\n\\\\n        LOG.info(\'Nova statedir ownership complete\')\\\\n\\\\n\\\\ndef get_exclude_paths():\\\\n    exclude_paths = os.environ.get(\'NOVA_STATEDIR_OWNERSHIP_SKIP\')\\\\n    if exclude_paths is not None:\\\\n        exclude_paths = exclude_paths.split(os.pathsep)\\\\n    return exclude_paths\\\\n\\\\n\\\\nif __name__ == \'__main__\':\\\\n    NovaStatedirOwnershipManager(\'/var/lib/nova\', exclude_paths=get_exclude_paths()).run()\\\\n\\\"}, \\\"nova_wait_for_compute_service.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\nimport argparse\\\\nimport logging\\\\nimport os\\\\nimport six\\\\nimport socket\\\\nimport sys\\\\nimport time\\\\n\\\\n\\\\nfrom keystoneauth1 import loading\\\\nfrom keystoneauth1 import session\\\\n\\\\nfrom novaclient import client\\\\n\\\\n# In python3 SafeConfigParser was renamed to ConfigParser and the default\\\\n# for duplicate options default to true. In case of nova it is valid to\\\\n# have duplicate option lines, e.g. passthrough_whitelist which leads to\\\\n# issues reading the nova.conf\\\\n# https://bugs.launchpad.net/tripleo/+bug/1827775\\\\nif six.PY3:\\\\n    from six.moves.configparser import ConfigParser\\\\n    config = ConfigParser(strict=False)\\\\nelse:\\\\n    from six.moves.configparser import SafeConfigParser\\\\n    config = SafeConfigParser()\\\\n\\\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\\\n\\\\nif debug.lower() == \'true\':\\\\n    loglevel = logging.DEBUG\\\\nelse:\\\\n    loglevel = logging.INFO\\\\n\\\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\\\nLOG = logging.getLogger(\'nova_wait_for_compute_service\')\\\\n\\\\niterations = 60\\\\ntimeout = 10\\\\nnova_cfg = \'/etc/nova/nova.conf\'\\\\n\\\\nif __name__ == \'__main__\':\\\\n    parser = argparse.ArgumentParser(usage=\'%(prog)s [options]\')\\\\n    parser.add_argument(\'-k\', \'--insecure\',\\\\n                        action=\\\\\\\"store_false\\\\\\\",\\\\n                        dest=\'insecure\',\\\\n                        default=True,\\\\n                        help=\'Allow insecure connection when using SSL\')\\\\n\\\\n    args = parser.parse_args()\\\\n    LOG.debug(\'Running with parameter insecure = %s\',\\\\n              args.insecure)\\\\n\\\\n    if os.path.isfile(nova_cfg):\\\\n        try:\\\\n            config.read(nova_cfg)\\\\n        except Exception:\\\\n            LOG.exception(\'Error while reading nova.conf:\')\\\\n    else:\\\\n        LOG.error(\'Nova configuration file %s does not exist\', nova_cfg)\\\\n        sys.exit(1)\\\\n\\\\n    my_host = config.get(\'DEFAULT\', \'host\')\\\\n    if not my_host:\\\\n        # If host isn\'t set nova defaults to this\\\\n        my_host = socket.gethostname()\\\\n\\\\n    loader = loading.get_plugin_loader(\'password\')\\\\n    auth = loader.load_from_options(\\\\n        auth_url=config.get(\'neutron\',\\\\n                            \'auth_url\'),\\\\n        username=config.get(\'neutron\',\\\\n                            \'username\'),\\\\n        password=config.get(\'neutron\',\\\\n                            \'password\'),\\\\n        project_name=config.get(\'neutron\',\\\\n                                \'project_name\'),\\\\n        project_domain_name=config.get(\'neutron\',\\\\n                                       \'project_domain_name\'),\\\\n        user_domain_name=config.get(\'neutron\',\\\\n                                    \'user_domain_name\'))\\\\n    sess = session.Session(auth=auth, verify=args.insecure)\\\\n    nova = client.Client(\'2.11\', session=sess, endpoint_type=\'internal\',\\\\n                         region_name=config.get(\'neutron\', \'region_name\'))\\\\n\\\\n    # Wait until this host is listed in the service list\\\\n    for i in range(iterations):\\\\n        try:\\\\n            service_list = nova.services.list(binary=\'nova-compute\')\\\\n            for entry in service_list:\\\\n                host = getattr(entry, \'host\', \'\')\\\\n                zone = getattr(entry, \'zone\', \'\')\\\\n                if host == my_host and zone != \'internal\':\\\\n                    LOG.info(\'Nova-compute service registered\')\\\\n                    sys.exit(0)\\\\n            LOG.info(\'Waiting for nova-compute service to register\')\\\\n        except Exception:\\\\n            LOG.exception(\\\\n                \'Error while waiting for nova-compute service to register\')\\\\n        time.sleep(timeout)\\\\nsys.exit(1)\\\\n\\\\n# vim: set et ts=4 sw=4 :\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"nova_compute_init_log\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/nova:/var/log/nova:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R nova:nova /var/log/nova\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781078317\\\"}}}, \\\"step_3\\\": {\\\"nova_statedir_owner\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"privileged\\\": false, \\\"detach\\\": false, \\\"volumes\\\": [\\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts:z\\\"], \\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\\\", \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781078317\\\", \\\"__OS_DEBUG\\\": \\\"true\\\", \\\"NOVA_STATEDIR_OWNERSHIP_SKIP\\\": \\\"triliovault-mounts\\\"}}}, \\\"step_5\\\": {\\\"nova_compute\\\": {\\\"start_order\\\": 3, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"memlock=67108864\\\"], \\\"ipc\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"nova\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_libvirt.target\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck 5672\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/nova:/var/log/nova\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/dev:/dev\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/run/nova:/run/nova:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/sys/class/net:/sys/class/net\\\", \\\"/sys/bus/pci:/sys/bus/pci\\\", \\\"/boot:/boot:ro\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"LIBGUESTFS_BACKEND\\\": \\\"direct\\\"}}, \\\"nova_wait_for_compute_service\\\": {\\\"start_order\\\": 4, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/nova:/var/log/nova\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts\\\"], \\\"user\\\": \\\"nova\\\", \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"__OS_DEBUG\\\": \\\"true\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/nova\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"Check for /var/lib/nova/instances directory exitance\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/nova/instances\\\"}, \\\"register\\\": \\\"check_nova_instances_result\\\"}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/_nova_secontext\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/nova/instances\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/tmpfiles.d\\\"}]}, {\\\"name\\\": \\\"ensure /run/nova is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-nova.conf\\\", \\\"content\\\": \\\"d /run/nova 0777 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"create tempfiles\\\", \\\"command\\\": \\\"systemd-tmpfiles --create\\\"}, {\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\"}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}, {\\\"name\\\": \\\"delay installation of systemd-container\\\", \\\"when\\\": \\\"check_nova_instances_result.stat.exists\\\", \\\"block\\\": [{\\\"name\\\": \\\"check systemd-container package installed or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"get latest package from downloaded package versions\\\", \\\"shell\\\": \\\"ls -1t /var/tmp/systemd-container* | head -1\\\", \\\"register\\\": \\\"latest_systemd_container_package\\\", \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"], \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Install systemd-container package on boot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Install systemd container package on system boot\\\\nBefore=tripleo_nova_virtqemud.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\\\nExecStartPost=rm -f /var/tmp/systemd-container*\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": [\\\"latest_systemd_container_package is defined\\\", \\\"(\'stdout\' in latest_systemd_container_package)\\\", \\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"enable install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"check if install-systemd-container service exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\"}, \\\"register\\\": \\\"install_systemd_container_result\\\"}, {\\\"name\\\": \\\"disable and mask install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"not is_systemd_container_package.changed\\\", \\\"install_systemd_container_result.stat.exists\\\"]}]}, {\\\"name\\\": \\\"is Nova Resume Guests State On Host Boot enabled\\\", \\\"set_fact\\\": {\\\"resume_guests_state_on_host_boot_enabled\\\": false}}, {\\\"name\\\": \\\"install libvirt-guests systemd unit file (docker)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'docker\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/libvirt-guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend/Resume Running libvirt Guests\\\\nAfter=network.target\\\\nAfter=time-sync.target\\\\nAfter=virt-guest-shutdown.target\\\\nAfter=docker.service\\\\nAfter=tripleo-container-shutdown.service\\\\nAfter=rhel-push-plugin.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\\\n# Hack just call traditional service until we factor\\\\n# out the code\\\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\\\nExecStop=/bin/{{container_cli}} stop nova_compute\\\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"libvirt-guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"libvirt-guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"install tripleo_nova_libvirt_guests systemd unit file (podman)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'podman\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt_guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Do we prepend nova startup with a delay\\\", \\\"set_fact\\\": {\\\"nova_compute_delay\\\": 0}}, {\\\"name\\\": \\\"install nova-compute delay wrapper script\\\", \\\"copy\\\": {\\\"content\\\": \\\"#!/usr/libexec/platform-python\\\\n\\\\\\\"\\\\\\\"\\\\\\\"\\\\nThis wrapper was created to add an optional delay to the startup of nova-compute.\\\\nWe know that instances will fail to boot, after a compute reboot, if ceph is not\\\\nhealthy.\\\\n\\\\nIdeally, we would poll ceph to get its health, but it\'s not guaranteed that the\\\\ncompute node will have access to the keys.\\\\n\\\\\\\"\\\\\\\"\\\\\\\"\\\\n\\\\nimport os\\\\nimport sys\\\\nimport time\\\\nimport logging\\\\nimport argparse\\\\n\\\\nparser = argparse.ArgumentParser(description=\'Process some integers.\')\\\\nparser.add_argument(\'--config-file\', dest=\'nova_config\', action=\'store\',\\\\n                    default=\\\\\\\"/etc/nova/nova.conf\\\\\\\",\\\\n                    help=\'path to nova configuration (default: /etc/nova/nova.conf)\')\\\\nparser.add_argument(\'--nova-binary\', dest=\'nova_binary\', action=\'store\',\\\\n                    default=\\\\\\\"/usr/bin/nova-compute\\\\\\\",\\\\n                    help=\'path to nova compute binary (default: /usr/bin/nova-compute)\')\\\\nparser.add_argument(\'--delay\', dest=\'delay\', action=\'store\',\\\\n                    default=120, type=int,\\\\n                    help=\'Number of seconds to wait until nova-compute is started\')\\\\nparser.add_argument(\'--state-dir\', dest=\'state_dir\', action=\'store\',\\\\n                    default=\\\\\\\"/run/nova/startup\\\\\\\", help=\'state-file directory\')\\\\nparser.add_argument(\'--state-file\', dest=\'state_file\', action=\'store\',\\\\n                    default=\\\\\\\"nova-compute-delayed\\\\\\\",\\\\n                    help=\'file exists if we already delayed nova-compute startup\')\\\\n\\\\n\\\\nsections = {}\\\\n(args, remaining) = parser.parse_known_args(sys.argv)\\\\n\\\\nreal_args = [args.nova_binary, \'--config-file\', args.nova_config]\\\\nreal_args.extend(remaining[1:])\\\\n\\\\nif not os.path.isdir(args.state_dir):\\\\n  os.makedirs(args.state_dir, mode = 0o751)\\\\n\\\\nstate_file_name = os.path.join(args.state_dir, args.state_file)\\\\n\\\\nif not os.path.isfile(state_file_name):\\\\n    logging.info(\\\\\\\"Delaying nova-compute startup by %s seconds\\\\\\\" % args.delay)\\\\n    time.sleep(args.delay)\\\\n    open(state_file_name, \'a\').close()\\\\n\\\\nlogging.info(\\\\\\\"Executing %s\\\\\\\" % real_args)\\\\nos.execv(args.nova_binary, real_args)\\\\n\\\", \\\"dest\\\": \\\"/var/lib/nova/delay-nova-compute\\\", \\\"mode\\\": 493}, \\\"when\\\": \\\"nova_compute_delay|int > 0\\\"}, {\\\"name\\\": \\\"Is irqbalance enabled\\\", \\\"set_fact\\\": {\\\"compute_irqbalance_disabled\\\": false}}, {\\\"name\\\": \\\"disable irqbalance service on compute\\\", \\\"when\\\": \\\"compute_irqbalance_disabled|bool\\\", \\\"service\\\": {\\\"name\\\": \\\"irqbalance.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"install systemd-container for a greenfield\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"not check_nova_instances_result.stat.exists\\\"], \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"validate nova-compute container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_compute\\\"}, \\\"register\\\": \\\"nova_compute_infos\\\", \\\"failed_when\\\": [\\\"nova_compute_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 6\\\"]}, {\\\"name\\\": \\\"manage PMEM namespaces for vPMEM\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_nvdimm\\\"}, \\\"vars\\\": {\\\"tripleo_nvdimm_pmem_namespaces\\\": \\\"\\\"}, \\\"when\\\": [\\\"step|int == 1\\\", \\\"tripleo_nvdimm_pmem_namespaces != \'\'\\\"]}, {\\\"name\\\": \\\"manage OS version 9 specific sysctls\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"ansible_facts[\'os_family\'] == \'RedHat\'\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Enable post-copy by setting unprivileged_userfaultfd\\\", \\\"sysctl\\\": {\\\"name\\\": \\\"vm.unprivileged_userfaultfd\\\", \\\"value\\\": 1, \\\"sysctl_set\\\": true, \\\"sysctl_file\\\": \\\"/etc/sysctl.d/99-tripleo-postcopy.conf\\\", \\\"state\\\": \\\"present\\\", \\\"reload\\\": true}}]}, {\\\"name\\\": \\\"enable/disable ksm\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"is KSM enabled\\\", \\\"set_fact\\\": {\\\"compute_ksm_enabled\\\": false}}, {\\\"name\\\": \\\"disable KSM on compute\\\", \\\"when\\\": \\\"not compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for ksm\\\", \\\"shell\\\": \\\"systemctl is-active ksm.service || systemctl is-enabled ksm.service\\\", \\\"become\\\": true, \\\"failed_when\\\": false, \\\"register\\\": \\\"ksm_service_check\\\"}, {\\\"name\\\": \\\"disable KSM services\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"], \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\"], \\\"register\\\": \\\"ksmdisabled\\\"}, {\\\"name\\\": \\\"delete PageKSM after disable ksm on compute\\\", \\\"command\\\": \\\"echo 2 >/sys/kernel/mm/ksm/run\\\", \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\", \\\"ksmdisabled is changed\\\"]}]}, {\\\"name\\\": \\\"enable KSM on compute\\\", \\\"when\\\": \\\"compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\\\", \\\"package\\\": {\\\"name\\\": \\\"qemu-kvm-common\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"]}, {\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\\\", \\\"package\\\": {\\\"name\\\": \\\"ksmtuned\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"]}, {\\\"name\\\": \\\"enable ksmtunded\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"started\\\", \\\"enabled\\\": true}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"]}]}]}], \\\"external_post_deploy_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"is additonal Cell?\\\", \\\"set_fact\\\": {\\\"nova_additional_cell\\\": false}}, {\\\"name\\\": \\\"check if discover hosts is required\\\", \\\"when\\\": [\\\"not nova_additional_cell|bool\\\", \\\"nova_cellv2_discovery_done is not defined\\\"], \\\"block\\\": [{\\\"name\\\": \\\"discover via nova_manager?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_manager\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_manager\\\"}, \\\"when\\\": [\\\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\\\"]}, {\\\"name\\\": \\\"discover via nova_api?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_api\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_api\\\"}, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\", \\\"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\\\"]}, {\\\"name\\\": \\\"Warn if no discovery host available\\\", \\\"fail\\\": {\\\"msg\\\": \\\"No hosts available to run nova cell_v2 host discovery.\\\"}, \\\"ignore_errors\\\": true, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\"]}, {\\\"name\\\": \\\"Discovering nova hosts\\\", \\\"command\\\": \\\"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\\\", \\\"become\\\": true, \\\"changed_when\\\": false, \\\"delegate_to\\\": \\\"{{ nova_cellv2_discovery_delegate_host }}\\\", \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is defined\\\"]}, {\\\"set_fact\\\": {\\\"nova_cellv2_discovery_done\\\": true}}]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}, {\\\"name\\\": \\\"nova_compute pre system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Unmount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"absent\\\", \\\"fstype\\\": \\\"nfs4\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}, {\\\"name\\\": \\\"nova_compute post system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 5\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\"}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": \\\"overcloud\\\"}, \\\"block\\\": [{\\\"name\\\": \\\"Get nova-compute service ID\\\", \\\"command\\\": \\\"openstack compute service list --service nova-compute --column ID --column Host --format yaml\\\", \\\"register\\\": \\\"nova_compute_service_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"is additional Cell?\\\", \\\"set_fact\\\": {\\\"is_additional_cell\\\": false}}, {\\\"name\\\": \\\"Set fact for nova_compute services\\\", \\\"set_fact\\\": {\\\"nova_compute_service\\\": \\\"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Check search output\\\", \\\"fail\\\": {\\\"msg\\\": \\\"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\\\"}, \\\"when\\\": [\\\"(nova_compute_service | length) > 1\\\"]}, {\\\"name\\\": \\\"Disable nova services\\\", \\\"when\\\": [\\\"(nova_compute_service | length) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable nova-compute service\\\", \\\"command\\\": \\\"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"when\\\": [\\\"not is_additional_cell|bool\\\"]}, {\\\"name\\\": \\\"Stop nova-compute container\\\", \\\"service\\\": {\\\"name\\\": \\\"tripleo_nova_compute\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_nova_compute\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete nova-compute service\\\", \\\"command\\\": \\\"openstack compute service delete {{ nova_compute_service[0].ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}, {\\\"service_name\\\": \\\"nova_libvirt\\\", \\\"firewall_rules\\\": {\\\"200 nova_libvirt\\\": {\\\"dport\\\": [16514, \\\"61152-61215\\\", \\\"5900-6923\\\"]}}, \\\"ansible_group_vars\\\": {\\\"tripleo_nova_libvirt_virsh_container\\\": \\\"nova_virtproxyd\\\"}, \\\"monitoring_subscription\\\": \\\"overcloud-nova-libvirt\\\", \\\"config_settings\\\": {\\\"nova::my_ip\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::rabbit_use_ssl\\\": \\\"True\\\", \\\"nova::keystone::service_user::send_service_user_token\\\": true, \\\"nova::keystone::service_user::project_name\\\": \\\"service\\\", \\\"nova::keystone::service_user::password\\\": \\\"5QAuCI6DgbWqEzUK0gVmITEDx\\\", \\\"nova::keystone::service_user::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::keystone::service_user::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::project_name\\\": \\\"service\\\", \\\"nova::placement::password\\\": \\\"BN25Oqhi9kgi2kJiX6IVi01JG\\\", \\\"nova::placement::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::placement::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::valid_interfaces\\\": \\\"internal\\\", \\\"nova::os_region_name\\\": \\\"regionOne\\\", \\\"nova::logging::debug\\\": true, \\\"nova::purge_config\\\": false, \\\"nova::network::neutron::project_name\\\": \\\"service\\\", \\\"nova::network::neutron::username\\\": \\\"neutron\\\", \\\"nova::network::neutron::region_name\\\": \\\"regionOne\\\", \\\"nova::dhcp_domain\\\": \\\"\\\", \\\"nova::network::neutron::password\\\": \\\"V6qvOdr4xOrW2qdKJR3d8Svn0\\\", \\\"nova::network::neutron::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::network::neutron::valid_interfaces\\\": \\\"internal\\\", \\\"nova::glance::valid_interfaces\\\": \\\"internal\\\", \\\"nova::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"nova::cinder_catalog_info\\\": \\\"volumev3:cinderv3:internalURL\\\", \\\"nova::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"nova::notify_on_state_change\\\": \\\"vm_and_task_state\\\", \\\"nova::notification_driver\\\": [\\\"noop\\\"], \\\"nova::notification_format\\\": \\\"unversioned\\\", \\\"nova::network::neutron::auth_type\\\": \\\"v3password\\\", \\\"nova::db::database_db_max_retries\\\": -1, \\\"nova::db::database_max_retries\\\": -1, \\\"nova::network::neutron::ovs_bridge\\\": \\\"br-int\\\", \\\"nova::compute::sync_power_state_interval\\\": 600, \\\"nova_is_additional_cell\\\": false, \\\"nova::cross_az_attach\\\": true, \\\"nova::cache::enabled\\\": true, \\\"nova::cache::tls_enabled\\\": true, \\\"nova::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"nova::rabbit_heartbeat_in_pthread\\\": false, \\\"nova::ovsdb_connection\\\": \\\"\\\", \\\"vhostuser_socket_group\\\": \\\"qemu\\\", \\\"nova_libvirt_opt_volumes\\\": [], \\\"ContainerNovaLibvirtImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"nova::compute::libvirt::log_outputs\\\": \\\"1:file:/var/log/libvirt/libvirtd.log\\\", \\\"nova::compute::libvirt::virtlogd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtlogd.log\\\", \\\"nova::compute::libvirt::virtsecretd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtsecretd.log\\\", \\\"nova::compute::libvirt::virtnodedevd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtnodedevd.log\\\", \\\"nova::compute::libvirt::virtqemud::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtqemud.log\\\", \\\"nova::compute::libvirt::virtproxyd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtproxyd.log\\\", \\\"nova::compute::libvirt::virtstoraged::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtstoraged.log\\\", \\\"nova::compute::libvirt::qemu::memory_backing_dir\\\": \\\"\\\", \\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\\\": true, \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\\\": \\\"/var/lib/container-config-scripts/virtlogd_wrapper\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::debug\\\": true, \\\"nova::compute::libvirt::migration_support\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": \\\"/etc/ceph/ceph.conf\\\", \\\"nova::compute::rbd::libvirt_rbd_user\\\": \\\"openstack\\\", \\\"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"nova::compute::rbd::rbd_keyring\\\": \\\"client.openstack\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": \\\"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": \\\"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\\\", \\\"tripleo::profile::base::nova::migration::client::libvirt_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": 2022, \\\"nova::compute::libvirt::services::libvirt_virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::enabled_perf_events\\\": [], \\\"nova::compute::libvirt::qemu::configure_qemu\\\": true, \\\"nova::compute::libvirt::qemu::max_files\\\": 32768, \\\"nova::compute::libvirt::qemu::max_processes\\\": 131072, \\\"nova::migration::qemu::configure_qemu\\\": true, \\\"nova::migration::qemu::migration_port_min\\\": 61152, \\\"nova::migration::qemu::migration_port_max\\\": 61215, \\\"nova::compute::libvirt::vncserver_listen\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::compute::libvirt::log_filters\\\": \\\"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\\\", \\\"nova::compute::libvirt::virtlogd::log_filters\\\": \\\"1:logging 4:object 4:json 4:event 1:util\\\", \\\"rbd_persistent_storage\\\": false, \\\"rbd_disk_cachemodes\\\": [\\\"network=writeback\\\"], \\\"nova::compute::libvirt::virtsecretd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtnodedevd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtstoraged::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtqemud::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtproxyd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"tripleo::profile::base::nova::libvirt::modular_libvirt\\\": true, \\\"nova::compute::libvirt::services::modular_libvirt\\\": true, \\\"nova::compute::libvirt::modular_libvirt\\\": true, \\\"nova::migration::libvirt::modular_libvirt\\\": true, \\\"tripleo::profile::base::nova::migration::client::libvirt_tls\\\": true, \\\"tripleo::profile::base::nova::libvirt::tls_password\\\": \\\"GhFjIdW1ysmls0LZQMCGaOen4\\\", \\\"nova::compute::libvirt::qemu::default_tls_verify\\\": true, \\\"nova::compute::libvirt::tls_priority\\\": \\\"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\\\", \\\"nova::migration::libvirt::listen_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::migration::libvirt::live_migration_inbound_addr\\\": \\\"%{hiera(\'fqdn_internal_api\')}\\\", \\\"nova::compute::libvirt::qemu::vnc_tls\\\": true, \\\"nova::compute::libvirt::qemu::vnc_tls_verify\\\": true, \\\"nova::compute::libvirt::qemu::nbd_tls\\\": true, \\\"nova::migration::libvirt::live_migration_with_native_tls\\\": true}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::libvirt\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_virtlogd.json\\\": {\\\"command\\\": \\\"/usr/local/bin/virtlogd_wrapper\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtsecretd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtnodedevd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtstoraged.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtqemud.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtproxyd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}}, \\\"container_config_scripts\\\": {\\\"nova_libvirt_init_secret.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -e\\\\n\\\\nCEPH_INFO=($*)\\\\n\\\\nif [ -z \\\\\\\"$CEPH_INFO\\\\\\\" ]; then\\\\n    echo \\\\\\\"error: At least one CLUSTER:CLIENT tuple must be specified\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\necho \\\\\\\"------------------------------------------------\\\\\\\"\\\\necho \\\\\\\"Initializing virsh secrets for: ${CEPH_INFO[@]}\\\\\\\"\\\\n\\\\nfor INFO in ${CEPH_INFO[@]}; do\\\\n    IFS=: read CLUSTER CLIENT <<< $INFO\\\\n    if [ ! -f /etc/ceph/${CLUSTER}.conf ]; then\\\\n        echo \\\\\\\"Error: /etc/ceph/${CLUSTER}.conf was not found\\\\\\\"\\\\n        echo \\\\\\\"Path to nova_libvirt_init_secret was ${CEPH_INFO}\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\n    FSID=$(awk \'$1 == \\\\\\\"fsid\\\\\\\" {print $3}\' /etc/ceph/${CLUSTER}.conf)\\\\n    if [ -z \\\\\\\"${FSID}\\\\\\\" ]; then\\\\n        echo \\\\\\\"Error: /etc/ceph/${CLUSTER}.conf contained an empty fsid definition\\\\\\\"\\\\n        echo \\\\\\\"Check your ceph configuration\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\n\\\\n    echo \\\\\\\"--------\\\\\\\"\\\\n    echo \\\\\\\"Initializing the virsh secret for \'$CLUSTER\' cluster ($FSID) \'$CLIENT\' client\\\\\\\"\\\\n\\\\n    # Ensure the secret XML file exists. Puppet should have created a secret.xml\\\\n    # file for the first cluster\'s secret, so detect when to use that file.\\\\n    if grep -q $FSID /etc/nova/secret.xml; then\\\\n        SECRET_FILE=\\\\\\\"/etc/nova/secret.xml\\\\\\\"\\\\n        SECRET_NAME=\\\\\\\"client.${CLIENT} secret\\\\\\\"\\\\n    else\\\\n        SECRET_FILE=\\\\\\\"/etc/nova/${CLUSTER}-secret.xml\\\\\\\"\\\\n        SECRET_NAME=\\\\\\\"${CLUSTER}.client.${CLIENT} secret\\\\\\\"\\\\n    fi\\\\n\\\\n    if [ ! -f $SECRET_FILE ]; then\\\\n        echo \\\\\\\"Creating $SECRET_FILE\\\\\\\"\\\\n        cat <<EOF > $SECRET_FILE\\\\n<secret ephemeral=\'no\' private=\'no\'>\\\\n  <usage type=\'ceph\'>\\\\n    <name>${SECRET_NAME}</name>\\\\n  </usage>\\\\n  <uuid>${FSID}</uuid>\\\\n</secret>\\\\nEOF\\\\n    else\\\\n        echo \\\\\\\"The $SECRET_FILE file already exists\\\\\\\"\\\\n    fi\\\\n\\\\n    # Ensure the libvirt secret is defined\\\\n    if /usr/bin/virsh secret-list | grep -q $FSID; then\\\\n        echo \\\\\\\"The virsh secret for $FSID has already been defined\\\\\\\"\\\\n    else\\\\n        /usr/bin/virsh secret-define --file $SECRET_FILE\\\\n    fi\\\\n\\\\n    # Fetch the key from the keyring and ensure the secret is set\\\\n    KEY=$(awk \'$1 == \\\\\\\"key\\\\\\\" {print $3}\' /etc/ceph/${CLUSTER}.client.${CLIENT}.keyring)\\\\n    if /usr/bin/virsh secret-get-value $FSID 2>/dev/null | grep -q $KEY; then\\\\n        echo \\\\\\\"The virsh secret for $FSID has already been set\\\\\\\"\\\\n    else\\\\n        /usr/bin/virsh secret-set-value --secret $FSID --base64 $KEY\\\\n    fi\\\\ndone\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"nova_virtqemud_init_logs\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R tss:tss /var/log/swtpm\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781078317\\\"}}, \\\"create_virtlogd_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::nova::virtlogd_wrapper\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781078317\\\"}}}, \\\"step_3\\\": {\\\"nova_virtlogd_wrapper\\\": {\\\"start_order\\\": 0, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"nova_virtsecretd\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtnodedevd\\\": {\\\"start_order\\\": 2, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtstoraged\\\": {\\\"start_order\\\": 3, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtqemud\\\": {\\\"start_order\\\": 4, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\\\"]}, \\\"nova_virtproxyd\\\": {\\\"start_order\\\": 5, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Ensure recovery of containerized virtqemud\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"become\\\": true, \\\"block\\\": [{\\\"name\\\": \\\"Create virtqemud recovery script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/libexec/recover_tripleo_nova_virtqemud.sh\\\", \\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/bin/bash\\\\npgrep -f /sbin/virtqemud\\\\n[ $? -eq 0 ] && exit 0\\\\nkill -9 $(cat /run/nova_virtqemud.pid)\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger service\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud\\\\nAfter=tripleo_nova_virtqemud.service\\\\nRequisite=tripleo_nova_virtqemud.service\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger timer\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\\\nPartOf=tripleo_nova_virtqemud.service\\\\n[Timer]\\\\nOnCalendar=*:5/10\\\\nOnActiveSec=120\\\\nOnUnitActiveSec=60\\\\nRandomizedDelaySec=1m\\\\n[Install]\\\\nWantedBy=timers.target\\\\n\\\"}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.service\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger timer\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.timer\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"register\\\": \\\"virtqemud_recover_timer_result\\\"}, {\\\"name\\\": \\\"Really enable virtqemud recovery trigger timer\\\", \\\"shell\\\": {\\\"cmd\\\": \\\"systemctl enable --now tripleo_nova_virtqemud_recover.timer\\\"}, \\\"when\\\": \\\"virtqemud_recover_timer_result.status.UnitFileState != \\\\\\\"enabled\\\\\\\"\\\"}]}, {\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create dirs for certificates and keys\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"directory\\\", \\\"serole\\\": \\\"object_r\\\", \\\"setype\\\": \\\"cert_t\\\", \\\"seuser\\\": \\\"system_u\\\"}, \\\"with_items\\\": [\\\"/etc/pki/libvirt\\\", \\\"/etc/pki/libvirt/private\\\", \\\"/etc/pki/qemu\\\"]}, {\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"libvirt-server-cert\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"libvirt/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/ipa/ca.crt /etc/pki/CA/cacert.pem\\\\nchown root:root /etc/pki/CA/cacert.pem\\\\nchmod 644 /etc/pki/CA/cacert.pem\\\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"libvirt-client-cert\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"libvirt/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-server-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"qemu/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp /etc/ipa/ca.crt /etc/pki/qemu/ca-cert.pem\\\\nchown root:root /etc/pki/qemu/ca-cert.pem\\\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\\\nchgrp qemu /etc/pki/qemu/server-*\\\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\\\nchmod 0640 /etc/pki/qemu/server-key.pem\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-client-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"qemu/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\\\nchgrp qemu /etc/pki/qemu/client-*\\\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\\\nchmod 0640 /etc/pki/qemu/client-key.pem\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}, {\\\"name\\\": \\\"Set up systemd target for libvirt services\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create systemd file\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt.target\\\", \\\"mode\\\": \\\"0644\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"content\\\": \\\"[Unit]\\\\nWants=tripleo_nova_virtsecretd.service\\\\nWants=tripleo_nova_virtnodedevd.service\\\\nWants=tripleo_nova_virtstoraged.service\\\\nWants=tripleo_nova_virtproxyd.service\\\\nWants=tripleo_nova_virtqemud.service\\\\nAfter=tripleo_nova_virtsecretd.service\\\\nAfter=tripleo_nova_virtnodedevd.service\\\\nAfter=tripleo_nova_virtstoraged.service\\\\nAfter=tripleo_nova_virtproxyd.service\\\\nAfter=tripleo_nova_virtqemud.service\\\\n\\\"}, \\\"become\\\": true, \\\"register\\\": \\\"libvirt_target_result\\\"}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt.target\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"become\\\": true, \\\"when\\\": \\\"libvirt_target_result.changed\\\"}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\", \\\"mode\\\": \\\"{{ item.mode | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/secrets\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/qemu\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/cache/libvirt\\\"}, {\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/run/libvirt\\\"}, {\\\"path\\\": \\\"/var/log/containers/libvirt/swtpm\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0770\\\"}]}, {\\\"name\\\": \\\"ensure qemu group is present on the host\\\", \\\"group\\\": {\\\"name\\\": \\\"qemu\\\", \\\"gid\\\": 107, \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"ensure qemu user is present on the host\\\", \\\"user\\\": {\\\"name\\\": \\\"qemu\\\", \\\"uid\\\": 107, \\\"group\\\": \\\"qemu\\\", \\\"state\\\": \\\"present\\\", \\\"shell\\\": \\\"/sbin/nologin\\\", \\\"comment\\\": \\\"qemu user\\\"}}, {\\\"name\\\": \\\"create directory for vhost-user sockets with qemu ownership\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/vhost_sockets\\\", \\\"state\\\": \\\"directory\\\", \\\"owner\\\": \\\"qemu\\\", \\\"group\\\": \\\"qemu\\\", \\\"setype\\\": \\\"virt_cache_t\\\", \\\"seuser\\\": \\\"system_u\\\"}}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"with_items\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": \\\"libvirt_installed.rc == 0\\\"}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"Enable os_enable_vtpm SELinux boolean for vTPM\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"os_enable_vtpm\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, [{\\\"name\\\": \\\"remove gnutls-qemu.config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/crypto-policies/local.d/gnutls-qemu.config\\\", \\\"state\\\": \\\"absent\\\"}, \\\"register\\\": \\\"update_gnutls_config\\\"}], {\\\"name\\\": \\\"update crypto policies\\\", \\\"command\\\": \\\"update-crypto-policies\\\", \\\"when\\\": \\\"update_gnutls_config.changed\\\"}], \\\"metadata_settings\\\": [{\\\"service\\\": \\\"libvirt\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"qemu\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"libvirt-vnc\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Fail if we are on RHEL8 as this is monolithic libvirt deployment\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\\\"}}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Get container virtlogd image\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"always\\\", \\\"set_fact\\\": {\\\"virtlogd_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}}, {\\\"name\\\": \\\"Force pull image novalibvirt\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ virtlogd_image }}\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Diff OS release in container image and baremetal\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\\\n\\\", \\\"args\\\": {\\\"executable\\\": \\\"/bin/bash\\\"}, \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_ubi_diff\\\"}, {\\\"name\\\": \\\"Fail if UBI of the container does not match RHEL of running host\\\", \\\"when\\\": [\\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"step|int == 1\\\", \\\"libvirt_ubi_diff.rc == 1\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"The host operating system versus container UBI does not match.\\\\n{{ libvirt_ubi_diff.stdout }}\\\\nMost likely container passed to NovaLibvirt was EL8 one.\\\\nYou have to pass the correct container for container-image-prepare.\\\\nIf you would continue all running workloads would get destroyed.\\\\n\\\"}}, {\\\"name\\\": \\\"Switch virtlogd image before system upgrade\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get running image version\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"old_virtlogd_image\\\"}, {\\\"name\\\": \\\"Switch running image to new image in wrapper script\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\\\n\\\", \\\"when\\\": [\\\"old_virtlogd_image.stdout != virtlogd_image\\\", \\\"old_virtlogd_image.stdout != \'\'\\\"]}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"check systemd-container package present or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\"}, {\\\"name\\\": \\\"download systemd-container package if not present\\\", \\\"yum\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\", \\\"download_only\\\": true, \\\"download_dir\\\": \\\"/var/tmp/\\\"}, \\\"when\\\": \\\"is_systemd_container_package.changed\\\"}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]}, {\\\"service_name\\\": \\\"nova_libvirt_guests\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\\\": false, \\\"nova::compute::libvirt_guests::shutdown_timeout\\\": \\\"300\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::compute::libvirt_guests\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}}, {\\\"service_name\\\": \\\"nova_migration_target\\\", \\\"firewall_rules\\\": {\\\"113 nova_migration_target accept libvirt subnet 172.17.0.0/24\\\": {\\\"source\\\": \\\"172.17.0.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 2022}, \\\"113 nova_migration_target accept api subnet 172.17.0.0/24\\\": {\\\"source\\\": \\\"172.17.0.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 2022}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::sshd::bannertext\\\": \\\"\\\", \\\"tripleo::profile::base::sshd::motd\\\": \\\"\\\", \\\"tripleo::profile::base::sshd::options\\\": {\\\"HostKey\\\": [\\\"/etc/ssh/ssh_host_rsa_key\\\", \\\"/etc/ssh/ssh_host_ecdsa_key\\\", \\\"/etc/ssh/ssh_host_ed25519_key\\\"], \\\"SyslogFacility\\\": \\\"AUTHPRIV\\\", \\\"AuthorizedKeysFile\\\": \\\".ssh/authorized_keys\\\", \\\"ChallengeResponseAuthentication\\\": \\\"no\\\", \\\"GSSAPIAuthentication\\\": \\\"no\\\", \\\"GSSAPICleanupCredentials\\\": \\\"no\\\", \\\"UsePAM\\\": \\\"yes\\\", \\\"UseDNS\\\": \\\"no\\\", \\\"PrintMotd\\\": \\\"no\\\", \\\"X11Forwarding\\\": \\\"yes\\\", \\\"AcceptEnv\\\": [\\\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\\\", \\\"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\\\", \\\"LC_IDENTIFICATION LC_ALL LANGUAGE\\\", \\\"XMODIFIERS\\\"], \\\"Subsystem\\\": \\\"sftp  /usr/libexec/openssh/sftp-server\\\"}, \\\"tripleo::profile::base::sshd::password_authentication\\\": \\\"yes\\\", \\\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\\\": [\\\"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\\\"], \\\"tripleo::profile::base::nova::migration::target::ssh_localaddrs\\\": [\\\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\\\", \\\"%{hiera(\'live_migration_ssh_inbound_addr\')}\\\"], \\\"live_migration_ssh_inbound_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"cold_migration_ssh_inbound_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::sshd::port\\\": [22]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::sshd\\\\ninclude tripleo::profile::base::nova::migration::target\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova-migration-target.json\\\": {\\\"command\\\": \\\"dumb-init --single-child -- /usr/sbin/sshd -D -p 2022\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/host-ssh/ssh_host_*_key\\\", \\\"dest\\\": \\\"/etc/ssh/\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0600\\\"}]}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"loop\\\": [{\\\"path\\\": \\\"/run/libvirt\\\", \\\"setype\\\": \\\"virt_var_run_t\\\"}]}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}], \\\"docker_config\\\": {\\\"step_4\\\": {\\\"nova_migration_target\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/ssh:/host-ssh:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"validate nova-migration-target container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_migration_target\\\"}, \\\"register\\\": \\\"nova_migration_target_infos\\\", \\\"failed_when\\\": [\\\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 5\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]}, {\\\"service_name\\\": \\\"logrotate_crond\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::logging::logrotate::maxsize\\\": \\\"10M\\\", \\\"tripleo::profile::base::logging::logrotate::rotation\\\": \\\"daily\\\", \\\"tripleo::profile::base::logging::logrotate::rotate\\\": \\\"14\\\", \\\"tripleo::profile::base::logging::logrotate::purge_after_days\\\": \\\"14\\\", \\\"tripleo::profile::base::logging::logrotate::dateext\\\": false}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"allow logrotate to read inside containers\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"logrotate_read_inside_containers\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"configure tmpwatch on the host\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Push script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"mode\\\": 493, \\\"content\\\": \\\"#!/bin/sh\\\\ntmpwatch --nodirs \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*err\\\\\\\" \\\\\\\\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\\\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\\\n\\\"}, \\\"vars\\\": {\\\"LogrotatePurgeAfterDays\\\": \\\"14\\\"}}, {\\\"name\\\": \\\"Insert cronjob in root crontab\\\", \\\"cron\\\": {\\\"name\\\": \\\"Remove old logs\\\", \\\"special_time\\\": \\\"daily\\\", \\\"user\\\": \\\"root\\\", \\\"job\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"crond\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::logrotate\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/logrotate-crond.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -s -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"logrotate_crond\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop logrotate container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"logrotate_crond\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}, {\\\"service_name\\\": \\\"podman\\\", \\\"config_settings\\\": {}, \\\"step_config\\\": \\\"\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Install and configure Podman\\\", \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, [{\\\"name\\\": \\\"Configure tripleo_container_manage to generate systemd drop-in dependencies\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/sysconfig/podman_drop_in\\\", \\\"content\\\": \\\"This file makes tripleo_container_manage generate additional systemd\\\\ndependencies for containers that have special\\\\nstart/stop ordering constraints. It ensures that\\\\nthose constraints are enforced on reboot/shutdown.\\\\n\\\"}}]], \\\"deploy_steps_tasks\\\": [{\\\"when\\\": [\\\"(step|int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"service_config_settings\\\": {}, \\\"workaround_upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"tags\\\": [\\\"setup_packages\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, {\\\"name\\\": \\\"Comment infra_image in container.conf\\\", \\\"lineinfile\\\": {\\\"dest\\\": \\\"/usr/share/containers/containers.conf\\\", \\\"regexp\\\": \\\"(?i)^(infra_image.*)\\\", \\\"line\\\": \\\"#\\\\\\\\1\\\", \\\"backrefs\\\": true, \\\"state\\\": \\\"present\\\"}, \\\"tags\\\": [\\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Force pre-fetch of container images\\\", \\\"when\\\": [\\\"(step|int) == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": \\\"Undercloud\\\"}}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": \\\"Undercloud\\\"}}]}, {\\\"service_name\\\": \\\"rsyslog\\\", \\\"config_settings\\\": {\\\"rsyslog::server::global_config\\\": {\\\"WorkDirectory\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": \\\"/var/lib/rsyslog\\\"}, \\\"MaxMessageSize\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": \\\"32k\\\"}}, \\\"rsyslog::confdir\\\": \\\"/etc/rsyslog.d\\\", \\\"rsyslog::package_name\\\": \\\"rsyslog\\\", \\\"rsyslog::package_version\\\": \\\"installed\\\", \\\"rsyslog::manage_package\\\": true, \\\"rsyslog::manage_confdir\\\": true, \\\"rsyslog::purge_config_files\\\": true, \\\"rsyslog::override_default_config\\\": true, \\\"rsyslog::config_file\\\": \\\"/etc/rsyslog.conf\\\", \\\"rsyslog::manage_service\\\": true, \\\"rsyslog::service_name\\\": \\\"rsyslog\\\", \\\"rsyslog::service_status\\\": \\\"running\\\", \\\"rsyslog::service_enabled\\\": true, \\\"rsyslog::external_service\\\": false, \\\"rsyslog::use_upstream_repo\\\": false, \\\"rsyslog::feature_packages\\\": [\\\"rsyslog-elasticsearch\\\", \\\"rsyslog-mmnormalize\\\"], \\\"rsyslog::global_config_priority\\\": 10, \\\"rsyslog::module_load_priority\\\": 20, \\\"rsyslog::input_priority\\\": 30, \\\"rsyslog::main_queue_priority\\\": 40, \\\"rsyslog::parser_priority\\\": 45, \\\"rsyslog::template_priority\\\": 50, \\\"rsyslog::filter_priority\\\": 55, \\\"rsyslog::action_priority\\\": 60, \\\"rsyslog::ruleset_priority\\\": 65, \\\"rsyslog::lookup_table_priority\\\": 70, \\\"rsyslog::legacy_config_priority\\\": 80, \\\"rsyslog::custom_priority\\\": 90, \\\"rsyslog::target_file\\\": \\\"50_openstack_logs.conf\\\", \\\"rsyslog::server::modules\\\": {\\\"imfile\\\": {}, \\\"omelasticsearch\\\": {}, \\\"omamqp1\\\": {}}, \\\"rsyslog::server::templates\\\": {\\\"rsyslog-node-index\\\": {\\\"type\\\": \\\"list\\\", \\\"list_descriptions\\\": [{\\\"constant\\\": {\\\"value\\\": \\\"%{hiera(\'fqdn_canonical\')}-\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"year\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"month\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"day\\\"}}]}, \\\"rsyslog-record\\\": {\\\"type\\\": \\\"list\\\", \\\"options\\\": {\\\"jsonf\\\": \\\"on\\\"}, \\\"list_descriptions\\\": [{\\\"property\\\": {\\\"outname\\\": \\\"@timestamp\\\", \\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"rfc3339\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"host\\\", \\\"name\\\": \\\"hostname\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"severity\\\", \\\"name\\\": \\\"syslogseverity\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"facility\\\", \\\"name\\\": \\\"syslogfacility-text\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"tag\\\", \\\"name\\\": \\\"syslogtag\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"source\\\", \\\"name\\\": \\\"app-name\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"message\\\", \\\"name\\\": \\\"msg\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"file\\\", \\\"name\\\": \\\"$!metadata!filename\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"cloud\\\", \\\"value\\\": \\\"overcloud.ooo.test\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"region\\\", \\\"value\\\": \\\"regionOne\\\", \\\"format\\\": \\\"jsonf\\\"}}]}}, \\\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\\\": \\\"on\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rsyslog\\\", \\\"puppet_tags\\\": \\\"rsyslog::generate_concat,concat::fragment\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::rsyslog\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rsyslog.json\\\": {\\\"command\\\": \\\"/usr/sbin/rsyslogd -n -iNONE\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"rsyslog\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:ro\\\", \\\"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\\\", \\\"/var/log:/var/log/host:ro\\\", \\\"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/log/containers/rsyslog\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}}, {\\\"name\\\": \\\"create persistent state directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/rsyslog.container\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}]}, {\\\"service_name\\\": \\\"snmp\\\", \\\"firewall_rules\\\": {\\\"124 snmp 192.168.122.0/24\\\": {\\\"dport\\\": 161, \\\"proto\\\": \\\"udp\\\", \\\"source\\\": \\\"192.168.122.0/24\\\"}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::snmp::snmpd_user\\\": \\\"ro_snmp_user\\\", \\\"tripleo::profile::base::snmp::snmpd_password\\\": \\\"Gw7UKk275edaf1BK4QNxasIq\\\", \\\"snmp::agentaddress\\\": [\\\"udp:161\\\", \\\"udp6:[::1]:161\\\"], \\\"snmp::snmpd_options\\\": \\\"-LS0-5d\\\"}, \\\"step_config\\\": \\\"include tripleo::profile::base::snmp\\\\n\\\", \\\"upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check if snmpd is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet snmpd\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"snmpd_enabled_result\\\"}, {\\\"name\\\": \\\"Set fact snmpd_enabled\\\", \\\"set_fact\\\": {\\\"snmpd_enabled\\\": \\\"{{ snmpd_enabled_result.rc == 0 }}\\\"}}]}, {\\\"name\\\": \\\"Stop snmp service\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"snmpd_enabled|bool\\\"], \\\"service\\\": \\\"name=snmpd state=stopped\\\"}]}, {\\\"service_name\\\": \\\"sshd\\\", \\\"firewall_rules\\\": {\\\"003 accept ssh from all\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22, \\\"extras\\\": {\\\"ensure\\\": \\\"present\\\"}}}, \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_sshd\\\"}, \\\"vars\\\": {\\\"tripleo_sshd_server_options\\\": {\\\"HostKey\\\": [\\\"/etc/ssh/ssh_host_rsa_key\\\", \\\"/etc/ssh/ssh_host_ecdsa_key\\\", \\\"/etc/ssh/ssh_host_ed25519_key\\\"], \\\"SyslogFacility\\\": \\\"AUTHPRIV\\\", \\\"AuthorizedKeysFile\\\": \\\".ssh/authorized_keys\\\", \\\"ChallengeResponseAuthentication\\\": \\\"no\\\", \\\"GSSAPIAuthentication\\\": \\\"no\\\", \\\"GSSAPICleanupCredentials\\\": \\\"no\\\", \\\"UsePAM\\\": \\\"yes\\\", \\\"UseDNS\\\": \\\"no\\\", \\\"PrintMotd\\\": \\\"no\\\", \\\"X11Forwarding\\\": \\\"yes\\\", \\\"AcceptEnv\\\": [\\\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\\\", \\\"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\\\", \\\"LC_IDENTIFICATION LC_ALL LANGUAGE\\\", \\\"XMODIFIERS\\\"], \\\"Subsystem\\\": \\\"sftp  /usr/libexec/openssh/sftp-server\\\"}, \\\"tripleo_sshd_password_authentication\\\": \\\"yes\\\", \\\"tripleo_sshd_banner_enabled\\\": false, \\\"tripleo_sshd_banner_text\\\": \\\"\\\", \\\"tripleo_sshd_motd_enabled\\\": false, \\\"tripleo_sshd_message_of_the_day\\\": \\\"\\\"}}]}, {\\\"service_name\\\": \\\"chrony\\\", \\\"firewall_rules\\\": {\\\"105 ntp\\\": {\\\"dport\\\": 123, \\\"proto\\\": \\\"udp\\\"}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Check for NTP service\\\", \\\"shell\\\": \\\"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\\\", \\\"failed_when\\\": false, \\\"become\\\": true, \\\"register\\\": \\\"ntp_service_check\\\"}, {\\\"name\\\": \\\"Disable NTP before configuring Chrony\\\", \\\"service\\\": {\\\"name\\\": \\\"ntpd\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"when\\\": [\\\"ntp_service_check.rc is defined\\\", \\\"ntp_service_check.rc == 0\\\"]}, {\\\"name\\\": \\\"Install, Configure and Run Chrony\\\", \\\"include_role\\\": {\\\"name\\\": \\\"chrony\\\"}}, {\\\"name\\\": \\\"Force NTP sync\\\", \\\"command\\\": \\\"chronyc makestep\\\"}, {\\\"name\\\": \\\"Ensure system is NTP time synced\\\", \\\"command\\\": \\\"chronyc waitsync 30\\\"}], \\\"ansible_group_vars\\\": {\\\"chrony_role_action\\\": \\\"all\\\", \\\"chrony_ntp_servers\\\": [\\\"pool.ntp.org\\\"], \\\"chrony_ntp_pools\\\": [], \\\"chrony_global_server_settings\\\": \\\"iburst minpoll 6 maxpoll 10\\\", \\\"chrony_global_pool_settings\\\": \\\"iburst minpoll 6 maxpoll 10\\\", \\\"chrony_manage_package\\\": true, \\\"chrony_acl_rules\\\": [\\\"deny all\\\"]}}, {\\\"service_name\\\": \\\"timezone\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Run timezone role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_timezone\\\"}, \\\"vars\\\": {\\\"tripleo_timezone\\\": \\\"UTC\\\"}}]}, {\\\"service_name\\\": \\\"tripleo_firewall\\\", \\\"config_settings\\\": {\\\"tripleo::firewall::manage_firewall\\\": false, \\\"tripleo::firewall::purge_firewall_rules\\\": false}, \\\"ansible_group_vars\\\": {\\\"tripleo_nftables_debug\\\": true}, \\\"firewall_rules\\\": {\\\"003 accept ssh from ctlplane subnet 192.168.122.0/24\\\": {\\\"source\\\": \\\"192.168.122.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Notice - ctlplane subnet is set\\\", \\\"debug\\\": {\\\"msg\\\": \\\"CIDRs found in the ctlplane network tags.\\\\n\\\"}}], \\\"host_firewall_tasks\\\": [{\\\"name\\\": \\\"Run firewall role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_firewall\\\"}}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}, {\\\"when\\\": [\\\"(step | int) == 3\\\"], \\\"block\\\": [{\\\"name\\\": \\\"blank ipv6 rule before activating ipv6 firewall.\\\", \\\"shell\\\": \\\"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\\\", \\\"args\\\": {\\\"creates\\\": \\\"/etc/sysconfig/ip6tables.n-o-upgrade\\\"}}, {\\\"name\\\": \\\"cleanup unmanaged rules pushed by iptables-services\\\", \\\"shell\\\": \\\"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\n\\\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -d fe80::\\\\\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\"}]}]}, {\\\"service_name\\\": \\\"tripleo_packages\\\", \\\"config_settings\\\": {\\\"tripleo::packages::enable_install\\\": true}, \\\"step_config\\\": \\\"include ::tripleo::packages\\\\n\\\", \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Gather missing facts\\\", \\\"setup\\\": {\\\"gather_subset\\\": [\\\"!all\\\", \\\"!min\\\", \\\"distribution\\\"]}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"Set leapp facts\\\", \\\"set_fact\\\": {\\\"upgrade_leapp_enabled\\\": \\\"{{ _upgradeLeappEnabled | bool and\\\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\\\", \\\"upgrade_leapp_debug\\\": false, \\\"upgrade_leapp_devel_skip\\\": \\\"\\\", \\\"upgrade_leapp_command_options\\\": \\\"\\\", \\\"upgrade_leapp_reboot_timeout\\\": 3600, \\\"upgrade_leapp_post_reboot_delay\\\": 120}, \\\"vars\\\": {\\\"_upgradeLeappEnabled\\\": false}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"system_upgrade_prepare step 3\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappRepoInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Remove firewalld bindings\\\", \\\"package\\\": {\\\"name\\\": \\\"python3-firewall\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"install leapp\\\", \\\"package\\\": {\\\"name\\\": \\\"leapp-repository-openstack\\\", \\\"state\\\": \\\"latest\\\"}}, {\\\"name\\\": \\\"Run LeappInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Remove vdo\\\", \\\"package\\\": {\\\"name\\\": \\\"vdo\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"add packages into Leapp\'s to_remove file\\\", \\\"vars\\\": {\\\"pkg_to_remove\\\": []}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_remove\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_remove }}\\\"}, {\\\"name\\\": \\\"add packages into Leapp\'s to_install file\\\", \\\"vars\\\": {\\\"pkg_to_install\\\": []}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_install\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_install }}\\\"}, {\\\"name\\\": \\\"check sshd_config file\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\"}, \\\"register\\\": \\\"sshd_config_result\\\"}, {\\\"name\\\": \\\"add PermitRootLogin option for leapp\\\", \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\", \\\"regexp\\\": \\\"^(# *)?PermitRootLogin\\\", \\\"line\\\": \\\"PermitRootLogin without-password\\\"}}, {\\\"name\\\": \\\"Remove paunch-services\\\", \\\"package\\\": {\\\"name\\\": \\\"paunch-services\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"tripleo_container_manage reconfiguration\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_manage\\\", \\\"tasks_from\\\": \\\"shutdown.yml\\\"}}]}, {\\\"name\\\": \\\"system_upgrade_prepare step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\\\", \\\"vars\\\": {\\\"modules_to_unload\\\": []}, \\\"shell\\\": \\\"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\\\\\"{{ item }}\\\\\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\\\n\\\", \\\"loop\\\": \\\"{{ modules_to_unload }}\\\"}, {\\\"name\\\": \\\"Remove leapp actors to prevent them inhibiting the upgrade\\\", \\\"vars\\\": {\\\"actors_to_remove\\\": []}, \\\"command\\\": {\\\"cmd\\\": \\\"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\\\\\"{}\\\\\\\" +\\\"}, \\\"loop\\\": \\\"{{ actors_to_remove }}\\\"}, {\\\"name\\\": \\\"set leapp required answers\\\", \\\"shell\\\": \\\"leapp answer --add --section check_vdo.confirm=True\\\\n\\\"}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}, {\\\"name\\\": \\\"Keep nics with prefix in NICsPrefixesToUdev from renaming\\\", \\\"vars\\\": {\\\"nics_prefixes_to_keep\\\": []}, \\\"shell\\\": \\\"ip -j link show | \\\\\\\\ jq -r --arg prefix \\\\\\\"{{ item }}\\\\\\\" \'.[] |\\\\n  select((.ifname | startswith($prefix)) and\\\\n  (.ifname | test(\\\\\\\"^.*v[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*_[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*\\\\\\\\\\\\\\\\..*$\\\\\\\") | not)) |\\\\n  if .permaddr? then .address=.permaddr else . end |\\\\n  \\\\\\\"SUBSYSTEM==\\\\\\\\\\\\\\\"net\\\\\\\\\\\\\\\",ACTION==\\\\\\\\\\\\\\\"add\\\\\\\\\\\\\\\",DRIVERS==\\\\\\\\\\\\\\\"?*\\\\\\\\\\\\\\\",\\\\\\\" + \\\\\\\"NAME=\\\\\\\\\\\\\\\"\\\\\\\" + .ifname +\\\\\\\"\\\\\\\\\\\\\\\" ,ATTR{address}==\\\\\\\\\\\\\\\"\\\\\\\" + .address + \\\\\\\"\\\\\\\\\\\\\\\"\\\\\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\\\n\\\", \\\"loop\\\": \\\"{{ nics_prefixes_to_keep|list }}\\\"}, {\\\"name\\\": \\\"run leapp upgrade (download packages)\\\", \\\"shell\\\": \\\"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\\\n\\\", \\\"when\\\": \\\"upgrade_leapp_enabled\\\"}]}, {\\\"name\\\": \\\"system_upgrade_run step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_reboot\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\", \\\"\'Undercloud\' not in group_names\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappPreRebootCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Check that nova_libvirt is running\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"is_virtlogd_image_running\\\"}, {\\\"name\\\": \\\"Remove systemd files to disable them\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/{{ item }}\\\", \\\"state\\\": \\\"absent\\\"}, \\\"with_items\\\": [\\\"tripleo_nova_libvirt.service\\\", \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_libvirt.target\\\"], \\\"when\\\": \\\"is_virtlogd_image_running.stdout != \'\'\\\"}, {\\\"name\\\": \\\"reboot to perform the upgrade\\\", \\\"reboot\\\": {\\\"reboot_timeout\\\": \\\"{{upgrade_leapp_reboot_timeout}}\\\", \\\"test_command\\\": \\\"source /etc/os-release; [ \\\\\\\"${VERSION_ID%.*}\\\\\\\" -ge \\\\\\\"8\\\\\\\" ] && systemctl is-system-running | grep -qE \\\\\\\"running|degraded\\\\\\\" || exit 1\\\", \\\"post_reboot_delay\\\": \\\"{{ upgrade_leapp_post_reboot_delay }}\\\"}}, {\\\"name\\\": \\\"Set selinux back to enforcing after leapp reboot\\\", \\\"selinux\\\": {\\\"policy\\\": \\\"targeted\\\", \\\"state\\\": \\\"enforcing\\\"}}, {\\\"name\\\": \\\"Run LeappPostRebootCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}]}, {\\\"name\\\": \\\"Host packages setup step0\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Package and repo update tasks\\\", \\\"block\\\": [{\\\"name\\\": \\\"Run UpgradeInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\nif [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Run UpgradeInitCommonCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": []}, \\\"dnf\\\": {\\\"name\\\": \\\"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed\\\", \\\"package\\\": {\\\"name\\\": [\\\"jq\\\", \\\"lvm2\\\", \\\"openstack-selinux\\\", \\\"os-net-config\\\", \\\"puppet-tripleo\\\", \\\"python3-heat-agent*\\\", \\\"rsync\\\"], \\\"state\\\": \\\"present\\\"}, \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\\\", \\\"vars\\\": {\\\"base_tripleo_packages\\\": []}, \\\"package\\\": {\\\"name\\\": \\\"{{ base_tripleo_packages }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\", \\\"base_tripleo_packages|length > 0\\\"]}, {\\\"name\\\": \\\"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\\\", \\\"shell\\\": \\\"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\\\ndo\\\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\\\\\"signatures\\\\\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\\\ndone\\\\n\\\", \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}]}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"loop\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": [\\\"libvirt_installed.rc == 0\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step2\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_upgrade.changed|bool\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step3\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for os-net-config upgrade\\\", \\\"shell\\\": \\\"yum check-upgrade | awk \'/os-net-config/{print}\'\\\", \\\"register\\\": \\\"os_net_config_need_upgrade\\\"}, {\\\"name\\\": \\\"Check that os-net-config has legacy configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.json\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_json\\\"}, {\\\"name\\\": \\\"Check that os-net-config has new configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.yaml\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_yaml\\\"}, {\\\"name\\\": \\\"Slurp the os-net-config config.json\\\", \\\"slurp\\\": {\\\"src\\\": \\\"/etc/os-net-config/config.json\\\"}, \\\"register\\\": \\\"os_config_json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Write updated /etc/os-net-config/config.yaml\\\", \\\"copy\\\": {\\\"content\\\": \\\"{{ os_config_json.content | b64decode | from_json | to_yaml }}\\\", \\\"dest\\\": \\\"/etc/os-net-config/config.yaml\\\"}, \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Remove legacy os-net-config configuration\\\", \\\"command\\\": \\\"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\"]}, {\\\"block\\\": [{\\\"name\\\": \\\"Upgrade os-net-config\\\", \\\"package\\\": \\\"name=os-net-config state=latest\\\"}, {\\\"name\\\": \\\"take new os-net-config parameters into account now\\\", \\\"command\\\": \\\"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\\\", \\\"register\\\": \\\"os_net_config_upgrade\\\", \\\"failed_when\\\": \\\"os_net_config_upgrade.rc not in [0,2]\\\", \\\"changed_when\\\": \\\"os_net_config_upgrade.rc == 2\\\"}], \\\"when\\\": [\\\"os_net_config_need_upgrade.stdout\\\", \\\"stat_config_yaml.stat.exists or stat_config_json.stat.exists\\\"]}, {\\\"name\\\": \\\"Update all packages\\\", \\\"when\\\": [\\\"not skip_package_update|bool\\\"], \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}, \\\"vars\\\": {\\\"skip_package_update\\\": false}}, {\\\"name\\\": \\\"Check whether openvswitch exits\\\", \\\"command\\\": \\\"systemctl status openvswitch.service\\\", \\\"register\\\": \\\"ovs_service\\\", \\\"ignore_errors\\\": true}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_service.stderr != \\\\\\\"Unit openvswitch.service could not be found.\\\\\\\"\\\"]}]}], \\\"external_upgrade_tasks\\\": [{\\\"name\\\": \\\"Clean up upgrade artifacts\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_cleanup\\\"], \\\"block\\\": [{\\\"name\\\": \\\"cleanup tripleo_persist\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_persist\\\", \\\"tasks_from\\\": \\\"cleanup.yml\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Enforce RHOSP rules regarding subscription.\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_redhat_enforce\\\"}, \\\"vars\\\": {\\\"skip_rhel_enforcement\\\": false}, \\\"when\\\": [\\\"step|int == 0\\\", \\\"ansible_facts[\'distribution\'] == \'RedHat\'\\\", \\\"not (skip_rhel_enforcement | bool)\\\"]}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream enabled\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": []}, \\\"tripleo_dnf_stream\\\": {\\\"name\\\": \\\"{{ item.module }}:{{ item.stream }}\\\", \\\"state\\\": \\\"enabled\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Check for existing yum.pid\\\", \\\"stat\\\": \\\"path=/run/yum.pid\\\", \\\"register\\\": \\\"yum_pid_file\\\", \\\"when\\\": \\\"step|int == 0 or step|int == 3\\\"}, {\\\"name\\\": \\\"Exit if existing yum process\\\", \\\"fail\\\": \\\"msg=\\\\\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\\\\\"\\\", \\\"when\\\": \\\"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\\\"}, {\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"when\\\": [\\\"step|int == 2\\\"], \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"step|int == 2\\\", \\\"ovs_upgrade.changed|bool\\\"]}, {\\\"name\\\": \\\"Update packages and EFI grub.cfg\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"not skip_package_update|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update all packages\\\", \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}], \\\"vars\\\": {\\\"skip_package_update\\\": false}}, {\\\"name\\\": \\\"Ensure openvswitch is running after update\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"ignore_errors\\\": true}]}, {\\\"service_name\\\": \\\"tuned\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}}], \\\"ansible_group_vars\\\": {\\\"tuned_profile\\\": \\\"throughput-performance\\\", \\\"tuned_custom_profile\\\": \\\"\\\"}}, {\\\"service_name\\\": \\\"ovn_controller\\\", \\\"firewall_rules\\\": {\\\"118 neutron vxlan networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 4789, \\\"state\\\": []}, \\\"119 neutron geneve networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"state\\\": []}, \\\"120 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"OUTPUT\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}, \\\"121 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"PREROUTING\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}}, \\\"config_settings\\\": {\\\"ovn::controller::ovn_bridge_mappings\\\": [\\\"datacentre:br-ex\\\"], \\\"ovn::controller::ovn_cms_options\\\": \\\"\\\", \\\"ovn::controller::ovn_encap_tos\\\": \\\"0\\\", \\\"vswitch::ovs::enable_hw_offload\\\": false, \\\"container_cpuset_cpus\\\": \\\"\\\", \\\"ContainerOvnControllerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ContainerOvnControllerConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ovn::southbound::port\\\": 6642, \\\"ovn::controller::ovn_encap_ip\\\": \\\"%{hiera(\'tenant\')}\\\", \\\"ovn::controller::ovn_encap_type\\\": \\\"geneve\\\", \\\"ovn::controller::ovn_bridge\\\": \\\"br-int\\\", \\\"ovn::controller::hostname\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ovn::controller::ovn_remote_probe_interval\\\": 60000, \\\"ovn::controller::ovn_openflow_probe_interval\\\": 60, \\\"ovn::controller::ovn_ofctrl_wait_before_clear\\\": 8000, \\\"ovn::controller::garp_max_timeout_sec\\\": 0, \\\"ovn::controller::ovn_monitor_all\\\": true, \\\"tripleo::profile::base::neutron::agents::ovn::protocol\\\": \\\"ssl\\\"}, \\\"service_config_settings\\\": {}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"vs_config,exec\\\", \\\"config_volume\\\": \\\"ovn_controller\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::agents::ovn\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/etc/sysconfig/modules:/etc/sysconfig/modules\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_controller.json\\\": {\\\"command\\\": \\\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock -p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C /etc/ipa/ca.crt\\\", \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/openvswitch\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/ovn\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"ovn_controller\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"docker_config\\\": {\\\"step_4\\\": {\\\"configure_cms_options\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\\\\\"$CMS_OPTS\\\\\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781078317\\\"}}, \\\"ovn_controller\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"openvswitch.service\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck 6642\\\"}, \\\"volumes\\\": [\\\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/var/lib/openvswitch/ovn:/run/ovn:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/openvswitch:z\\\", \\\"/var/log/containers/openvswitch:/var/log/ovn:z\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\\\", \\\"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_controller\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"ovn_controller/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_controller\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/openvswitch\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/openvswitch/ovn\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Copy in cleanup script\\\", \\\"copy\\\": {\\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Cleanup neutron OVS bridges. To be called on startup to avoid\\\\n# \\\\\\\"difficult-to-debug\\\\\\\" issues with partially configured resources.\\\\n\\\\nNEUTRON_OVS_CONF=/var/lib/config-data/puppet-generated/neutron/etc/neutron/plugins/ml2/openvswitch_agent.ini\\\\n\\\\nif [ -e ${NEUTRON_OVS_CONF} ];\\\\nthen\\\\n    INT_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs integration_bridge`\\\\n    TUN_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs tunnel_bridge`\\\\nfi\\\\n\\\\nfor port in `ovs-vsctl list-ports ${INT_BRIDGE:-\\\\\\\"br-int\\\\\\\"}`;\\\\ndo\\\\n    skip_cleanup=`ovs-vsctl --if-exists get Interface $port external_ids:skip_cleanup`\\\\n    if ! [[ \\\\\\\"x$skip_cleanup\\\\\\\" == \\\\\\\"x\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\" ]];\\\\n    then\\\\n        ovs-vsctl del-port ${INT_BRIDGE:-\\\\\\\"br-int\\\\\\\"} $port\\\\n    fi\\\\ndone\\\\n\\\\novs-vsctl --if-exists del-br ${TUN_BRIDGE:-\\\\\\\"br-tun\\\\\\\"}\\\\n\\\\n# Clean up trunk port bridges\\\\nfor br in $(ovs-vsctl list-br | egrep \'tbr-[0-9a-f\\\\\\\\-]+\'); do\\\\n    ovs-vsctl --if-exists del-br $br\\\\ndone\\\\n\\\", \\\"dest\\\": \\\"/usr/libexec/neutron-cleanup\\\", \\\"force\\\": true, \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"Copy in cleanup service\\\", \\\"copy\\\": {\\\"content\\\": \\\"[Unit]\\\\nDescription=Neutron cleanup on startup\\\\nAfter=openvswitch.service network.target\\\\nBefore=tripleo_neutron_ovs_agent.service tripleo_neutron_dhcp.service tripleo_neutron_l3_agent.service tripleo_nova_compute.service\\\\nRefuseManualStop=yes\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/libexec/neutron-cleanup\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\", \\\"dest\\\": \\\"/usr/lib/systemd/system/neutron-cleanup.service\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Enabling the cleanup service\\\", \\\"service\\\": {\\\"name\\\": \\\"neutron-cleanup\\\", \\\"enabled\\\": true}, \\\"when\\\": \\\"not (ansible_check_mode|bool)\\\"}], \\\"external_deploy_tasks\\\": [{\\\"when\\\": [\\\"step|int == 0\\\"], \\\"name\\\": \\\"ovn_controller_external_deploy_init\\\", \\\"block\\\": [{\\\"name\\\": \\\"create ovn mac address for Compute role nodes\\\", \\\"tripleo_ovn_mac_addresses\\\": {\\\"playbook_dir\\\": \\\"{{ playbook_dir }}\\\", \\\"stack_name\\\": \\\"overcloud\\\", \\\"role_name\\\": \\\"Compute\\\", \\\"server_resource_names\\\": \\\"{{ groups[\\\\\\\"Compute\\\\\\\"] }}\\\", \\\"ovn_bridge_mappings\\\": [\\\"datacentre:br-ex\\\"], \\\"ovn_static_bridge_mac_mappings\\\": {}}}]}], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_controller image pull successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_image_update\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"OVN Container image used\\\", \\\"debug\\\": {\\\"msg\\\": \\\"ovn container will be using {{ image }}\\\"}, \\\"vars\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"vars\\\": {\\\"timeout\\\": 8000}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovs_vsctl\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Was the update of OVN OVS related parameter successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovs_vsctl\\\"], \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\"], \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovs_vsctl.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"set_fact\\\": {\\\"any_ovn_host\\\": \\\"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\\\"}, \\\"tags\\\": \\\"ovn\\\", \\\"when\\\": \\\"step|int == 1\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"delegate_to\\\": \\\"{{ any_ovn_host }}\\\", \\\"when\\\": \\\"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\\\", \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\", \\\"query\\\": \\\"results[?item == \'{{item}}\'].stdout\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_update\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"conmon_pidfile\\\": \\\"{{ pidfile | json_query(query) | first }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Was the ovn_controller successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_update\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Fetch running ovn_controller image\\\", \\\"shell\\\": \\\"set -e\\\\npodman inspect --format \\\\\\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\\\\\" ovn_controller\\\\n\\\", \\\"register\\\": \\\"running_ovn_image\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"]}, {\\\"name\\\": \\\"Run ovn_controller upgrade\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"vars\\\": {\\\"ovn_controller_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\"}, \\\"when\\\": [\\\"step|int == 4\\\", \\\"running_ovn_image.stdout != ovn_controller_image\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"vars\\\": {\\\"timeout\\\": 8000}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"]}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"conmon_pidfile\\\": \\\"{{ pidfile.stdout }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}]}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": \\\"overcloud\\\"}, \\\"block\\\": [{\\\"name\\\": \\\"Get neutron agents ID\\\", \\\"command\\\": \\\"openstack network agent list --column ID --column Host --column Binary --format yaml\\\", \\\"register\\\": \\\"neutron_agents_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"Filter only current host\\\", \\\"set_fact\\\": {\\\"neutron_agents\\\": \\\"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Deleting OVN agents\\\", \\\"block\\\": [{\\\"name\\\": \\\"Stop OVN containers\\\", \\\"loop\\\": [\\\"tripleo_ovn_controller\\\", \\\"tripleo_ovn_metadata_agent\\\"], \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_containers\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete neutron agents\\\", \\\"loop\\\": \\\"{{ neutron_agents }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"agent\\\", \\\"label\\\": \\\"{{ agent.Host }}/{{ agent.Binary }}\\\"}, \\\"command\\\": \\\"openstack network agent delete {{ agent.ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}, {\\\"service_name\\\": \\\"ovn_metadata\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ovn-metadata\\\", \\\"config_settings\\\": {\\\"neutron::notification_driver\\\": [\\\"noop\\\"], \\\"neutron::core_plugin\\\": \\\"ml2\\\", \\\"neutron::service_plugins\\\": [\\\"qos\\\", \\\"ovn-router\\\", \\\"trunk\\\", \\\"segments\\\", \\\"port_forwarding\\\", \\\"log\\\"], \\\"neutron::report_interval\\\": 300, \\\"neutron::logging::debug\\\": true, \\\"neutron::purge_config\\\": false, \\\"neutron::allow_overlapping_ips\\\": true, \\\"neutron::dhcp_agent_notification\\\": false, \\\"neutron::dns_domain\\\": \\\"ooo.test\\\", \\\"neutron::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"neutron::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"neutron::db::database_db_max_retries\\\": -1, \\\"neutron::db::database_max_retries\\\": -1, \\\"neutron::db::sync::db_sync_timeout\\\": 900, \\\"neutron::global_physnet_mtu\\\": 1350, \\\"neutron::db::sync::extra_params\\\": \\\"\\\", \\\"neutron::vlan_transparent\\\": false, \\\"neutron::rabbit_heartbeat_in_pthread\\\": false, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\\\": true, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\\\": \\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper\\\", \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\\\": true, \\\"tripleo::profile::base::neutron::container_cli\\\": \\\"podman\\\", \\\"neutron::agents::ovn_metadata::shared_secret\\\": \\\"0L1TuMmYu9cXN2twLue5RLHjS\\\", \\\"neutron::agents::ovn_metadata::auth_password\\\": \\\"V6qvOdr4xOrW2qdKJR3d8Svn0\\\", \\\"neutron::agents::ovn_metadata::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"neutron::agents::ovn_metadata::auth_tenant\\\": \\\"service\\\", \\\"neutron::agents::ovn_metadata::metadata_host\\\": \\\"overcloud.internalapi.ooo.test\\\", \\\"neutron::agents::ovn_metadata::ovsdb_connection_timeout\\\": 180, \\\"neutron::agents::ovn_metadata::ovsdb_probe_interval\\\": 60000, \\\"neutron::agents::ovn_metadata::hwol_qos_enabled\\\": false, \\\"ovn::northbound::port\\\": 6641, \\\"ovn::southbound::port\\\": 6642, \\\"neutron::agents::ovn_metadata::debug\\\": true, \\\"neutron::agents::ovn_metadata::metadata_protocol\\\": \\\"https\\\", \\\"neutron::agents::ovn_metadata::metadata_workers\\\": \\\"1\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::protocol\\\": \\\"ssl\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\"}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"neutron_config,ovn_metadata_agent_config\\\", \\\"config_volume\\\": \\\"neutron\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::ovn_metadata\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\\\", \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_metadata_agent.json\\\": {\\\"command\\\": \\\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini --log-file=/var/log/neutron/ovn-metadata-agent.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"create_haproxy_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\"]}}, \\\"step_4\\\": {\\\"setup_ovs_manager\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"exec\\\", \\\"include tripleo::profile::base::neutron::ovn_metadata\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1781078317\\\"}}, \\\"ovn_metadata_agent\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"cgroupns\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/neutron:/var/log/neutron:z\\\", \\\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\", \\\"/run/netns:/run/netns:shared\\\", \\\"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\\\", \\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\\\", \\\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"ovn_metadata\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_metadata\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"ovn_metadata/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_metadata_agent\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/neutron\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"create /run/netns with temp namespace\\\", \\\"command\\\": \\\"ip netns add ns_temp\\\", \\\"register\\\": \\\"ipnetns_add_result\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"remove temp namespace\\\", \\\"command\\\": \\\"ip netns delete ns_temp\\\", \\\"failed_when\\\": false, \\\"when\\\": [\\\"ipnetns_add_result.rc is defined\\\", \\\"ipnetns_add_result.rc == 0\\\"]}, {\\\"name\\\": \\\"create /var/lib/neutron\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}, {\\\"name\\\": \\\"set conditions\\\", \\\"set_fact\\\": {\\\"haproxy_wrapper_enabled\\\": true, \\\"debug_enabled\\\": true, \\\"docker_additional_sockets\\\": [\\\"/var/lib/openstack/docker.sock\\\"]}}, {\\\"name\\\": \\\"create kill_scripts directory within /var/lib/neutron\\\", \\\"file\\\": {\\\"state\\\": \\\"directory\\\", \\\"path\\\": \\\"/var/lib/neutron/kill_scripts\\\"}}, {\\\"name\\\": \\\"create haproxy kill script\\\", \\\"when\\\": \\\"haproxy_wrapper_enabled|bool\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/var/lib/neutron/kill_scripts/haproxy-kill\\\", \\\"mode\\\": 493, \\\"content\\\": \\\"#!/bin/bash\\\\n{% if debug_enabled|bool -%}\\\\nset -x\\\\n{% endif -%}\\\\nadd_date() {\\\\n  echo \\\\\\\"$(date) $@\\\\\\\"\\\\n}\\\\n\\\\n# Set up script logging for debugging purpose.\\\\n# It will be taken care of by logrotate since there is the .log\\\\n# suffix.\\\\nexec 3>&1 4>&2\\\\ntrap \'exec 2>&4 1>&3\' 0 1 2 3\\\\nexec 1>>/var/log/neutron/kill-script.log 2>&1\\\\n\\\\nSIG=$1\\\\nPID=$2\\\\nNETNS=$(ip netns identify ${PID})\\\\n\\\\nif [ \\\\\\\"x${NETNS}\\\\\\\" == \\\\\\\"x\\\\\\\" ]; then\\\\n  CLI=\\\\\\\"nsenter --all --preserve-credentials -t 1 podman\\\\\\\"\\\\n  SIG=9\\\\nelse\\\\n  CLI=\\\\\\\"nsenter --net=/run/netns/${NETNS} --preserve-credentials -m -t 1 podman\\\\\\\"\\\\nfi\\\\n\\\\nkill_container() {\\\\n  add_date \\\\\\\"Killing container $1 ($2)\\\\\\\"\\\\n  signal_container $1 $2 9\\\\n}\\\\n\\\\nstop_container() {\\\\n  add_date \\\\\\\"Stopping container $1 ($2)\\\\\\\"\\\\n  $CLI stop $2\\\\n}\\\\n\\\\nsignal_container() {\\\\n  SIGNAL=$3\\\\n  if [ -z \\\\\\\"$SIGNAL\\\\\\\" ]; then\\\\n      SIGNAL=\\\\\\\"HUP\\\\\\\"\\\\n  fi\\\\n  add_date \\\\\\\"Sending signal \'$SIGNAL\' to $1 ($2)\\\\\\\"\\\\n  $CLI kill --signal $SIGNAL $2\\\\n}\\\\n\\\\ndelete_container() {\\\\n  add_date \\\\\\\"Deleting container $1 ($2)\\\\\\\"\\\\n  $CLI rm $2 || echo \\\\\\\"Deleting container $1 ($2) failed\\\\\\\"\\\\n}\\\\n\\\\n\\\\n{% raw -%}\\\\nif [ -f /proc/$PID/cgroup ]; then\\\\n  # Get container ID based on process cgroups\\\\n  CT_ID=$(awk \'BEGIN {FS=\\\\\\\".scope|-\\\\\\\"} /\\\\\\\\/libpod-/ {if ($(NF-1)) print $(NF-1);exit}\' /proc/$PID/cgroup)\\\\n  CT_NAME=$($CLI inspect -f \'{{.Name}}\' $CT_ID)\\\\n\\\\n  case $SIG in\\\\n    HUP)\\\\n      signal_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    9)\\\\n      kill_container $CT_NAME $CT_ID\\\\n      delete_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    15)\\\\n      stop_container $CT_NAME $CT_ID\\\\n      delete_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    *)\\\\n      add_date \\\\\\\"Unknown action ${SIG} for ${CT_NAME} ${CT_ID}\\\\\\\"\\\\n      exit 1\\\\n      ;;\\\\n  esac\\\\n\\\\nelse\\\\n  add_date \\\\\\\"No such PID: ${PID}\\\\\\\"\\\\n  exit 1\\\\nfi\\\\n{% endraw %}\\\\n\\\"}}], \\\"upgrade_tasks\\\": [], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Check if python3-openvswitch3.1 workaround is needed\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\\\n\\\", \\\"register\\\": \\\"metadata_python_ovs_3_1\\\", \\\"failed_when\\\": false, \\\"loop\\\": \\\"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}, {\\\"name\\\": \\\"Update ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_metadata_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_metadata_agent image pull successful.\\\", \\\"when\\\": [\\\"\'results\' in ovn_metadata_image_update\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_metadata_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"tags\\\": [\\\"ovn_metadata_parallel\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0}]}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"never\\\", \\\"ovn_metadata_serial\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"loop_control\\\": {\\\"pause\\\": 1}}]}]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(196,'2026-06-10 07:59:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(197,'2026-06-10 07:59:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(198,'2026-06-10 07:59:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat CloudWatch API service, disabled by default since Pike\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the disabled Heat CloudWatch API\", \"value\": {\"service_name\": \"heat_api_cloudwatch_disabled\", \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (199,'2026-06-10 07:59:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Add services and subhosts to IPA server\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"PythonInterpreter\": {\"type\": \"string\", \"description\": \"The python interpreter to use for python and ansible actions\", \"default\": \"$(command -v python3 || command -v python)\"}, \"IdMDomain\": {\"default\": \"ooo.test\", \"description\": \"IDM domain to register IDM client. Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"string\"}, \"IdMServer\": {\"default\": \"ipa.ooo.test\", \"description\": \"FQDN for the FreeIPA server.  If you set this value, IdMDomain also has to be provided.  Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"comma_delimited_list\"}, \"IdMNovaKeytab\": {\"default\": \"FILE:/etc/novajoin/krb5.keytab\", \"description\": \"keytab for the nova/[host fqdn] user on the FreeIPA server.\", \"type\": \"string\"}, \"IdMNovaCredentialCache\": {\"default\": \"/etc/novajoin/krb5.cache\", \"description\": \"credential cache for nova/[host fqdn] user\", \"type\": \"string\"}, \"MakeHomeDir\": {\"type\": \"boolean\", \"description\": \"Configure PAM to create a users home directory if it does not exist.\", \"default\": false}, \"IdMNoNtpSetup\": {\"default\": false, \"description\": \"Set to true to add --no-ntp to the IDM client install call. This will cause IDM client install not to set up NTP.\", \"type\": \"boolean\"}, \"IdMEnrollBaseServer\": {\"default\": true, \"description\": \"Set to true to enroll the base server (computes, controllers)\", \"type\": \"boolean\"}, \"IdMInstallClientPackages\": {\"default\": false, \"description\": \"Set to True to have ansible-freeipa install ipa client packages on the overcloud node.\", \"type\": \"boolean\"}, \"IdMModifyDNS\": {\"default\": true, \"description\": \"Set to false to disable DNS records manipulation in the FreeIPA server.\", \"type\": \"boolean\"}, \"IdMZoneSplitIPv4\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}, \"IdMZoneSplitIPv6\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}}, \"conditions\": {\"idm_server_provided\": {\"not\": {\"equals\": [{\"get_param\": \"IdMServer\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ipaservice service\", \"value\": {\"service_name\": \"ipaservice\", \"upgrade_tasks\": [], \"step_config\": \"\", \"ipa_registration_tasks\": [{\"name\": \"Get undercloud FQDN\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"set_fact\": {\"undercloud_fqdn\": \"{{ ansible_facts[\'fqdn\'] }}\"}}, {\"include_role\": {\"name\": \"tripleo_ipa_registration\", \"apply\": {\"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ undercloud_fqdn }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}}, \"vars\": {\"tripleo_ipa_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}, \"tripleo_ipa_delegate_server\": \"{{ inventory_hostname }}\", \"tripleo_ipa_base_server_fqdn\": \"{{ fqdn_canonical }}\", \"tripleo_ipa_server_metadata\": \"{{ service_metadata_settings | to_json }}\"}, \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}, {\"name\": \"Enroll the node as an ipa client\", \"vars\": {\"ipaclient_install_packages\": {\"get_param\": \"IdMInstallClientPackages\"}, \"idm_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}}, \"block\": [{\"name\": \"check if default.conf exists\", \"stat\": {\"path\": \"/etc/ipa/default.conf\"}, \"register\": \"ipa_conf_exists\"}, {\"name\": \"install openssl-perl\", \"become\": true, \"package\": {\"name\": \"openssl-perl\", \"state\": \"present\"}, \"when\": [\"ipaclient_install_packages|bool\"]}, {\"name\": \"register as an ipa client\", \"include_role\": {\"name\": \"ipaclient\", \"apply\": {\"become\": true}}, \"vars\": {\"map_merge\": [{\"state\": \"present\", \"ipaclient_otp\": \"{{ ipa_host_otp }}\", \"ipaclient_mkhomedir\": {\"get_param\": \"MakeHomeDir\"}, \"ipaclient_no_ntp\": {\"get_param\": \"IdMNoNtpSetup\"}, \"ipaclient_force\": true, \"ipaclient_hostname\": \"{{ fqdn_canonical }}\", \"ansible_fqdn\": \"{{ ipaclient_hostname }}\", \"ipaclients\": [\"ipaclient_hostname\"], \"ansible_distribution\": \"{{ ansible_facts[\'distribution\'] }}\", \"ansible_distribution_major_version\": \"{{ ansible_facts[\'distribution_major_version\'] }}\", \"ansible_distribution_release\": \"{{ ansible_facts[\'distribution_release\'] }}\", \"ansible_distribution_version\": \"{{ ansible_facts[\'distribution_version\'] }}\", \"ansible_os_family\": \"{{ ansible_facts[\'os_family\'] }}\"}, {\"if\": [\"idm_server_provided\", {\"ipaclient_servers\": {\"get_param\": \"IdMServer\"}, \"ipaclient_domain\": {\"get_param\": \"IdMDomain\"}}]}]}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"restart certmonger service\", \"become\": true, \"systemd\": {\"state\": \"restarted\", \"daemon_reload\": true, \"name\": \"certmonger.service\"}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"set discovered ipa realm\", \"set_fact\": {\"idm_realm\": {\"str_replace\": {\"template\": \"{{ lookup(\'ini\', \'realm default=DEFAULT section=global file=/etc/ipa/default.conf\')}}\", \"params\": {\"DEFAULT\": {\"yaql\": {\"expression\": \"$.data.toUpper()\", \"data\": {\"get_param\": \"IdMDomain\"}}}}}}}}], \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}], \"external_deploy_tasks\": [{\"name\": \"add the DNS entries into IPA in step 1\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"tripleo_ipa_dns\"}, \"vars\": {\"tripleo_ipa_ptr_zone_split_ipv4\": {\"get_param\": \"IdMZoneSplitIPv4\"}, \"tripleo_ipa_ptr_zone_split_ipv6\": {\"get_param\": \"IdMZoneSplitIPv6\"}}, \"when\": {\"get_param\": \"IdMModifyDNS\"}}], \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ ansible_facts[\'fqdn\'] }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}], \"scale_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"down\", \"block\": [{\"name\": \"unregister node from ipa server\", \"import_role\": {\"name\": \"tripleo_ipa_cleanup\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"vars\": {\"tripleo_ipa_keytab\": {\"get_param\": \"IdMNovaKeytab\"}, \"tripleo_ipa_hosts_to_delete\": [\"{{ fqdn_canonical }}\"]}}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"check if ipa server has required permissions\", \"import_role\": {\"name\": \"tls_everywhere\", \"tasks_from\": \"ipa-server-check\"}, \"tags\": [\"opendev-validation\", \"opendev-validation-tls-everywhere\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(200,'2026-06-10 07:59:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(201,'2026-06-10 07:59:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat Engine service\\n\", \"parameters\": {\"ContainerHeatEngineImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\"}, \"ContainerHeatConfigImage\": {\"description\": \"The container image to use for the heat config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatEngineLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.engine\", \"file\": \"/var/log/containers/heat/heat-engine.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"HeatEngineOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatEngineOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatEnableDBPurge\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in the Heat database.\\n\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatMaxNestedStackDepth\": {\"default\": 6, \"description\": \"Maximum number of nested stack depth.\", \"type\": \"number\"}, \"HeatReauthenticationAuthMethod\": {\"description\": \"Allow reauthentication on token expiry, such that long-running tasks may complete. Note this defeats the expiry of any provided user tokens.\", \"type\": \"string\", \"default\": \"\", \"constraints\": [{\"allowed_values\": [\"\", \"trusts\"]}]}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"osNd9JfhsrCO9svVkwwbZnQ0E\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\"}, \"HeatAuthEncryptionKey\": {\"description\": \"Auth encryption key for heat-engine\", \"type\": \"string\", \"hidden\": true, \"default\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\"}, \"MonitoringSubscriptionHeatEngine\": {\"default\": \"overcloud-heat-engine\", \"type\": \"string\"}, \"HeatConvergenceEngine\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Enables the heat engine with the convergence architecture.\"}, \"HeatMaxResourcesPerStack\": {\"type\": \"number\", \"default\": 1000, \"description\": \"Maximum resources allowed per top-level stack. -1 stands for unlimited.\"}, \"HeatEnginePluginDirs\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"An array of directories to search for plug-ins.\"}, \"HeatConfigureDelegatedRoles\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Create delegated roles\"}, \"ClientRetryLimit\": {\"type\": \"number\", \"default\": 2, \"description\": \"Client retries for transient errors.\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatEngineLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatEngine\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatEngineImage\": \"ContainerHeatEngineImage\", \"ContainerHeatConfigImage\": \"ContainerHeatConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatEngineImage\": {\"get_param\": \"ContainerHeatEngineImage\"}, \"ContainerHeatConfigImage\": {\"get_param\": \"ContainerHeatConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat Engine role.\", \"value\": {\"service_name\": \"heat_engine\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatEngine\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::engine::configure_delegated_roles\": {\"get_param\": \"HeatConfigureDelegatedRoles\"}, \"heat::engine::trusts_delegated_roles\": [], \"heat::engine::max_nested_stack_depth\": {\"get_param\": \"HeatMaxNestedStackDepth\"}, \"heat::engine::max_resources_per_stack\": {\"get_param\": \"HeatMaxResourcesPerStack\"}, \"heat::engine::reauthentication_auth_method\": {\"get_param\": \"HeatReauthenticationAuthMethod\"}, \"heat::engine::heat_metadata_server_url\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}, \"heat::engine::heat_waitcondition_server_url\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1/waitcondition\"}}, \"heat::engine::convergence_engine\": {\"get_param\": \"HeatConvergenceEngine\"}, \"heat::engine::client_retry_limit\": {\"get_param\": \"ClientRetryLimit\"}, \"tripleo::profile::base::heat::manage_db_purge\": {\"get_param\": \"HeatEnableDBPurge\"}, \"heat::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"heat\", \"password\": {\"get_param\": \"HeatPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/heat\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"heat\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"heat::keystone_ec2_uri\": {\"list_join\": [\"\", [{\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"/ec2tokens\"]]}, \"heat::keystone::domain::domain_password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"heat::engine::auth_encryption_key\": {\"get_param\": \"HeatAuthEncryptionKey\"}, \"heat::engine::plugin_dirs\": {\"get_param\": \"HeatEnginePluginDirs\"}}, {\"if\": [\"heat_workers_set\", {\"heat::engine::num_engine_workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_engine\": [{\"get_param\": \"HeatEngineLoggingSource\"}]}, \"mysql\": {\"heat::db::mysql::password\": {\"get_param\": \"HeatPassword\"}, \"heat::db::mysql::user\": \"heat\", \"heat::db::mysql::host\": \"%\", \"heat::db::mysql::dbname\": \"heat\"}}, \"puppet_config\": {\"config_volume\": \"heat\", \"puppet_tags\": \"heat_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::heat::engine\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_engine.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/heat-engine --config-file /usr/share/heat/heat-dist.conf --config-file /etc/heat/heat.conf\", {\"get_attr\": [\"HeatEngineLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_engine_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec heat_engine su heat -s /bin/bash -c \'heat-manage db_sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatEngineLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"heat_engine_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatEngineLogging\", \"volumes\"]}, {\"get_param\": \"HeatEngineOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_engine_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatEngineOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}]}}}, \"step_4\": {\"heat_engine\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"net\": \"host\", \"privileged\": false, \"stop_grace_period\": 60, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatEngineLogging\", \"volumes\"]}, {\"get_param\": \"HeatEngineOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_engine.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatEngineOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HeatEngineLogging\", \"host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat engine container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_engine\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_engine\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(202,'2026-06-10 07:59:52',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Manila API service\\n\", \"parameters\": {\"ContainerManilaApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"ContainerManilaConfigImage\": {\"description\": \"The container image to use for the manila config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"ManilaWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for manila::wsgi::apache\", \"default\": \"%{::os_workers}\"}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"ManilaApiPolicies\": {\"description\": \"A hash of policies to configure for Manila API.\\ne.g. { manila-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"MonitoringSubscriptionManilaApi\": {\"default\": \"overcloud-manila-api\", \"type\": \"string\"}, \"ManilaEnabledShareProtocols\": {\"default\": \"\", \"description\": \"List of protocols to be allowed for share creation in manila. When not set, the list is inferred via the storage back end/s enabled.\", \"type\": \"comma_delimited_list\"}, \"ManilaCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"ManilaCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"ManilaCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"manila\"}, \"ManilaCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"ManilaCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/manila/manila-rowsflush.log\"}, \"ManilaCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ManilaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerManilaApiImage\": \"ContainerManilaApiImage\", \"ContainerManilaConfigImage\": \"ContainerManilaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerManilaApiImage\": {\"get_param\": \"ContainerManilaApiImage\"}, \"ContainerManilaConfigImage\": {\"get_param\": \"ContainerManilaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila API role.\", \"value\": {\"service_name\": \"manila_api\", \"firewall_rules\": {\"150 manila\": {\"dport\": [8786]}}, \"firewall_frontend_rules\": {\"100 manila_haproxy_frontend\": {\"dport\": [8786]}}, \"firewall_ssl_frontend_rules\": {\"100 manila_haproxy_frontend_ssl\": {\"dport\": [13786]}}, \"keystone_resources\": {\"manila\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Admin\", \"uri\"]}}, \"users\": {\"manila\": {\"password\": {\"get_param\": \"ManilaPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"share\"}, \"manilav2\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"uri\"]}}, \"users\": {\"manilav2\": {\"password\": {\"get_param\": \"ManilaPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"sharev2\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionManilaApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ManilaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"manila::keystone::authtoken::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"manila::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"manila::keystone::authtoken::project_name\": \"service\", \"manila::keystone::authtoken::user_domain_name\": \"Default\", \"manila::keystone::authtoken::project_domain_name\": \"Default\", \"manila::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"manila::keystone::authtoken::interface\": \"internal\", \"manila::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"manila::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"manila::api::service_name\": \"httpd\", \"manila::api::enable_proxy_headers_parsing\": true, \"manila::api::default_share_type\": \"default\", \"manila_enabled_share_protocols\": {\"get_param\": \"ManilaEnabledShareProtocols\"}, \"manila::policy::policies\": {\"get_param\": \"ManilaApiPolicies\"}, \"manila::cron::db_purge::minute\": {\"get_param\": \"ManilaCronDbPurgeMinute\"}, \"manila::cron::db_purge::hour\": {\"get_param\": \"ManilaCronDbPurgeHour\"}, \"manila::cron::db_purge::monthday\": {\"get_param\": \"ManilaCronDbPurgeMonthday\"}, \"manila::cron::db_purge::month\": {\"get_param\": \"ManilaCronDbPurgeMonth\"}, \"manila::cron::db_purge::weekday\": {\"get_param\": \"ManilaCronDbPurgeWeekday\"}, \"manila::cron::db_purge::user\": {\"get_param\": \"ManilaCronDbPurgeUser\"}, \"manila::cron::db_purge::age\": {\"get_param\": \"ManilaCronDbPurgeAge\"}, \"manila::cron::db_purge::destination\": {\"get_param\": \"ManilaCronDbPurgeDestination\"}, \"manila::cron::db_purge::maxdelay\": {\"get_param\": \"ManilaCronDbPurgeMaxDelay\"}, \"manila::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::workers\": {\"get_param\": \"ManilaWorkers\"}}]}, \"service_config_settings\": {\"get_attr\": [\"ManilaBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"manila\", \"puppet_tags\": \"manila_config,manila_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::manila::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/manila_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/manila_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec manila_api su manila -s /bin/bash -c \'/usr/bin/manila-manage db sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/manila_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"manila_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R manila:manila /var/log/manila\"]}}, \"step_3\": {\"manila_api_db_sync\": {\"user\": \"root\", \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"manila_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"manila_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron manila\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"Create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/manila\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/manila-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop manila api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"manila_api\"], \"tripleo_delegate_to\": \"{{ groups[\'manila_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(203,'2026-06-10 07:59:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerHeatEngineImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatEngineImage\": \"ContainerHeatEngineImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatEngineImage\": {\"get_param\": \"ContainerHeatEngineImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"heat_init_log\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/log/containers/heat:/var/log/heat:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R heat:heat /var/log/heat\"]}}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/heat:/var/log/heat:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/heat\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(204,'2026-06-10 07:59:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"ContainerKeystoneConfigImage\": {\"description\": \"The container image to use for the keystone config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1781078317, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"U723oHmIgjQCMvwRlNhiXicOo\"}, \"KeystoneTokenProvider\": {\"description\": \"The keystone token format\", \"type\": \"string\", \"default\": \"fernet\", \"constraints\": [{\"allowed_values\": [\"fernet\"]}]}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"PublicTLSCAFile\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the public network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"KeystoneSSLCertificate\": {\"default\": \"\", \"description\": \"Keystone certificate for verifying token validity.\", \"type\": \"string\"}, \"KeystoneSSLCertificateKey\": {\"default\": \"\", \"description\": \"Keystone key for signing tokens.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneNotificationFormat\": {\"description\": \"The Keystone notification format\", \"default\": \"basic\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"basic\", \"cadf\"]}]}, \"KeystoneNotificationTopics\": {\"description\": \"Keystone notification topics to enable\", \"default\": [], \"type\": \"comma_delimited_list\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"KeystoneDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Keystone service.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"AdminToken\": {\"description\": \"The keystone auth secret and db password.\", \"type\": \"string\", \"hidden\": true, \"default\": \"D80PzqdO8TvKo1qS4aEG0FonN\"}, \"TokenExpiration\": {\"default\": 3600, \"description\": \"Set a token expiration time in seconds.\", \"type\": \"number\"}, \"KeystoneWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for keystone::wsgi::apache\", \"default\": 1}, \"MonitoringSubscriptionKeystone\": {\"default\": \"overcloud-keystone\", \"type\": \"string\"}, \"KeystoneCredential0\": {\"type\": \"string\", \"description\": \"The first Keystone credential key. Must be a valid key.\", \"default\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\"}, \"KeystoneCredential1\": {\"type\": \"string\", \"description\": \"The second Keystone credential key. Must be a valid key.\", \"default\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\"}, \"KeystoneFernetKeys\": {\"type\": \"json\", \"description\": \"Mapping containing keystone\'s fernet keys and their paths.\", \"default\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}}, \"KeystoneFernetMaxActiveKeys\": {\"type\": \"number\", \"description\": \"The maximum active keys in the keystone fernet key repository.\", \"default\": 5}, \"ManageKeystoneFernetKeys\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether TripleO should manage the keystone fernet keys or not. If set to true, the fernet keys will get the values from the saved keys repository in mistral (the KeystoneFernetKeys variable). If set to false, only the stack creation initializes the keys, but subsequent updates won\'t touch them.\"}, \"KeystoneLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.keystone\", \"file\": \"/var/log/containers/keystone/keystone.log\"}}, \"KeystonePolicies\": {\"description\": \"A hash of policies to configure for Keystone.\\ne.g. { keystone-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"KeystoneLDAPDomainEnable\": {\"description\": \"Trigger to call ldap_backend puppet keystone define.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneLDAPBackendConfigs\": {\"description\": \"Hash containing the configurations for the LDAP backends configured in keystone.\", \"type\": \"json\", \"default\": {}, \"hidden\": true}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"KeystoneNotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Driver or drivers to handle sending notifications. This parameter is\\nspecific to Keystone.\\n\"}, \"KeystoneEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Keystone database.\\n\", \"type\": \"boolean\"}, \"KeystoneCronTrustFlushEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Ensure\\n\", \"default\": \"present\"}, \"KeystoneCronTrustFlushMinute\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Minute\\n\", \"default\": \"1\"}, \"KeystoneCronTrustFlushHour\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Hour\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonth\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Week Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMaxDelay\": {\"type\": \"number\", \"description\": \"Cron to purge expired or soft-deleted trusts - Max Delay\\n\", \"default\": 0}, \"KeystoneCronTrustFlushDestination\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Log destination\\n\", \"default\": \"/var/log/keystone/keystone-trustflush.log\"}, \"KeystoneCronTrustFlushUser\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - User\\n\", \"default\": \"keystone\"}, \"KeystoneChangePasswordUponFirstUse\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Enabling this option requires users to change their password when the user is created, or upon administrative reset.\", \"constraints\": [{\"allowed_values\": [\"\", \"true\", \"True\", \"TRUE\", \"false\", \"False\", \"FALSE\"]}]}, \"KeystoneDisableUserAccountDaysInactive\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of days a user can go without authenticating before being considered \\\"inactive\\\" and automatically disabled (locked).\"}, \"KeystoneLockoutDuration\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of seconds a user account will be locked when the maximum number of failed authentication attempts (as specified by KeystoneLockoutFailureAttempts) is exceeded.\"}, \"KeystoneLockoutFailureAttempts\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of times that a user can fail to authenticate before the user account is locked for the number of seconds specified by KeystoneLockoutDuration.\"}, \"KeystoneMinimumPasswordAge\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days that a password must be used before the user can change it. This prevents users from changing their passwords immediately in order to wipe out their password history and reuse an old password.\"}, \"KeystonePasswordExpiresDays\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days for which a password will be considered valid before requiring it to be changed.\"}, \"KeystonePasswordRegex\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The regular expression used to validate password strength requirements.\"}, \"KeystonePasswordRegexDescription\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Describe your password regular expression here in language for humans.\"}, \"KeystoneUniqueLastPasswordCount\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This controls the number of previous user password iterations to keep in history, in order to enforce that newly created passwords are unique.\"}, \"KeystoneCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"KeystoneEnableMember\": {\"description\": \"Create the _member_ role, useful for undercloud deployment.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneFederationEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for federated authentication.\"}, \"KeystoneTrustedDashboards\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of dashboard URLs trusted for single sign-on.\"}, \"KeystoneAuthMethods\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of methods used for authentication.\"}, \"KeystoneOpenIdcEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for OpenIDC federation.\"}, \"KeystoneOpenIdcIdpName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The name associated with the IdP in Keystone.\"}, \"KeystoneOpenIdcProviderMetadataUrl\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The url that points to your OpenID Connect provider metadata\"}, \"KeystoneOpenIdcClientId\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client ID to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcClientSecret\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client secret to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcCryptoPassphrase\": {\"type\": \"string\", \"default\": \"openstack\", \"description\": \"Passphrase to use when encrypting data for OpenID Connect handshake.\"}, \"KeystoneOpenIdcOutgoingProxy\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The outgoing proxy to use for OpenID connections.\"}, \"KeystoneOpenIdcResponseType\": {\"type\": \"string\", \"default\": \"id_token\", \"description\": \"Response type to be expected from the OpenID Connect provider.\"}, \"KeystoneOpenIdcRemoteIdAttribute\": {\"type\": \"string\", \"default\": \"OIDC-iss\", \"description\": \"Attribute to be used to obtain the entity ID of the Identity Provider from the environment.\"}, \"KeystoneOpenIdcEnableOAuth\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable OAuth 2.0 integration.\"}, \"KeystoneOpenIdcIntrospectionEndpoint\": {\"type\": \"string\", \"default\": \"\", \"description\": \"OAuth 2.0 introspection endpoint for mod_auth_openidc\"}, \"KeystoneOpenIdcClaimDelimiter\": {\"type\": \"string\", \"default\": \";\", \"description\": \"The delimiter to use when setting multi-valued claims.\"}, \"KeystoneOpenIdcPassUserInfoAs\": {\"type\": \"string\", \"default\": \"claims\", \"description\": \"Define the way(s) in which the claims resolved from the userinfo endpoint are passed to the application according to OIDCPassClaimsAs.\", \"constraints\": [{\"allowed_values\": [\"claims\", \"json\", \"jwt\"]}]}, \"KeystoneOpenIdcPassClaimsAs\": {\"type\": \"string\", \"default\": \"both\", \"description\": \"Define the way in which the claims and tokens are passed to the application environment: \\\"none\\\": no claims/tokens are passed \\\"environment\\\": claims/tokens are passed as environment variables \\\"headers\\\": claims/tokens are passed in headers (also useful in reverse proxy scenario\'s) \\\"both\\\": claims/tokens are passed as both headers as well as environment variables (default)\", \"constraints\": [{\"allowed_values\": [\"none\", \"environment\", \"headers\", \"both\"]}]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"KeystoneLogging\": {\"type\": \"OS::TripleO::Services::Logging::Keystone\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\", \"ContainerKeystoneConfigImage\": \"ContainerKeystoneConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}, \"ContainerKeystoneConfigImage\": {\"get_param\": \"ContainerKeystoneConfigImage\"}}}]}}}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}, \"keystone_fernet_tokens\": {\"equals\": [{\"get_param\": \"KeystoneTokenProvider\"}, \"fernet\"]}, \"nontls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"not\": {\"get_param\": \"MemcachedTLS\"}}]}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"keystone_outgoing_proxy\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}, \"\"]}}, {\"get_param\": \"KeystoneOpenIdcEnable\"}]}, \"change_password_upon_first_use_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}, \"\"]}}, \"disable_user_account_days_inactive_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}, \"\"]}}, \"lockout_duration_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutDuration\"}, \"\"]}}, \"lockout_failure_attempts_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutFailureAttempts\"}, \"\"]}}, \"minimum_password_age_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneMinimumPasswordAge\"}, \"\"]}}, \"password_expires_days_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordExpiresDays\"}, \"\"]}}, \"password_regex_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegex\"}, \"\"]}}, \"password_regex_description_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegexDescription\"}, \"\"]}}, \"unique_last_password_count_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneUniqueLastPasswordCount\"}, \"\"]}}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneCorsAllowedOrigin\"}, \"\"]}}, \"keystone_notification_driver_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneNotificationDriver\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Keystone API role.\", \"value\": {\"service_name\": \"keystone\", \"firewall_rules\": {\"111 keystone\": {\"dport\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 keystone_public_haproxy_frontend\": {\"dport\": [5000]}, \"100 keystone_admin_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_ssl_frontend_rules\": {\"100 keystone_public_haproxy_frontend_ssl\": {\"dport\": [13000]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionKeystone\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"if\": [\"cors_allowed_origin_set\", {\"keystone::cors::allowed_origin\": {\"get_param\": \"KeystoneCorsAllowedOrigin\"}}]}, {\"keystone::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"keystone\", \"password\": {\"get_param\": \"AdminToken\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/keystone\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"keystone\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"keystone::token_expiration\": {\"get_param\": \"TokenExpiration\"}, \"keystone::policy::policies\": {\"get_param\": \"KeystonePolicies\"}, \"keystone_ssl_certificate\": {\"get_param\": \"KeystoneSSLCertificate\"}, \"keystone_ssl_certificate_key\": {\"get_param\": \"KeystoneSSLCertificateKey\"}, \"keystone::token_provider\": {\"get_param\": \"KeystoneTokenProvider\"}, \"keystone::enable_fernet_setup\": {\"if\": [\"keystone_fernet_tokens\", true, false]}, \"keystone::fernet_max_active_keys\": {\"get_param\": \"KeystoneFernetMaxActiveKeys\"}, \"keystone::enable_proxy_headers_parsing\": true, \"keystone::enable_credential_setup\": true, \"keystone::credential_keys\": {\"/etc/keystone/credential-keys/0\": {\"content\": {\"get_param\": \"KeystoneCredential0\"}}, \"/etc/keystone/credential-keys/1\": {\"content\": {\"get_param\": \"KeystoneCredential1\"}}}, \"keystone::fernet_keys\": {\"get_param\": \"KeystoneFernetKeys\"}, \"keystone::fernet_replace_keys\": {\"get_param\": \"ManageKeystoneFernetKeys\"}, \"keystone::logging::debug\": {\"if\": [{\"get_param\": \"KeystoneDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"keystone::notification_driver\": {\"if\": [\"keystone_notification_driver_set\", {\"get_param\": \"KeystoneNotificationDriver\"}, {\"get_param\": \"NotificationDriver\"}]}, \"keystone::notification_format\": {\"get_param\": \"KeystoneNotificationFormat\"}, \"tripleo::profile::base::keystone::extra_notification_topics\": {\"get_param\": \"KeystoneNotificationTopics\"}, \"keystone_enable_db_purge\": {\"get_param\": \"KeystoneEnableDBPurge\"}, \"keystone::cron::trust_flush::ensure\": {\"get_param\": \"KeystoneCronTrustFlushEnsure\"}, \"keystone::cron::trust_flush::minute\": {\"get_param\": \"KeystoneCronTrustFlushMinute\"}, \"keystone::cron::trust_flush::hour\": {\"get_param\": \"KeystoneCronTrustFlushHour\"}, \"keystone::cron::trust_flush::monthday\": {\"get_param\": \"KeystoneCronTrustFlushMonthday\"}, \"keystone::cron::trust_flush::month\": {\"get_param\": \"KeystoneCronTrustFlushMonth\"}, \"keystone::cron::trust_flush::weekday\": {\"get_param\": \"KeystoneCronTrustFlushWeekday\"}, \"keystone::cron::trust_flush::maxdelay\": {\"get_param\": \"KeystoneCronTrustFlushMaxDelay\"}, \"keystone::cron::trust_flush::destination\": {\"get_param\": \"KeystoneCronTrustFlushDestination\"}, \"keystone::cron::trust_flush::user\": {\"get_param\": \"KeystoneCronTrustFlushUser\"}, \"keystone::rabbit_heartbeat_timeout_threshold\": 60, \"keystone::rabbit_heartbeat_in_pthread\": false, \"keystone::service_name\": \"httpd\", \"keystone::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::api_port\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}], \"keystone::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, \"keystone::wsgi::apache::workers\": {\"get_param\": \"KeystoneWorkers\"}, \"keystone::wsgi::apache::threads\": 1, \"keystone::db::database_db_max_retries\": -1, \"keystone::db::database_max_retries\": -1, \"keystone::wsgi::apache::bind_host\": [{\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}}}]}, {\"keystone::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"keystone::cache::backend_argument\": [{\"str_replace\": {\"template\": \"memcached_expire_time: $EXPIRATION\", \"params\": {\"$EXPIRATION\": {\"get_param\": \"TokenExpiration\"}}}}], \"keystone::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"keystone::cache::backend\": \"dogpile.cache.pymemcache\", \"keystone::token_caching\": true}, {\"keystone::cache::backend\": \"dogpile.cache.memcached\"}]}, {\"if\": [{\"get_param\": \"KeystoneFederationEnable\"}, {\"keystone_federation_enabled\": true, \"keystone::federation::trusted_dashboards\": {\"get_param\": \"KeystoneTrustedDashboards\"}}]}, {\"if\": [{\"get_param\": \"KeystoneOpenIdcEnable\"}, {\"keystone_openidc_enabled\": true, \"keystone::federation::openidc::methods\": {\"get_param\": \"KeystoneAuthMethods\"}, \"keystone::federation::openidc::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::federation::openidc::idp_name\": {\"get_param\": \"KeystoneOpenIdcIdpName\"}, \"keystone::federation::openidc::openidc_provider_metadata_url\": {\"get_param\": \"KeystoneOpenIdcProviderMetadataUrl\"}, \"keystone::federation::openidc::openidc_client_id\": {\"get_param\": \"KeystoneOpenIdcClientId\"}, \"keystone::federation::openidc::openidc_client_secret\": {\"get_param\": \"KeystoneOpenIdcClientSecret\"}, \"keystone::federation::openidc::openidc_crypto_passphrase\": {\"get_param\": \"KeystoneOpenIdcCryptoPassphrase\"}, \"keystone::federation::openidc::openidc_response_type\": {\"get_param\": \"KeystoneOpenIdcResponseType\"}, \"keystone::federation::openidc::remote_id_attribute\": {\"get_param\": \"KeystoneOpenIdcRemoteIdAttribute\"}, \"keystone::federation::openidc::openidc_enable_oauth\": {\"get_param\": \"KeystoneOpenIdcEnableOAuth\"}, \"keystone::federation::openidc::openidc_introspection_endpoint\": {\"get_param\": \"KeystoneOpenIdcIntrospectionEndpoint\"}, \"keystone::federation::openidc::openidc_pass_userinfo_as\": {\"get_param\": \"KeystoneOpenIdcPassUserInfoAs\"}, \"keystone::federation::openidc::openidc_pass_claim_as\": {\"get_param\": \"KeystoneOpenIdcPassClaimsAs\"}, \"keystone::federation::openidc::openidc_claim_delimiter\": {\"get_param\": \"KeystoneOpenIdcClaimDelimiter\"}, \"keystone::federation::openidc::openidc_cache_type\": {\"if\": [\"nontls_cache_enabled\", \"memcache\"]}}]}, {\"if\": [\"keystone_outgoing_proxy\", {\"keystone::federation::openidc::openidc_outgoing_proxy\": {\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}}]}, {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"tripleo::profile::base::keystone::ldap_backend_enable\": true, \"keystone::using_domain_config\": true, \"tripleo::profile::base::keystone::ldap_backends_config\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}]}, {\"if\": [\"change_password_upon_first_use_set\", {\"keystone::security_compliance::change_password_upon_first_use\": {\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}}]}, {\"if\": [\"disable_user_account_days_inactive_set\", {\"keystone::security_compliance::disable_user_account_days_inactive\": {\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}}]}, {\"if\": [\"lockout_duration_set\", {\"keystone::security_compliance::lockout_duration\": {\"get_param\": \"KeystoneLockoutDuration\"}}]}, {\"if\": [\"lockout_failure_attempts_set\", {\"keystone::security_compliance::lockout_failure_attempts\": {\"get_param\": \"KeystoneLockoutFailureAttempts\"}}]}, {\"if\": [\"minimum_password_age_set\", {\"keystone::security_compliance::minimum_password_age\": {\"get_param\": \"KeystoneMinimumPasswordAge\"}}]}, {\"if\": [\"password_expires_days_set\", {\"keystone::security_compliance::password_expires_days\": {\"get_param\": \"KeystonePasswordExpiresDays\"}}]}, {\"if\": [\"password_regex_set\", {\"keystone::security_compliance::password_regex\": {\"get_param\": \"KeystonePasswordRegex\"}}]}, {\"if\": [\"password_regex_description_set\", {\"keystone::security_compliance::password_regex_description\": {\"get_param\": \"KeystonePasswordRegexDescription\"}}]}, {\"if\": [\"unique_last_password_count_set\", {\"keystone::security_compliance::unique_last_password_count\": {\"get_param\": \"KeystoneUniqueLastPasswordCount\"}}]}, {\"apache::default_vhost\": false}, {\"get_attr\": [\"KeystoneLogging\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_keystone\": {\"get_param\": \"KeystoneLoggingSource\"}}, \"mysql\": {\"keystone::db::mysql::password\": {\"get_param\": \"AdminToken\"}, \"keystone::db::mysql::user\": \"keystone\", \"keystone::db::mysql::host\": \"%\", \"keystone::db::mysql::dbname\": \"keystone\"}, \"pacemaker\": {\"keystone::endpoint::public_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::endpoint::internal_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"keystone::endpoint::admin_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"keystone::endpoint::region\": {\"get_param\": \"KeystoneRegion\"}, \"keystone::admin_password\": {\"get_param\": \"AdminPassword\"}}, \"horizon\": {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"horizon::keystone_multidomain_support\": true, \"horizon::keystone_default_domain\": \"Default\"}]}}, \"puppet_config\": {\"config_volume\": \"keystone\", \"puppet_tags\": \"keystone_config,keystone_domain_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Keystone_user\', \'Keystone_endpoint\', \'Keystone_domain\', \'Keystone_tenant\', \'Keystone_user_role\', \'Keystone_role\', \'Keystone_service\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::keystone\\n\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/keystone.json\": {\"command\": \"/usr/sbin/httpd\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/keystone/fernet-keys\", \"dest\": \"/etc/keystone/fernet-keys\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/keystone_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"KeystoneLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"keystone_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"KeystoneLogging\", \"environment\"]}, {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}]}, \"command\": [\"/usr/bin/bootstrap_host_exec\", \"keystone\", \"/usr/local/bin/kolla_start\"]}, \"keystone\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"keystone_bootstrap\": {\"start_order\": 3, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"/usr/bin/bootstrap_host_exec\", \"keystone\", \"keystone-manage\", \"bootstrap\"], \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"OS_BOOTSTRAP_PASSWORD\": {\"get_param\": \"AdminPassword\"}, \"OS_BOOTSTRAP_USERNAME\": \"admin\", \"OS_BOOTSTRAP_PROJECT_NAME\": \"admin\", \"OS_BOOTSTRAP_ROLE_NAME\": \"admin\", \"OS_BOOTSTRAP_SERVICE_NAME\": \"keystone\", \"OS_BOOTSTRAP_ADMIN_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_PUBLIC_URL\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_INTERNAL_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_REGION_ID\": {\"get_param\": \"KeystoneRegion\"}}}, \"keystone_cron\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"user\": \"root\", \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron keystone\"}, \"command\": [\"/bin/bash\", \"-c\", \"/usr/local/bin/kolla_set_configs && /usr/sbin/crond -n\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/keystone_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"keystone_refresh\": {\"start_order\": 1, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"pkill\", \"--signal\", \"USR1\", \"httpd\"]}}}, \"external_deploy_tasks\": [{\"name\": \"Manage clouds.yaml files\", \"when\": [\"step|int == 1\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Create /etc/openstack directory if it does not exist\", \"become\": true, \"file\": {\"mode\": \"0755\", \"owner\": \"root\", \"path\": \"/etc/openstack\", \"state\": \"directory\"}}, {\"name\": \"Configure /etc/openstack/clouds.yaml\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"clouds\"}, \"vars\": {\"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_cloud_config\": {\"auth\": {\"auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"password\": {\"get_param\": \"AdminPassword\"}, \"project_domain_name\": \"Default\", \"project_name\": \"admin\", \"user_domain_name\": \"Default\", \"username\": \"admin\"}, \"cacert\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"PublicTLSCAFile\"}, \"\"]}, \"identity_api_version\": \"3\", \"volume_api_version\": \"3\", \"region_name\": {\"get_param\": \"KeystoneRegion\"}}}}]}, {\"name\": \"Manage Keystone resources\", \"become\": true, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Manage Keystone resources for OpenStack services\", \"include_role\": {\"name\": \"tripleo_keystone_resources\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_service_project\": \"service\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_region\": {\"get_param\": \"KeystoneRegion\"}, \"tripleo_keystone_resources_admin_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_public_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_internal_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_admin_password\": {\"get_param\": \"AdminPassword\"}, \"tripleo_keystone_resources_member_role_enabled\": {\"get_param\": \"KeystoneEnableMember\"}}}, {\"name\": \"is Keystone LDAP enabled\", \"set_fact\": {\"keystone_ldap_domain_enabled\": {\"get_param\": \"KeystoneLDAPDomainEnable\"}}}, {\"name\": \"Set fact for tripleo_keystone_ldap_domains\", \"set_fact\": {\"tripleo_keystone_ldap_domains\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}, \"when\": \"keystone_ldap_domain_enabled|bool\"}, {\"name\": \"Manage Keystone domains from LDAP config\", \"when\": \"keystone_ldap_domain_enabled|bool\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"domains\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"batched_tripleo_keystone_resources_domains\": \"{{ tripleo_keystone_ldap_domains | list }}\"}}]}], \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"validate keystone container state\", \"containers.podman.podman_container_info\": {\"name\": \"keystone\"}, \"register\": \"keystone_infos\", \"failed_when\": [\"keystone_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in keystone_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-keystone\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 4\"]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"KeystoneLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check if file certs_valid exist\", \"stat\": {\"path\": \"/etc/openldap/certs/certs_valid\"}, \"register\": \"certs_valid_stat\"}, {\"name\": \"Check if file cert9.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/cert9.db\"}, \"register\": \"cert9_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"name\": \"Check if file key4.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/key4.db\"}, \"register\": \"key4_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"fail\": {\"msg\": \"Keys and/or certificates were found in /etc/openldap/certs but these conflicts with keystone python LDAP calls.  If you know those certificates are valid and not causing any conflicts, you can touch /etc/openldap/certs/certs_valid in order to skip this failure and retry or you can delete the files located in /etc/openldap/certs and retry.\\n\"}, \"when\": \"( cert9_stat.stat.exists or key4_stat.stat.exists ) and not certs_valid_stat.stat.exists\"}]]}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop keystone container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"keystone\", \"keystone_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'keystone\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(205,'2026-06-10 07:59:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(206,'2026-06-10 07:59:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (207,'2026-06-10 07:59:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Manila base service. Shared by manila-api/scheduler/share services\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ManilaIPv6\": {\"default\": false, \"description\": \"Set to True to enable IPv6 access in manila.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ManilaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Manila services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"ManilaStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Manila service\'s storage availability zone.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Base service.\", \"value\": {\"service_name\": \"manila_base\", \"config_settings\": {\"manila::storage_availability_zone\": {\"get_param\": \"ManilaStorageAvailabilityZone\"}, \"manila::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"manila::logging::debug\": {\"if\": [{\"get_param\": \"ManilaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"manila::db::database_db_max_retries\": -1, \"manila::db::database_max_retries\": -1, \"manila::sql_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"manila\", \"password\": {\"get_param\": \"ManilaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/manila\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"manila\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"manila::network::neutron::network_plugin_ipv6_enabled\": {\"get_param\": \"ManilaIPv6\"}, \"manila::network::neutron::network_plugin_ipv4_enabled\": {\"if\": [{\"get_param\": \"ManilaIPv6\"}, false, true]}, \"manila::rabbit_heartbeat_in_pthread\": false}, \"service_config_settings\": {\"mysql\": {\"manila::db::mysql::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::db::mysql::user\": \"manila\", \"manila::db::mysql::host\": \"%\", \"manila::db::mysql::dbname\": \"manila\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(208,'2026-06-10 07:59:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"keystone_init_log\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R keystone:keystone /var/log/keystone\"], \"volumes\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}}}}, \"environment\": {\"description\": \"Extra environment variables needed for the service to log to files.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(210,'2026-06-10 07:59:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API CFN service\\n\", \"parameters\": {\"ContainerHeatApiCfnImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"ContainerHeatApiCfnConfigImage\": {\"description\": \"The container image to use for the heat_api_cfn config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"HeatApiCfnLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api.cfn\", \"file\": \"/var/log/containers/heat/heat_api_cfn.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"osNd9JfhsrCO9svVkwwbZnQ0E\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApiCnf\": {\"default\": \"overcloud-heat-api-cfn\", \"type\": \"string\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiCfnLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApiCfn\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiCfnImage\": \"ContainerHeatApiCfnImage\", \"ContainerHeatApiCfnConfigImage\": \"ContainerHeatApiCfnConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiCfnImage\": {\"get_param\": \"ContainerHeatApiCfnImage\"}, \"ContainerHeatApiCfnConfigImage\": {\"get_param\": \"ContainerHeatApiCfnConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API CFN role.\", \"value\": {\"service_name\": \"heat_api_cfn\", \"firewall_rules\": {\"125 heat_cfn\": {\"dport\": [8000]}}, \"firewall_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend\": {\"dport\": [8000]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend_ssl\": {\"dport\": [13005]}}, \"keystone_resources\": {\"heat-cfn\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"uri\"]}}, \"users\": {\"heat-cfn\": {\"password\": {\"get_param\": \"HeatPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"cloudformation\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApiCnf\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::api_cfn::service_name\": \"httpd\", \"heat::wsgi::apache_api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api_cfn::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api_cfn\": [{\"get_param\": \"HeatApiCfnLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api_cfn\", \"puppet_tags\": \"heat_config,file,concat,file_line\", \"step_config\": \"include tripleo::profile::base::heat::api_cfn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api_cfn.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiCfnLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api_cfn\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cfn.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api_cfn:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiCfnLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat cfn container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api_cfn\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api_cfn\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(211,'2026-06-10 07:59:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(212,'2026-06-10 07:59:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(213,'2026-06-10 07:59:55',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-0\", \"NodeIndex\": \"0\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"249a35cc-1588-4b42-b236-f5fd6bbdf411\"}}, \"1\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-1\", \"NodeIndex\": \"1\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"249a35cc-1588-4b42-b236-f5fd6bbdf411\"}}, \"2\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-2\", \"NodeIndex\": \"2\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"249a35cc-1588-4b42-b236-f5fd6bbdf411\"}}}, \"outputs\": {\"blacklist_hostname\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_hostname\"]}, {\"get_attr\": [\"1\", \"blacklist_hostname\"]}, {\"get_attr\": [\"2\", \"blacklist_hostname\"]}]}, \"hosts_entry\": {\"value\": [{\"get_attr\": [\"0\", \"hosts_entry\"]}, {\"get_attr\": [\"1\", \"hosts_entry\"]}, {\"get_attr\": [\"2\", \"hosts_entry\"]}]}, \"ansible_host_vars_map\": {\"value\": [{\"get_attr\": [\"0\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"1\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"2\", \"ansible_host_vars_map\"]}]}, \"attributes, nova_server_resource\": {\"value\": {\"0\": {\"get_attr\": [\"0\", \"nova_server_resource\"]}, \"1\": {\"get_attr\": [\"1\", \"nova_server_resource\"]}, \"2\": {\"get_attr\": [\"2\", \"nova_server_resource\"]}}}, \"hostname\": {\"value\": [{\"get_attr\": [\"0\", \"hostname\"]}, {\"get_attr\": [\"1\", \"hostname\"]}, {\"get_attr\": [\"2\", \"hostname\"]}]}, \"storage_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_ip_address\"]}, {\"get_attr\": [\"1\", \"storage_ip_address\"]}, {\"get_attr\": [\"2\", \"storage_ip_address\"]}]}, \"tenant_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"tenant_ip_address\"]}, {\"get_attr\": [\"1\", \"tenant_ip_address\"]}, {\"get_attr\": [\"2\", \"tenant_ip_address\"]}]}, \"hostname_map\": {\"value\": [{\"get_attr\": [\"0\", \"hostname_map\"]}, {\"get_attr\": [\"1\", \"hostname_map\"]}, {\"get_attr\": [\"2\", \"hostname_map\"]}]}, \"blacklist_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"1\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"2\", \"blacklist_ip_address\"]}]}, \"nova_server_resource\": {\"value\": [{\"get_attr\": [\"0\", \"nova_server_resource\"]}, {\"get_attr\": [\"1\", \"nova_server_resource\"]}, {\"get_attr\": [\"2\", \"nova_server_resource\"]}]}, \"internal_api_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"1\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"2\", \"internal_api_ip_address\"]}]}, \"ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"ip_address\"]}, {\"get_attr\": [\"1\", \"ip_address\"]}, {\"get_attr\": [\"2\", \"ip_address\"]}]}, \"refs_map\": {\"value\": {\"0\": {\"get_resource\": \"0\"}, \"1\": {\"get_resource\": \"1\"}, \"2\": {\"get_resource\": \"2\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(214,'2026-06-10 07:59:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Compute node configured by Puppet\", \"parameters\": {\"OvercloudComputeFlavor\": {\"description\": \"Flavor for the Compute node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"NovaImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"DEPRECATED Use ComputeImage instead\"}, \"ComputeImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeIPs\": {\"default\": {}, \"type\": \"json\"}, \"NovaComputeIPs\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeIPs instead\", \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"NovaComputeServerMetadata\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeServerMetadata instead\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {\"ipa_enroll\": true}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"NovaImage\", \"NovaComputeServerMetadata\", \"NovaComputeIPs\"]}], \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"deprecated_param_image_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaImage\"}, \"overcloud-full\"]}}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"Compute_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"NovaCompute\": {\"type\": \"OS::TripleO::ComputeServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"if\": [\"deprecated_param_image_set\", {\"get_param\": \"NovaImage\"}, {\"get_param\": \"ComputeImage\"}]}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, {\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"NovaComputeServerMetadata\"}, {\"get_param\": \"ComputeServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeSchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::Compute::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::Compute::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::Compute::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"NovaCompute\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::Compute::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"ComputeExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"NovaComputeAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"NovaComputeAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for Compute server\", \"value\": {\"get_resource\": \"NovaCompute\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-0\", \"CloudDomain\": \"ooo.test\", \"ComputeSchedulerHints\": {}, \"NodeIndex\": 0, \"ServiceNames\": \"boot_params_service,ca_certs,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,ipaservice,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"249a35cc-1588-4b42-b236-f5fd6bbdf411\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(215,'2026-06-10 07:59:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"osNd9JfhsrCO9svVkwwbZnQ0E\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (216,'2026-06-10 07:59:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(217,'2026-06-10 07:59:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"osNd9JfhsrCO9svVkwwbZnQ0E\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(218,'2026-06-10 07:59:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.250\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.250\", \"storage_mgmt\": \"172.20.0.248\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.248\", \"internal_api\": \"172.17.0.242\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.242\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.164\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.164\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.164\", \"host_nobrackets\": \"172.21.0.164\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.164:2049\", \"uri_no_suffix\": \"nfs://172.21.0.164:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(219,'2026-06-10 07:59:56',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"image\": {\"type\": \"string\", \"default\": \"unused\"}, \"flavor\": {\"type\": \"string\", \"default\": \"unused\"}, \"key_name\": {\"type\": \"string\", \"default\": \"unused\", \"description\": \"Name of keypair to assign to servers\"}, \"security_groups\": {\"type\": \"json\", \"default\": []}, \"user_data_format\": {\"type\": \"string\"}, \"user_data\": {\"type\": \"string\", \"default\": \"\"}, \"name\": {\"type\": \"string\", \"default\": \"deployed-server\"}, \"image_update_policy\": {\"type\": \"string\", \"default\": \"\"}, \"networks\": {\"type\": \"comma_delimited_list\", \"default\": \"\"}, \"metadata\": {\"type\": \"json\", \"default\": {}}, \"software_config_transport\": {\"default\": \"POLL_SERVER_CFN\", \"type\": \"string\"}, \"scheduler_hints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"ControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"The name of the undercloud Neutron control plane subnet\", \"type\": \"string\"}}, \"resources\": {\"deployed-server\": {\"type\": \"OS::Heat::DeployedServer\", \"properties\": {\"name\": {\"get_param\": \"name\"}, \"software_config_transport\": {\"get_param\": \"software_config_transport\"}}}, \"ControlPlanePort\": {\"type\": \"OS::TripleO::DeployedServer::ControlPlanePort\", \"properties\": {\"network\": \"ctlplane\", \"fixed_ips\": [{\"subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}], \"name\": {\"list_join\": [\"-\", [{\"get_param\": \"name\"}, \"ctlplane\"]]}, \"replacement_policy\": \"AUTO\", \"tags\": [{\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"RootStackName\"}}}}]}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"deployed-server\"}}, \"networks\": {\"value\": {\"ctlplane\": [{\"get_attr\": [\"ControlPlanePort\", \"fixed_ips\", 0, \"ip_address\"]}]}}, \"addresses\": {\"value\": {\"ctlplane\": [{\"subnets\": {\"get_attr\": [\"ControlPlanePort\", \"subnets\"]}}]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"os_collect_config\": {\"value\": {\"get_attr\": [\"deployed-server\", \"os_collect_config\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"image\": \"overcloud-full\", \"flavor\": \"baremetal\", \"key_name\": \"default\", \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": \"249a35cc-1588-4b42-b236-f5fd6bbdf411\", \"name\": \"np0000069420\", \"image_update_policy\": \"REBUILD_PRESERVE_EPHEMERAL\", \"networks\": \".member.0.network=ctlplane,.member.0.subnet=ctlplane-subnet\", \"metadata\": {\"ipa_enroll\": true, \"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"software_config_transport\": \"POLL_SERVER_HEAT\", \"scheduler_hints\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1781078317, \"GlancePassword\": \"ApomcwoXm9jjJOvUNPSNDY3vi\", \"HAProxyStatsPassword\": \"kidfQULq1xgBfPvuhAsTlRfxc\", \"HeatAuthEncryptionKey\": \"mxp8ouoxlsYQ33n4LsS7mtjHRw7PPmBY\", \"HeatPassword\": \"osNd9JfhsrCO9svVkwwbZnQ0E\", \"HeatStackDomainAdminPassword\": \"g1LEfOBKKbcq5SbSCs2X8hvPc\", \"HorizonSecret\": \"M1cr1IduHd\", \"KeystoneCredential0\": \"sNvmw4AX2R8zK9ij05E9vz4TqsNVdXlYqUYZE5LTO7Y=\", \"KeystoneCredential1\": \"dqtKWyGGk2m3j1RgxPvK_EppSR51wrh7z3q7ELJKdMg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"v5Zwv_Y-bKV87amOxEXWxiRH076GdRIz1KN1CtiCyCc=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"YN2G6M3CMjsvvDPYi-rlXabyrLwVgbqEF7KDT9szhvU=\"}}, \"LibvirtTLSPassword\": \"GhFjIdW1ysmls0LZQMCGaOen4\", \"ManilaPassword\": \"G7HIu4ezbmoxfJlSXB8gqZxmA\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEpAIBAAKCAQEAvK5jljiulqSkUBhxTKiA2ElkG5cp1gCyA60rADZVYpyaA2BA\\nsJHLYAHEIzmV4y+8Y/tn+RTc/m3jfD5fs14ESsM6ZOj/hxdR7KwPntKziGWejRy0\\ngblAH+RsxP89rs+K2HkDa0VOkZdkmmlS4bCxDM4EI8zhmphlZMq4einXgbUuHF8T\\n4n89P///iMYpkyB5x/tN9Cn0aigu9CZjRCQjN/jWR5DdSHMyDXKoQ6snR84qQvHd\\n35BzrHeVmnJbIIt+AElWbzxCtV5b1jOhKrzjOlr1Yh+4jeuoAfUWP3tDFzo5JYUb\\nXJ6gcpGaCVwvBjtcqlsBVG7eaYBh8efxElFtywIDAQABAoIBAAfRY//39kf4p3RI\\nJv2pp7kOhW7dOxcKbVXYqYT3O198JKeKJ/QI/nfKavGYs7y3oCM2ag74jdWfAQOH\\nZBi/BweAAl3nB5t13Gelk3odueGncEPhkhsj7WPE57rb5pblM5gXn4wk0YYX00vQ\\nnGYMl7FzodlH5nss4FqmSbGKJUtS/6y8nDeLopYrOb4U13i9PLVOB+9FN6Wjl7Ua\\n9mgxZqQqw+e6fJmazalBrhQ88y2WyacU4iRwVpeYO4qzSk6vRgPeMh0FVgcWpgKq\\nUaujPiYurtnJa4Jwg6WzLU819u91JIc+zf54o4BduykaH5PaC1Y5UbU0SiAXAWdl\\nOaylyGkCgYEA+PpBiJXw7+emmW6xwAG/giwfmzeG++OyNZ5vFViiQAIf8LjC5cXS\\n1WJvqny0EaPLYXZiqKs1i+WYw3xJ15ztWMi9eSwJFsuYeTYvXjfL2VhIi/0majSs\\n5TrqG76cIQ+PMH/EqeeHEdbxRy/MYuvOClmfOT11wmScuhXuPqFl7EMCgYEAwgDD\\nSBE5fZWlD9AFFoFVJA4MUiAIpxYcecOTbp5ErCXsf7IexobIl301rcs0atw/kWz2\\napSEGZtVHw0oXyB7PsyGokYgjESWyUhz2Y4fxXKP4wKe9sgb0wT/SagcWZB/t2To\\nQFCYepMGg4LBjot/Kyqh3N/29QxfJ5v/oTN1I9kCgYEAozPv5ydaQvfXBfZAf7rl\\nnN9tbGJOkiikNW+AIz7xRAHgi/ugjdtJo2QeDGQn6PQ0KdPfQe7Qb751j5aWFMah\\n8jPLt3T9FDsq3DF/hUQP1I2BKHotRyr2NmCS+tLMJwO6+bCW6kSBDlmV2PLlB+bI\\nLZKnw26dFWq8LWKYw+cqF18CgYEAwNJlRhHopEvCHW9SP0YYy5cy48V3FCtD7jpX\\nJREljDy9TUZKlGOOqBMI8U4RMUzr2a0FVnV6vsDG3/AB+lqcZJSAFHXDD+d0P2dF\\nziwWo/bz0Fvgh8Po89n5qsnuM48NgchHlvUEOIA9byTdIMLBiLP84T2xhWnggcvp\\nTd2JRjECgYAUKyHeQMQ6APdBR4J0Kp0IY04SvBWcQlRyuywxsGTl6/nZLNZl9pXF\\n98io3/L59HMtb2yvgwEKuyswK3aXRkvOrexChvAKnhwXtUu44PB+f8744g9G7FRR\\nYk7LMKGzwKlqG2K52t72Gf9eLF4PAJKROoFEvo6cb1BJqyVvp1ZKyA==\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQC8rmOWOK6WpKRQGHFMqIDYSWQblynWALIDrSsANlVinJoDYECwkctgAcQjOZXjL7xj+2f5FNz+beN8Pl+zXgRKwzpk6P+HF1HsrA+e0rOIZZ6NHLSBuUAf5GzE/z2uz4rYeQNrRU6Rl2SaaVLhsLEMzgQjzOGamGVkyrh6KdeBtS4cXxPifz0///+IximTIHnH+030KfRqKC70JmNEJCM3+NZHkN1IczINcqhDqydHzipC8d3fkHOsd5Waclsgi34ASVZvPEK1XlvWM6EqvOM6WvViH7iN66gB9RY/e0MXOjklhRtcnqBykZoJXC8GO1yqWwFUbt5pgGHx5/ESUW3L Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"CYj66O9ul6B4Ms1VDLtRsDkqA\", \"MysqlMariabackupPassword\": \"j1B32DBXFtXhrmqmIBzhbZcyq\", \"MysqlRootPassword\": \"L35jp4QTgu\", \"NeutronMetadataProxySharedSecret\": \"0L1TuMmYu9cXN2twLue5RLHjS\", \"NeutronPassword\": \"V6qvOdr4xOrW2qdKJR3d8Svn0\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"5QAuCI6DgbWqEzUK0gVmITEDx\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"LQHJGvWavpJOwm1H\", \"PlacementPassword\": \"BN25Oqhi9kgi2kJiX6IVi01JG\", \"RabbitCookie\": \"KjeY00J96Nf58taeNnak\", \"RabbitPassword\": \"oJbv168qQwLeaczn4eKAziD6x\", \"RedisPassword\": \"13qiQT0Nynohgkp6fAkpbtLxa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"bfaESMXUEXlZt3K4RcmWX0NwK\", \"SnmpdReadonlyUserPassword\": \"Gw7UKk275edaf1BK4QNxasIq\", \"SwiftHashSuffix\": \"tS1t4L6hrXqwDzfhw129zch9t\", \"SwiftPassword\": \"dihluj6scSLfHal79MiU7e1XH\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(220,'2026-06-10 07:59:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \" A fake OS::Neutron::Port stack which outputs fixed_ips and subnets based on the input from the DeployedServerPortMap (set via parameter_defaults). This lookup requires the use of port naming conventions. In order for this to work with deployed-server the keys should be <hostname>-<network>. Example: parameter_defaults: DeployedServerPortMap: gatsby-ctlplane: fixed_ips: - ip_address: 127.0.0.1 subnets: - cidr: 127.0.0.0/24 network: tags: - 127.0.0.0/24\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"DeployedServerPortMap\": {\"default\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"type\": \"json\"}, \"IsVirtualIP\": {\"default\": false, \"type\": \"boolean\"}, \"Role\": {\"description\": \"The TripleO Role Name\\n\", \"type\": \"string\", \"default\": \"\"}}, \"outputs\": {\"fixed_ips\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"fixed_ips\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"subnets\"]}}, \"network\": {\"value\": {\"get_param\": [\"DeployedServerPortMap\", {\"get_param\": \"name\"}, \"network\"]}}, \"name\": {\"value\": {\"get_param\": \"name\"}}, \"status\": {\"value\": \"DOWN\"}, \"allowed_address_pairs\": {\"value\": {}}, \"device_id\": {\"value\": \"\"}, \"device_owner\": {\"value\": {\"get_param\": \"network\"}}, \"dns_assignment\": {\"value\": \"\"}, \"port_security_enabled\": {\"value\": false}, \"admin_state_up\": {\"value\": false}, \"security_groups\": {\"value\": {}}, \"network_id\": {\"value\": \"\"}, \"tenant_id\": {\"value\": \"\"}, \"qos_policy_id\": {\"value\": \"\"}, \"mac_address\": {\"value\": \"\"}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"np0000069420-ctlplane\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000069417\", \"overcloud-controller-1\": \"np0000069418\", \"overcloud-controller-2\": \"np0000069419\", \"overcloud-novacompute-0\": \"np0000069420\", \"overcloud-novacompute-1\": \"np0000069421\", \"overcloud-novacompute-2\": \"np0000069422\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000069417-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069418-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069419-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069420-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069421-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000069422-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000069417\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069418\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069419\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069420\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069421\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000069422\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.164\", \"ip_address_uri\": \"172.21.0.164\", \"ip_subnet\": \"172.21.0.164/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.242\", \"ip_address_uri\": \"172.17.0.242\", \"ip_subnet\": \"172.17.0.242/24\"}, \"storage\": {\"ip_address\": \"172.18.0.250\", \"ip_address_uri\": \"172.18.0.250\", \"ip_subnet\": \"172.18.0.250/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.248\", \"ip_address_uri\": \"172.20.0.248\", \"ip_subnet\": \"172.20.0.248/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"U723oHmIgjQCMvwRlNhiXicOo\", \"AdminToken\": \"D80PzqdO8TvKo1qS4aEG0FonN\", \"CeilometerMeteringSecret\": \"EN0BRljM39cmljy9d0IOJQNAu\", \"CeilometerPassword\": \"S7StMMDKvgk7UEFIb9ggBAhnr\", \"CephClientKey\": \"AQAtGSlqAAAAABAAQDhrarjr1gn5xKzqOWm9Ig==\", \"CephClusterFSID\": \"0ef465c4-bfda-42ef-bf2c-05e267a0e48e\", \"CinderPassword\": \"V7WgDxaLxT5M80e5C9n2UCcFO\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwift